@@ -18,10 +18,10 @@
 
 package org.apache.phoenix.end2end;
 
-import org.apache.hadoop.hbase.client.HTableInterface;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
+import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.exception.SQLExceptionCode;
 import org.apache.phoenix.jdbc.PhoenixConnection;
@@ -64,15 +64,15 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
     public ExpectedException exception = ExpectedException.none();
     private static Connection conn;
     private Properties prop;
-    private boolean isViewScenario, mutable;
+    private boolean isViewIndex, mutable;
     private String phoenixObjectName;
     private String indexNames;
     private final String tableDDLOptions;
     String fullIndexNameOne, fullIndexNameTwo, fullTableName;
 
 
-    public AlterAddCascadeIndexIT(boolean isViewScenario, boolean mutable) {
-        this.isViewScenario = isViewScenario;
+    public AlterAddCascadeIndexIT(boolean isViewIndex, boolean mutable) {
+        this.isViewIndex = isViewIndex;
         StringBuilder optionBuilder = new StringBuilder("COLUMN_ENCODED_BYTES=0");
         if (!mutable) {
 
@@ -110,7 +110,7 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
                 "      population BIGINT,\n" +
                 "      CONSTRAINT my_pk PRIMARY KEY (state, city)) " + tableDDLOptions);
 
-        if(isViewScenario) {
+        if(isViewIndex) {
             conn.createStatement().execute("CREATE VIEW IF NOT EXISTS " + fullViewName +
                     " (city_area INTEGER, avg_fam_size INTEGER) AS " +
                     "SELECT * FROM "+fullTableName+" WHERE state = 'CA'");
@@ -136,10 +136,10 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
     // Test with ALTER TABLE/VIEW CASCADE INDEX ALL with upserting into new column
     @Test
     public void testAlterDBOAddCascadeIndexAllUpsert() throws Exception {
-        String query = "ALTER " +(isViewScenario ? "VIEW " : "TABLE ") + phoenixObjectName + " ADD new_column_3 VARCHAR(64) CASCADE INDEX ALL";
+        String query = "ALTER " +(isViewIndex? "VIEW " : "TABLE ") + phoenixObjectName + " ADD new_column_3 VARCHAR(64) CASCADE INDEX ALL";
         conn.createStatement().execute(query);
         PreparedStatement ps;
-        if(isViewScenario) {
+        if(isViewIndex) {
             ps = conn.prepareStatement("UPSERT INTO " + phoenixObjectName +
                     "(state,city,population,city_area,avg_fam_size,new_column_3) " +
                     "VALUES('CA','Santa Barbara',912332,1300,4,'test_column')");
@@ -151,7 +151,7 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
         ps.executeUpdate();
         ColumnInfo [] columnArray =  {new ColumnInfo("new_column_3", PVarchar.INSTANCE.getSqlType(), 64)};
         ColumnInfo [] columnIndexArray =  {new ColumnInfo("0:new_column_3", PVarchar.INSTANCE.getSqlType(), 64)};
-        if(isViewScenario) {
+        if(isViewIndex) {
             assertDBODefinition(conn, phoenixObjectName, PTableType.VIEW, 6, columnArray, false);
             assertDBODefinition(conn, fullIndexNameOne, PTableType.INDEX, 5, columnIndexArray, false);
             assertDBODefinition(conn, fullIndexNameTwo, PTableType.INDEX, 5, columnIndexArray, false);
@@ -172,51 +172,16 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
 
     }
 
-    // Test with ALTER TABLE/VIEW CASCADE INDEX ALL with no indexes
-    @Test
-    public void testAlterDBOAddCascadeIndexAll_noIndexes() throws Exception {
-        String schemaName = "S_"+generateUniqueName();
-        String tableName = "T_"+generateUniqueName();
-        String viewName = "V_"+generateUniqueName();
-
-        String fullViewName = SchemaUtil.getQualifiedTableName(schemaName, viewName);
-        String fullTableName = SchemaUtil.getQualifiedTableName(schemaName, tableName);
-
-        conn.createStatement().execute("CREATE TABLE IF NOT EXISTS " + fullTableName + " (\n" +
-                "      state CHAR(2) NOT NULL,\n" +
-                "      city VARCHAR NOT NULL,\n" +
-                "      population BIGINT,\n" +
-                "      CONSTRAINT my_pk PRIMARY KEY (state, city)) " + tableDDLOptions);
-
-        if(isViewScenario) {
-            conn.createStatement().execute("CREATE VIEW IF NOT EXISTS " + fullViewName
-                    + " (city_area INTEGER, avg_fam_size INTEGER) AS " + "SELECT * FROM "
-                    + fullTableName + " WHERE state = 'CA'");
-        }
-
-        String query = "ALTER " +(isViewScenario ? "VIEW " : "TABLE ") + (isViewScenario ? fullViewName : fullTableName)
-                + " ADD new_column_3 VARCHAR(64) CASCADE INDEX ALL";
-        conn.createStatement().execute(query);
-
-        ColumnInfo [] columnArray =  {new ColumnInfo("new_column_3", PVarchar.INSTANCE.getSqlType(), 64)};
-        if(isViewScenario) {
-            assertDBODefinition(conn, fullViewName, PTableType.VIEW, 6, columnArray, false);
-        } else {
-            assertDBODefinition(conn, fullTableName, PTableType.TABLE, 4, columnArray, false);
-        }
-
-    }
-
     // Test with CASCADE INDEX <index_name>
     @Test
     public void testAlterDBOAddCascadeIndex() throws Exception {
         ColumnInfo [] columnArray =  {new ColumnInfo("new_column_1", PFloat.INSTANCE.getSqlType())};
         ColumnInfo [] columnIndexArray =  {new ColumnInfo("0:new_column_1", PDecimal.INSTANCE.getSqlType())};
 
-        String query = "ALTER " + (isViewScenario ? "VIEW " : "TABLE ")
+        String query = "ALTER " + (isViewIndex? "VIEW " : "TABLE ")
                 + phoenixObjectName + " ADD new_column_1 FLOAT CASCADE INDEX " + indexNames.split(",")[0];
         conn.createStatement().execute(query);
-        if(isViewScenario) {
+        if(isViewIndex) {
             assertDBODefinition(conn, phoenixObjectName, PTableType.VIEW, 6, columnArray, false);
             assertDBODefinition(conn, fullIndexNameOne, PTableType.INDEX, 5, columnIndexArray, false);
             assertDBODefinition(conn, fullIndexNameTwo, PTableType.INDEX, 4, columnIndexArray, true);
@@ -234,10 +199,10 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
                 new ColumnInfo("new_column_2", PDouble.INSTANCE.getSqlType())};
         ColumnInfo [] columnIndexArray =  {new ColumnInfo("0:new_column_1", PDecimal.INSTANCE.getSqlType()),
                 new ColumnInfo("0:new_column_2", PDecimal.INSTANCE.getSqlType())};
-        String query = "ALTER " + (isViewScenario ? "VIEW " : "TABLE ") + phoenixObjectName
+        String query = "ALTER " + (isViewIndex ? "VIEW " : "TABLE ") + phoenixObjectName
                 + " ADD new_column_1 FLOAT, new_column_2 DOUBLE CASCADE INDEX " + indexNames.split(",")[0];
         conn.createStatement().execute(query);
-        if(isViewScenario) {
+        if(isViewIndex) {
             assertDBODefinition(conn, phoenixObjectName, PTableType.VIEW, 7, columnArray, false);
             assertDBODefinition(conn, fullIndexNameOne, PTableType.INDEX, 6, columnIndexArray, false);
             assertDBODefinition(conn, fullIndexNameTwo, PTableType.INDEX, 4, columnIndexArray, true);
@@ -254,10 +219,10 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
     public void testAlterDBOAddCascadeIndexes() throws Exception {
         ColumnInfo [] columnArray = {new ColumnInfo("new_column_1", PDouble.INSTANCE.getSqlType())};
         ColumnInfo [] columnIndexArray = {new ColumnInfo("0:new_column_1", PDecimal.INSTANCE.getSqlType())};
-        String query = "ALTER " + (isViewScenario ? "VIEW " : "TABLE ")
+        String query = "ALTER " + (isViewIndex ? "VIEW " : "TABLE ")
                 + phoenixObjectName + " ADD new_column_1 DOUBLE CASCADE INDEX " + indexNames;
         conn.createStatement().execute(query);
-        if(isViewScenario) {
+        if(isViewIndex) {
             assertDBODefinition(conn, phoenixObjectName, PTableType.VIEW, 6, columnArray, false);
             assertDBODefinition(conn, fullIndexNameOne, PTableType.INDEX, 5, columnIndexArray, false);
             assertDBODefinition(conn, fullIndexNameTwo, PTableType.INDEX, 5, columnIndexArray, false);
@@ -276,10 +241,10 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
         ColumnInfo [] columIndexArray =  {new ColumnInfo("0:new_column_1", PDecimal.INSTANCE.getSqlType()),
                 new ColumnInfo("0:new_column_2", PDecimal.INSTANCE.getSqlType())};
 
-        String query = "ALTER " + (isViewScenario ? "VIEW " : "TABLE ")
+        String query = "ALTER " + (isViewIndex ? "VIEW " : "TABLE ")
                 + phoenixObjectName + " ADD new_column_1 FLOAT, new_column_2 DOUBLE CASCADE INDEX " + indexNames;
         conn.createStatement().execute(query);
-        if(isViewScenario) {
+        if(isViewIndex) {
             assertDBODefinition(conn, phoenixObjectName, PTableType.VIEW, 7, columnArray, false);
             assertDBODefinition(conn, fullIndexNameOne, PTableType.INDEX, 6, columIndexArray, false);
             assertDBODefinition(conn, fullIndexNameTwo, PTableType.INDEX, 6, columIndexArray, false);
@@ -295,14 +260,14 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
     @Test
     public void testAlterDBOException() throws SQLException {
 
-        String query = "ALTER " + (isViewScenario ? "VIEW " : "TABLE ") + phoenixObjectName + " ADD new_column VARCHAR ALL";
+        String query = "ALTER " + (isViewIndex ? "VIEW " : "TABLE ") + phoenixObjectName + " ADD new_column VARCHAR ALL";
         try {
             conn.createStatement().execute(query);
         } catch (Exception e) {
             assertTrue(e.getMessage().contains(SYNTAX_ERROR));
         }
 
-        query = "ALTER " + (isViewScenario ? "VIEW " : "TABLE ") + phoenixObjectName
+        query = "ALTER " + (isViewIndex ? "VIEW " : "TABLE ") + phoenixObjectName
                 + " ADD new_column VARCHAR CASCADE " + indexNames.split(",")[0];
         try {
             conn.createStatement().execute(query);
@@ -310,7 +275,7 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
             assertTrue(e.getMessage().contains(SYNTAX_ERROR));
         }
 
-        query = "ALTER " + (isViewScenario ? "VIEW " : "TABLE ") + phoenixObjectName
+        query = "ALTER " + (isViewIndex ? "VIEW " : "TABLE ") + phoenixObjectName
                 + " ADD new_column VARCHAR INDEX " + indexNames.split(",")[0];
         try {
             conn.createStatement().execute(query);
@@ -318,7 +283,7 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
             assertTrue(e.getMessage().contains(SYNTAX_ERROR));
         }
 
-        query = "ALTER " + (isViewScenario ? "VIEW " : "TABLE ")
+        query = "ALTER " + (isViewIndex ? "VIEW " : "TABLE ")
                 + phoenixObjectName + " ADD new_column_1 DOUBLE CASCADE INDEX INCORRECT_NAME";
         try {
             conn.createStatement().execute(query);
@@ -329,13 +294,13 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
         String localIndex = generateUniqueName();
         String createLocalIndex = "CREATE LOCAL INDEX " + localIndex + " ON "
                 + phoenixObjectName + "(avg_fam_size) INCLUDE (population)";
-        if(!isViewScenario) {
+        if(!isViewIndex) {
             createLocalIndex = "CREATE LOCAL INDEX " + localIndex + " ON "
                     + phoenixObjectName + "(state, population)";
 
         }
         conn.createStatement().execute(createLocalIndex);
-        query = "ALTER " + (isViewScenario ? "VIEW " : "TABLE ")
+        query = "ALTER " + (isViewIndex ? "VIEW " : "TABLE ")
                 + phoenixObjectName + " ADD new_column_1 DOUBLE CASCADE INDEX "+localIndex;
         try {
             conn.createStatement().execute(query);
@@ -344,7 +309,7 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
                     .NOT_SUPPORTED_CASCADE_FEATURE_LOCAL_INDEX.getMessage()));
         }
 
-        query = "ALTER " + (isViewScenario ? "VIEW " : "TABLE ")
+        query = "ALTER " + (isViewIndex ? "VIEW " : "TABLE ")
                 + phoenixObjectName + " ADD new_column_2 DOUBLE CASCADE INDEX "+localIndex + "," + indexNames;
         try {
             conn.createStatement().execute(query);
@@ -358,7 +323,7 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
     // Exception for incorrect index name
     @Test
     public void testAlterDBOIncorrectIndexNameCombination() throws Exception {
-        String query = "ALTER " + (isViewScenario ? "VIEW " : "TABLE ")
+        String query = "ALTER " + (isViewIndex ? "VIEW " : "TABLE ")
                 + phoenixObjectName + " ADD new_column_1 DOUBLE CASCADE INDEX INCORRECT_NAME, "+ indexNames;
         try {
             conn.createStatement().execute(query);
@@ -367,7 +332,7 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
         }
         ColumnInfo [] columnArray =  {new ColumnInfo("new_column_1", PFloat.INSTANCE.getSqlType())};
         ColumnInfo [] columnIndexArray =  {new ColumnInfo("0:new_column_1", PDecimal.INSTANCE.getSqlType())};
-        if(isViewScenario) {
+        if(isViewIndex) {
             assertDBODefinition(conn, phoenixObjectName, PTableType.VIEW, 5, columnArray, true);
             assertDBODefinition(conn, fullIndexNameOne, PTableType.INDEX, 4, columnIndexArray, true);
             assertDBODefinition(conn, fullIndexNameTwo, PTableType.INDEX, 4, columnIndexArray, true);
@@ -416,7 +381,7 @@ public class AlterAddCascadeIndexIT extends ParallelStatsDisabledIT {
     public void assertNumberOfHBaseCells(String tableName, int expected) {
         try {
             ConnectionQueryServices cqs = conn.unwrap(PhoenixConnection.class).getQueryServices();
-            HTableInterface table = cqs.getTable(Bytes.toBytes(tableName));
+            Table table = cqs.getTable(Bytes.toBytes(tableName));
 
             Scan scan = new Scan();
             scan.setRaw(true);
