@@ -38,7 +38,7 @@ import java.util.Collection;
 import java.util.List;
 import java.util.Properties;
 
-import org.apache.commons.lang.ArrayUtils;
+import org.apache.commons.lang3.ArrayUtils;
 import org.apache.hadoop.hbase.client.HTable;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
@@ -72,8 +72,8 @@ import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.junit.runners.Parameterized.Parameters;
 
-import com.google.common.base.Function;
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.base.Function;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 @RunWith(Parameterized.class)
 public class AlterTableWithViewsIT extends SplitSystemCatalogIT {
@@ -774,7 +774,7 @@ public class AlterTableWithViewsIT extends SplitSystemCatalogIT {
             delta += salted ? 1 : 0;
         String[] cols;
         if (isMultiTenant && tableType!=PTableType.VIEW) {
-            cols = (String[])ArrayUtils.addAll(new String[]{"TENANT_ID"}, columnNames);
+            cols = ArrayUtils.addAll(new String[]{"TENANT_ID"}, columnNames);
         }
         else {
             cols = columnNames;
