@@ -19,10 +19,10 @@ package org.apache.phoenix.end2end;
 
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.ADD_DATA;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.ADD_DELETE;
+import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.ADD_VIEW_INDEX;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.CREATE_ADD;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.CREATE_DIVERGED_VIEW;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.INDEX_REBUILD_ASYNC;
-import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.ADD_VIEW_INDEX;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.QUERY_ADD_DATA;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.QUERY_ADD_DELETE;
 import static org.apache.phoenix.end2end.BackwardCompatibilityTestUtil.QUERY_CREATE_ADD;
@@ -41,7 +41,9 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
+import java.io.IOException;
 import java.sql.Connection;
 import java.sql.DriverManager;
 import java.util.Collection;
@@ -51,8 +53,10 @@ import org.apache.hadoop.hbase.HBaseTestingUtility;
 import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
-import org.apache.phoenix.coprocessor.TaskMetaDataEndpoint;
+import org.apache.hadoop.hbase.client.TableDescriptor;
+import org.apache.phoenix.compat.hbase.CompatUtil;
 import org.apache.phoenix.coprocessor.SystemCatalogRegionObserver;
+import org.apache.phoenix.coprocessor.TaskMetaDataEndpoint;
 import org.apache.phoenix.jdbc.PhoenixDatabaseMetaData;
 import org.apache.phoenix.jdbc.PhoenixDriver;
 import org.apache.phoenix.query.QueryServices;
@@ -66,6 +70,8 @@ import org.junit.experimental.categories.Category;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.junit.runners.Parameterized.Parameters;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * This class is meant for testing all compatible client versions 
@@ -77,11 +83,15 @@ import org.junit.runners.Parameterized.Parameters;
 @Category(NeedsOwnMiniClusterTest.class)
 public class BackwardCompatibilityIT {
 
+    private static final Logger LOGGER = LoggerFactory.getLogger(
+        BackwardCompatibilityIT.class);
+
     private final String compatibleClientVersion;
     private static Configuration conf;
     private static HBaseTestingUtility hbaseTestUtil;
     private static String zkQuorum;
     private static String url;
+    private String tmpDir;
 
     public BackwardCompatibilityIT(String compatibleClientVersion) {
         this.compatibleClientVersion = compatibleClientVersion;
@@ -94,6 +104,7 @@ public class BackwardCompatibilityIT {
 
     @Before
     public synchronized void doSetup() throws Exception {
+        tmpDir = System.getProperty("java.io.tmpdir");
         conf = HBaseConfiguration.create();
         hbaseTestUtil = new HBaseTestingUtility(conf);
         setUpConfigForMiniCluster(conf);
@@ -107,11 +118,15 @@ public class BackwardCompatibilityIT {
     
     @After
     public void cleanUpAfterTest() throws Exception {
+        boolean refCountLeaked = CompatUtil.isAnyStoreRefCountLeaked(
+            hbaseTestUtil.getAdmin());
         try {
             DriverManager.deregisterDriver(PhoenixDriver.INSTANCE);
         } finally {
             hbaseTestUtil.shutdownMiniCluster();
         }
+        System.setProperty("java.io.tmpdir", tmpDir);
+        assertFalse("refCount leaked", refCountLeaked);
     }
 
     /**
@@ -134,7 +149,7 @@ public class BackwardCompatibilityIT {
     public void testCreateDivergedViewWithOldClientReadFromNewClient() throws Exception {
         // Create a base table, view and make it diverge from an old client
         executeQueryWithClientVersion(compatibleClientVersion, CREATE_DIVERGED_VIEW, zkQuorum);
-        executeQueriesWithCurrentVersion(QUERY_CREATE_DIVERGED_VIEW,url, NONE);
+        executeQueriesWithCurrentVersion(QUERY_CREATE_DIVERGED_VIEW, url, NONE);
         assertExpectedOutput(QUERY_CREATE_DIVERGED_VIEW);
     }
 
@@ -308,8 +323,8 @@ public class BackwardCompatibilityIT {
         assertExpectedOutput(QUERY_CREATE_ADD);
 
         // Deletes with the new client
-        executeQueriesWithCurrentVersion(ADD_DELETE, url, NONE);
-        executeQueriesWithCurrentVersion(QUERY_ADD_DELETE, url,NONE);
+        executeQueriesWithCurrentVersion(ADD_DELETE,url, NONE);
+        executeQueriesWithCurrentVersion(QUERY_ADD_DELETE, url, NONE);
         assertExpectedOutput(QUERY_ADD_DELETE);
     }
 
@@ -330,7 +345,7 @@ public class BackwardCompatibilityIT {
         if (majorVersion == 4 && minorVersion == 15) {
             conn = hbaseTestUtil.getConnection();
             admin = conn.getAdmin();
-            HTableDescriptor tableDescriptor = admin.getTableDescriptor(
+            TableDescriptor tableDescriptor = admin.getDescriptor(
                 TableName.valueOf(PhoenixDatabaseMetaData.SYSTEM_TASK_NAME));
             assertNull("split policy should be null with compatible client version: "
                 + compatibleClientVersion, tableDescriptor.getRegionSplitPolicyClassName());
@@ -348,7 +363,7 @@ public class BackwardCompatibilityIT {
         }
         // connect with client > 4.15, and we have new split policy and new
         // coprocessor loaded
-        HTableDescriptor tableDescriptor = admin.getTableDescriptor(
+        TableDescriptor tableDescriptor = admin.getDescriptor(
             TableName.valueOf(PhoenixDatabaseMetaData.SYSTEM_TASK_NAME));
         assertEquals("split policy not updated with compatible client version: "
             + compatibleClientVersion,
