@@ -17,6 +17,7 @@
  */
 package org.apache.phoenix.end2end;
 
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
 import org.apache.hadoop.hbase.HBaseIOException;
 import org.apache.hadoop.hbase.TableName;
@@ -28,16 +29,20 @@ import org.apache.hadoop.hbase.coprocessor.SimpleRegionObserver;
 import org.apache.hadoop.hbase.regionserver.MiniBatchOperationInProgress;
 import org.apache.hadoop.hbase.util.Bytes;
 
+import org.apache.phoenix.compat.hbase.coprocessor.CompatBaseScannerRegionObserver;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.mapreduce.index.IndexTool;
+import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.util.*;
+import org.junit.BeforeClass;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 import org.junit.runner.RunWith;
 
 import java.io.IOException;
 import java.sql.*;
+import java.util.Map;
 import java.util.Properties;
 import java.util.Random;
 import java.util.concurrent.CountDownLatch;
@@ -65,14 +70,24 @@ public class ConcurrentMutationsExtendedIT extends ParallelStatsDisabledIT {
     private static final String MVCC_LOCK_TEST_TABLE_PREFIX = "MVCCLOCKTEST_";
     private static final String LOCK_TEST_TABLE_PREFIX = "LOCKTEST_";
     private static final int ROW_LOCK_WAIT_TIME = 10000;
-
+    private static final int MAX_LOOKBACK_AGE = 1000000;
     private final Object lock = new Object();
 
+    @BeforeClass
+    public static synchronized void doSetup() throws Exception {
+        Map<String, String> props = Maps.newHashMapWithExpectedSize(1);
+        props.put(QueryServices.GLOBAL_INDEX_ROW_AGE_THRESHOLD_TO_DELETE_MS_ATTRIB, Long.toString(0));
+        props.put(CompatBaseScannerRegionObserver.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY,
+            Integer.toString(MAX_LOOKBACK_AGE));
+        setUpTestDriver(new ReadOnlyProps(props.entrySet().iterator()));
+    }
+
     static long verifyIndexTable(String tableName, String indexName,
             Connection conn) throws Exception {
         // This checks the state of every raw index row without rebuilding any row
         IndexTool indexTool = IndexToolIT.runIndexTool(true, false, "", tableName,
                 indexName, null, 0, IndexTool.IndexVerifyType.ONLY);
+        System.out.println(indexTool.getJob().getCounters());
         assertEquals(0, indexTool.getJob().getCounters().findCounter(REBUILT_INDEX_ROW_COUNT).getValue());
         assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_INVALID_INDEX_ROW_COUNT).getValue());
         assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_MISSING_INDEX_ROW_COUNT).getValue());
@@ -80,11 +95,14 @@ public class ConcurrentMutationsExtendedIT extends ParallelStatsDisabledIT {
         assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_BEYOND_MAXLOOKBACK_INVALID_INDEX_ROW_COUNT).getValue());
         assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_OLD_INDEX_ROW_COUNT).getValue());
         assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_UNKNOWN_INDEX_ROW_COUNT).getValue());
+
         // This checks the state of an index row after it is repaired
         long actualRowCount = IndexScrutiny.scrutinizeIndex(conn, tableName, indexName);
         // We want to check the index rows again as they may be modified by the read repair
         indexTool = IndexToolIT.runIndexTool(true, false, "", tableName, indexName,
                 null, 0, IndexTool.IndexVerifyType.ONLY);
+        System.out.println(indexTool.getJob().getCounters());
+
         assertEquals(0, indexTool.getJob().getCounters().findCounter(REBUILT_INDEX_ROW_COUNT).getValue());
         assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_INVALID_INDEX_ROW_COUNT).getValue());
         assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_MISSING_INDEX_ROW_COUNT).getValue());
@@ -141,15 +159,10 @@ public class ConcurrentMutationsExtendedIT extends ParallelStatsDisabledIT {
                     for (int i = 0; i < 50; i++) {
                         Thread.sleep(20);
                         synchronized (lock) {
-                            PhoenixConnection conn = null;
-                            try {
-                                conn =
-                                        DriverManager.getConnection(getUrl(), props)
-                                                .unwrap(PhoenixConnection.class);
+                            try (PhoenixConnection conn = DriverManager.getConnection(getUrl(), props)
+                                .unwrap(PhoenixConnection.class)) {
                                 conn.setAutoCommit(true);
                                 conn.createStatement().execute("DELETE FROM " + tableName);
-                            } finally {
-                                if (conn != null) conn.close();
                             }
                         }
                     }
@@ -172,19 +185,14 @@ public class ConcurrentMutationsExtendedIT extends ParallelStatsDisabledIT {
                     int nRowsToUpsert = 1000;
                     for (int i = 0; i < nRowsToUpsert; i++) {
                         synchronized (lock) {
-                            PhoenixConnection conn = null;
-                            try {
-                                conn =
-                                        DriverManager.getConnection(getUrl(), props)
-                                                .unwrap(PhoenixConnection.class);
+                            try (PhoenixConnection conn = DriverManager.getConnection(getUrl(), props)
+                                .unwrap(PhoenixConnection.class)) {
                                 conn.createStatement().execute(
-                                        "UPSERT INTO " + tableName + " VALUES (" + (i % 10)
-                                                + ", 0, 1)");
+                                    "UPSERT INTO " + tableName + " VALUES (" + (i % 10)
+                                        + ", 0, 1)");
                                 if ((i % 20) == 0 || i == nRowsToUpsert - 1) {
                                     conn.commit();
                                 }
-                            } finally {
-                                if (conn != null) conn.close();
                             }
                         }
                     }
@@ -281,7 +289,6 @@ public class ConcurrentMutationsExtendedIT extends ParallelStatsDisabledIT {
         conn.createStatement().execute("CREATE TABLE " + tableName
                 + "(k1 INTEGER NOT NULL, k2 INTEGER NOT NULL, a.v1 INTEGER, b.v2 INTEGER, c.v3 INTEGER, d.v4 INTEGER," +
                 "CONSTRAINT pk PRIMARY KEY (k1,k2))  COLUMN_ENCODED_BYTES = 0, VERSIONS=1");
-        TestUtil.addCoprocessor(conn, tableName, DelayingRegionObserver.class);
         conn.createStatement().execute("CREATE INDEX " + indexName + " ON " + tableName + "(v1) INCLUDE(v2, v3)");
         final CountDownLatch doneSignal = new CountDownLatch(nThreads);
         Runnable[] runnables = new Runnable[nThreads];
