@@ -60,7 +60,7 @@ import org.apache.phoenix.util.TestUtil;
 import org.junit.Ignore;
 import org.junit.Test;
 
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -114,7 +114,7 @@ public class EmptyColumnIT extends ParallelStatsDisabledIT {
                     while (cellScanner.advance()) {
                         Cell current = cellScanner.current();
                         // if current.timestamp > emptyColumnCell.timestamp then it returns -1
-                        if (CellComparator.compareTimestamps(current, emptyColumnCell) < 0) {
+                        if (CellComparator.getInstance().compareTimestamps(current, emptyColumnCell) < 0) {
                             emptyColumnHasMaxTimestamp &= false;
                         }
                     }
