@@ -35,8 +35,8 @@ import java.util.Map;
 import java.util.Properties;
 
 import org.apache.hadoop.hbase.client.Table;
-import org.apache.hadoop.hbase.regionserver.ScanInfoUtil;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.phoenix.compat.hbase.coprocessor.CompatBaseScannerRegionObserver;
 import org.apache.phoenix.compile.ExplainPlan;
 import org.apache.phoenix.compile.ExplainPlanAttributes;
 import org.apache.phoenix.coprocessor.IndexRebuildRegionScanner;
@@ -57,10 +57,8 @@ import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.junit.runners.Parameterized.Parameters;
 
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 
 /**
  * Tests for the {@link IndexTool}
@@ -102,7 +100,7 @@ public class IndexExtendedIT extends BaseTest {
     public static synchronized void doSetup() throws Exception {
         Map<String, String> serverProps = Maps.newHashMapWithExpectedSize(2);
         serverProps.put(QueryServices.EXTRA_JDBC_ARGUMENTS_ATTRIB, QueryServicesOptions.DEFAULT_EXTRA_JDBC_ARGUMENTS);
-        serverProps.put(ScanInfoUtil.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY, Integer.toString(60*60)); // An hour
+        serverProps.put(CompatBaseScannerRegionObserver.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY, Integer.toString(60*60)); // An hour
         Map<String, String> clientProps = Maps.newHashMapWithExpectedSize(2);
         clientProps.put(QueryServices.TRANSACTIONS_ENABLED, Boolean.TRUE.toString());
         clientProps.put(QueryServices.FORCE_ROW_KEY_ORDER_ATTRIB, Boolean.TRUE.toString());
@@ -391,15 +389,15 @@ public class IndexExtendedIT extends BaseTest {
             // Verify that the index table is not in the ACTIVE state
             assertFalse(checkIndexState(conn, indexFullName, PIndexState.ACTIVE, 0L));
 
-            // Run the index MR job and verify that the index table rebuild fails
-            IndexToolIT.runIndexTool(true, false, schemaName, dataTableName,
-                    indexTableName, null, -1, IndexTool.IndexVerifyType.AFTER);
+            if (CompatBaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
+                // Run the index MR job and verify that the index table rebuild fails
+                IndexToolIT.runIndexTool(true, false, schemaName, dataTableName,
+                        indexTableName, null, -1, IndexTool.IndexVerifyType.AFTER);
+                // job failed, verify that the index table is still not in the ACTIVE state
+                assertFalse(checkIndexState(conn, indexFullName, PIndexState.ACTIVE, 0L));
+            }
 
             IndexRebuildRegionScanner.setIgnoreIndexRebuildForTesting(false);
-
-            // job failed, verify that the index table is still not in the ACTIVE state
-            assertFalse(checkIndexState(conn, indexFullName, PIndexState.ACTIVE, 0L));
-
             // Run the index MR job and verify that the index table rebuild succeeds
             IndexToolIT.runIndexTool(true, false, schemaName, dataTableName,
                     indexTableName, null, 0, IndexTool.IndexVerifyType.AFTER);
