@@ -17,22 +17,21 @@
  */
 package org.apache.phoenix.end2end;
 
-import com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.Admin;
 import org.apache.hadoop.hbase.client.Delete;
-import org.apache.hadoop.hbase.client.HBaseAdmin;
-import org.apache.hadoop.hbase.client.HConnection;
-import org.apache.hadoop.hbase.client.HTableInterface;
 import org.apache.hadoop.hbase.client.Put;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.Table;
-import org.apache.hadoop.hbase.regionserver.ScanInfoUtil;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.mapreduce.CounterGroup;
+import org.apache.phoenix.compat.hbase.HbaseCompatCapabilities;
+import org.apache.phoenix.compat.hbase.coprocessor.CompatBaseScannerRegionObserver;
 import org.apache.phoenix.coprocessor.IndexRepairRegionScanner;
 import org.apache.phoenix.hbase.index.IndexRegionObserver;
 import org.apache.phoenix.index.IndexMaintainer;
@@ -87,10 +86,11 @@ import static org.apache.phoenix.mapreduce.index.PhoenixIndexToolJobCounters.SCA
 import static org.apache.phoenix.util.TestUtil.TEST_PROPERTIES;
 import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
+import static org.junit.Assume.assumeTrue;
 
 @Category(NeedsOwnMiniClusterTest.class)
 @RunWith(Parameterized.class)
@@ -134,7 +134,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
     public static synchronized void doSetup() throws Exception {
         // below settings are needed to enforce major compaction
         Map<String, String> props = Maps.newHashMapWithExpectedSize(2);
-        props.put(ScanInfoUtil.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY, Integer.toString(0));
+        props.put(CompatBaseScannerRegionObserver.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY, Integer.toString(0));
         props.put(QueryServices.GLOBAL_INDEX_ROW_AGE_THRESHOLD_TO_DELETE_MS_ATTRIB, Long.toString(0));
         setUpTestDriver(new ReadOnlyProps(props.entrySet().iterator()));
     }
@@ -659,6 +659,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
 
     @Test
     public void testFromIndexToolForIncrementalVerify() throws Exception {
+        assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         final int NROWS = 4;
         ManualEnvironmentEdge customEdge = new ManualEnvironmentEdge();
         String schemaName = generateUniqueName();
@@ -670,8 +671,6 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
         Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
         try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
             long t0 = EnvironmentEdgeManager.currentTimeMillis();
-            customEdge.setValue(t0);
-            EnvironmentEdgeManager.injectEdge(customEdge);
 
             conn.createStatement().execute("CREATE TABLE " + dataTableFullName
                 + " (ID INTEGER NOT NULL PRIMARY KEY, VAL1 INTEGER, VAL2 INTEGER) " + tableDDLOptions);
@@ -688,6 +687,8 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
             conn.createStatement().execute(String.format(
                 "CREATE INDEX %s ON %s (VAL1) INCLUDE (VAL2)", indexTableName, dataTableFullName));
 
+            customEdge.setValue(EnvironmentEdgeManager.currentTimeMillis());
+            EnvironmentEdgeManager.injectEdge(customEdge);
             customEdge.incrementValue(delta);
             long t1 = customEdge.currentTime();
 
@@ -819,12 +820,12 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
     }
 
     public void deleteAllRows(Connection conn, TableName tableName) throws SQLException,
-        IOException, InterruptedException {
+            IOException, InterruptedException {
         Scan scan = new Scan();
-        HBaseAdmin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().
-            getAdmin();
-        HConnection hbaseConn = admin.getConnection();
-        HTableInterface table = hbaseConn.getTable(tableName);
+        Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().
+                getAdmin();
+        org.apache.hadoop.hbase.client.Connection hbaseConn = admin.getConnection();
+        Table table = hbaseConn.getTable(tableName);
         boolean deletedRows = false;
         try (ResultScanner scanner = table.getScanner(scan)) {
             for (Result r : scanner) {
@@ -838,7 +839,7 @@ public class IndexRepairRegionScannerIT extends ParallelStatsDisabledIT {
         }
         //don't flush/compact if we didn't write anything, because we'll hang forever
         if (deletedRows) {
-            getUtility().getHBaseAdmin().flush(tableName);
+            getUtility().getAdmin().flush(tableName);
             TestUtil.majorCompact(getUtility(), tableName);
         }
     }
