@@ -17,33 +17,34 @@
  */
 package org.apache.phoenix.end2end;
 
-import com.google.common.collect.Maps;
-
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
+import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
-import org.apache.hadoop.hbase.HColumnDescriptor;
-import org.apache.hadoop.hbase.HTableDescriptor;
-import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
 import org.apache.hadoop.hbase.client.ConnectionFactory;
+import org.apache.hadoop.hbase.client.CoprocessorDescriptor;
+import org.apache.hadoop.hbase.client.CoprocessorDescriptorBuilder;
 import org.apache.hadoop.hbase.client.Delete;
-import org.apache.hadoop.hbase.client.HBaseAdmin;
-import org.apache.hadoop.hbase.client.HConnection;
-import org.apache.hadoop.hbase.client.HTableInterface;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.Table;
+import org.apache.hadoop.hbase.client.TableDescriptor;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.coprocessor.BaseRegionObserver;
 import org.apache.hadoop.hbase.coprocessor.ObserverContext;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
 import org.apache.hadoop.hbase.regionserver.RegionScanner;
-import org.apache.hadoop.hbase.regionserver.ScanInfoUtil;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.Pair;
 import org.apache.hadoop.mapreduce.Counters;
+import org.apache.phoenix.compat.hbase.HbaseCompatCapabilities;
+import org.apache.phoenix.compat.hbase.coprocessor.CompatBaseScannerRegionObserver;
 import org.apache.phoenix.coprocessor.IndexRebuildRegionScanner;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.mapreduce.index.IndexTool;
@@ -63,6 +64,7 @@ import org.apache.phoenix.util.SchemaUtil;
 import org.apache.phoenix.util.TestUtil;
 import org.junit.After;
 import org.junit.Assert;
+import org.junit.Assume;
 import org.junit.BeforeClass;
 import org.junit.Ignore;
 import org.junit.Rule;
@@ -114,6 +116,7 @@ import static org.apache.phoenix.util.TestUtil.TEST_PROPERTIES;
 import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 
 @RunWith(Parameterized.class)
@@ -121,11 +124,13 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
 
     public static final int MAX_LOOKBACK_AGE = 3600;
     private final String tableDDLOptions;
+
+    private final boolean directApi = true;
+    private final boolean useSnapshot = false;
+    private final boolean mutable;
     private final String indexDDLOptions;
-    private boolean directApi = true;
-    private boolean useSnapshot = false;
-    private boolean mutable;
     private boolean singleCell;
+
     @Rule
     public ExpectedException exceptionRule = ExpectedException.none();
 
@@ -162,12 +167,16 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
         serverProps.put(QueryServices.EXTRA_JDBC_ARGUMENTS_ATTRIB,
                 QueryServicesOptions.DEFAULT_EXTRA_JDBC_ARGUMENTS);
         serverProps.put(QueryServices.INDEX_REBUILD_PAGE_SIZE_IN_ROWS, Long.toString(8));
-        serverProps.put(ScanInfoUtil.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY, Long.toString(MAX_LOOKBACK_AGE));
+        serverProps.put(CompatBaseScannerRegionObserver.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY,
+            Long.toString(MAX_LOOKBACK_AGE));
         serverProps.put(QueryServices.TASK_HANDLING_INTERVAL_MS_ATTRIB,
             Long.toString(Long.MAX_VALUE));
         serverProps.put(QueryServices.TASK_HANDLING_INITIAL_DELAY_MS_ATTRIB,
             Long.toString(Long.MAX_VALUE));
         serverProps.put(QueryServices.GLOBAL_INDEX_ROW_AGE_THRESHOLD_TO_DELETE_MS_ATTRIB, Long.toString(0));
+        //In HBase 2.2.6 and HBase 2.3.0+, helps region server assignments when under an injected
+        // edge clock. See HBASE-24511.
+        serverProps.put("hbase.regionserver.rpc.retry.interval", Long.toString(0));
         Map<String, String> clientProps = Maps.newHashMapWithExpectedSize(4);
         clientProps.put(QueryServices.USE_STATS_FOR_PARALLELIZATION, Boolean.toString(true));
         clientProps.put(QueryServices.STATS_UPDATE_FREQ_MS_ATTRIB, Long.toString(5));
@@ -269,18 +278,22 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
             conn.createStatement()
                     .execute(String.format("CREATE INDEX %s ON %s (NAME) INCLUDE (CODE) ASYNC " + this.indexDDLOptions,
                             indexTableName, dataTableFullName));
-            IndexToolIT.runIndexTool(directApi, useSnapshot, schemaName, dataTableName, indexTableName, null, 0,
+            IndexTool indexTool = IndexToolIT.runIndexTool(directApi, useSnapshot, schemaName, dataTableName, indexTableName, null, 0,
                     IndexTool.IndexVerifyType.ONLY);
-            Cell cell =
-                    IndexToolIT.getErrorMessageFromIndexToolOutputTable(conn, dataTableFullName,
-                            indexTableFullName);
-            try {
-                String expectedErrorMsg = IndexRebuildRegionScanner.ERROR_MESSAGE_MISSING_INDEX_ROW;
-                String actualErrorMsg = Bytes
-                        .toString(cell.getValueArray(), cell.getValueOffset(), cell.getValueLength());
-                assertTrue(expectedErrorMsg.equals(actualErrorMsg));
-            } catch(Exception ex) {
-                Assert.fail("Fail to parsing the error message from IndexToolOutputTable");
+            if (CompatBaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
+                Cell cell =
+                        IndexToolIT.getErrorMessageFromIndexToolOutputTable(conn, dataTableFullName,
+                                indexTableFullName);
+                try {
+                    String expectedErrorMsg = IndexRebuildRegionScanner.ERROR_MESSAGE_MISSING_INDEX_ROW;
+                    String actualErrorMsg = Bytes
+                            .toString(cell.getValueArray(), cell.getValueOffset(), cell.getValueLength());
+                    assertEquals(expectedErrorMsg, actualErrorMsg);
+                } catch (Exception ex) {
+                    Assert.fail("Fail to parsing the error message from IndexToolOutputTable");
+                }
+            } else {
+                assertEquals(1, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_BEYOND_MAXLOOKBACK_MISSING_INDEX_ROW_COUNT).getValue());
             }
 
             // Run the index tool to populate the index while verifying rows
@@ -290,9 +303,11 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
             // Set ttl of index table ridiculously low so that all data is expired
             Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin();
             TableName indexTable = TableName.valueOf(indexTableFullName);
-            HColumnDescriptor desc = admin.getTableDescriptor(indexTable).getColumnFamilies()[0];
-            desc.setTimeToLive(1);
-            admin.modifyColumn(indexTable, desc);
+            ColumnFamilyDescriptor desc =
+                admin.getDescriptor(indexTable).getColumnFamilies()[0];
+            ColumnFamilyDescriptor newDesc =
+                ColumnFamilyDescriptorBuilder.newBuilder(desc).setTimeToLive(1).build();
+            admin.modifyColumnFamily(indexTable, newDesc);
             Thread.sleep(1000);
             Pair<Integer, Integer> status = admin.getAlterStatus(indexTable);
             int retry = 0;
@@ -300,7 +315,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
                 Thread.sleep(2000);
                 status = admin.getAlterStatus(indexTable);
             }
-            assertTrue(status.getFirst() == 0);
+            assertEquals(0, (int) status.getFirst());
 
             TableName indexToolOutputTable = TableName.valueOf(IndexVerificationOutputRepository.OUTPUT_TABLE_NAME_BYTES);
             admin.disableTable(indexToolOutputTable);
@@ -313,7 +328,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
                     conn.unwrap(PhoenixConnection.class).getQueryServices()
                             .getTable(indexToolOutputTable.getName());
             Result r = hIndexToolTable.getScanner(scan).next();
-            assertTrue(r == null);
+            assertNull(r);
         }
     }
 
@@ -356,11 +371,15 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
             ConnectionQueryServices queryServices = conn.unwrap(PhoenixConnection.class).getQueryServices();
             Admin admin = queryServices.getAdmin();
             TableName tn = TableName.valueOf(Bytes.toBytes(dataTableFullName));
-            HTableDescriptor td =
-                admin.getTableDescriptor(tn);
+            TableDescriptor td = admin.getDescriptor(tn);
+            CoprocessorDescriptor cd =
+                CoprocessorDescriptorBuilder.newBuilder(FastFailRegionObserver.class.getName()).
+                    setPriority(1).build();
+            TableDescriptor newTD =
+                TableDescriptorBuilder.newBuilder(td).
+                    setCoprocessor(cd).build();
             //add the fast fail coproc and make sure it goes first
-            td.addCoprocessor(FastFailRegionObserver.class.getName(), null, 1, null);
-            admin.modifyTable(tn, td);
+            admin.modifyTable(newTD);
             // Run the index MR job and it should fail (return -1)
             IndexToolIT.runIndexTool(directApi, useSnapshot, schemaName, dataTableName, indexTableName,
                     null, -1, new String[0]);
@@ -406,8 +425,13 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_VALID_INDEX_ROW_COUNT).getValue());
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_EXPIRED_INDEX_ROW_COUNT).getValue());
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_INVALID_INDEX_ROW_COUNT).getValue());
-            assertEquals(NROWS, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_MISSING_INDEX_ROW_COUNT).getValue());
-            assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_BEYOND_MAXLOOKBACK_MISSING_INDEX_ROW_COUNT).getValue());
+            if (CompatBaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
+                assertEquals(NROWS, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_MISSING_INDEX_ROW_COUNT).getValue());
+                assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_BEYOND_MAXLOOKBACK_MISSING_INDEX_ROW_COUNT).getValue());
+            } else {
+                assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_MISSING_INDEX_ROW_COUNT).getValue());
+                assertEquals(NROWS, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_BEYOND_MAXLOOKBACK_MISSING_INDEX_ROW_COUNT).getValue());
+            }
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_BEYOND_MAXLOOKBACK_INVALID_INDEX_ROW_COUNT).getValue());
             long actualRowCount = IndexScrutiny.scrutinizeIndex(conn, dataTableFullName, indexTableFullName);
             assertEquals(NROWS, actualRowCount);
@@ -574,17 +598,23 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
             IndexRebuildRegionScanner.setIgnoreIndexRebuildForTesting(true);
             conn.createStatement().execute(String.format(
                     "CREATE INDEX %s ON %s (NAME) INCLUDE (ZIP) ASYNC " + this.indexDDLOptions, indexTableName, viewFullName));
-            // Run the index MR job and verify that the index table rebuild fails
-            IndexToolIT.runIndexTool(directApi, useSnapshot, schemaName, viewName, indexTableName,
-                    null, -1, IndexTool.IndexVerifyType.AFTER);
-            // The index tool output table should report that there is a missing index row
-            Cell cell = IndexToolIT.getErrorMessageFromIndexToolOutputTable(conn, dataTableFullName, "_IDX_" + dataTableFullName);
-            try {
-                String expectedErrorMsg = IndexRebuildRegionScanner.ERROR_MESSAGE_MISSING_INDEX_ROW;
-                String actualErrorMsg = Bytes.toString(cell.getValueArray(), cell.getValueOffset(), cell.getValueLength());
-                assertTrue(expectedErrorMsg.equals(actualErrorMsg));
-            } catch(Exception ex){
-                Assert.fail("Fail to parsing the error message from IndexToolOutputTable");
+            if (CompatBaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
+                // Run the index MR job and verify that the index table rebuild fails
+                IndexToolIT.runIndexTool(directApi, useSnapshot, schemaName, viewName, indexTableName,
+                        null, -1, IndexTool.IndexVerifyType.AFTER);
+                // The index tool output table should report that there is a missing index row
+                Cell cell = IndexToolIT.getErrorMessageFromIndexToolOutputTable(conn, dataTableFullName, "_IDX_" + dataTableFullName);
+                try {
+                    String expectedErrorMsg = IndexRebuildRegionScanner.ERROR_MESSAGE_MISSING_INDEX_ROW;
+                    String actualErrorMsg = Bytes.toString(cell.getValueArray(), cell.getValueOffset(), cell.getValueLength());
+                    assertEquals(expectedErrorMsg, actualErrorMsg);
+                } catch (Exception ex) {
+                    Assert.fail("Fail to parsing the error message from IndexToolOutputTable");
+                }
+            } else {
+                IndexTool indexTool = IndexToolIT.runIndexTool(directApi, useSnapshot, schemaName, viewName, indexTableName,
+                        null, 0, IndexTool.IndexVerifyType.AFTER);
+                assertEquals(1, indexTool.getJob().getCounters().findCounter(AFTER_REBUILD_BEYOND_MAXLOOKBACK_MISSING_INDEX_ROW_COUNT).getValue());
             }
             IndexRebuildRegionScanner.setIgnoreIndexRebuildForTesting(false);
         }
@@ -611,13 +641,15 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
             // called PHOENIX_INDEX_TOOL
             IndexToolIT.runIndexTool(directApi, useSnapshot, schemaName, dataTableName, indexTableName,
                     null, 0, IndexTool.IndexVerifyType.ONLY);
-            Cell cell = IndexToolIT.getErrorMessageFromIndexToolOutputTable(conn, dataTableFullName, indexTableFullName);
-            try {
-                String expectedErrorMsg = IndexRebuildRegionScanner.ERROR_MESSAGE_MISSING_INDEX_ROW;
-                String actualErrorMsg = Bytes.toString(cell.getValueArray(), cell.getValueOffset(), cell.getValueLength());
-                assertTrue(expectedErrorMsg.equals(actualErrorMsg));
-            } catch(Exception ex) {
-                Assert.fail("Fail to parsing the error message from IndexToolOutputTable");
+            if (CompatBaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
+                Cell cell = IndexToolIT.getErrorMessageFromIndexToolOutputTable(conn, dataTableFullName, indexTableFullName);
+                try {
+                    String expectedErrorMsg = IndexRebuildRegionScanner.ERROR_MESSAGE_MISSING_INDEX_ROW;
+                    String actualErrorMsg = Bytes.toString(cell.getValueArray(), cell.getValueOffset(), cell.getValueLength());
+                    assertEquals(expectedErrorMsg, actualErrorMsg);
+                } catch (Exception ex) {
+                    Assert.fail("Fail to parsing the error message from IndexToolOutputTable");
+                }
             }
 
             // VERIFY option should not change the index state.
@@ -636,6 +668,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
 
     @Test
     public void testIndexToolForIncrementalRebuild() throws Exception {
+        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         String schemaName = generateUniqueName();
         String dataTableName = generateUniqueName();
         String dataTableFullName = SchemaUtil.getTableName(schemaName, dataTableName);
@@ -702,6 +735,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
 
     @Test
     public void testIndexToolForIncrementalVerify() throws Exception {
+        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         ManualEnvironmentEdge customEdge = new ManualEnvironmentEdge();
         String schemaName = generateUniqueName();
         String dataTableName = generateUniqueName();
@@ -831,6 +865,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
 
     @Test
     public void testIndexToolForIncrementalVerify_viewIndex() throws Exception {
+        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         ManualEnvironmentEdge customeEdge = new ManualEnvironmentEdge();
         String schemaName = generateUniqueName();
         String dataTableName = generateUniqueName();
@@ -999,8 +1034,10 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
             //now clear out all the rebuilt index rows
             truncateIndexAndIndexToolTables(indexTableFullName);
 
+            boolean MaxLookbackEnabled =
+                    CompatBaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration());
             //now check that disabling logging AFTER leaves only the BEFORE logs on a BOTH run
-            assertDisableLogging(conn, 2, IndexTool.IndexVerifyType.BOTH,
+            assertDisableLogging(conn, MaxLookbackEnabled ? 2 : 0, IndexTool.IndexVerifyType.BOTH,
                 IndexTool.IndexDisableLoggingType.AFTER,
                 IndexVerificationOutputRepository.PHASE_BEFORE_VALUE, schemaName,
                 dataTableName, indexTableName,
@@ -1030,6 +1067,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
 
     @Test
     public void testEnableOutputLoggingForMaxLookback() throws Exception {
+        Assume.assumeTrue(HbaseCompatCapabilities.isMaxLookbackTimeSupported());
         //by default we don't log invalid or missing rows past max lookback age to the
         // PHOENIX_INDEX_TOOL table. Verify that we can flip that logging on from the client-side
         // using a system property (such as from the command line) and have it log rows on the
@@ -1044,17 +1082,15 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
         String indexTableFullName = SchemaUtil.getTableName(schemaName, indexTableName);
 
         try(Connection conn = DriverManager.getConnection(getUrl())) {
-            ManualEnvironmentEdge injectEdge = new ManualEnvironmentEdge();
-            injectEdge.setValue(EnvironmentEdgeManager.currentTimeMillis());
-            EnvironmentEdgeManager.injectEdge(injectEdge);
+
             deleteAllRows(conn,
                 TableName.valueOf(IndexVerificationOutputRepository.OUTPUT_TABLE_NAME));
             String stmString1 =
                 "CREATE TABLE " + dataTableFullName
                     + " (ID INTEGER NOT NULL PRIMARY KEY, NAME VARCHAR, ZIP INTEGER) ";
             conn.createStatement().execute(stmString1);
+            conn.commit();
 
-            injectEdge.incrementValue(1L);
             String upsertQuery = String.format("UPSERT INTO %s VALUES(?, ?, ?)", dataTableFullName);
             PreparedStatement stmt1 = conn.prepareStatement(upsertQuery);
 
@@ -1062,7 +1098,6 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
             IndexToolIT.upsertRow(stmt1, 1);
             IndexToolIT.upsertRow(stmt1, 2);
             conn.commit();
-            injectEdge.incrementValue(1L); //we have to increment time to see our writes
             //now create an index async so it won't have the two rows in the base table
 
             String stmtString2 =
@@ -1071,6 +1106,10 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
                     indexTableName, dataTableFullName);
             conn.createStatement().execute(stmtString2);
             conn.commit();
+            ManualEnvironmentEdge injectEdge = new ManualEnvironmentEdge();
+            injectEdge.setValue(EnvironmentEdgeManager.currentTimeMillis());
+            EnvironmentEdgeManager.injectEdge(injectEdge);
+            injectEdge.incrementValue(1L);
             injectEdge.incrementValue(MAX_LOOKBACK_AGE * 1000);
             deleteAllRows(conn, TableName.valueOf(IndexVerificationOutputRepository.OUTPUT_TABLE_NAME));
             getUtility().getConfiguration().
@@ -1080,6 +1119,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
                 indexTableName, null, 0, IndexTool.IndexVerifyType.ONLY);
             TestUtil.dumpTable(conn, TableName.valueOf(IndexVerificationOutputRepository.OUTPUT_TABLE_NAME));
             Counters counters = it.getJob().getCounters();
+            System.out.println(counters.toString());
             assertEquals(2L,
                 counters.findCounter(BEFORE_REBUILD_BEYOND_MAXLOOKBACK_MISSING_INDEX_ROW_COUNT).getValue());
             injectEdge.incrementValue(1L);
@@ -1134,8 +1174,13 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_VALID_INDEX_ROW_COUNT).getValue());
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_EXPIRED_INDEX_ROW_COUNT).getValue());
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_INVALID_INDEX_ROW_COUNT).getValue());
-            assertEquals(NROWS, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_MISSING_INDEX_ROW_COUNT).getValue());
-            assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_BEYOND_MAXLOOKBACK_MISSING_INDEX_ROW_COUNT).getValue());
+            if (CompatBaseScannerRegionObserver.isMaxLookbackTimeEnabled(getUtility().getConfiguration())) {
+                assertEquals(NROWS, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_MISSING_INDEX_ROW_COUNT).getValue());
+                assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_BEYOND_MAXLOOKBACK_MISSING_INDEX_ROW_COUNT).getValue());
+            } else {
+                assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_MISSING_INDEX_ROW_COUNT).getValue());
+                assertEquals(NROWS, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_BEYOND_MAXLOOKBACK_MISSING_INDEX_ROW_COUNT).getValue());
+            }
             assertEquals(0, indexTool.getJob().getCounters().findCounter(BEFORE_REBUILD_BEYOND_MAXLOOKBACK_INVALID_INDEX_ROW_COUNT).getValue());
         }
     }
@@ -1188,6 +1233,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
 
     @Test
     public void testIncrementalRebuildWithPageSize() throws Exception {
+        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         String schemaName = generateUniqueName();
         String dataTableName = generateUniqueName();
         String fullDataTableName = SchemaUtil.getTableName(schemaName, dataTableName);
@@ -1243,6 +1289,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
 
     @Test
     public void testUpdatablePKFilterViewIndexRebuild() throws Exception {
+        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         if (!mutable) {
             return;
         }
@@ -1321,6 +1368,7 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
 
     @Test
     public void testUpdatableNonPkFilterViewIndexRebuild() throws Exception {
+        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         if (!mutable) {
             return;
         }
@@ -1409,10 +1457,9 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
 
             for (Result result = scanner.next(); result != null; result = scanner.next()) {
                 for (Cell cell : result.rawCells()) {
-                    if (KeyValue.Type.codeToType(cell.getTypeByte()) == KeyValue.Type.Put) {
+                    if (cell.getType().equals(Cell.Type.Put)) {
                         numPuts++;
-                    } else if (KeyValue.Type
-                            .codeToType(cell.getTypeByte()) == KeyValue.Type.DeleteFamily) {
+                    } else if (cell.getType().equals(Cell.Type.DeleteFamily)) {
                                 numDeletes++;
                             }
                 }
@@ -1424,10 +1471,10 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
     public void deleteAllRows(Connection conn, TableName tableName) throws SQLException,
         IOException, InterruptedException {
         Scan scan = new Scan();
-        HBaseAdmin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().
+        Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().
             getAdmin();
-        HConnection hbaseConn = admin.getConnection();
-        HTableInterface table = hbaseConn.getTable(tableName);
+        org.apache.hadoop.hbase.client.Connection hbaseConn = admin.getConnection();
+        Table table = hbaseConn.getTable(tableName);
         boolean deletedRows = false;
         try (ResultScanner scanner = table.getScanner(scan)) {
             for (Result r : scanner) {
@@ -1441,22 +1488,22 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
         }
         //don't flush/compact if we didn't write anything, because we'll hang forever
         if (deletedRows) {
-            getUtility().getHBaseAdmin().flush(tableName);
+            getUtility().getAdmin().flush(tableName);
             TestUtil.majorCompact(getUtility(), tableName);
         }
     }
 
     private void truncateIndexAndIndexToolTables(String indexTableFullName) throws IOException {
         truncateIndexToolTables();
-        getUtility().getHBaseAdmin().disableTable(TableName.valueOf(indexTableFullName));
-        getUtility().getHBaseAdmin().truncateTable(TableName.valueOf(indexTableFullName), true);
+        getUtility().getAdmin().disableTable(TableName.valueOf(indexTableFullName));
+        getUtility().getAdmin().truncateTable(TableName.valueOf(indexTableFullName), true);
     }
 
     private void truncateIndexToolTables() throws IOException {
-        getUtility().getHBaseAdmin().disableTable(TableName.valueOf(IndexVerificationOutputRepository.OUTPUT_TABLE_NAME));
-        getUtility().getHBaseAdmin().truncateTable(TableName.valueOf(IndexVerificationOutputRepository.OUTPUT_TABLE_NAME), true);
-        getUtility().getHBaseAdmin().disableTable(TableName.valueOf(RESULT_TABLE_NAME));
-        getUtility().getHBaseAdmin().truncateTable(TableName.valueOf(RESULT_TABLE_NAME), true);
+        getUtility().getAdmin().disableTable(TableName.valueOf(IndexVerificationOutputRepository.OUTPUT_TABLE_NAME));
+        getUtility().getAdmin().truncateTable(TableName.valueOf(IndexVerificationOutputRepository.OUTPUT_TABLE_NAME), true);
+        getUtility().getAdmin().disableTable(TableName.valueOf(RESULT_TABLE_NAME));
+        getUtility().getAdmin().truncateTable(TableName.valueOf(RESULT_TABLE_NAME), true);
     }
 
     private void assertDisableLogging(Connection conn, int expectedRows,
@@ -1509,11 +1556,11 @@ public class IndexToolForNonTxGlobalIndexIT extends BaseUniqueNamesOwnClusterIT
         ResultScanner rs = hIndexToolTable.getScanner(s);
         int count =0;
         for(Result r : rs) {
-            Assert.assertTrue(r != null);
+            assertNotNull(r);
             List<Cell> cells = r.getColumnCells(RESULT_TABLE_COLUMN_FAMILY, INDEX_TOOL_RUN_STATUS_BYTES);
             Assert.assertEquals(cells.size(), 1);
-            Assert.assertTrue(Bytes.toString(cells.get(0).getRow()).startsWith(String.valueOf(scn)));
-            output.add(Bytes.toString(cells.get(0).getValue()));
+            Assert.assertTrue(Bytes.toString(CellUtil.cloneRow(cells.get(0))).startsWith(String.valueOf(scn)));
+            output.add(Bytes.toString(CellUtil.cloneValue(cells.get(0))));
             count++;
         }
         //for each region
