@@ -17,11 +17,11 @@
  */
 package org.apache.phoenix.end2end;
 
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
 import org.apache.phoenix.compile.ExplainPlan;
 import org.apache.phoenix.compile.ExplainPlanAttributes;
 import org.apache.phoenix.jdbc.PhoenixPreparedStatement;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellUtil;
@@ -173,6 +173,10 @@ public class IndexToolIT extends BaseUniqueNamesOwnClusterIT {
         List<Object[]> list = Lists.newArrayListWithExpectedSize(48);
         boolean[] Booleans = new boolean[] { false, true };
         for (String transactionProvider : new String[] {"TEPHRA", "OMID", null}) {
+            if(transactionProvider !=null &&
+                    !TransactionFactory.Provider.valueOf(transactionProvider).runTests()) {
+                continue;
+            }
             for (boolean mutable : Booleans) {
                 for (boolean localIndex : Booleans) {
                     if (!localIndex 
@@ -591,7 +595,7 @@ public class IndexToolIT extends BaseUniqueNamesOwnClusterIT {
         TableName indexTN = TableName.valueOf(indexTableFullName);
         try (Connection conn =
                 DriverManager.getConnection(getUrl(), PropertiesUtil.deepCopy(TEST_PROPERTIES));
-                HBaseAdmin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
+                Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
             String dataDDL =
                     "CREATE TABLE " + dataTableFullName + "(\n"
                             + "ID VARCHAR NOT NULL PRIMARY KEY,\n"
@@ -724,6 +728,7 @@ public class IndexToolIT extends BaseUniqueNamesOwnClusterIT {
                     String.format(
                         "SELECT ID FROM %s WHERE LPAD(UPPER(NAME, 'en_US'),8,'x')||'_xyz' = 'xxUNAME2_xyz'",
                         qDataTableName);
+
             ResultSet rs = conn.createStatement().executeQuery("EXPLAIN " + selectSql);
             String actualExplainPlan = QueryUtil.getExplainPlan(rs);
 
@@ -963,7 +968,7 @@ public class IndexToolIT extends BaseUniqueNamesOwnClusterIT {
         conf.set(QueryServices.TRANSACTIONS_ENABLED, Boolean.TRUE.toString());
         indexingTool.setConf(conf);
         final String[] cmdArgs = getArgValues(directApi, useSnapshot, schemaName, dataTableName,
-                indexTableName, tenantId, verifyType, disableLoggingType);
+            indexTableName, tenantId, verifyType, disableLoggingType);
         List<String> cmdArgList = new ArrayList<>(Arrays.asList(cmdArgs));
         cmdArgList.addAll(Arrays.asList(additionalArgs));
         LOGGER.info("Running IndexTool with {}", Arrays.toString(cmdArgList.toArray()), new Exception("Stack Trace"));
