@@ -17,30 +17,28 @@
  */
 package org.apache.phoenix.end2end;
 
-import com.google.common.collect.Maps;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
-import org.apache.hadoop.hbase.protobuf.generated.AdminProtos;
 import org.apache.hadoop.hbase.regionserver.HRegion;
-import org.apache.hadoop.hbase.regionserver.ScanInfoUtil;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.phoenix.compat.hbase.HbaseCompatCapabilities;
+import org.apache.phoenix.compat.hbase.coprocessor.CompatBaseScannerRegionObserver;
 import org.apache.phoenix.exception.SQLExceptionCode;
 import org.apache.phoenix.query.QueryServices;
-import org.apache.phoenix.util.EnvironmentEdge;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.phoenix.util.EnvironmentEdgeManager;
 import org.apache.phoenix.util.ManualEnvironmentEdge;
 import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.QueryUtil;
 import org.apache.phoenix.util.ReadOnlyProps;
 import org.apache.phoenix.util.TestUtil;
+import org.junit.After;
 import org.junit.Assert;
+import org.junit.Assume;
 import org.junit.Before;
 import org.junit.BeforeClass;
 import org.junit.Test;
-import org.junit.AfterClass;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 
 import java.io.IOException;
 import java.sql.Connection;
@@ -61,7 +59,6 @@ import static org.junit.Assert.assertFalse;
 
 @NeedsOwnMiniClusterTest
 public class MaxLookbackIT extends BaseUniqueNamesOwnClusterIT {
-    private static final Logger LOG = LoggerFactory.getLogger(MaxLookbackIT.class);
     private static final int MAX_LOOKBACK_AGE = 15;
     private static final int ROWS_POPULATED = 2;
     public static final int WAIT_AFTER_TABLE_CREATION_MILLIS = 1;
@@ -69,37 +66,48 @@ public class MaxLookbackIT extends BaseUniqueNamesOwnClusterIT {
     private StringBuilder optionBuilder;
     ManualEnvironmentEdge injectEdge;
     private int ttl;
+    //max lookback isn't supported in HBase 2.1 and 2.2 because of missing coprocessor
+    // interfaces; see HBASE-24321
+    private final static boolean isMaxLookbackSupported =
+            HbaseCompatCapabilities.isMaxLookbackTimeSupported();
 
     @BeforeClass
     public static synchronized void doSetup() throws Exception {
+        Assume.assumeTrue(isMaxLookbackSupported);
         Map<String, String> props = Maps.newHashMapWithExpectedSize(1);
         props.put(QueryServices.GLOBAL_INDEX_ROW_AGE_THRESHOLD_TO_DELETE_MS_ATTRIB, Long.toString(0));
-        props.put(ScanInfoUtil.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY, Integer.toString(MAX_LOOKBACK_AGE));
+        props.put(CompatBaseScannerRegionObserver.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY, Integer.toString(MAX_LOOKBACK_AGE));
         setUpTestDriver(new ReadOnlyProps(props.entrySet().iterator()));
     }
 
     @Before
     public void beforeTest(){
+        Assume.assumeTrue(isMaxLookbackSupported);
         EnvironmentEdgeManager.reset();
         optionBuilder = new StringBuilder();
         this.tableDDLOptions = optionBuilder.toString();
         ttl = 0;
         injectEdge = new ManualEnvironmentEdge();
         injectEdge.setValue(EnvironmentEdgeManager.currentTimeMillis());
-        EnvironmentEdgeManager.injectEdge(injectEdge);
     }
 
-    @AfterClass
-    public static synchronized void afterClass() {
+    @After
+    public synchronized void afterTest() throws Exception {
         boolean refCountLeaked = isAnyStoreRefCountLeaked();
+        if (!isMaxLookbackSupported) {
+            return;
+        }
         EnvironmentEdgeManager.reset();
         assertFalse("refCount leaked", refCountLeaked);
     }
 
     @Test
     public void testTooLowSCNWithMaxLookbackAge() throws Exception {
+        Assume.assumeTrue(isMaxLookbackSupported);
         String dataTableName = generateUniqueName();
         createTable(dataTableName);
+        injectEdge.setValue(System.currentTimeMillis());
+        EnvironmentEdgeManager.injectEdge(injectEdge);
         //increase long enough to make sure we can find the syscat row for the table
         injectEdge.incrementValue(WAIT_AFTER_TABLE_CREATION_MILLIS);
         populateTable(dataTableName);
@@ -121,17 +129,19 @@ public class MaxLookbackIT extends BaseUniqueNamesOwnClusterIT {
 
     @Test(timeout=120000L)
     public void testRecentlyDeletedRowsNotCompactedAway() throws Exception {
+        Assume.assumeTrue(isMaxLookbackSupported);
         try (Connection conn = DriverManager.getConnection(getUrl())) {
             String dataTableName = generateUniqueName();
             String indexName = generateUniqueName();
             createTable(dataTableName);
-            injectEdge.incrementValue(WAIT_AFTER_TABLE_CREATION_MILLIS);
+
             TableName dataTable = TableName.valueOf(dataTableName);
             populateTable(dataTableName);
             createIndex(dataTableName, indexName, 1);
+            injectEdge.setValue(System.currentTimeMillis());
+            EnvironmentEdgeManager.injectEdge(injectEdge);
             TableName indexTable = TableName.valueOf(indexName);
-            //make sure we're after the inserts have been committed
-            injectEdge.incrementValue(1);
+            injectEdge.incrementValue(WAIT_AFTER_TABLE_CREATION_MILLIS);
             long beforeDeleteSCN = EnvironmentEdgeManager.currentTimeMillis();
             injectEdge.incrementValue(10); //make sure we delete at a different ts
             Statement stmt = conn.createStatement();
@@ -169,6 +179,7 @@ public class MaxLookbackIT extends BaseUniqueNamesOwnClusterIT {
             conn.createStatement().execute("upsert into " + dataTableName +
                 " values ('c', 'cd', 'cde', 'cdef')");
             conn.commit();
+            injectEdge.incrementValue(1L);
             majorCompact(dataTable);
             majorCompact(indexTable);
             //should still be ROWS_POPULATED because we added one and deleted one
@@ -186,6 +197,7 @@ public class MaxLookbackIT extends BaseUniqueNamesOwnClusterIT {
 
     @Test(timeout=60000L)
     public void testTTLAndMaxLookbackAge() throws Exception {
+        Assume.assumeTrue(isMaxLookbackSupported);
         ttl = 20;
         optionBuilder.append("TTL=" + ttl);
         tableDDLOptions = optionBuilder.toString();
@@ -198,10 +210,10 @@ public class MaxLookbackIT extends BaseUniqueNamesOwnClusterIT {
             String dataTableName = generateUniqueName();
             String indexName = generateUniqueName();
             createTable(dataTableName);
-            //increment to make sure we don't "look back" past table creation
-            injectEdge.incrementValue(WAIT_AFTER_TABLE_CREATION_MILLIS);
             populateTable(dataTableName);
             createIndex(dataTableName, indexName, 1);
+            injectEdge.setValue(System.currentTimeMillis());
+            EnvironmentEdgeManager.injectEdge(injectEdge);
             injectEdge.incrementValue(1);
             long afterFirstInsertSCN = EnvironmentEdgeManager.currentTimeMillis();
             TableName dataTable = TableName.valueOf(dataTableName);
@@ -258,6 +270,7 @@ public class MaxLookbackIT extends BaseUniqueNamesOwnClusterIT {
 
     @Test(timeout=60000)
     public void testRecentMaxVersionsNotCompactedAway() throws Exception {
+        Assume.assumeTrue(isMaxLookbackSupported);
         int versions = 2;
         optionBuilder.append("VERSIONS=" + versions);
         tableDDLOptions = optionBuilder.toString();
@@ -268,10 +281,12 @@ public class MaxLookbackIT extends BaseUniqueNamesOwnClusterIT {
             String dataTableName = generateUniqueName();
             String indexName = generateUniqueName();
             createTable(dataTableName);
-            //increment to make sure we don't "look back" past table creation
-            injectEdge.incrementValue(WAIT_AFTER_TABLE_CREATION_MILLIS);
             populateTable(dataTableName);
             createIndex(dataTableName, indexName, versions);
+            injectEdge.setValue(System.currentTimeMillis());
+            EnvironmentEdgeManager.injectEdge(injectEdge);
+            //increment to make sure we don't "look back" past table creation
+            injectEdge.incrementValue(WAIT_AFTER_TABLE_CREATION_MILLIS);
             injectEdge.incrementValue(1); //increment by 1 so we can see our write
             long afterInsertSCN = EnvironmentEdgeManager.currentTimeMillis();
             //make sure table and index metadata is set up right for versions
@@ -332,7 +347,7 @@ public class MaxLookbackIT extends BaseUniqueNamesOwnClusterIT {
     }
 
     private void flush(TableName table) throws IOException {
-        Admin admin = getUtility().getHBaseAdmin();
+        Admin admin = getUtility().getAdmin();
         admin.flush(table);
     }
 
