@@ -17,11 +17,13 @@
  */
 package org.apache.phoenix.end2end;
 
-import org.apache.hadoop.hbase.HColumnDescriptor;
-import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.KeepDeletedCells;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
+import org.apache.hadoop.hbase.client.TableDescriptor;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.Pair;
 import org.apache.phoenix.exception.SQLExceptionCode;
@@ -69,16 +71,13 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
     private static final int INITIAL_UPDATE_CACHE_FREQUENCY_VIEWS = 900;
     private static final int MODIFIED_TTL_VALUE = INITIAL_TTL_VALUE + 300;
     private static final KeepDeletedCells MODIFIED_KEEP_DELETED_CELLS_VALUE =
-            (INITIAL_KEEP_DELETED_CELLS_VALUE == KeepDeletedCells.TRUE) ?
-                    KeepDeletedCells.FALSE: KeepDeletedCells.TRUE;
-    private static final int MODIFIED_REPLICATION_SCOPE_VALUE =
-            (INITIAL_REPLICATION_SCOPE_VALUE == 1) ? 0 : 1;
+            (INITIAL_KEEP_DELETED_CELLS_VALUE == KeepDeletedCells.TRUE) ? KeepDeletedCells.FALSE: KeepDeletedCells.TRUE;
+    private static final int MODIFIED_REPLICATION_SCOPE_VALUE = (INITIAL_REPLICATION_SCOPE_VALUE == 1) ? 0 : 1;
     private static final int MODIFIED_UPDATE_CACHE_FREQUENCY = INITIAL_UPDATE_CACHE_FREQUENCY + 300;
     private static final int MODIFIED_UPDATE_CACHE_FREQUENCY_VIEWS = INITIAL_UPDATE_CACHE_FREQUENCY_VIEWS + 300;
 
 
-    // Test that we disallow specifying synced properties to be set per column family
-    // when creating a table
+    // Test that we disallow specifying synced properties to be set per column family when creating a table
     @Test
     public void testDisallowSyncedPropsToBeSetColFamSpecificCreateTable() throws Exception {
         Connection conn = DriverManager.getConnection(getUrl(), new Properties());
@@ -89,12 +88,10 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
                         + " (id INTEGER not null primary key, "
                         + COL_FAM1 + ".name varchar(10), " + COL_FAM2 + ".flag boolean) "
                         + COL_FAM1 + "." + propName + "=" + DUMMY_PROP_VALUE);
-                fail("Should fail with SQLException when setting synced property for"
-                        + " a specific column family");
+                fail("Should fail with SQLException when setting synced property for a specific column family");
             } catch (SQLException sqlE) {
                 assertEquals("Should fail to set synced property for a specific column family",
-                        SQLExceptionCode.COLUMN_FAMILY_NOT_ALLOWED_FOR_PROPERTY.getErrorCode(),
-                        sqlE.getErrorCode());
+                        SQLExceptionCode.COLUMN_FAMILY_NOT_ALLOWED_FOR_PROPERTY.getErrorCode(), sqlE.getErrorCode());
             }
         }
         conn.close();
@@ -109,8 +106,7 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
         conn.close();
     }
 
-    // Test that we disallow specifying synced properties to be set when creating an index
-    // on a physical table or a view
+    // Test that we disallow specifying synced properties to be set when creating an index on a physical table or a view
     @Test
     public void testDisallowSyncedPropsToBeSetCreateIndex() throws Exception {
         Connection conn = DriverManager.getConnection(getUrl(), new Properties());
@@ -125,23 +121,19 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
                 conn.createStatement().execute("create local index " + localIndexName
                         + " on " + tableName + "(name) "
                         + propName + "=" + DUMMY_PROP_VALUE);
-                fail("Should fail with SQLException when setting synced property for "
-                        + "a local index");
+                fail("Should fail with SQLException when setting synced property for a local index");
             } catch (SQLException sqlE) {
                 assertEquals("Should fail to set synced property for a local index",
-                        SQLExceptionCode.CANNOT_SET_OR_ALTER_PROPERTY_FOR_INDEX.getErrorCode(),
-                        sqlE.getErrorCode());
+                        SQLExceptionCode.CANNOT_SET_OR_ALTER_PROPERTY_FOR_INDEX.getErrorCode(), sqlE.getErrorCode());
             }
             try {
                 conn.createStatement().execute("create index " + globalIndexName
                         + " on " + tableName + "(flag) "
                         + propName + "=" + DUMMY_PROP_VALUE);
-                fail("Should fail with SQLException when setting synced property for"
-                        + " a global index");
+                fail("Should fail with SQLException when setting synced property for a global index");
             } catch (SQLException sqlE) {
                 assertEquals("Should fail to set synced property for a global index",
-                        SQLExceptionCode.CANNOT_SET_OR_ALTER_PROPERTY_FOR_INDEX.getErrorCode(),
-                        sqlE.getErrorCode());
+                        SQLExceptionCode.CANNOT_SET_OR_ALTER_PROPERTY_FOR_INDEX.getErrorCode(), sqlE.getErrorCode());
             }
             try {
                 conn.createStatement().execute("create index view_index"
@@ -149,8 +141,7 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
                 fail("Should fail with SQLException when setting synced property for a view index");
             } catch (SQLException sqlE) {
                 assertEquals("Should fail to set synced property for a view index",
-                        SQLExceptionCode.CANNOT_SET_OR_ALTER_PROPERTY_FOR_INDEX.getErrorCode(),
-                        sqlE.getErrorCode());
+                        SQLExceptionCode.CANNOT_SET_OR_ALTER_PROPERTY_FOR_INDEX.getErrorCode(), sqlE.getErrorCode());
             }
         }
         conn.close();
@@ -164,15 +155,13 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
         createIndexTable(conn, tableName, PTable.IndexType.LOCAL).getSecond();
         String globalIndexName = createIndexTable(conn, tableName, PTable.IndexType.GLOBAL).getSecond();
 
-        // We pass the base table as the physical HBase table since our check includes checking
-        // the local index column family too
+        // We pass the base table as the physical HBase table since our check includes checking the local index column family too
         verifyHBaseColumnFamilyProperties(tableName, conn, false, false);
         verifyHBaseColumnFamilyProperties(globalIndexName, conn, false, false);
         conn.close();
     }
 
-    // Test that the physical view index table has the same value of synced properties
-    // as its base table
+    // Test that the physical view index table has the same value of synced properties as its base table
     @Test
     public void testSyncedPropsBaseTableCreateViewIndex() throws Exception {
         Connection conn = DriverManager.getConnection(getUrl(), new Properties());
@@ -184,8 +173,7 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
         conn.close();
     }
 
-    // Test that we disallow specifying synced properties to be set per column family
-    // when altering a table
+    // Test that we disallow specifying synced properties to be set per column family when altering a table
     @Test
     public void testDisallowSyncedPropsToBeSetColFamSpecificAlterTable() throws Exception {
         Connection conn = DriverManager.getConnection(getUrl(), new Properties());
@@ -196,12 +184,10 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
             try {
                 conn.createStatement().execute("alter table " + tableName
                         + " set " + COL_FAM1 + "." + propName + "=" + DUMMY_PROP_VALUE);
-                fail("Should fail with SQLException when altering synced property for a"
-                        + " specific column family");
+                fail("Should fail with SQLException when altering synced property for a specific column family");
             } catch (SQLException sqlE) {
                 assertEquals("Should fail to alter synced property for a specific column family",
-                        SQLExceptionCode.COLUMN_FAMILY_NOT_ALLOWED_FOR_PROPERTY.getErrorCode(),
-                        sqlE.getErrorCode());
+                        SQLExceptionCode.COLUMN_FAMILY_NOT_ALLOWED_FOR_PROPERTY.getErrorCode(), sqlE.getErrorCode());
             }
             alterAllSyncedPropsString.append(String.format(modPropString, propName));
         }
@@ -210,18 +196,15 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
         try {
             conn.createStatement().execute("alter table " + tableName + " set "
                     + alterAllSyncedPropsString.substring(0, alterAllSyncedPropsString.length() - 1));
-            fail("Should fail with SQLException when altering synced properties for a"
-                    + " specific column family");
+            fail("Should fail with SQLException when altering synced properties for a specific column family");
         } catch (SQLException sqlE) {
             assertEquals("Should fail to alter synced properties for a specific column family",
-                    SQLExceptionCode.COLUMN_FAMILY_NOT_ALLOWED_FOR_PROPERTY.getErrorCode(),
-                    sqlE.getErrorCode());
+                    SQLExceptionCode.COLUMN_FAMILY_NOT_ALLOWED_FOR_PROPERTY.getErrorCode(), sqlE.getErrorCode());
         }
         conn.close();
     }
 
-    // Test that any alteration of the synced properties gets propagated to all indexes and
-    // the physical view index table
+    // Test that any alteration of the synced properties gets propagated to all indexes and the physical view index table
     @Test
     public void testAlterSyncedPropsPropagateToAllIndexesAndViewIndex() throws Exception {
         Connection conn = DriverManager.getConnection(getUrl(), new Properties());
@@ -264,19 +247,15 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
                 conn.createStatement().execute(
                         "alter table " + tableName + " add " + NEW_CF + ".new_column varchar(2) "
                                 + NEW_CF + "." + propName + "=" + DUMMY_PROP_VALUE);
-                fail("Should fail with SQLException when altering synced property for a"
-                        + " specific column family when adding a column");
+                fail("Should fail with SQLException when altering synced property for a specific column family when adding a column");
             } catch (SQLException sqlE) {
-                assertEquals("Should fail to alter synced property for a specific"
-                                + " column family when adding a column",
-                        SQLExceptionCode.COLUMN_FAMILY_NOT_ALLOWED_FOR_PROPERTY.getErrorCode(),
-                        sqlE.getErrorCode());
+                assertEquals("Should fail to alter synced property for a specific column family when adding a column",
+                        SQLExceptionCode.COLUMN_FAMILY_NOT_ALLOWED_FOR_PROPERTY.getErrorCode(), sqlE.getErrorCode());
             }
         }
 
-        // Test that when we add a new column (belonging to a new column family) and set any
-        // property that should be in sync, then the property is modified for all existing
-        // column families of the base table and its indexes
+        // Test that when we add a new column (belonging to a new column family) and set any property that should be
+        // in sync, then the property is modified for all existing column families of the base table and its indexes
         Set<String> tablesToCheck = new HashSet<>();
         tablesToCheck.add(tableName);
         for (int i=0; i<2; i++) {
@@ -287,8 +266,8 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
         tablesToCheck.add(createIndexTable(conn, tableName, null).getSecond());
 
         // Now add a new column family while simultaneously modifying properties to be kept in sync,
-        // as well as a property which does not need to be kept in sync. Properties to be kept
-        // in sync should get propagated to all index tables and already existing column families
+        // as well as a property which does not need to be kept in sync. Properties to be kept in sync
+        // should get propagated to all index tables and already existing column families
         conn.createStatement().execute(
                 "alter table " + tableName + " add " + NEW_CF + ".new_column varchar(2) "
                 + "KEEP_DELETED_CELLS=" + MODIFIED_KEEP_DELETED_CELLS_VALUE
@@ -299,15 +278,15 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
             verifyHBaseColumnFamilyProperties(table, conn, true, true);
         }
         try (Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
-            HColumnDescriptor[] columnFamilies =
-                    admin.getTableDescriptor(TableName.valueOf(tableName)).getColumnFamilies();
-            for (HColumnDescriptor cfd: columnFamilies) {
+            ColumnFamilyDescriptor[] columnFamilies = admin.getDescriptor(TableName.valueOf(tableName))
+                    .getColumnFamilies();
+            for (ColumnFamilyDescriptor cfd: columnFamilies) {
                 if (cfd.getNameAsString().equals(NEW_CF)) {
                     assertEquals("Newly added column fmaily should have updated property",
                             300000, cfd.getBlocksize());
                 } else {
                     assertEquals("Existing column families should have default value for property",
-                            HColumnDescriptor.DEFAULT_BLOCKSIZE, cfd.getBlocksize());
+                            ColumnFamilyDescriptorBuilder.DEFAULT_BLOCKSIZE, cfd.getBlocksize());
                 }
             }
         }
@@ -324,12 +303,10 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
             try {
                 conn.createStatement().execute("alter table " + globalIndexName + " set "
                 + propName + "=" + DUMMY_PROP_VALUE);
-                fail("Should fail with SQLException when altering synced property"
-                        + " for a global index");
+                fail("Should fail with SQLException when altering synced property for a global index");
             } catch (SQLException sqlE) {
                 assertEquals("Should fail to alter synced property for a global index",
-                        SQLExceptionCode.CANNOT_SET_OR_ALTER_PROPERTY_FOR_INDEX.getErrorCode(),
-                        sqlE.getErrorCode());
+                        SQLExceptionCode.CANNOT_SET_OR_ALTER_PROPERTY_FOR_INDEX.getErrorCode(), sqlE.getErrorCode());
             }
         }
         conn.close();
@@ -361,40 +338,39 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
 
         try (Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
             for (String tableName: createdTables) {
-                final HTableDescriptor tableDescriptor;
-                final HColumnDescriptor defaultCF;
+                final TableDescriptor tableDescriptor;
+                final ColumnFamilyDescriptor defaultCF;
                 if (MetaDataUtil.isViewIndex(tableName)) {
                     // We won't be able to get the PTable for a view index table
                     tableDescriptor = conn.unwrap(PhoenixConnection.class).getQueryServices()
                             .getTableDescriptor(Bytes.toBytes(tableName));
-                    defaultCF = tableDescriptor.getFamily(DEFAULT_COLUMN_FAMILY_BYTES);
+                    defaultCF = tableDescriptor.getColumnFamily(DEFAULT_COLUMN_FAMILY_BYTES);
                 } else {
                     PTable table = PhoenixRuntime.getTable(conn, tableName);
                     tableDescriptor = conn.unwrap(PhoenixConnection.class).getQueryServices()
                             .getTableDescriptor(table.getPhysicalName().getBytes());
-                    defaultCF = tableDescriptor.getFamily(SchemaUtil.getEmptyColumnFamily(table));
+                    defaultCF = tableDescriptor.getColumnFamily(SchemaUtil.getEmptyColumnFamily(table));
                 }
 
-                HTableDescriptor newTableDesc = new HTableDescriptor(tableDescriptor);
+                TableDescriptorBuilder tableDescBuilder = TableDescriptorBuilder.newBuilder(tableDescriptor);
                 if (tableName.equals(baseTableName) || tableName.equals(baseTableName1)) {
-                    for (HColumnDescriptor cfd: tableDescriptor.getColumnFamilies()) {
-                        // Modify all column families except the default column family
-                        // for the base tables
+                    for (ColumnFamilyDescriptor cfd: tableDescriptor.getColumnFamilies()) {
+                        // Modify all column families except the default column family for the base tables
                         if (!cfd.equals(defaultCF)) {
-                            HColumnDescriptor newCfd = new HColumnDescriptor(cfd);
-                            modifySyncedPropsForCF(newCfd);
-                            newTableDesc.modifyFamily(newCfd);
+                            ColumnFamilyDescriptorBuilder cfdb = ColumnFamilyDescriptorBuilder.newBuilder(cfd);
+                            modifySyncedPropsForCF(cfdb);
+                            tableDescBuilder.modifyColumnFamily(cfdb.build());
                         }
                     }
                 } else {
-                    for (HColumnDescriptor cfd: tableDescriptor.getColumnFamilies()) {
+                    for (ColumnFamilyDescriptor cfd: tableDescriptor.getColumnFamilies()) {
                         // Modify all column families for other tables
-                        HColumnDescriptor newCfd = new HColumnDescriptor(cfd);
-                        modifySyncedPropsForCF(newCfd);
-                        newTableDesc.modifyFamily(newCfd);
+                        ColumnFamilyDescriptorBuilder cfdb = ColumnFamilyDescriptorBuilder.newBuilder(cfd);
+                        modifySyncedPropsForCF(cfdb);
+                        tableDescBuilder.modifyColumnFamily(cfdb.build());
                     }
                 }
-                admin.modifyTable(newTableDesc.getTableName(), newTableDesc);
+                admin.modifyTable(tableDescBuilder.build());
             }
         }
         // Now synchronize required properties and verify HBase metadata property values
@@ -416,18 +392,18 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
 
         try (Connection conn = DriverManager.getConnection(getUrl(), new Properties())) {
             baseTableName = createBaseTableWithProps(conn);
-            createdTablesAndViews.put(baseTableName, new HashSet<String>());
+            createdTablesAndViews.put(baseTableName, new HashSet<>());
             Set<String> indexes = createdTablesAndViews.get(baseTableName);
             indexes.add(createIndexTable(conn, baseTableName, PTable.IndexType.GLOBAL).getSecond());
             indexes.add(createIndexTable(conn, baseTableName, PTable.IndexType.LOCAL).getFirst());
 
             viewName = createViewOnBaseTableOrView(conn, baseTableName);
-            createdTablesAndViews.put(viewName, new HashSet<String>());
+            createdTablesAndViews.put(viewName, new HashSet<>());
             indexes = createdTablesAndViews.get(viewName);
             indexes.add(createIndexTable(conn, viewName, PTable.IndexType.GLOBAL).getSecond());
 
             viewName2 = createViewOnBaseTableOrView(conn, viewName);
-            createdTablesAndViews.put(viewName2, new HashSet<String>());
+            createdTablesAndViews.put(viewName2, new HashSet<>());
             indexes = createdTablesAndViews.get(viewName2);
             indexes.add(createIndexTable(conn, viewName2, PTable.IndexType.LOCAL).getFirst());
 
@@ -481,18 +457,17 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
 
     /**
      * Helper method to modify the synced properties for a column family descriptor
-     * @param cfd The column family descriptor object
+     * @param cfdb The column family descriptor builder object
      * @throws SQLException
      */
-    private void modifySyncedPropsForCF(HColumnDescriptor cfd) throws SQLException {
-        cfd.setTimeToLive(MODIFIED_TTL_VALUE);
-        cfd.setKeepDeletedCells(MODIFIED_KEEP_DELETED_CELLS_VALUE);
-        cfd.setScope(MODIFIED_REPLICATION_SCOPE_VALUE);
+    private void modifySyncedPropsForCF(ColumnFamilyDescriptorBuilder cfdb) throws SQLException {
+        cfdb.setTimeToLive(MODIFIED_TTL_VALUE);
+        cfdb.setKeepDeletedCells(MODIFIED_KEEP_DELETED_CELLS_VALUE);
+        cfdb.setScope(MODIFIED_REPLICATION_SCOPE_VALUE);
     }
 
     /**
-     * Helper method to create or alter a base table with specific values set for properties to be
-     * kept in sync
+     * Helper method to create or alter a base table with specific values set for properties to be kept in sync
      * @param conn Phoenix connection
      * @return Name of the HBase table created
      * @throws SQLException
@@ -565,23 +540,19 @@ public class PropertiesInSyncIT extends ParallelStatsDisabledIT {
     private void verifyHBaseColumnFamilyProperties(String tableName, Connection conn, boolean propModified,
             boolean ignoreTTL) throws Exception {
         final int expectedTTL = propModified ? MODIFIED_TTL_VALUE:INITIAL_TTL_VALUE;
-        final KeepDeletedCells expectedKeepDeletedCells = propModified ?
-                MODIFIED_KEEP_DELETED_CELLS_VALUE: INITIAL_KEEP_DELETED_CELLS_VALUE;
-        final int expectedReplicationScope = propModified ?
-                MODIFIED_REPLICATION_SCOPE_VALUE:INITIAL_REPLICATION_SCOPE_VALUE;
+        final KeepDeletedCells expectedKeepDeletedCells = propModified ? MODIFIED_KEEP_DELETED_CELLS_VALUE: INITIAL_KEEP_DELETED_CELLS_VALUE;
+        final int expectedReplicationScope = propModified ? MODIFIED_REPLICATION_SCOPE_VALUE:INITIAL_REPLICATION_SCOPE_VALUE;
 
         try (Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
             // Note that this includes the local index column family as well
-            HColumnDescriptor[] columnFamilies =
-                    admin.getTableDescriptor(TableName.valueOf(tableName)).getColumnFamilies();
-            for (HColumnDescriptor cfd: columnFamilies) {
+            ColumnFamilyDescriptor[] columnFamilies = admin.getDescriptor(TableName.valueOf(tableName))
+                    .getColumnFamilies();
+            for (ColumnFamilyDescriptor cfd: columnFamilies) {
                 if (!ignoreTTL) {
                     assertEquals("Mismatch in TTL", expectedTTL, cfd.getTimeToLive());
                 }
-                assertEquals("Mismatch in KEEP_DELETED_CELLS", expectedKeepDeletedCells,
-                        cfd.getKeepDeletedCells());
-                assertEquals("Mismatch in REPLICATION_SCOPE", expectedReplicationScope,
-                        cfd.getScope());
+                assertEquals("Mismatch in KEEP_DELETED_CELLS", expectedKeepDeletedCells, cfd.getKeepDeletedCells());
+                assertEquals("Mismatch in REPLICATION_SCOPE", expectedReplicationScope, cfd.getScope());
             }
         }
     }
