@@ -25,6 +25,7 @@ import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.SYSTEM_MUTEX_TABLE
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.TYPE_SEQUENCE;
 import static org.apache.phoenix.util.TestUtil.ATABLE_NAME;
 import static org.apache.phoenix.util.TestUtil.CUSTOM_ENTITY_DATA_FULL_NAME;
+import static org.apache.phoenix.util.TestUtil.ENTITY_HISTORY_TABLE_NAME;
 import static org.apache.phoenix.util.TestUtil.PTSDB_NAME;
 import static org.apache.phoenix.util.TestUtil.STABLE_NAME;
 import static org.apache.phoenix.util.TestUtil.TABLE_WITH_SALTING;
@@ -44,14 +45,20 @@ import java.sql.DriverManager;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
+import java.util.HashSet;
 import java.util.Properties;
+import java.util.Set;
 
-import org.apache.hadoop.hbase.HColumnDescriptor;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.HTableDescriptor;
-import org.apache.hadoop.hbase.client.HBaseAdmin;
-import org.apache.hadoop.hbase.client.HTableInterface;
+import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
 import org.apache.hadoop.hbase.client.Put;
+import org.apache.hadoop.hbase.client.Result;
+import org.apache.hadoop.hbase.client.Table;
+import org.apache.hadoop.hbase.client.TableDescriptor;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.io.encoding.DataBlockEncoding;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.coprocessor.GroupedAggregateRegionObserver;
@@ -86,7 +93,7 @@ public class QueryDatabaseMetaDataIT extends ParallelStatsDisabledIT {
                         + "    a.col1 integer,\n" + "    b.col2 bigint,\n" + "    b.col3 decimal,\n"
                         + "    b.col4 decimal(5),\n" + "    b.col5 decimal(6,3))\n" + "    a."
                         + HConstants.VERSIONS + "=" + 1 + "," + "a."
-                        + HColumnDescriptor.DATA_BLOCK_ENCODING + "='" + DataBlockEncoding.NONE
+                        + ColumnFamilyDescriptorBuilder.DATA_BLOCK_ENCODING + "='" + DataBlockEncoding.NONE
                         + "'";
         if (extraProps != null && extraProps.length() > 0) {
             ddl += "," + extraProps;
@@ -352,6 +359,60 @@ public class QueryDatabaseMetaDataIT extends ParallelStatsDisabledIT {
         }
     }
 
+    @Test
+    public void testShowSchemas() throws SQLException {
+        try (Connection conn = DriverManager.getConnection(getUrl())) {
+            ResultSet rs = conn.prepareStatement("show schemas").executeQuery();
+            assertTrue(rs.next());
+            assertEquals("SYSTEM", rs.getString("TABLE_SCHEM"));
+            assertEquals(null, rs.getString("TABLE_CATALOG"));
+            assertFalse(rs.next());
+            // Create another schema and make sure it is listed.
+            String schema = "showschemastest_" + generateUniqueName();
+            String fullTable = schema + "." + generateUniqueName();
+            ensureTableCreated(getUrl(), fullTable, ENTITY_HISTORY_TABLE_NAME, null);
+            // show schemas
+            rs = conn.prepareStatement("show schemas").executeQuery();
+            Set<String> schemas = new HashSet<>();
+            while (rs.next()) {
+                schemas.add(rs.getString("TABLE_SCHEM"));
+                assertEquals(null, rs.getString("TABLE_CATALOG"));
+            }
+            assertEquals(2, schemas.size());
+            assertTrue(schemas.contains("SYSTEM"));
+            assertTrue(schemas.contains(schema.toUpperCase()));
+            // show schemas like 'SYST%' and only SYSTEM should show up.
+            rs = conn.prepareStatement("show schemas like 'SYST%'").executeQuery();
+            assertTrue(rs.next());
+            assertEquals("SYSTEM", rs.getString("TABLE_SCHEM"));
+            assertEquals(null, rs.getString("TABLE_CATALOG"));
+            assertFalse(rs.next());
+        }
+    }
+
+    @Test
+    public void testShowTables() throws SQLException {
+        try (Connection conn = DriverManager.getConnection(getUrl())) {
+            // List all the tables in a particular schema.
+            ResultSet rs = conn.prepareStatement("show tables in SYSTEM").executeQuery();
+            Set<String> tables = new HashSet<>();
+            while (rs.next()) {
+                tables.add(rs.getString("TABLE_NAME"));
+                assertEquals("SYSTEM", rs.getString("TABLE_SCHEM"));
+            }
+            assertEquals(8, tables.size());
+            assertTrue(tables.contains("CATALOG"));
+            assertTrue(tables.contains("FUNCTION"));
+
+            tables.clear();
+            // Add a filter on the table name.
+            rs = conn.prepareStatement("show tables in SYSTEM like 'FUNC%'").executeQuery();
+            while (rs.next()) tables.add(rs.getString("TABLE_NAME"));
+            assertEquals(1, tables.size());
+            assertTrue(tables.contains("FUNCTION"));
+        }
+    }
+
     @Test
     public void testSchemaMetadataScan() throws SQLException {
         String table1 = generateUniqueName();
@@ -752,43 +813,41 @@ public class QueryDatabaseMetaDataIT extends ParallelStatsDisabledIT {
             byte[] cfC = Bytes.toBytes("c");
             byte[][] familyNames = new byte[][] { cfB, cfC };
             byte[] htableName = SchemaUtil.getTableNameAsBytes(schemaName, tableName);
-            HBaseAdmin admin = pconn.getQueryServices().getAdmin();
+            Admin admin = pconn.getQueryServices().getAdmin();
             try {
-                admin.disableTable(htableName);
-                admin.deleteTable(htableName);
-                admin.enableTable(htableName);
+                admin.disableTable(TableName.valueOf(htableName));
+                admin.deleteTable(TableName.valueOf(htableName));
+                admin.enableTable(TableName.valueOf(htableName));
             } catch (org.apache.hadoop.hbase.TableNotFoundException e) {
             }
 
-            @SuppressWarnings("deprecation")
-            HTableDescriptor descriptor = new HTableDescriptor(htableName);
+            TableDescriptorBuilder builder = TableDescriptorBuilder.newBuilder(TableName.valueOf(htableName));
             for (byte[] familyName : familyNames) {
-                HColumnDescriptor columnDescriptor = new HColumnDescriptor(familyName);
-                descriptor.addFamily(columnDescriptor);
+                builder.addColumnFamily(ColumnFamilyDescriptorBuilder.of(familyName));
             }
-            admin.createTable(descriptor);
+            admin.createTable(builder.build());
             createMDTestTable(pconn, tableName,
-            "a." + HColumnDescriptor.BLOCKSIZE+ "=" + 50000);
+                "a." + ColumnFamilyDescriptorBuilder.BLOCKSIZE+ "=" + 50000);
 
-            descriptor = admin.getTableDescriptor(htableName);
+            TableDescriptor descriptor = admin.getDescriptor(TableName.valueOf(htableName));
             assertEquals(3, descriptor.getColumnFamilies().length);
-            HColumnDescriptor cdA = descriptor.getFamily(cfA);
-            assertEquals(HColumnDescriptor.DEFAULT_KEEP_DELETED, cdA.getKeepDeletedCells());
-            assertNotEquals(HColumnDescriptor.DEFAULT_BLOCKSIZE, cdA.getBlocksize());
+            ColumnFamilyDescriptor cdA = descriptor.getColumnFamily(cfA);
+            assertEquals(ColumnFamilyDescriptorBuilder.DEFAULT_KEEP_DELETED, cdA.getKeepDeletedCells());
+            assertNotEquals(ColumnFamilyDescriptorBuilder.DEFAULT_BLOCKSIZE, cdA.getBlocksize());
             assertEquals(DataBlockEncoding.NONE, cdA.getDataBlockEncoding()); // Overriden using
                                                                               // WITH
             assertEquals(1, cdA.getMaxVersions());// Overriden using WITH
-            HColumnDescriptor cdB = descriptor.getFamily(cfB);
+            ColumnFamilyDescriptor cdB = descriptor.getColumnFamily(cfB);
             // Allow KEEP_DELETED_CELLS to be false for VIEW
-            assertEquals(HColumnDescriptor.DEFAULT_KEEP_DELETED, cdB.getKeepDeletedCells());
-            assertEquals(HColumnDescriptor.DEFAULT_BLOCKSIZE, cdB.getBlocksize());
+            assertEquals(ColumnFamilyDescriptorBuilder.DEFAULT_KEEP_DELETED, cdB.getKeepDeletedCells());
+            assertEquals(ColumnFamilyDescriptorBuilder.DEFAULT_BLOCKSIZE, cdB.getBlocksize());
             assertEquals(DataBlockEncoding.NONE, cdB.getDataBlockEncoding()); // Should keep the
                                                                               // original value.
             // CF c should stay the same since it's not a Phoenix cf.
-            HColumnDescriptor cdC = descriptor.getFamily(cfC);
+            ColumnFamilyDescriptor cdC = descriptor.getColumnFamily(cfC);
             assertNotNull("Column family not found", cdC);
-            assertEquals(HColumnDescriptor.DEFAULT_KEEP_DELETED, cdC.getKeepDeletedCells());
-            assertEquals(HColumnDescriptor.DEFAULT_BLOCKSIZE, cdC.getBlocksize());
+            assertEquals(ColumnFamilyDescriptorBuilder.DEFAULT_KEEP_DELETED, cdC.getKeepDeletedCells());
+            assertEquals(ColumnFamilyDescriptorBuilder.DEFAULT_BLOCKSIZE, cdC.getBlocksize());
             assertFalse(SchemaUtil.DEFAULT_DATA_BLOCK_ENCODING == cdC.getDataBlockEncoding());
             assertTrue(descriptor.hasCoprocessor(UngroupedAggregateRegionObserver.class.getName()));
             assertTrue(descriptor.hasCoprocessor(GroupedAggregateRegionObserver.class.getName()));
@@ -834,19 +893,18 @@ public class QueryDatabaseMetaDataIT extends ParallelStatsDisabledIT {
             byte[] cfC = Bytes.toBytes("c");
             byte[][] familyNames = new byte[][] { cfB, cfC };
             byte[] htableName = SchemaUtil.getTableNameAsBytes(schemaName, tableName);
-            try (HBaseAdmin admin = pconn.getQueryServices().getAdmin()) {
+            try (Admin admin = pconn.getQueryServices().getAdmin()) {
                 try {
-                    admin.disableTable(htableName);
-                    admin.deleteTable(htableName);
+                    admin.disableTable(TableName.valueOf(htableName));
+                    admin.deleteTable(TableName.valueOf(htableName));
                 } catch (org.apache.hadoop.hbase.TableNotFoundException e) {
                 }
 
-                HTableDescriptor descriptor = new HTableDescriptor(htableName);
+                TableDescriptorBuilder builder = TableDescriptorBuilder.newBuilder(TableName.valueOf(htableName));
                 for (byte[] familyName : familyNames) {
-                    HColumnDescriptor columnDescriptor = new HColumnDescriptor(familyName);
-                    descriptor.addFamily(columnDescriptor);
+                    builder.addColumnFamily(ColumnFamilyDescriptorBuilder.of(familyName));
                 }
-                admin.createTable(descriptor);
+                admin.createTable(builder.build());
             }
             String createStmt =
                     "create view " + generateUniqueName() + "  (id char(1) not null primary key,\n"
@@ -911,7 +969,7 @@ public class QueryDatabaseMetaDataIT extends ParallelStatsDisabledIT {
                 // expected to fail b/c table is read-only
             }
 
-            HTableInterface htable =
+            Table htable =
                     pconn.getQueryServices()
                             .getTable(SchemaUtil.getTableNameAsBytes(schemaName, tableName));
             Put put = new Put(Bytes.toBytes("0"));
