@@ -62,7 +62,7 @@ import org.apache.phoenix.util.ReadOnlyProps;
 import org.junit.BeforeClass;
 import org.junit.Test;
 
-import com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 
 
 public class QueryLoggerIT extends BaseUniqueNamesOwnClusterIT {
@@ -103,44 +103,47 @@ public class QueryLoggerIT extends BaseUniqueNamesOwnClusterIT {
         Connection conn = DriverManager.getConnection(getUrl(),props);
         assertEquals(conn.unwrap(PhoenixConnection.class).getLogLevel(),LogLevel.DEBUG);
         String query = "SELECT * FROM " + tableName;
-        ResultSet rs = conn.createStatement().executeQuery(query);
-        StatementContext context = ((PhoenixResultSet)rs).getContext();
-        String queryId = context.getQueryLogger().getQueryId();
-        while (rs.next()) {
-            rs.getString(1);
-            rs.getString(2);
+        StatementContext context;
+        try (ResultSet rs = conn.createStatement().executeQuery(query)) {
+            context = ((PhoenixResultSet) rs).getContext();
+            while (rs.next()) {
+                rs.getString(1);
+                rs.getString(2);
+            }
         }
-        ResultSet explainRS = conn.createStatement().executeQuery("Explain " + query);
+        String queryId = context.getQueryLogger().getQueryId();
 
         String logQuery = "SELECT * FROM " + SYSTEM_CATALOG_SCHEMA + ".\"" + SYSTEM_LOG_TABLE + "\"";
         int delay = 5000;
 
         // sleep for sometime to let query log committed
         Thread.sleep(delay);
-        rs = conn.createStatement().executeQuery(logQuery);
-        boolean foundQueryLog = false;
+        try (ResultSet explainRS = conn.createStatement().executeQuery("Explain " + query);
+             ResultSet rs = conn.createStatement().executeQuery(logQuery)) {
+            boolean foundQueryLog = false;
 
-        while (rs.next()) {
-            if (rs.getString(QUERY_ID).equals(queryId)) {
-                foundQueryLog = true;
-                assertEquals(rs.getString(BIND_PARAMETERS), null);
-                assertEquals(rs.getString(USER), System.getProperty("user.name"));
-                assertEquals(rs.getString(CLIENT_IP), InetAddress.getLocalHost().getHostAddress());
-                assertEquals(rs.getString(EXPLAIN_PLAN), QueryUtil.getExplainPlan(explainRS));
-                assertEquals(rs.getString(GLOBAL_SCAN_DETAILS), context.getScan().toJSON());
-                assertEquals(rs.getLong(NO_OF_RESULTS_ITERATED), 10);
-                assertEquals(rs.getString(QUERY), query);
-                assertEquals(rs.getString(QUERY_STATUS), QueryStatus.COMPLETED.toString());
-                assertEquals(rs.getString(TENANT_ID), null);
-                assertTrue(rs.getString(SCAN_METRICS_JSON)==null);
-                assertEquals(rs.getString(EXCEPTION_TRACE),null);
-            }else{
-                //confirm we are not logging system queries
-                assertFalse(rs.getString(QUERY).toString().contains(SYSTEM_CATALOG_SCHEMA));
+            while (rs.next()) {
+                if (rs.getString(QUERY_ID).equals(queryId)) {
+                    foundQueryLog = true;
+                    assertEquals(rs.getString(BIND_PARAMETERS), null);
+                    assertEquals(rs.getString(USER), System.getProperty("user.name"));
+                    assertEquals(rs.getString(CLIENT_IP), InetAddress.getLocalHost().getHostAddress());
+                    assertEquals(rs.getString(EXPLAIN_PLAN), QueryUtil.getExplainPlan(explainRS));
+                    assertEquals(rs.getString(GLOBAL_SCAN_DETAILS), context.getScan().toJSON());
+                    assertEquals(rs.getLong(NO_OF_RESULTS_ITERATED), 10);
+                    assertEquals(rs.getString(QUERY), query);
+                    assertEquals(rs.getString(QUERY_STATUS), QueryStatus.COMPLETED.toString());
+                    assertEquals(rs.getString(TENANT_ID), null);
+                    assertTrue(rs.getString(SCAN_METRICS_JSON) == null);
+                    assertEquals(rs.getString(EXCEPTION_TRACE), null);
+                } else {
+                    //confirm we are not logging system queries
+                    assertFalse(rs.getString(QUERY).toString().contains(SYSTEM_CATALOG_SCHEMA));
+                }
             }
+            assertTrue(foundQueryLog);
+            conn.close();
         }
-        assertTrue(foundQueryLog);
-        conn.close();
     }
     
     @Test
@@ -155,18 +158,19 @@ public class QueryLoggerIT extends BaseUniqueNamesOwnClusterIT {
         String query = "SELECT * FROM " + tableName;
         int count=100;
         for (int i = 0; i < count; i++) {
-            ResultSet rs = conn.createStatement().executeQuery(query);
-            while(rs.next()){
-                
+            try (ResultSet rs = conn.createStatement().executeQuery(query)) {
+                while (rs.next()) {
+
+                }
             }
         }
-        
         String logQuery = "SELECT * FROM " + SYSTEM_CATALOG_SCHEMA + ".\"" + SYSTEM_LOG_TABLE + "\"";
-        ResultSet rs = conn.createStatement().executeQuery(logQuery);
+        
         int delay = 5000;
 
         // sleep for sometime to let query log committed
         Thread.sleep(delay);
+        ResultSet rs = conn.createStatement().executeQuery(logQuery);
         int logCount=0;
         while (rs.next()) {
             logCount++;
@@ -186,37 +190,39 @@ public class QueryLoggerIT extends BaseUniqueNamesOwnClusterIT {
         Connection conn = DriverManager.getConnection(getUrl(),props);
         assertEquals(conn.unwrap(PhoenixConnection.class).getLogLevel(),LogLevel.INFO);
         String query = "SELECT * FROM " + tableName;
-        
-        ResultSet rs = conn.createStatement().executeQuery(query);
-        StatementContext context = ((PhoenixResultSet)rs).getContext();
-        String queryId = context.getQueryLogger().getQueryId();
-        while (rs.next()) {
-            rs.getString(1);
-            rs.getString(2);
+        StatementContext context;
+        try (ResultSet rs = conn.createStatement().executeQuery(query)) {
+            context = ((PhoenixResultSet) rs).getContext();
+            while (rs.next()) {
+                rs.getString(1);
+                rs.getString(2);
+            }
         }
+        String queryId = context.getQueryLogger().getQueryId();
 
         String logQuery = "SELECT * FROM " + SYSTEM_CATALOG_SCHEMA + ".\"" + SYSTEM_LOG_TABLE + "\"";
         int delay = 5000;
 
         // sleep for sometime to let query log committed
         Thread.sleep(delay);
-        rs = conn.createStatement().executeQuery(logQuery);
-        boolean foundQueryLog = false;
-        while (rs.next()) {
-            if (rs.getString(QUERY_ID).equals(queryId)) {
-                foundQueryLog = true;
-                assertEquals(rs.getString(USER), System.getProperty("user.name"));
-                assertEquals(rs.getString(CLIENT_IP), InetAddress.getLocalHost().getHostAddress());
-                assertEquals(rs.getString(EXPLAIN_PLAN), null);
-                assertEquals(rs.getString(GLOBAL_SCAN_DETAILS),null);
-                assertEquals(rs.getLong(NO_OF_RESULTS_ITERATED), 10);
-                assertEquals(rs.getString(QUERY), query);
-                assertEquals(rs.getString(QUERY_STATUS),QueryStatus.COMPLETED.toString());
-                assertEquals(rs.getString(TENANT_ID), null);
+        try (ResultSet rs = conn.createStatement().executeQuery(logQuery)) {
+            boolean foundQueryLog = false;
+            while (rs.next()) {
+                if (rs.getString(QUERY_ID).equals(queryId)) {
+                    foundQueryLog = true;
+                    assertEquals(rs.getString(USER), System.getProperty("user.name"));
+                    assertEquals(rs.getString(CLIENT_IP), InetAddress.getLocalHost().getHostAddress());
+                    assertEquals(rs.getString(EXPLAIN_PLAN), null);
+                    assertEquals(rs.getString(GLOBAL_SCAN_DETAILS), null);
+                    assertEquals(rs.getLong(NO_OF_RESULTS_ITERATED), 10);
+                    assertEquals(rs.getString(QUERY), query);
+                    assertEquals(rs.getString(QUERY_STATUS), QueryStatus.COMPLETED.toString());
+                    assertEquals(rs.getString(TENANT_ID), null);
+                }
             }
+            assertTrue(foundQueryLog);
+            conn.close();
         }
-        assertTrue(foundQueryLog);
-        conn.close();
     }
     
     @Test
@@ -274,46 +280,50 @@ public class QueryLoggerIT extends BaseUniqueNamesOwnClusterIT {
         final MyClock clock = new MyClock(100);
         EnvironmentEdgeManager.injectEdge(clock);
         try{
-        String query = "SELECT * FROM " + tableName +" where V = ?";
-        
-        PreparedStatement pstmt = conn.prepareStatement(query);
-        pstmt.setString(1, "value5");
-        ResultSet rs = pstmt.executeQuery();
-        StatementContext context = ((PhoenixResultSet)rs).getContext();
-        String queryId = context.getQueryLogger().getQueryId();
-        while (rs.next()) {
-            rs.getString(1);
-            rs.getString(2);
-        }
-        ResultSet explainRS = conn.createStatement()
-                .executeQuery("Explain " + "SELECT * FROM " + tableName + " where V = 'value5'");
-        String logQuery = "SELECT * FROM " + SYSTEM_CATALOG_SCHEMA + ".\"" + SYSTEM_LOG_TABLE + "\"";
-        int delay = 5000;
-
-        // sleep for sometime to let query log committed
-        Thread.sleep(delay);
-        rs = conn.createStatement().executeQuery(logQuery);
-        boolean foundQueryLog = false;
-        while (rs.next()) {
-            if (rs.getString(QUERY_ID).equals(queryId)) {
-                foundQueryLog = true;
-                assertEquals(rs.getString(BIND_PARAMETERS), loglevel == LogLevel.TRACE ? "value5" : null);
-                assertEquals(rs.getString(USER), System.getProperty("user.name"));
-                assertEquals(rs.getString(CLIENT_IP), InetAddress.getLocalHost().getHostAddress());
-                assertEquals(rs.getString(EXPLAIN_PLAN), QueryUtil.getExplainPlan(explainRS));
-                assertEquals(rs.getString(GLOBAL_SCAN_DETAILS), context.getScan().toJSON());
-                assertEquals(rs.getLong(NO_OF_RESULTS_ITERATED), 1);
-                assertEquals(rs.getString(QUERY), query);
-                assertEquals(rs.getString(QUERY_STATUS), QueryStatus.COMPLETED.toString());
-                assertTrue(LogLevel.TRACE == loglevel ? rs.getString(SCAN_METRICS_JSON).contains("scanMetrics")
-                        : rs.getString(SCAN_METRICS_JSON) == null);
-                assertEquals(rs.getTimestamp(START_TIME).getTime(),100);
-                assertEquals(rs.getString(TENANT_ID), null);
+            String query = "SELECT * FROM " + tableName +" where V = ?";
+            StatementContext context;
+            PreparedStatement pstmt = conn.prepareStatement(query);
+            pstmt.setString(1, "value5");
+            try (ResultSet rs = pstmt.executeQuery()) {
+                 context = ((PhoenixResultSet) rs).getContext();
+                while (rs.next()) {
+                    rs.getString(1);
+                    rs.getString(2);
+                }
             }
-        }
-        assertTrue(foundQueryLog);
-        conn.close();
-        }finally{
+            String queryId = context.getQueryLogger().getQueryId();
+
+            String logQuery = "SELECT * FROM " + SYSTEM_CATALOG_SCHEMA + ".\"" + SYSTEM_LOG_TABLE + "\"";
+            int delay = 5000;
+
+            // sleep for sometime to let query log committed
+            Thread.sleep(delay);
+            String explainQuery = "Explain " + "SELECT * FROM " + tableName + " where V = 'value5'";
+            try (ResultSet explainRS = conn.createStatement()
+                    .executeQuery(explainQuery);
+                 ResultSet rs = conn.createStatement().executeQuery(logQuery)) {
+                boolean foundQueryLog = false;
+                while (rs.next()) {
+                    if (rs.getString(QUERY_ID).equals(queryId)) {
+                        foundQueryLog = true;
+                        assertEquals(rs.getString(BIND_PARAMETERS), loglevel == LogLevel.TRACE ? "value5" : null);
+                        assertEquals(rs.getString(USER), System.getProperty("user.name"));
+                        assertEquals(rs.getString(CLIENT_IP), InetAddress.getLocalHost().getHostAddress());
+                        assertEquals(rs.getString(EXPLAIN_PLAN), QueryUtil.getExplainPlan(explainRS));
+                        assertEquals(rs.getString(GLOBAL_SCAN_DETAILS), context.getScan().toJSON());
+                        assertEquals(rs.getLong(NO_OF_RESULTS_ITERATED), 1);
+                        assertEquals(rs.getString(QUERY), query);
+                        assertEquals(rs.getString(QUERY_STATUS), QueryStatus.COMPLETED.toString());
+                        assertTrue(LogLevel.TRACE == loglevel ? rs.getString(SCAN_METRICS_JSON).contains("scanMetrics")
+                                : rs.getString(SCAN_METRICS_JSON) == null);
+                        assertEquals(rs.getTimestamp(START_TIME).getTime(), 100);
+                        assertEquals(rs.getString(TENANT_ID), null);
+                    }
+                }
+                assertTrue(foundQueryLog);
+                conn.close();
+            }
+        }finally {
             EnvironmentEdgeManager.injectEdge(null);
         }
     }
