@@ -46,14 +46,12 @@ import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.TableName;
-import org.apache.hadoop.hbase.client.HBaseAdmin;
+import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.SnapshotDescription;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
-import org.apache.hadoop.hbase.master.AssignmentManager;
-import org.apache.hadoop.hbase.regionserver.HRegion;
 import org.apache.hadoop.hbase.snapshot.RestoreSnapshotHelper;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.io.DoubleWritable;
-import org.apache.hadoop.hbase.protobuf.generated.HBaseProtos;
 import org.apache.hadoop.io.NullWritable;
 import org.apache.hadoop.io.Text;
 import org.apache.hadoop.mapreduce.Job;
@@ -74,7 +72,6 @@ import org.junit.Assert;
 import org.junit.Before;
 import org.junit.BeforeClass;
 import org.junit.Test;
-
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.slf4j.Logger;
@@ -126,7 +123,7 @@ public class TableSnapshotReadsMapReduceIT extends BaseUniqueNamesOwnClusterIT {
   public static synchronized void doSetup() throws Exception {
       Map<String,String> props = Maps.newHashMapWithExpectedSize(1);
       setUpTestDriver(new ReadOnlyProps(props.entrySet().iterator()));
-      getUtility().getHBaseAdmin().setBalancerRunning(false, true);
+      getUtility().getAdmin().balancerSwitch(false, true);
   }
 
   @Before
@@ -137,7 +134,6 @@ public class TableSnapshotReadsMapReduceIT extends BaseUniqueNamesOwnClusterIT {
       conn.createStatement().execute(String.format(CREATE_TABLE, tableName));
       conn.commit();
     }
-
     // configure Phoenix M/R job to read snapshot
     conf = getUtility().getConfiguration();
     job = Job.getInstance(conf);
@@ -257,7 +253,6 @@ public class TableSnapshotReadsMapReduceIT extends BaseUniqueNamesOwnClusterIT {
     job.setOutputFormatClass(PhoenixOutputFormat.class);
   }
 
-
   private void configureJob(Job job, String tableName, String inputQuery, String condition, boolean shouldSplit) throws Exception {
     try {
       upsertAndSnapshot(tableName, shouldSplit, job.getConfiguration());
@@ -368,7 +363,7 @@ public class TableSnapshotReadsMapReduceIT extends BaseUniqueNamesOwnClusterIT {
 
     TableName hbaseTableName = TableName.valueOf(tableName);
     try (Connection conn = DriverManager.getConnection(getUrl());
-         HBaseAdmin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
+         Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
 
       if (shouldSplit) {
         splitTableSync(admin, hbaseTableName, Bytes.toBytes("CCCC"), 2);
@@ -376,7 +371,7 @@ public class TableSnapshotReadsMapReduceIT extends BaseUniqueNamesOwnClusterIT {
 
       snapshotCreateSync(hbaseTableName, admin, SNAPSHOT_NAME);
 
-      List<HBaseProtos.SnapshotDescription> snapshots = admin.listSnapshots();
+      List<SnapshotDescription> snapshots = admin.listSnapshots();
       Assert.assertEquals(tableName, snapshots.get(0).getTable());
 
       // Capture the snapshot timestamp to use as SCN while reading the table later
@@ -399,10 +394,10 @@ public class TableSnapshotReadsMapReduceIT extends BaseUniqueNamesOwnClusterIT {
   }
 
   private void snapshotCreateSync(TableName hbaseTableName,
-      HBaseAdmin admin, String snapshotName) throws IOException, InterruptedException {
+      Admin admin, String snapshotName) throws IOException, InterruptedException {
     boolean isSnapshotCreated = false;
-    HBaseProtos.SnapshotDescription snapshotDescription =
-      HBaseProtos.SnapshotDescription.newBuilder().setName(snapshotName).build();
+    SnapshotDescription snapshotDescription =
+      new SnapshotDescription(snapshotName);
     // 3 retries while creating snapshot. if all 3 retries exhausted, we have
     // some valid issue.
     for (int i = 0; i < 3; i++) {
@@ -437,42 +432,13 @@ public class TableSnapshotReadsMapReduceIT extends BaseUniqueNamesOwnClusterIT {
     }
   }
 
-  private void splitTableSync(HBaseAdmin admin, TableName hbaseTableName,
-      byte[] splitPoint, int expectedRegions) throws IOException,
-      InterruptedException {
-    admin.split(hbaseTableName, splitPoint);
-    AssignmentManager assignmentManager =
-      getUtility().getHBaseCluster().getMaster().getAssignmentManager();
-    // wait for split daughter regions coming online for ~20s
-    for (int i = 0; i < 20; i++) {
-      Thread.sleep(1000);
-      List<HRegion> regions = getUtility().getHBaseCluster()
-        .getRegions(hbaseTableName);
-      if (regions.size() >= expectedRegions) {
-        boolean allRegionsOnline = true;
-        for (HRegion region : regions) {
-          if (!assignmentManager.getRegionStates()
-              .isRegionOnline(region.getRegionInfo())) {
-            allRegionsOnline = false;
-            break;
-          }
-        }
-        if (allRegionsOnline) {
-          break;
-        }
-      }
-      LOGGER.info("Sleeping for 1000 ms while waiting for {} to split and all regions to come online",
-        hbaseTableName.getNameAsString());
-    }
-  }
-
   private void deleteSnapshotIfExists(String snapshotName) throws Exception {
     try (Connection conn = DriverManager.getConnection(getUrl());
-         HBaseAdmin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
-      List<HBaseProtos.SnapshotDescription> snapshotDescriptions = admin.listSnapshots();
+         Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
+      List<SnapshotDescription> snapshotDescriptions = admin.listSnapshots();
       boolean isSnapshotPresent = false;
       if (CollectionUtils.isNotEmpty(snapshotDescriptions)) {
-        for (HBaseProtos.SnapshotDescription snapshotDescription : snapshotDescriptions) {
+        for (SnapshotDescription snapshotDescription : snapshotDescriptions) {
           if (snapshotName.equals(snapshotDescription.getName())) {
             isSnapshotPresent = true;
             break;
