@@ -35,6 +35,7 @@ import static org.junit.Assert.fail;
 
 import java.sql.Connection;
 import java.sql.DatabaseMetaData;
+import java.sql.Driver;
 import java.sql.DriverManager;
 import java.sql.ResultSet;
 import java.sql.SQLException;
@@ -45,8 +46,7 @@ import java.util.List;
 import java.util.Properties;
 import java.util.Set;
 
-import org.apache.hadoop.hbase.client.HBaseAdmin;
-import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
+import org.apache.hadoop.hbase.client.Admin;
 import org.apache.phoenix.coprocessor.TaskRegionObserver;
 import org.apache.phoenix.exception.SQLExceptionCode;
 import org.apache.phoenix.jdbc.PhoenixConnection;
@@ -61,7 +61,6 @@ import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.PropertiesUtil;
 import org.apache.phoenix.util.SchemaUtil;
 import org.apache.phoenix.util.StringUtil;
-import org.junit.BeforeClass;
 import org.junit.Test;
 
 
@@ -71,7 +70,7 @@ public class TenantSpecificTablesDDLIT extends BaseTenantSpecificTablesIT {
     public void testCreateTenantSpecificTable() throws Exception {
         // ensure we didn't create a physical HBase table for the tenant-specific table
         Connection conn = DriverManager.getConnection(getUrl(), PropertiesUtil.deepCopy(TEST_PROPERTIES));
-        HBaseAdmin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin();
+        Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin();
         assertEquals(0, admin.listTables(TENANT_TABLE_NAME).length);
     }
     
@@ -432,14 +431,51 @@ public class TenantSpecificTablesDDLIT extends BaseTenantSpecificTablesIT {
 			//Expected
 		}
 	}
-    
+
+	@Test
+    public void testShowTablesMultiTenant() throws Exception {
+        // Each tenant should only be able list tables corresponding to their TENANT_ID
+        String tenantId2 = "T_" + generateUniqueName();
+        String secondTenantConnectionURL =
+            PHOENIX_JDBC_TENANT_SPECIFIC_URL.replace(TENANT_ID,  tenantId2);
+        String tenantTable2 = "V_" + generateUniqueName();
+        createTestTable(
+            secondTenantConnectionURL, TENANT_TABLE_DDL.replace(TENANT_TABLE_NAME, tenantTable2));
+
+        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
+        // Non-tenant connections should list all the tables.
+        try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
+            Set<String> tables = new HashSet<>();
+            ResultSet rs = conn.prepareStatement("show tables").executeQuery();
+            while (rs.next()) {
+              tables.add(rs.getString("TABLE_NAME"));
+            }
+            assertTrue(tables.contains(PARENT_TABLE_NAME));
+            assertTrue(tables.contains(TENANT_TABLE_NAME));
+            assertTrue(tables.contains(tenantTable2));
+        }
+        // Tenant specific connections should not list tables from other tenants.
+        try (Connection conn = DriverManager.getConnection(secondTenantConnectionURL, props)) {
+            Set<String> tables = new HashSet<>();
+            ResultSet rs = conn.prepareStatement("show tables").executeQuery();
+            while (rs.next()) {
+              tables.add(rs.getString("TABLE_NAME"));
+            }
+            assertTrue(tables.contains(PARENT_TABLE_NAME));
+            assertFalse(tables.contains(TENANT_TABLE_NAME));
+            assertTrue(tables.contains(tenantTable2));
+        }
+    }
+
     @Test
     public void testTableMetadataScan() throws Exception {
         // create a tenant table with same name for a different tenant to make sure we are not picking it up in metadata scans for TENANT_ID
         String tenantId2 = "T_" + generateUniqueName();
-        String secondTenatConnectionURL = PHOENIX_JDBC_TENANT_SPECIFIC_URL.replace(TENANT_ID,  tenantId2);
+        String secondTenantConnectionURL =
+            PHOENIX_JDBC_TENANT_SPECIFIC_URL.replace(TENANT_ID,  tenantId2);
         String tenantTable2 = "V_" + generateUniqueName();
-        createTestTable(secondTenatConnectionURL, TENANT_TABLE_DDL.replace(TENANT_TABLE_NAME, tenantTable2));
+        createTestTable(
+            secondTenantConnectionURL, TENANT_TABLE_DDL.replace(TENANT_TABLE_NAME, tenantTable2));
         
         Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
         Connection conn = DriverManager.getConnection(getUrl(), props);
