@@ -37,6 +37,7 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.Properties;
 import java.util.Set;
 import java.util.concurrent.Callable;
@@ -51,6 +52,7 @@ import org.apache.hadoop.hbase.DoNotRetryIOException;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.coprocessor.ObserverContext;
 import org.apache.phoenix.coprocessor.BaseMetaDataEndpointObserver;
+import org.apache.phoenix.coprocessor.MetaDataEndpointObserver;
 import org.apache.phoenix.coprocessor.PhoenixMetaDataCoprocessorHost
         .PhoenixMetaDataControllerEnvironment;
 import org.apache.phoenix.exception.PhoenixIOException;
@@ -60,6 +62,7 @@ import org.apache.phoenix.schema.ConcurrentTableMutationException;
 import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.schema.PTableType;
 import org.apache.phoenix.schema.TableNotFoundException;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.PropertiesUtil;
 import org.apache.phoenix.util.ReadOnlyProps;
@@ -72,8 +75,6 @@ import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.junit.runners.Parameterized.Parameters;
 
-import com.google.common.collect.Maps;
-
 /**
  * Tests for views dealing with other ongoing concurrent operations and
  * failure scenarios
@@ -670,6 +671,14 @@ public class ViewConcurrencyAndFailureIT extends SplitSystemCatalogIT {
     public static class TestMetaDataRegionObserver
             extends BaseMetaDataEndpointObserver {
 
+        // Note that we need this in master branch since it is invoked via
+        // PhoenixObserverOperation#callObserver(). Without this, the pre-hooks
+        // of this RegionObserver will not be hit.
+        @Override
+        public Optional<MetaDataEndpointObserver> getPhoenixObserver() {
+            return Optional.of(this);
+        }
+
         @Override
         public void preAlterTable(
                 final ObserverContext<PhoenixMetaDataControllerEnvironment> ctx,
