@@ -17,7 +17,8 @@
  */
 package org.apache.phoenix.end2end;
 
-import static com.google.common.collect.Lists.newArrayListWithExpectedSize;
+import static org.apache.phoenix.thirdparty.com.google.common.collect.Lists
+        .newArrayListWithExpectedSize;
 import static org.apache.phoenix.coprocessor.PhoenixMetaDataCoprocessorHost
         .PHOENIX_META_DATA_COPROCESSOR_CONF_KEY;
 import static org.apache.phoenix.coprocessor.TaskRegionObserver.TASK_DETAILS;
@@ -62,12 +63,12 @@ import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 
-import org.apache.hadoop.hbase.HColumnDescriptor;
+import org.apache.hadoop.hbase.HBaseTestingUtility;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
-import org.apache.hadoop.hbase.client.HBaseAdmin;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
 import org.apache.hadoop.hbase.util.Bytes;
@@ -89,14 +90,13 @@ import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.QueryUtil;
 import org.apache.phoenix.util.ReadOnlyProps;
 import org.apache.phoenix.util.SchemaUtil;
-import org.apache.phoenix.util.TestUtil;
 import org.apache.phoenix.util.ViewUtil;
 import org.junit.BeforeClass;
 import org.junit.Test;
 
-import com.google.common.base.Predicate;
-import com.google.common.collect.Collections2;
-import com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.base.Predicate;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Collections2;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.junit.experimental.categories.Category;
 
 /**
@@ -154,7 +154,7 @@ public class ViewMetadataIT extends SplitSystemCatalogIT {
 
         TaskRegionEnvironment = (RegionCoprocessorEnvironment)getUtility()
                 .getRSForFirstRegionInTable(SYSTEM_TASK_HBASE_TABLE_NAME)
-                .getOnlineRegions(SYSTEM_TASK_HBASE_TABLE_NAME)
+                .getRegions(SYSTEM_TASK_HBASE_TABLE_NAME)
                 .get(0).getCoprocessorHost()
                 .findCoprocessorEnvironment(TaskRegionObserver.class.getName());
     }
@@ -185,13 +185,14 @@ public class ViewMetadataIT extends SplitSystemCatalogIT {
         String tableNameStr = generateUniqueName();
         String familyNameStr = generateUniqueName();
 
-        HBaseAdmin admin = driver.getConnectionQueryServices(getUrl(),
-                TestUtil.TEST_PROPERTIES).getAdmin();
+        TableDescriptorBuilder builder = TableDescriptorBuilder.newBuilder(
+                TableName.valueOf(tableNameStr));
+        builder.setColumnFamily(ColumnFamilyDescriptorBuilder.of(
+                familyNameStr));
 
-        HTableDescriptor desc = new HTableDescriptor(TableName.valueOf(
-                tableNameStr));
-        desc.addFamily(new HColumnDescriptor(familyNameStr));
-        admin.createTable(desc);
+        HBaseTestingUtility testUtil = getUtility();
+        Admin admin = testUtil.getAdmin();
+        admin.createTable(builder.build());
         Connection conn = DriverManager.getConnection(getUrl());
 
         //PK is not specified, without where clause
@@ -255,9 +256,10 @@ public class ViewMetadataIT extends SplitSystemCatalogIT {
             // test for a view that is in non-default schema
             {
                 TableName tableName = TableName.valueOf(NS, TBL);
-                HTableDescriptor desc = new HTableDescriptor(tableName);
-                desc.addFamily(new HColumnDescriptor(CF));
-                admin.createTable(desc);
+                TableDescriptorBuilder builder = TableDescriptorBuilder
+                        .newBuilder(tableName);
+                builder.setColumnFamily(ColumnFamilyDescriptorBuilder.of(CF));
+                admin.createTable(builder.build());
 
                 String view1 = NS + "." + TBL;
                 conn.createStatement().execute(
@@ -278,9 +280,10 @@ public class ViewMetadataIT extends SplitSystemCatalogIT {
             // default schema (for backward compatibility)
             {
                 TableName tableName = TableName.valueOf(NS + "." + TBL);
-                HTableDescriptor desc = new HTableDescriptor(tableName);
-                desc.addFamily(new HColumnDescriptor(CF));
-                admin.createTable(desc);
+                TableDescriptorBuilder builder = TableDescriptorBuilder
+                        .newBuilder(tableName);
+                builder.addColumnFamily(ColumnFamilyDescriptorBuilder.of(CF));
+                admin.createTable(builder.build());
 
                 String view2 = "\"" + NS + "." + TBL + "\"";
                 conn.createStatement().execute(
@@ -301,9 +304,10 @@ public class ViewMetadataIT extends SplitSystemCatalogIT {
             // non-default schema
             {
                 TableName tableName = TableName.valueOf(NS, NS + "." + TBL);
-                HTableDescriptor desc = new HTableDescriptor(tableName);
-                desc.addFamily(new HColumnDescriptor(CF));
-                admin.createTable(desc);
+                TableDescriptorBuilder builder = TableDescriptorBuilder
+                        .newBuilder(tableName);
+                builder.setColumnFamily(ColumnFamilyDescriptorBuilder.of(CF));
+                admin.createTable(builder.build());
 
                 String view3 = NS + ".\"" + NS + "." + TBL + "\"";
                 conn.createStatement().execute(
@@ -936,8 +940,8 @@ public class ViewMetadataIT extends SplitSystemCatalogIT {
         }
         String ddl = "CREATE TABLE " + fullTableName1
                 + " (k INTEGER NOT NULL PRIMARY KEY, v1 DATE)";
-        HBaseAdmin admin = conn.unwrap(PhoenixConnection.class)
-                .getQueryServices().getAdmin();
+        Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices()
+                .getAdmin();
         conn.createStatement().execute(ddl);
         assertTrue(admin.tableExists(SchemaUtil.getPhysicalTableName(
                 SchemaUtil.normalizeIdentifier(fullTableName1),
@@ -999,6 +1003,7 @@ public class ViewMetadataIT extends SplitSystemCatalogIT {
         ddl = "CREATE LOCAL INDEX " + indexName + " on " + fullViewName1
                 + "(v2)";
         conn.createStatement().execute(ddl);
+
         ddl = "CREATE VIEW " + fullViewName2 + "(v2 VARCHAR) AS SELECT * FROM "
                 + fullTableName + " WHERE k > 10";
         conn.createStatement().execute(ddl);
@@ -1197,6 +1202,7 @@ public class ViewMetadataIT extends SplitSystemCatalogIT {
         ddl = "CREATE INDEX " + indexName3 + " ON " + fullViewName2 + " (v2)";
         conn.createStatement().execute(ddl);
 
+
         // Execute DROP...CASCADE
         conn.createStatement().execute("DROP TABLE " + fullTableName
                 + " CASCADE");
@@ -1399,4 +1405,6 @@ public class ViewMetadataIT extends SplitSystemCatalogIT {
         assertEquals(prefix + "V3", filteredCols.iterator().next().getName()
                 .getString());
     }
+
+
 }
