@@ -20,11 +20,13 @@ package org.apache.phoenix.end2end;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.HRegionInfo;
 import org.apache.hadoop.hbase.TableName;
-import org.apache.hadoop.hbase.coprocessor.BaseWALObserver;
+import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.coprocessor.ObserverContext;
+import org.apache.hadoop.hbase.coprocessor.WALCoprocessor;
 import org.apache.hadoop.hbase.coprocessor.WALCoprocessorEnvironment;
+import org.apache.hadoop.hbase.coprocessor.WALObserver;
 import org.apache.hadoop.hbase.regionserver.wal.WALCoprocessorHost;
-import org.apache.hadoop.hbase.regionserver.wal.WALEdit;
+import org.apache.hadoop.hbase.wal.WALEdit;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.wal.WAL;
 import org.apache.hadoop.hbase.wal.WALKey;
@@ -63,6 +65,7 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
+import java.util.Optional;
 import java.util.Properties;
 
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.CHANGE_DETECTION_ENABLED;
@@ -463,7 +466,7 @@ public class WALAnnotationIT extends BaseUniqueNamesOwnClusterIT {
     }
 
     private AnnotatedWALObserver getTestCoprocessor(TableName tableName) throws IOException {
-        HRegionInfo info = getUtility().getHBaseCluster().getRegions(tableName).get(0).getRegionInfo();
+        RegionInfo info = getUtility().getHBaseCluster().getRegions(tableName).get(0).getRegionInfo();
         WAL wal = getUtility().getHBaseCluster().getRegionServer(0).getWAL(info);
         WALCoprocessorHost host = wal.getCoprocessorHost();
         return (AnnotatedWALObserver) host.findCoprocessor(AnnotatedWALObserver.class.getName());
@@ -519,7 +522,7 @@ public class WALAnnotationIT extends BaseUniqueNamesOwnClusterIT {
         return DriverManager.getConnection(getUrl(), props);
     }
 
-    public static class AnnotatedWALObserver extends BaseWALObserver {
+    public static class AnnotatedWALObserver implements WALCoprocessor, WALObserver {
         Map<TableName, List<Map<String, byte[]>>> walAnnotations = new HashMap<>();
 
         public Map<TableName, List<Map<String, byte[]>>> getWalAnnotations() {
@@ -536,16 +539,21 @@ public class WALAnnotationIT extends BaseUniqueNamesOwnClusterIT {
 
         @Override
         public void postWALWrite(ObserverContext<? extends WALCoprocessorEnvironment> ctx,
-                                 HRegionInfo info, WALKey logKey, WALEdit logEdit) throws IOException {
-            TableName tableName = logKey.getTablename();
+                                 RegionInfo info, WALKey logKey, WALEdit logEdit) throws IOException {
+            TableName tableName = logKey.getTableName();
             Map<String, byte[]> annotationMap =
                 CompatIndexRegionObserver.getAttributeValuesFromWALKey(logKey);
             if (annotationMap.size() > 0) {
                 if (!walAnnotations.containsKey(tableName)) {
                     walAnnotations.put(tableName, new ArrayList<Map<String, byte[]>>());
                 }
-                walAnnotations.get(logKey.getTablename()).add(annotationMap);
+                walAnnotations.get(logKey.getTableName()).add(annotationMap);
             }
         }
+
+        @Override
+        public Optional<WALObserver> getWALObserver() {
+            return Optional.of((WALObserver)this);
+        }
     }
 }
