@@ -34,12 +34,12 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.Properties;
 
-import org.apache.hadoop.hbase.KeyValue;
+import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.TableName;
-import org.apache.hadoop.hbase.client.HTable;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
+import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.end2end.ParallelStatsDisabledIT;
 import org.apache.phoenix.expression.KeyValueColumnExpression;
@@ -50,7 +50,6 @@ import org.apache.phoenix.query.QueryConstants;
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.schema.ColumnNotFoundException;
 import org.apache.phoenix.schema.PColumn;
-import org.apache.phoenix.schema.PName;
 import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.schema.PTableImpl;
 import org.apache.phoenix.schema.PTableKey;
@@ -198,34 +197,43 @@ public class DropColumnIT extends ParallelStatsDisabledIT {
                 scan.setRaw(true);
                 scan.setStartRow(key);
                 scan.setStopRow(key);
-                HTable table = (HTable) conn.unwrap(PhoenixConnection.class).getQueryServices().getTable(dataTableName.getBytes());
+                Table table = conn.unwrap(PhoenixConnection.class).getQueryServices().getTable(dataTableName.getBytes());
                 ResultScanner results = table.getScanner(scan);
                 Result result = results.next();
                 assertNotNull(result);
                 
-                assertEquals("data table column value should have been deleted", KeyValue.Type.DeleteColumn.getCode(), result.getColumn(QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES, dataCq).get(0).getTypeByte());
+                assertEquals("data table column value should have been deleted",
+                    Cell.Type.DeleteColumn,
+                    result.getColumnCells(QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES, dataCq).get
+                    (0).getType());
+
                 assertNull(results.next());
                 
                 // key value for v2 should have been deleted from the global index table
                 scan = new Scan();
                 scan.setRaw(true);
-                table = (HTable) conn.unwrap(PhoenixConnection.class).getQueryServices().getTable(indexTableName.getBytes());
+                table = conn.unwrap(PhoenixConnection.class).getQueryServices().getTable(indexTableName.getBytes());
                 results = table.getScanner(scan);
                 result = results.next();
                 assertNotNull(result);
-                assertEquals("data table column value should have been deleted", KeyValue.Type.DeleteColumn.getCode(), result.getColumn(QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES, globalIndexCq).get(0).getTypeByte());
+                assertEquals("data table column value should have been deleted",
+                    Cell.Type.DeleteColumn,
+                    result.getColumnCells(QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES,
+                        globalIndexCq).get(0).getType());
                 assertNull(results.next());
                 
                 // key value for v2 should have been deleted from the local index table
                 scan = new Scan();
                 scan.setRaw(true);
                 scan.addFamily(QueryConstants.DEFAULT_LOCAL_INDEX_COLUMN_FAMILY_BYTES);
-                table = (HTable) conn.unwrap(PhoenixConnection.class).getQueryServices().getTable(dataTableName.getBytes());
+                table = conn.unwrap(PhoenixConnection.class).getQueryServices().getTable(dataTableName.getBytes());
                 results = table.getScanner(scan);
                 result = results.next();
                 assertNotNull(result);
-                assertEquals("data table col"
-                        + "umn value should have been deleted", KeyValue.Type.DeleteColumn.getCode(), result.getColumn(QueryConstants.DEFAULT_LOCAL_INDEX_COLUMN_FAMILY_BYTES, localIndexCq).get(0).getTypeByte());
+                assertEquals("data table column value should have been deleted",
+                    Cell.Type.DeleteColumn,
+                    result.getColumnCells(QueryConstants.DEFAULT_LOCAL_INDEX_COLUMN_FAMILY_BYTES,
+                        localIndexCq).get(0).getType());
                 assertNull(results.next()); 
             }
             else {
@@ -248,7 +256,7 @@ public class DropColumnIT extends ParallelStatsDisabledIT {
         byte[] key = Bytes.toBytes("a");
         scan.setStartRow(key);
         scan.setStopRow(key);
-        HTable table = (HTable) conn.unwrap(PhoenixConnection.class).getQueryServices().getTable(dataTableName.getBytes());
+        Table table = conn.unwrap(PhoenixConnection.class).getQueryServices().getTable(dataTableName.getBytes());
         ResultScanner results = table.getScanner(scan);
         Result result = results.next();
         assertNotNull(result);
@@ -270,7 +278,7 @@ public class DropColumnIT extends ParallelStatsDisabledIT {
         // key value for v2 should exist in the global index table
         scan = new Scan();
         scan.setRaw(true);
-        table = (HTable) conn.unwrap(PhoenixConnection.class).getQueryServices().getTable(indexTableName.getBytes());
+        table = conn.unwrap(PhoenixConnection.class).getQueryServices().getTable(indexTableName.getBytes());
         results = table.getScanner(scan);
         result = results.next();
         assertNotNull(result);
@@ -293,7 +301,7 @@ public class DropColumnIT extends ParallelStatsDisabledIT {
         scan = new Scan();
         scan.setRaw(true);
         scan.addFamily(QueryConstants.DEFAULT_LOCAL_INDEX_COLUMN_FAMILY_BYTES);
-        table = (HTable) conn.unwrap(PhoenixConnection.class).getQueryServices().getTable(dataTableName.getBytes());
+        table = conn.unwrap(PhoenixConnection.class).getQueryServices().getTable(dataTableName.getBytes());
         results = table.getScanner(scan);
         result = results.next();
         assertNotNull(result);
@@ -320,6 +328,7 @@ public class DropColumnIT extends ParallelStatsDisabledIT {
         String localIndexTableName1 = "LOCAL_" + indexTableName + "_1";
         String localIndexTableName2 = "LOCAL_" + indexTableName + "_2";
         try (Connection conn = getConnection()) {
+
             conn.setAutoCommit(false);
             conn.createStatement().execute(
                 "CREATE TABLE " + dataTableFullName
@@ -374,8 +383,8 @@ public class DropColumnIT extends ParallelStatsDisabledIT {
             
             // verify that the regular index physical table was dropped
             try {
-                conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()
-                        .getTableDescriptor(TableName.valueOf(indexTableName));
+                conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin().getDescriptor(
+                        TableName.valueOf(indexTableName));
                 fail("Index table should have been dropped");
             } catch (org.apache.hadoop.hbase.TableNotFoundException e) {
             }
@@ -388,7 +397,7 @@ public class DropColumnIT extends ParallelStatsDisabledIT {
             // there should be a single row belonging to localIndexTableName2 
             Scan scan = new Scan();
             scan.addFamily(QueryConstants.DEFAULT_LOCAL_INDEX_COLUMN_FAMILY_BYTES);
-            HTable table = (HTable) conn.unwrap(PhoenixConnection.class).getQueryServices()
+            Table table = conn.unwrap(PhoenixConnection.class).getQueryServices()
                     .getTable(localIndexTablePhysicalName);
             ResultScanner results = table.getScanner(scan);
             Result result = results.next();
