@@ -47,22 +47,16 @@ import java.util.concurrent.ThreadFactory;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
 
-import org.apache.hadoop.hbase.HBaseIOException;
-import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellScanner;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
+import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
 import org.apache.hadoop.hbase.client.Durability;
 import org.apache.hadoop.hbase.client.HTable;
 import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.Put;
-import org.apache.hadoop.hbase.coprocessor.ObserverContext;
-import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
-import org.apache.hadoop.hbase.coprocessor.SimpleRegionObserver;
-import org.apache.hadoop.hbase.regionserver.wal.WALEdit;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
@@ -99,8 +93,8 @@ import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.junit.runners.Parameterized.Parameters;
 
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 
 
 @RunWith(Parameterized.class)
@@ -287,7 +281,7 @@ public class ImmutableIndexIT extends BaseUniqueNamesOwnClusterIT {
     }
 
     private void assertIndexMutations(Connection conn) throws SQLException {
-        Iterator<Pair<byte[], List<KeyValue>>> iterator = PhoenixRuntime.getUncommittedDataIterator(conn);
+        Iterator<Pair<byte[], List<Cell>>> iterator = PhoenixRuntime.getUncommittedDataIterator(conn);
         assertTrue(iterator.hasNext());
         iterator.next();
         assertEquals(!localIndex || 
@@ -365,6 +359,7 @@ public class ImmutableIndexIT extends BaseUniqueNamesOwnClusterIT {
                     assertEquals(true, isWriteOnDisabledIndexFailed);
                     PIndexState indexState = TestUtil.getIndexState(conn, fullIndexName);
                     assertEquals(PIndexState.ACTIVE, indexState);
+
                 }
             }
         }
@@ -510,11 +505,9 @@ public class ImmutableIndexIT extends BaseUniqueNamesOwnClusterIT {
     // used to create an index while a batch of rows are being written
     public static class CreateIndexRegionObserver extends SimpleRegionObserver {
         @Override
-        public void postPut(ObserverContext<RegionCoprocessorEnvironment> c,
-                Put put, WALEdit edit, final Durability durability)
-                        throws HBaseIOException {
-            String tableName = c.getEnvironment().getRegion().getRegionInfo()
-                    .getTable().getNameAsString();
+        public void postPut(org.apache.hadoop.hbase.coprocessor.ObserverContext<RegionCoprocessorEnvironment> c,
+                Put put, org.apache.hadoop.hbase.wal.WALEdit edit, Durability durability) throws java.io.IOException {
+            String tableName = c.getEnvironment().getRegion().getRegionInfo().getTable().getNameAsString();
             if (tableName.equalsIgnoreCase(TABLE_NAME)
                     // create the index after the second batch  
                     && Bytes.startsWith(put.getRow(), Bytes.toBytes("varchar200_upsert_select"))) {
