@@ -23,20 +23,14 @@ import org.apache.hadoop.hbase.client.Admin;
 import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
 import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
-import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.end2end.ParallelStatsDisabledIT;
 import org.apache.phoenix.hbase.index.IndexRegionObserver;
 import org.apache.phoenix.hbase.index.Indexer;
-import org.apache.phoenix.hbase.index.covered.NonTxIndexBuilder;
 import org.apache.phoenix.index.GlobalIndexChecker;
-import org.apache.phoenix.index.PhoenixIndexBuilder;
-import org.apache.phoenix.index.PhoenixIndexCodec;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.query.QueryServices;
-import org.apache.phoenix.query.QueryServicesOptions;
 import org.apache.phoenix.util.SchemaUtil;
-import org.junit.Assert;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
@@ -46,10 +40,13 @@ import java.sql.DriverManager;
 import java.sql.SQLException;
 import java.util.Arrays;
 import java.util.Collection;
-import java.util.HashMap;
-import java.util.Map;
 import java.util.Properties;
 
+import static org.apache.phoenix.end2end.index.IndexTestUtil.assertCoprocConfig;
+import static org.apache.phoenix.end2end.index.IndexTestUtil.assertCoprocsContains;
+import static org.apache.phoenix.end2end.index.IndexTestUtil.assertCoprocsNotContains;
+import static org.apache.phoenix.end2end.index.IndexTestUtil.assertUsingOldCoprocs;
+
 @RunWith(Parameterized.class)
 public class IndexCoprocIT extends ParallelStatsDisabledIT {
     private boolean isNamespaceMapped = false;
@@ -82,35 +79,15 @@ public class IndexCoprocIT extends ParallelStatsDisabledIT {
             isNamespaceMapped).getString();
         String physicalIndexName = SchemaUtil.getPhysicalHBaseTableName(schemaName,
             indexName, isNamespaceMapped).getString();
-        Admin admin = ((PhoenixConnection) getConnection()).getQueryServices().getAdmin();
+        Admin admin = getConnection().getQueryServices().getAdmin();
 
         createBaseTable(schemaName, tableName, isMultiTenant, 0, null);
         createIndexTable(schemaName, tableName, indexName);
 
-        TableDescriptor baseDescriptor = admin.getDescriptor(TableName.valueOf(physicalTableName));
-        TableDescriptorBuilder baseDescBuilder = TableDescriptorBuilder.newBuilder(baseDescriptor);
-        TableDescriptor indexDescriptor = admin.getDescriptor(TableName.valueOf(physicalIndexName));
-        TableDescriptorBuilder indexDescBuilder = TableDescriptorBuilder.newBuilder(indexDescriptor);
-
-        assertCoprocsContains(IndexRegionObserver.class, baseDescriptor);
-        assertCoprocsContains(GlobalIndexChecker.class, indexDescriptor);
-
-        removeCoproc(IndexRegionObserver.class, baseDescBuilder, admin);
-        removeCoproc(IndexRegionObserver.class, indexDescBuilder, admin);
-        removeCoproc(GlobalIndexChecker.class, indexDescBuilder, admin);
-
-        Map<String, String> props = new HashMap<String, String>();
-        props.put(NonTxIndexBuilder.CODEC_CLASS_NAME_KEY, PhoenixIndexCodec.class.getName());
-        Indexer.enableIndexing(baseDescBuilder, PhoenixIndexBuilder.class,
-            props, QueryServicesOptions.DEFAULT_COPROCESSOR_PRIORITY);
-        admin.modifyTable(baseDescBuilder.build());
-        baseDescriptor = admin.getDescriptor(TableName.valueOf(physicalTableName));
-        indexDescriptor = admin.getDescriptor(TableName.valueOf(physicalIndexName));
-        assertUsingOldCoprocs(baseDescriptor, indexDescriptor);
-
+        IndexTestUtil.downgradeCoprocs(physicalTableName, physicalIndexName, admin);
         createBaseTable(schemaName, tableName, true, 0, null);
-        baseDescriptor = admin.getDescriptor(TableName.valueOf(physicalTableName));
-        indexDescriptor = admin.getDescriptor(TableName.valueOf(physicalIndexName));
+        TableDescriptor baseDescriptor = admin.getDescriptor(TableName.valueOf(physicalTableName));
+        TableDescriptor indexDescriptor = admin.getDescriptor(TableName.valueOf(physicalIndexName));
         assertUsingOldCoprocs(baseDescriptor, indexDescriptor);
     }
 
@@ -150,7 +127,7 @@ public class IndexCoprocIT extends ParallelStatsDisabledIT {
             isNamespaceMapped).getString();
         String physicalIndexName = SchemaUtil.getPhysicalHBaseTableName(schemaName,
             indexName, isNamespaceMapped).getString();
-        Admin admin = ((PhoenixConnection) getConnection()).getQueryServices().getAdmin();
+        Admin admin = getConnection().getQueryServices().getAdmin();
 
         createBaseTable(schemaName, tableName, isMultiTenant, 0, null);
         createIndexTable(schemaName, tableName, indexName);
@@ -167,15 +144,6 @@ public class IndexCoprocIT extends ParallelStatsDisabledIT {
         assertCoprocsContains(IndexRegionObserver.class, baseDescriptor);
         assertCoprocsContains(GlobalIndexChecker.class, indexDescriptor);
     }
-    private void assertUsingOldCoprocs(TableDescriptor baseDescriptor,
-                                       TableDescriptor indexDescriptor) {
-        assertCoprocsContains(Indexer.class, baseDescriptor);
-        assertCoprocConfig(baseDescriptor, Indexer.class.getName(),
-            INDEXER_CONFIG);
-        assertCoprocsNotContains(IndexRegionObserver.class, baseDescriptor);
-        assertCoprocsNotContains(IndexRegionObserver.class, indexDescriptor);
-        assertCoprocsNotContains(GlobalIndexChecker.class, indexDescriptor);
-    }
 
     private void assertUsingNewCoprocs(TableDescriptor baseDescriptor) {
         assertCoprocsContains(IndexRegionObserver.class, baseDescriptor);
@@ -194,58 +162,6 @@ public class IndexCoprocIT extends ParallelStatsDisabledIT {
             GLOBAL_INDEX_CHECKER_CONFIG);
     }
 
-    private void assertCoprocsContains(Class clazz, TableDescriptor descriptor) {
-        String expectedCoprocName = clazz.getName();
-        boolean foundCoproc = isCoprocPresent(descriptor, expectedCoprocName);
-        Assert.assertTrue("Could not find coproc " + expectedCoprocName +
-            " in descriptor " + descriptor,foundCoproc);
-    }
-
-    private void assertCoprocsNotContains(Class clazz, TableDescriptor descriptor) {
-        String expectedCoprocName = clazz.getName();
-        boolean foundCoproc = isCoprocPresent(descriptor, expectedCoprocName);
-        Assert.assertFalse("Could find coproc " + expectedCoprocName +
-            " in descriptor " + descriptor,foundCoproc);
-    }
-
-    private boolean isCoprocPresent(TableDescriptor descriptor, String expectedCoprocName) {
-        boolean foundCoproc = false;
-        for (String coprocName : descriptor.getCoprocessors()){
-            if (coprocName.equals(expectedCoprocName)){
-                foundCoproc = true;
-                break;
-            }
-        }
-        return foundCoproc;
-    }
-
-    private void removeCoproc(Class clazz, TableDescriptorBuilder descBuilder, Admin admin) throws Exception {
-        descBuilder.removeCoprocessor(clazz.getName());
-        admin.modifyTable(descBuilder.build());
-    }
-
-    public static void assertCoprocConfig(TableDescriptor indexDesc,
-                                   String className, String expectedConfigValue){
-        boolean foundConfig = false;
-        for (Map.Entry<Bytes, Bytes> entry :
-            indexDesc.getValues().entrySet()){
-            String propKey = Bytes.toString(entry.getKey().get());
-            String propValue = Bytes.toString(entry.getValue().get());
-            //Unfortunately, a good API to read coproc properties didn't show up until
-            //HBase 2.0. Doing this the painful String-matching way to be compatible with 1.x
-            if (propKey.contains("coprocessor")){
-                if (propValue.contains(className)){
-                    Assert.assertEquals(className + " is configured incorrectly",
-                        expectedConfigValue,
-                        propValue);
-                    foundConfig = true;
-                    break;
-                }
-            }
-        }
-        Assert.assertTrue("Couldn't find config for " + className, foundConfig);
-    }
-
     private void createIndexTable(String schemaName, String tableName, String indexName)
         throws SQLException {
         Connection conn = getConnection();
@@ -300,5 +216,4 @@ public class IndexCoprocIT extends ParallelStatsDisabledIT {
         props.setProperty(QueryServices.IS_NAMESPACE_MAPPING_ENABLED, Boolean.toString(isNamespaceMapped));
         return (PhoenixConnection) DriverManager.getConnection(getUrl(),props);
     }
-
-}
+}
\ No newline at end of file
