@@ -685,12 +685,11 @@ public class IndexMetadataIT extends ParallelStatsDisabledIT {
             TestUtil.waitForIndexState(conn, indexName, PIndexState.ACTIVE);
 
             // Check task status
-            String query = "SELECT * " +
-                    " FROM " + PhoenixDatabaseMetaData.SYSTEM_TASK_NAME + " WHERE " +
+            String query = "SELECT * " + " FROM " + PhoenixDatabaseMetaData.SYSTEM_TASK_NAME + " WHERE " +
                     PhoenixDatabaseMetaData.TASK_TYPE + " = " + PTable.TaskType.INDEX_REBUILD.getSerializedValue() +
                     " AND " + PhoenixDatabaseMetaData.TABLE_NAME + " = '" + testTable + "'";
-            rs = conn.createStatement().executeQuery(query);
 
+            rs = conn.createStatement().executeQuery(query);
             assertTrue(rs.next());
             String taskStatus = rs.getString(PhoenixDatabaseMetaData.TASK_STATUS);
             assertEquals(PTable.TaskStatus.COMPLETED.toString(), taskStatus);
