@@ -19,8 +19,6 @@ package org.apache.phoenix.end2end.index;
 
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
-import org.apache.hadoop.hbase.client.HBaseAdmin;
-import org.apache.hadoop.hbase.client.HTable;
 import org.apache.hadoop.hbase.client.Put;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
@@ -34,11 +32,11 @@ import org.apache.phoenix.mapreduce.index.IndexVerificationOutputRepository;
 import org.apache.phoenix.mapreduce.index.IndexVerificationOutputRepository.IndexVerificationErrorType;
 import org.apache.phoenix.mapreduce.index.IndexVerificationOutputRow;
 import org.apache.phoenix.query.ConnectionQueryServices;
+import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.util.EnvironmentEdgeManager;
 import org.apache.phoenix.util.ManualEnvironmentEdge;
 import org.apache.phoenix.util.ReadOnlyProps;
 import org.apache.phoenix.util.TestUtil;
-import org.bouncycastle.util.Strings;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.BeforeClass;
@@ -49,7 +47,7 @@ import java.io.IOException;
 import java.sql.Connection;
 import java.sql.DriverManager;
 import java.sql.SQLException;
-import java.util.Collections;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
@@ -68,7 +66,8 @@ public class IndexVerificationOutputRepositoryIT extends ParallelStatsDisabledIT
 
     @BeforeClass
     public static synchronized void setupClass() throws Exception {
-        Map<String, String> props = Collections.emptyMap();
+        Map<String, String> props = new HashMap<>();
+        props.put(QueryServices.TASK_HANDLING_INTERVAL_MS_ATTRIB, "100000000");
         setUpTestDriver(new ReadOnlyProps(props.entrySet().iterator()));
     }
 
@@ -119,12 +118,11 @@ public class IndexVerificationOutputRepositoryIT extends ParallelStatsDisabledIT
     @Test
     public void testTTLOnOutputTable() throws SQLException, IOException {
         String mockString = "mock_value";
-        byte[] mockStringBytes = Strings.toByteArray(mockString);
-        ManualEnvironmentEdge customClock = new ManualEnvironmentEdge();
-        customClock.setValue(1);
-        EnvironmentEdgeManager.injectEdge(customClock);
+        byte[] mockStringBytes = Bytes.toBytes(mockString);
+
         try (Connection conn = DriverManager.getConnection(getUrl())) {
-            HTable hTable = new HTable(config, OUTPUT_TABLE_NAME_BYTES);
+            Table hTable = conn.unwrap(PhoenixConnection.class).getQueryServices().getTable(
+                OUTPUT_TABLE_NAME_BYTES);
 
             IndexVerificationOutputRepository
                     outputRepository =
@@ -132,11 +130,14 @@ public class IndexVerificationOutputRepositoryIT extends ParallelStatsDisabledIT
 
             outputRepository.createOutputTable(conn);
             TestUtil.assertTableHasTtl(conn, TableName.valueOf(OUTPUT_TABLE_NAME_BYTES), DEFAULT_LOG_TTL);
+            ManualEnvironmentEdge customClock = new ManualEnvironmentEdge();
+            customClock.setValue(EnvironmentEdgeManager.currentTimeMillis());
+            EnvironmentEdgeManager.injectEdge(customClock);
             outputRepository.logToIndexToolOutputTable(mockStringBytes, mockStringBytes,
                     1, 2, mockString, mockStringBytes, mockStringBytes,
                     EnvironmentEdgeManager.currentTimeMillis(), mockStringBytes, true,
                 INVALID_ROW);
-
+            customClock.incrementValue(1L);
             Assert.assertEquals(1, TestUtil.getRowCount(hTable, false));
 
             customClock.incrementValue(1000*(DEFAULT_LOG_TTL+5));
@@ -327,8 +328,8 @@ public class IndexVerificationOutputRepositoryIT extends ParallelStatsDisabledIT
             Admin admin = queryServices.getAdmin();
             TableName outputTableName = TableName.valueOf(OUTPUT_TABLE_NAME_BYTES);
             if (admin.tableExists(outputTableName)) {
-                ((HBaseAdmin) admin).disableTable(OUTPUT_TABLE_NAME_BYTES);
-                ((HBaseAdmin) admin).deleteTable(OUTPUT_TABLE_NAME_BYTES);
+                admin.disableTable(outputTableName);
+                admin.deleteTable(outputTableName);
             }
         }
         EnvironmentEdgeManager.reset();
