@@ -23,8 +23,8 @@ import java.util.Map;
 
 import org.junit.runners.Parameterized.Parameters;
 
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 
 public class HashJoinGlobalIndexIT extends HashJoinIT {
 
