@@ -65,7 +65,6 @@ import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
 
 import org.apache.hadoop.metrics2.AbstractMetric;
-import org.apache.phoenix.compat.hbase.HbaseCompatCapabilities;
 import org.apache.phoenix.compile.StatementContext;
 import org.apache.phoenix.exception.SQLExceptionCode;
 import org.apache.phoenix.jdbc.PhoenixConnection;
@@ -82,9 +81,9 @@ import org.mockito.internal.util.reflection.Whitebox;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Joiner;
-import com.google.common.collect.Lists;
-import com.google.common.collect.Sets;
+import org.apache.phoenix.thirdparty.com.google.common.base.Joiner;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Sets;
 
 /**
  * Tests that
@@ -227,10 +226,6 @@ public class PhoenixMetricsIT extends BasePhoenixMetricsIT {
     // The test sink is defined at GlobalPhoenixMetricsTestSink
     // Configuration for Hadoop-metrics2 comes from hadoop-metrics2.properties file located in test/resources
     private boolean verifyMetricsFromSink() {
-        if (!HbaseCompatCapabilities.hasNewMetrics()) {
-            //The tested functionality is missing in Hbase 1.3 see PHOENIX-4857
-            return true;
-        }
         Map<String, Long> expectedMetrics = new HashMap<>();
         for (GlobalMetric m : PhoenixRuntime.getGlobalPhoenixClientMetrics()) {
             expectedMetrics.put(m.getMetricType().name(), m.getValue());
