@@ -41,7 +41,6 @@ import java.util.concurrent.Executors;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 
-import com.google.common.util.concurrent.ThreadFactoryBuilder;
 import org.apache.phoenix.end2end.ParallelStatsDisabledIT;
 import org.apache.phoenix.jdbc.PhoenixDatabaseMetaData;
 import org.apache.phoenix.jdbc.PhoenixEmbeddedDriver;
@@ -51,6 +50,7 @@ import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.schema.MetaDataClient;
 import org.apache.phoenix.schema.PName;
 import org.apache.phoenix.schema.types.PVarchar;
+import org.apache.phoenix.thirdparty.com.google.common.util.concurrent.ThreadFactoryBuilder;
 import org.apache.phoenix.transaction.TransactionFactory;
 import org.apache.phoenix.util.PropertiesUtil;
 import org.apache.phoenix.util.SchemaUtil;
@@ -360,9 +360,9 @@ public class UpdateCacheIT extends ParallelStatsDisabledIT {
                         if (conn.isClosed()) {
                             Thread.currentThread().interrupt();
                         } else {
-                            LOGGER.error("Error while scanning "
-                                + PhoenixDatabaseMetaData.SYSTEM_MUTEX_NAME + " , thread: "
-                                + Thread.currentThread().getName(), e);
+                            LOGGER.error("Error while scanning {} , thread: {}",
+                                PhoenixDatabaseMetaData.SYSTEM_MUTEX_NAME,
+                                Thread.currentThread().getName(), e);
                         }
                     }
                 }
