@@ -51,14 +51,14 @@ import org.apache.phoenix.hbase.index.util.ImmutableBytesPtr;
 import org.apache.phoenix.memory.InsufficientMemoryException;
 import org.apache.phoenix.memory.MemoryManager.MemoryChunk;
 import org.apache.phoenix.util.Closeables;
-import org.apache.phoenix.util.KeyValueUtil;
+import org.apache.phoenix.util.PhoenixKeyValueUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 
 /**
  * The main entry point is in GroupedAggregateRegionObserver. It instantiates a SpillableGroupByCache and invokes a
- * get() method on it. There is no: "if key not exists -> put into map" case, since the cache is a Loading cache and
+ * get() method on it. There is no: {@code "if key not exists -> put into map" } case, since the cache is a Loading cache and
  * therefore handles the put under the covers. I tried to implement the final cache element accesses (RegionScanner
  * below) streaming, i.e. there is just an iterator on it and removed the existing result materialization.
  * SpillableGroupByCache implements a LRU cache using a LinkedHashMap with access order. There is a configurable an
@@ -120,10 +120,10 @@ public class SpillableGroupByCache implements GroupByCache {
     /**
      * Instantiates a Loading LRU Cache that stores key / aggregator[] tuples used for group by queries
      *
-     * @param estSize
-     * @param estValueSize
+     * @param env
+     * @param tenantId
      * @param aggs
-     * @param ctxt
+     * @param estSizeNum
      */
     public SpillableGroupByCache(final RegionCoprocessorEnvironment env, ImmutableBytesPtr tenantId,
             ServerAggregators aggs, final int estSizeNum) {
@@ -366,7 +366,7 @@ public class SpillableGroupByCache implements GroupByCache {
                             " with aggregators " + aggs.toString() + " value = " +
                             Bytes.toStringBinary(value));
                 }
-                results.add(KeyValueUtil.newKeyValue(key.get(), key.getOffset(), key.getLength(), SINGLE_COLUMN_FAMILY,
+                results.add(PhoenixKeyValueUtil.newKeyValue(key.get(), key.getOffset(), key.getLength(), SINGLE_COLUMN_FAMILY,
                         SINGLE_COLUMN, AGG_TIMESTAMP, value, 0, value.length));
                 return cacheIter.hasNext();
             }
