@@ -17,7 +17,7 @@
  */
 package org.apache.phoenix.compile;
 
-import com.google.common.base.Optional;
+import org.apache.phoenix.thirdparty.com.google.common.base.Optional;
 
 /**
  * CompiledOffset represents the result of the Compiler on the OFFSET clause.
