@@ -27,7 +27,7 @@ import java.util.List;
 import java.util.Map;
 
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.client.HTableInterface;
+import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.coprocessor.MetaDataProtocol;
 import org.apache.phoenix.coprocessor.MetaDataProtocol.MetaDataMutationResult;
@@ -94,11 +94,11 @@ import org.apache.phoenix.util.TransactionUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Preconditions;
-import com.google.common.collect.ArrayListMultimap;
-import com.google.common.collect.ImmutableList;
-import com.google.common.collect.ListMultimap;
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.base.Preconditions;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ArrayListMultimap;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableList;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ListMultimap;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 /**
  * Validates FROM clause and builds a ColumnResolver for resolving column references
@@ -185,7 +185,7 @@ public class FromCompiler {
                 boolean isNamespaceMapped = SchemaUtil.isNamespaceMappingEnabled(statement.getTableType(), connection.getQueryServices().getProps());
                 byte[] fullTableName = SchemaUtil.getPhysicalHBaseTableName(
                     baseTable.getSchemaName(), baseTable.getTableName(), isNamespaceMapped).getBytes();
-                HTableInterface htable = null;
+                Table htable = null;
                 try {
                     htable = services.getTable(fullTableName);
                 } catch (UnsupportedOperationException ignore) {
@@ -253,7 +253,7 @@ public class FromCompiler {
     }
 
     public static ColumnResolver getResolverForSchema(String schema, PhoenixConnection connection) throws SQLException {
-        return new SchemaResolver(connection, SchemaUtil.normalizeIdentifier(schema), true);
+        return new SchemaResolver(connection, schema, true);
     }
 
     public static ColumnResolver getResolver(NamedTableNode tableNode, PhoenixConnection connection) throws SQLException {
@@ -407,12 +407,12 @@ public class FromCompiler {
                     .setType(PTableType.VIEW)
                     .setViewType(PTable.ViewType.MAPPED)
                     .setTimeStamp(scn == null ? HConstants.LATEST_TIMESTAMP : scn)
-                    .setPkColumns(Collections.<PColumn>emptyList())
-                    .setAllColumns(Collections.<PColumn>emptyList())
+                    .setPkColumns(Collections.emptyList())
+                    .setAllColumns(Collections.emptyList())
                     .setRowKeySchema(RowKeySchema.EMPTY_SCHEMA)
-                    .setIndexes(Collections.<PTable>emptyList())
+                    .setIndexes(Collections.emptyList())
                     .setFamilyAttributes(families)
-                    .setPhysicalNames(Collections.<PName>emptyList())
+                    .setPhysicalNames(Collections.emptyList())
                     .setNamespaceMapped(isNamespaceMapped)
                     .build();
             theTable = this.addDynamicColumns(table.getDynamicColumns(), theTable);
@@ -952,12 +952,12 @@ public class FromCompiler {
                     .setBaseColumnCount(QueryConstants.BASE_TABLE_BASE_COLUMN_COUNT)
                     .setEncodedCQCounter(PTable.EncodedCQCounter.NULL_COUNTER)
                     .setUseStatsForParallelization(true)
-                    .setExcludedColumns(ImmutableList.<PColumn>of())
+                    .setExcludedColumns(ImmutableList.of())
                     .setSchemaName(PName.EMPTY_NAME)
                     .setTableName(PName.EMPTY_NAME)
                     .setRowKeyOrderOptimizable(false)
-                    .setIndexes(Collections.<PTable>emptyList())
-                    .setPhysicalNames(ImmutableList.<PName>of())
+                    .setIndexes(Collections.emptyList())
+                    .setPhysicalNames(ImmutableList.of())
                     .setColumns(columns)
                     .build();
 
