@@ -34,7 +34,7 @@ import java.util.ListIterator;
 import java.util.Map;
 import java.util.Set;
 
-import com.google.common.collect.ImmutableList;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableList;
 
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.util.Pair;
@@ -105,9 +105,9 @@ import org.apache.phoenix.util.ParseNodeUtil;
 import org.apache.phoenix.util.ParseNodeUtil.RewriteResult;
 import org.apache.phoenix.util.SchemaUtil;
 
-import com.google.common.base.Preconditions;
-import com.google.common.collect.Lists;
-import com.google.common.collect.Sets;
+import org.apache.phoenix.thirdparty.com.google.common.base.Preconditions;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Sets;
 
 
 public class JoinCompiler {
@@ -397,7 +397,7 @@ public class JoinCompiler {
 
         /**
          * Pruning columns for each {@link JoinCompiler.Table} if
-         * {@link @link JoinCompiler.Table#isSubselect()}.
+         * {@link JoinCompiler.Table#isSubselect()}.
          * @throws SQLException
          */
         public void pruneSubselectAliasedNodes() throws SQLException {
@@ -1569,7 +1569,7 @@ public class JoinCompiler {
                 .setBaseColumnCount(BASE_TABLE_BASE_COLUMN_COUNT)
                 .setEncodedCQCounter(PTable.EncodedCQCounter.NULL_COUNTER)
                 .setUseStatsForParallelization(left.useStatsForParallelization())
-                .setExcludedColumns(ImmutableList.<PColumn>of())
+                .setExcludedColumns(ImmutableList.of())
                 .setTenantId(left.getTenantId())
                 .setSchemaName(left.getSchemaName())
                 .setTableName(PNameFactory.newName(SchemaUtil.getTableName(left.getName().getString(),
@@ -1577,7 +1577,7 @@ public class JoinCompiler {
                 .setPkName(left.getPKName())
                 .setRowKeyOrderOptimizable(left.rowKeyOrderOptimizable())
                 .setBucketNum(left.getBucketNum())
-                .setIndexes(left.getIndexes() == null ? Collections.<PTable>emptyList() : left.getIndexes())
+                .setIndexes(left.getIndexes() == null ? Collections.emptyList() : left.getIndexes())
                 .setParentSchemaName(left.getParentSchemaName())
                 .setParentTableName(left.getParentTableName())
                 .setPhysicalNames(ImmutableList.<PName>of())
