@@ -17,6 +17,7 @@
  */
 package org.apache.phoenix.coprocessor;
 
+import org.apache.phoenix.query.QueryConstants;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.ExtendedCellBuilder;
@@ -335,6 +336,11 @@ public class AddColumnMutator implements ColumnMutator {
                                 EnvironmentEdgeManager.currentTimeMillis(), null);
                     }
                     if (familyName!=null && familyName.length > 0) {
+                        MetaDataMutationResult result =
+                                compareWithPkColumns(colName, table, familyName);
+                        if (result != null) {
+                            return result;
+                        }
                         PColumnFamily family =
                                 table.getColumnFamily(familyName);
                         family.getPColumnForColumnNameBytes(colName);
@@ -437,6 +443,24 @@ public class AddColumnMutator implements ColumnMutator {
         return null;
     }
 
+    private MetaDataMutationResult compareWithPkColumns(byte[] colName,
+            PTable table, byte[] familyName) {
+        // check if column is matching with any of pk columns if given
+        // column belongs to default CF
+        if (Bytes.compareTo(familyName, QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES) == 0
+                && colName != null && colName.length > 0) {
+            for (PColumn pColumn : table.getPKColumns()) {
+                if (Bytes.compareTo(
+                        pColumn.getName().getBytes(), colName) == 0) {
+                    return new MetaDataProtocol.MetaDataMutationResult(
+                            MetaDataProtocol.MutationCode.COLUMN_ALREADY_EXISTS,
+                            EnvironmentEdgeManager.currentTimeMillis(), table);
+                }
+            }
+        }
+        return null;
+    }
+
     @Override
     public List<Pair<PTable, PColumn>> getTableAndDroppedColumnPairs() {
         return Collections.emptyList();
