@@ -39,13 +39,15 @@ import java.util.Arrays;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
-import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.coprocessor.ObserverContext;
+import org.apache.hadoop.hbase.coprocessor.RegionCoprocessor;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
+import org.apache.hadoop.hbase.coprocessor.RegionObserver;
 import org.apache.hadoop.hbase.regionserver.Region;
 import org.apache.hadoop.hbase.regionserver.RegionScanner;
 import org.apache.hadoop.hbase.util.Bytes;
@@ -76,25 +78,31 @@ import org.apache.phoenix.util.Closeables;
 import org.apache.phoenix.util.EncodedColumnsUtil;
 import org.apache.phoenix.util.EnvironmentEdgeManager;
 import org.apache.phoenix.util.IndexUtil;
-import org.apache.phoenix.util.KeyValueUtil;
 import org.apache.phoenix.util.LogUtil;
+import org.apache.phoenix.util.PhoenixKeyValueUtil;
 import org.apache.phoenix.util.ScanUtil;
 import org.apache.phoenix.util.SizedUtil;
 import org.apache.phoenix.util.TupleUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 
 /**
  * Region observer that aggregates grouped rows (i.e. SQL query with GROUP BY clause)
  *
  * @since 0.1
  */
-public class GroupedAggregateRegionObserver extends BaseScannerRegionObserver {
+public class GroupedAggregateRegionObserver extends BaseScannerRegionObserver implements RegionCoprocessor {
     private static final Logger LOGGER = LoggerFactory
             .getLogger(GroupedAggregateRegionObserver.class);
     public static final int MIN_DISTINCT_VALUES = 100;
+    
+    @Override
+    public Optional<RegionObserver> getRegionObserver() {
+      return Optional.of(this);
+    }
+
 
     /**
      * Replaces the RegionScanner s with a RegionScanner that groups by the key formed by the list
@@ -307,7 +315,7 @@ public class GroupedAggregateRegionObserver extends BaseScannerRegionObserver {
             long estSize = sizeOfUnorderedGroupByMap(aggregateMap.size(), aggregators.getEstimatedByteSize());
             chunk.resize(estSize);
 
-            final List<KeyValue> aggResults = new ArrayList<KeyValue>(aggregateMap.size());
+            final List<Cell> aggResults = new ArrayList<Cell>(aggregateMap.size());
 
             final Iterator<Map.Entry<ImmutableBytesPtr, Aggregator[]>> cacheIter =
                     aggregateMap.entrySet().iterator();
@@ -324,8 +332,8 @@ public class GroupedAggregateRegionObserver extends BaseScannerRegionObserver {
                             + " with aggregators " + Arrays.asList(rowAggregators).toString()
                             + " value = " + Bytes.toStringBinary(value), customAnnotations));
                 }
-                KeyValue keyValue =
-                        KeyValueUtil.newKeyValue(key.get(), key.getOffset(), key.getLength(),
+                Cell keyValue =
+                        PhoenixKeyValueUtil.newKeyValue(key.get(), key.getOffset(), key.getLength(),
                             SINGLE_COLUMN_FAMILY, SINGLE_COLUMN, AGG_TIMESTAMP, value, 0,
                             value.length);
                 aggResults.add(keyValue);
@@ -380,18 +388,11 @@ public class GroupedAggregateRegionObserver extends BaseScannerRegionObserver {
         }
     }
 
-    @Override
-    protected boolean isRegionObserverFor(Scan scan) {
-        return scan.getAttribute(BaseScannerRegionObserver.UNORDERED_GROUP_BY_EXPRESSIONS) != null ||
-                scan.getAttribute(BaseScannerRegionObserver.KEY_ORDERED_GROUP_BY_EXPRESSIONS) != null;
-    }
-
     /**
      * Used for an aggregate query in which the key order does not necessarily match the group by
      * key order. In this case, we must collect all distinct groups within a region into a map,
      * aggregating as we go.
      */
-
     private static class UnorderedGroupByRegionScanner extends BaseRegionScanner {
         private final Region region;
         private final Pair<Integer, Integer> minMaxQualifiers;
@@ -402,17 +403,13 @@ public class GroupedAggregateRegionObserver extends BaseScannerRegionObserver {
         private final List<Expression> expressions;
         private final long pageSizeMs;
         private RegionScanner regionScanner = null;
-        private final boolean spillableEnabled;
         private final GroupByCache groupByCache;
 
         private UnorderedGroupByRegionScanner(final ObserverContext<RegionCoprocessorEnvironment> c,
-                                            final Scan scan, final RegionScanner scanner, final List<Expression> expressions,
-                                            final ServerAggregators aggregators, final long limit, final long pageSizeMs) {
+                                              final Scan scan, final RegionScanner scanner, final List<Expression> expressions,
+                                              final ServerAggregators aggregators, final long limit, final long pageSizeMs) {
             super(scanner);
             this.region = c.getEnvironment().getRegion();
-            minMaxQualifiers = EncodedColumnsUtil.getMinMaxQualifiersFromScan(scan);
-            useQualifierAsIndex = EncodedColumnsUtil.useQualifierAsIndex(minMaxQualifiers);
-            encodingScheme = EncodedColumnsUtil.getQualifierEncodingScheme(scan);
             this.aggregators = aggregators;
             this.limit = limit;
             this.pageSizeMs = pageSizeMs;
@@ -427,9 +424,13 @@ public class GroupedAggregateRegionObserver extends BaseScannerRegionObserver {
                         (int) (Bytes.toInt(estDistValsBytes) * 1.5f));
             }
 
-            spillableEnabled = conf.getBoolean(GROUPBY_SPILLABLE_ATTRIB, DEFAULT_GROUPBY_SPILLABLE);
-            groupByCache = GroupByCacheFactory.INSTANCE.newCache(env, ScanUtil.getTenantId(scan),
-                    ScanUtil.getCustomAnnotations(scan), aggregators, estDistVals);
+            minMaxQualifiers = EncodedColumnsUtil.getMinMaxQualifiersFromScan(scan);
+            useQualifierAsIndex = EncodedColumnsUtil.useQualifierAsIndex(EncodedColumnsUtil.getMinMaxQualifiersFromScan(scan));
+            final boolean spillableEnabled = conf.getBoolean(GROUPBY_SPILLABLE_ATTRIB, DEFAULT_GROUPBY_SPILLABLE);
+            encodingScheme = EncodedColumnsUtil.getQualifierEncodingScheme(scan);
+
+            groupByCache = GroupByCacheFactory.INSTANCE.newCache(
+                    env, ScanUtil.getTenantId(scan), ScanUtil.getCustomAnnotations(scan), aggregators, estDistVals);
             if (LOGGER.isDebugEnabled()) {
                 LOGGER.debug(LogUtil.addCustomAnnotations(
                         "Grouped aggregation over unordered rows with scan " + scan
@@ -512,7 +513,6 @@ public class GroupedAggregateRegionObserver extends BaseScannerRegionObserver {
      * Used for an aggregate query in which the key order match the group by key order. In this
      * case, we can do the aggregation as we scan, by detecting when the group by key changes.
      */
-
     private static class OrderedGroupByRegionScanner extends BaseRegionScanner {
         private final Scan scan;
         private final Region region;
@@ -521,7 +521,6 @@ public class GroupedAggregateRegionObserver extends BaseScannerRegionObserver {
         private final PTable.QualifierEncodingScheme encodingScheme;
         private final ServerAggregators aggregators;
         private final long limit;
-        private Aggregator[] rowAggregators;
         private final List<Expression> expressions;
         private final long pageSizeMs;
         private long rowCount = 0;
@@ -532,17 +531,21 @@ public class GroupedAggregateRegionObserver extends BaseScannerRegionObserver {
                                             final ServerAggregators aggregators, final long limit, final long pageSizeMs) {
             super(scanner);
             this.scan = scan;
-            this.region = c.getEnvironment().getRegion();
-            minMaxQualifiers = EncodedColumnsUtil.getMinMaxQualifiersFromScan(scan);
-            useQualifierAsIndex = EncodedColumnsUtil.useQualifierAsIndex(minMaxQualifiers);
-            encodingScheme = EncodedColumnsUtil.getQualifierEncodingScheme(scan);
             this.aggregators = aggregators;
-            rowAggregators = aggregators.getAggregators();
             this.limit = limit;
             this.pageSizeMs = pageSizeMs;
             this.expressions = expressions;
+            region = c.getEnvironment().getRegion();
+            minMaxQualifiers = EncodedColumnsUtil.getMinMaxQualifiersFromScan(scan);
+            useQualifierAsIndex = EncodedColumnsUtil.useQualifierAsIndex(minMaxQualifiers);
+            encodingScheme = EncodedColumnsUtil.getQualifierEncodingScheme(scan);
+            if (LOGGER.isDebugEnabled()) {
+                LOGGER.debug(LogUtil.addCustomAnnotations(
+                        "Grouped aggregation over ordered rows with scan " + scan + ", group by "
+                                + expressions + ", aggregators " + aggregators,
+                        ScanUtil.getCustomAnnotations(scan)));
+            }
         }
-
         @Override
         public boolean next(List<Cell> results) throws IOException {
             boolean hasMore;
@@ -552,7 +555,7 @@ public class GroupedAggregateRegionObserver extends BaseScannerRegionObserver {
             long now;
             Tuple result = useQualifierAsIndex ? new PositionBasedMultiKeyValueTuple() : new MultiKeyValueTuple();
             ImmutableBytesPtr key = null;
-
+            Aggregator[] rowAggregators = aggregators.getAggregators();
             // If we're calculating no aggregate functions, we can exit at the
             // start of a new row. Otherwise, we have to wait until an agg
             int countOffset = rowAggregators.length == 0 ? 1 : 0;
@@ -609,8 +612,8 @@ public class GroupedAggregateRegionObserver extends BaseScannerRegionObserver {
             }
             if (currentKey != null) {
                 byte[] value = aggregators.toBytes(rowAggregators);
-                KeyValue keyValue =
-                        KeyValueUtil.newKeyValue(currentKey.get(), currentKey.getOffset(),
+                Cell keyValue =
+                        PhoenixKeyValueUtil.newKeyValue(currentKey.get(), currentKey.getOffset(),
                                 currentKey.getLength(), SINGLE_COLUMN_FAMILY, SINGLE_COLUMN,
                                 AGG_TIMESTAMP, value, 0, value.length);
                 results.add(keyValue);
@@ -634,4 +637,10 @@ public class GroupedAggregateRegionObserver extends BaseScannerRegionObserver {
             return false;
         }
     }
+
+    @Override
+    protected boolean isRegionObserverFor(Scan scan) {
+        return scan.getAttribute(BaseScannerRegionObserver.UNORDERED_GROUP_BY_EXPRESSIONS) != null ||
+               scan.getAttribute(BaseScannerRegionObserver.KEY_ORDERED_GROUP_BY_EXPRESSIONS) != null;
+    }
 }
