@@ -34,7 +34,6 @@ import java.util.TreeSet;
 
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellUtil;
-import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.client.Delete;
 import org.apache.hadoop.hbase.client.Mutation;
@@ -48,6 +47,7 @@ import org.apache.hadoop.hbase.regionserver.Region;
 import org.apache.hadoop.hbase.regionserver.RegionScanner;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.query.HBaseFactoryProvider;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.phoenix.util.ByteUtil;
 import org.apache.phoenix.compile.ScanRanges;
 import org.apache.phoenix.filter.SkipScanFilter;
@@ -58,13 +58,11 @@ import org.apache.phoenix.mapreduce.index.IndexTool;
 import org.apache.phoenix.query.KeyRange;
 import org.apache.phoenix.schema.types.PLong;
 import org.apache.phoenix.schema.types.PVarbinary;
-import org.apache.phoenix.util.KeyValueUtil;
+import org.apache.phoenix.util.PhoenixKeyValueUtil;
 import org.apache.phoenix.util.ServerUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.collect.Maps;
-
 /**
  * This is an index table region scanner which scans index table rows locally and then extracts data table row keys
  * from them. Using the data table row keys, the data table rows are scanned using the HBase client available to
@@ -85,7 +83,7 @@ public class IndexRepairRegionScanner extends GlobalIndexRegionScanner {
 
         byte[] dataTableName = scan.getAttribute(PHYSICAL_DATA_TABLE_NAME);
         dataHTable = hTableFactory.getTable(new ImmutableBytesPtr(dataTableName));
-        indexTableTTL = region.getTableDesc().getColumnFamilies()[0].getTimeToLive();
+        indexTableTTL = region.getTableDescriptor().getColumnFamilies()[0].getTimeToLive();
         try (org.apache.hadoop.hbase.client.Connection connection =
                      HBaseFactoryProvider.getHConnectionFactory().createConnection(env.getConfiguration())) {
             regionEndKeys = connection.getRegionLocator(dataHTable.getName()).getEndKeys();
@@ -129,9 +127,8 @@ public class IndexRepairRegionScanner extends GlobalIndexRegionScanner {
     }
 
     protected void commitBatch(List<Mutation> indexUpdates) throws IOException, InterruptedException {
-        ungroupedAggregateRegionObserver.checkForRegionClosing();
-        region.batchMutate(indexUpdates.toArray(new Mutation[indexUpdates.size()]),
-                HConstants.NO_NONCE, HConstants.NO_NONCE);
+        ungroupedAggregateRegionObserver.checkForRegionClosingOrSplitting();
+        region.batchMutate(indexUpdates.toArray(new Mutation[indexUpdates.size()]));
     }
 
     protected void repairIndexRows(Map<byte[], List<Mutation>> indexMutationMap,
@@ -150,14 +147,16 @@ public class IndexRepairRegionScanner extends GlobalIndexRegionScanner {
         Scan dataScan = new Scan();
         dataScan.setTimeRange(scan.getTimeRange().getMin(), scan.getTimeRange().getMax());
         scanRanges.initializeScan(dataScan);
-        SkipScanFilter skipScanFilter = scanRanges.getSkipScanFilter();
-        dataScan.setFilter(new SkipScanFilter(skipScanFilter, true));
+        if(isRawFilterSupported) {
+            SkipScanFilter skipScanFilter = scanRanges.getSkipScanFilter();
+            dataScan.setFilter(new SkipScanFilter(skipScanFilter, true));
+        }
         dataScan.setRaw(true);
         dataScan.setMaxVersions();
         dataScan.setCacheBlocks(false);
         try (ResultScanner resultScanner = dataHTable.getScanner(dataScan)) {
             for (Result result = resultScanner.next(); (result != null); result = resultScanner.next()) {
-                ungroupedAggregateRegionObserver.checkForRegionClosing();
+                ungroupedAggregateRegionObserver.checkForRegionClosingOrSplitting();
                 prepareExpectedIndexMutations(result, expectedIndexMutationMap);
             }
         } catch (Throwable t) {
@@ -171,7 +170,7 @@ public class IndexRepairRegionScanner extends GlobalIndexRegionScanner {
         Scan indexScan = prepareIndexScan(expectedIndexMutationMap);
         try (RegionScanner regionScanner = region.getScanner(indexScan)) {
             do {
-                ungroupedAggregateRegionObserver.checkForRegionClosing();
+                ungroupedAggregateRegionObserver.checkForRegionClosingOrSplitting();
                 List<Cell> row = new ArrayList<Cell>();
                 hasMore = regionScanner.nextRaw(row);
                 if (!row.isEmpty()) {
@@ -193,7 +192,7 @@ public class IndexRepairRegionScanner extends GlobalIndexRegionScanner {
         indexScan.setCacheBlocks(false);
         try (RegionScanner regionScanner = region.getScanner(indexScan)) {
             do {
-                ungroupedAggregateRegionObserver.checkForRegionClosing();
+                ungroupedAggregateRegionObserver.checkForRegionClosingOrSplitting();
                 List<Cell> row = new ArrayList<Cell>();
                 hasMore = regionScanner.nextRaw(row);
                 if (!row.isEmpty()) {
@@ -244,7 +243,6 @@ public class IndexRepairRegionScanner extends GlobalIndexRegionScanner {
         }
     }
 
-
     private void addRepairAndOrVerifyTask(TaskBatch<Boolean> tasks,
                                           final Set<byte[]> dataRowKeys,
                                           final Map<byte[], List<Mutation>> actualIndexMutationMap,
@@ -253,8 +251,9 @@ public class IndexRepairRegionScanner extends GlobalIndexRegionScanner {
             @Override
             public Boolean call() throws Exception {
                 try {
-                    if (Thread.currentThread().isInterrupted() || env.getRegionServerServices().isAborted() ||
-                            env.getRegionServerServices().isStopped()) {
+                    //in HBase 1.x we could check if the coproc environment was closed or aborted,
+                    //but in HBase 2.x the coproc environment can't check region server services
+                    if (Thread.currentThread().isInterrupted()) {
                         exceptionMessage = "Pool closed, not attempting to rebuild and/or verify index rows! " + indexHTable.getName();
                         throw new IOException(exceptionMessage);
                     }
@@ -381,7 +380,7 @@ public class IndexRepairRegionScanner extends GlobalIndexRegionScanner {
                         not having this check will impact/delay the region closing -- affecting the availability
                         as this method holds the read lock on the region.
                      */
-                    ungroupedAggregateRegionObserver.checkForRegionClosing();
+                    ungroupedAggregateRegionObserver.checkForRegionClosingOrSplitting();
                     List<Cell> row = new ArrayList<Cell>();
                     hasMore = localScanner.nextRaw(row);
                     if (!row.isEmpty()) {
@@ -412,15 +411,17 @@ public class IndexRepairRegionScanner extends GlobalIndexRegionScanner {
         }
 
         if (minTimestamp != 0) {
-            nextStartKey = ByteUtil.calculateTheClosestNextRowKeyForPrefix(lastCell.getRow());
+            nextStartKey = ByteUtil.calculateTheClosestNextRowKeyForPrefix(CellUtil.cloneRow(lastCell));
         }
         byte[] rowCountBytes = PLong.INSTANCE.toBytes(Long.valueOf(rowCount));
         final Cell aggKeyValue;
         if (lastCell == null) {
-            aggKeyValue = KeyValueUtil.newKeyValue(UNGROUPED_AGG_ROW_KEY, SINGLE_COLUMN_FAMILY,
+            aggKeyValue = PhoenixKeyValueUtil.newKeyValue(UNGROUPED_AGG_ROW_KEY,
+                    SINGLE_COLUMN_FAMILY,
                     SINGLE_COLUMN, AGG_TIMESTAMP, rowCountBytes, 0, rowCountBytes.length);
         } else {
-            aggKeyValue = KeyValueUtil.newKeyValue(CellUtil.cloneRow(lastCell), SINGLE_COLUMN_FAMILY,
+            aggKeyValue = PhoenixKeyValueUtil.newKeyValue(CellUtil.cloneRow(lastCell),
+                    SINGLE_COLUMN_FAMILY,
                     SINGLE_COLUMN, AGG_TIMESTAMP, rowCountBytes, 0, rowCountBytes.length);
         }
         results.add(aggKeyValue);
