@@ -38,12 +38,12 @@ import java.util.concurrent.Future;
 
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellUtil;
-import org.apache.hadoop.hbase.HRegionInfo;
-import org.apache.hadoop.hbase.KeyValue;
+
 import org.apache.hadoop.hbase.client.Delete;
 import org.apache.hadoop.hbase.client.Durability;
 import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.Put;
+import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
@@ -65,6 +65,7 @@ import org.apache.phoenix.hbase.index.parallel.ThreadPoolBuilder;
 import org.apache.phoenix.hbase.index.parallel.ThreadPoolManager;
 import org.apache.phoenix.hbase.index.parallel.WaitForCompletionTaskRunner;
 import org.apache.phoenix.hbase.index.util.GenericKeyValueBuilder;
+
 import org.apache.phoenix.hbase.index.util.ImmutableBytesPtr;
 import org.apache.phoenix.index.PhoenixIndexCodec;
 import org.apache.phoenix.mapreduce.index.IndexTool;
@@ -72,13 +73,13 @@ import org.apache.phoenix.mapreduce.index.IndexVerificationResultRepository;
 import org.apache.phoenix.query.KeyRange;
 import org.apache.phoenix.schema.types.PLong;
 import org.apache.phoenix.schema.types.PVarbinary;
-import org.apache.phoenix.util.KeyValueUtil;
+import org.apache.phoenix.util.PhoenixKeyValueUtil;
 import org.apache.phoenix.util.ServerUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Throwables;
-import com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.base.Throwables;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 
 public class IndexerRegionScanner extends GlobalIndexRegionScanner {
 
@@ -112,7 +113,7 @@ public class IndexerRegionScanner extends GlobalIndexRegionScanner {
     }
 
     @Override
-    public HRegionInfo getRegionInfo() {
+    public RegionInfo getRegionInfo() {
         return region.getRegionInfo();
     }
 
@@ -129,11 +130,10 @@ public class IndexerRegionScanner extends GlobalIndexRegionScanner {
             }
         } finally {
             this.pool.stop("IndexerRegionScanner is closing");
-            hTableFactory.shutdown();
-            indexHTable.close();
             if (verify) {
                 verificationResultRepository.close();
             }
+            super.close();
         }
     }
 
@@ -347,7 +347,7 @@ public class IndexerRegionScanner extends GlobalIndexRegionScanner {
 
     private byte[] commitIfReady(byte[] uuidValue, UngroupedAggregateRegionObserver.MutationList mutationList) throws IOException {
         if (ServerUtil.readyToCommit(mutationList.size(), mutationList.byteSize(), maxBatchSize, maxBatchSizeBytes)) {
-            ungroupedAggregateRegionObserver.checkForRegionClosing();
+            ungroupedAggregateRegionObserver.checkForRegionClosingOrSplitting();
             ungroupedAggregateRegionObserver.commitBatchWithRetries(region, mutationList, blockingMemstoreSize);
             uuidValue = ServerCacheClient.generateId();
             mutationList.clear();
@@ -374,7 +374,7 @@ public class IndexerRegionScanner extends GlobalIndexRegionScanner {
                         Put put = null;
                         Delete del = null;
                         for (Cell cell : row) {
-                            if (KeyValue.Type.codeToType(cell.getTypeByte()) == KeyValue.Type.Put) {
+                            if (cell.getType().equals(Cell.Type.Put)) {
                                 if (!partialRebuild && familyMap != null && !isColumnIncluded(cell)) {
                                     continue;
                                 }
@@ -386,7 +386,7 @@ public class IndexerRegionScanner extends GlobalIndexRegionScanner {
                                 if (del == null) {
                                     del = new Delete(CellUtil.cloneRow(cell));
                                 }
-                                del.addDeleteMarker(cell);
+                                del.add(cell);
                             }
                         }
                         if (put == null && del == null) {
@@ -413,7 +413,7 @@ public class IndexerRegionScanner extends GlobalIndexRegionScanner {
                 if (verify) {
                     verifyIndex();
                 } else if (!mutations.isEmpty()) {
-                    ungroupedAggregateRegionObserver.checkForRegionClosing();
+                    ungroupedAggregateRegionObserver.checkForRegionClosingOrSplitting();
                     ungroupedAggregateRegionObserver.commitBatchWithRetries(region, mutations, blockingMemstoreSize);
                     mutations.clear();
                 }
@@ -432,10 +432,12 @@ public class IndexerRegionScanner extends GlobalIndexRegionScanner {
         byte[] rowCountBytes = PLong.INSTANCE.toBytes(Long.valueOf(rowCount));
         final Cell aggKeyValue;
         if (lastCell == null) {
-            aggKeyValue = KeyValueUtil.newKeyValue(UNGROUPED_AGG_ROW_KEY, SINGLE_COLUMN_FAMILY,
+            aggKeyValue = PhoenixKeyValueUtil.newKeyValue(UNGROUPED_AGG_ROW_KEY,
+                SINGLE_COLUMN_FAMILY,
                     SINGLE_COLUMN, AGG_TIMESTAMP, rowCountBytes,0, rowCountBytes.length);
         } else {
-            aggKeyValue = KeyValueUtil.newKeyValue(CellUtil.cloneRow(lastCell), SINGLE_COLUMN_FAMILY,
+            aggKeyValue = PhoenixKeyValueUtil.newKeyValue(CellUtil.cloneRow(lastCell),
+                SINGLE_COLUMN_FAMILY,
                     SINGLE_COLUMN, AGG_TIMESTAMP, rowCountBytes, 0, rowCountBytes.length);
         }
         results.add(aggKeyValue);
