@@ -22,20 +22,23 @@ import com.google.protobuf.RpcCallback;
 import com.google.protobuf.RpcController;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.AuthUtil;
-import org.apache.hadoop.hbase.CompoundConfiguration;
 import org.apache.hadoop.hbase.CoprocessorEnvironment;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
-import org.apache.hadoop.hbase.HColumnDescriptor;
-import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.NamespaceDescriptor;
 import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
 import org.apache.hadoop.hbase.client.Connection;
 import org.apache.hadoop.hbase.client.ConnectionFactory;
-import org.apache.hadoop.hbase.coprocessor.BaseMasterAndRegionObserver;
+import org.apache.hadoop.hbase.client.TableDescriptor;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
+import org.apache.hadoop.hbase.coprocessor.HasRegionServerServices;
 import org.apache.hadoop.hbase.coprocessor.MasterCoprocessorEnvironment;
+import org.apache.hadoop.hbase.coprocessor.MasterObserver;
 import org.apache.hadoop.hbase.coprocessor.ObserverContext;
+import org.apache.hadoop.hbase.coprocessor.ObserverContextImpl;
+import org.apache.hadoop.hbase.coprocessor.RegionCoprocessor;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
-import org.apache.hadoop.hbase.coprocessor.RegionServerCoprocessorEnvironment;
+import org.apache.hadoop.hbase.ipc.RpcCall;
 import org.apache.hadoop.hbase.ipc.RpcServer;
 import org.apache.hadoop.hbase.ipc.RpcUtil;
 import org.apache.hadoop.hbase.ipc.ServerRpcController;
@@ -49,14 +52,13 @@ import org.apache.hadoop.hbase.security.UserProvider;
 import org.apache.hadoop.hbase.security.access.AccessChecker;
 import org.apache.hadoop.hbase.security.access.AccessControlClient;
 import org.apache.hadoop.hbase.security.access.AccessControlConstants;
+import org.apache.hadoop.hbase.security.access.AccessControlUtil;
 import org.apache.hadoop.hbase.security.access.AuthResult;
 import org.apache.hadoop.hbase.security.access.Permission;
 import org.apache.hadoop.hbase.security.access.Permission.Action;
-import org.apache.hadoop.hbase.security.access.TableAuthManager;
 import org.apache.hadoop.hbase.security.access.UserPermission;
-import org.apache.hadoop.hbase.util.Bytes;
-import org.apache.hadoop.hbase.zookeeper.ZooKeeperWatcher;
-import org.apache.phoenix.compat.hbase.CompatObserverContext;
+import org.apache.hadoop.hbase.zookeeper.ZKWatcher;
+import org.apache.phoenix.compat.hbase.CompatPermissionUtil;
 import org.apache.phoenix.coprocessor.PhoenixMetaDataCoprocessorHost.PhoenixMetaDataControllerEnvironment;
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.query.QueryServicesOptions;
@@ -74,33 +76,41 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Optional;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicReference;
 
+import static org.apache.phoenix.compat.hbase.CompatPermissionUtil.authorizeUserTable;
+import static org.apache.phoenix.compat.hbase.CompatPermissionUtil.getPermissionFromUP;
+import static org.apache.phoenix.compat.hbase.CompatPermissionUtil.getUserFromUP;
+
 public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
 
     private PhoenixMetaDataControllerEnvironment env;
-    AtomicReference<ArrayList<BaseMasterAndRegionObserver>> accessControllers = new AtomicReference<>();
-    private boolean accessCheckEnabled;
+    AtomicReference<ArrayList<MasterObserver>> accessControllers = new AtomicReference<>();
     private boolean hbaseAccessControllerEnabled;
+    private boolean accessCheckEnabled;
     private boolean execPermissionsCheckEnabled;
     private UserProvider userProvider;
     private AccessChecker accessChecker;
     public static final Logger LOGGER = LoggerFactory.getLogger(PhoenixAccessController.class);
     private static final Logger AUDITLOG =
             LoggerFactory.getLogger("SecurityLogger."+PhoenixAccessController.class.getName());
-
-    private List<BaseMasterAndRegionObserver> getAccessControllers() throws IOException {
-        ArrayList<BaseMasterAndRegionObserver> oldAccessControllers = accessControllers.get();
+    
+    @Override
+    public Optional<MetaDataEndpointObserver> getPhoenixObserver() {
+        return Optional.of(this);
+    }
+    
+    private List<MasterObserver> getAccessControllers() throws IOException {
+        ArrayList<MasterObserver> oldAccessControllers = accessControllers.get();
         if (oldAccessControllers == null) {
             oldAccessControllers = new ArrayList<>();
             RegionCoprocessorHost cpHost = this.env.getCoprocessorHost();
-            List<BaseMasterAndRegionObserver> coprocessors = cpHost.findCoprocessors(BaseMasterAndRegionObserver.class);
-            for (BaseMasterAndRegionObserver cp : coprocessors) {
-                if (cp instanceof AccessControlService.Interface) {
-                    oldAccessControllers.add(cp);
-                    if (cp.getClass().getName().equals(
-                        org.apache.hadoop.hbase.security.access.AccessController.class.getName())) {
+            for (RegionCoprocessor cp : cpHost.findCoprocessors(RegionCoprocessor.class)) {
+                if (cp instanceof AccessControlService.Interface && cp instanceof MasterObserver) {
+                    oldAccessControllers.add((MasterObserver)cp);
+                    if(cp.getClass().getName().equals(org.apache.hadoop.hbase.security.access.AccessController.class.getName())) {
                         hbaseAccessControllerEnabled = true;
                     }
                 }
@@ -110,6 +120,10 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
         return accessControllers.get();
     }
 
+    public ObserverContext<MasterCoprocessorEnvironment> getMasterObsevrverContext() throws IOException {
+        return new ObserverContextImpl<MasterCoprocessorEnvironment>(getActiveUser());
+    }
+    
     @Override
     public void preGetTable(ObserverContext<PhoenixMetaDataControllerEnvironment> ctx, String tenantId,
             String tableName, TableName physicalTableName) throws IOException {
@@ -126,10 +140,10 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
         Configuration conf = env.getConfiguration();
         this.accessCheckEnabled = conf.getBoolean(QueryServices.PHOENIX_ACLS_ENABLED,
                 QueryServicesOptions.DEFAULT_PHOENIX_ACLS_ENABLED);
-        if (!this.accessCheckEnabled) {
-            LOGGER.warn(
+            if (!this.accessCheckEnabled) {
+                LOGGER.warn(
                         "PhoenixAccessController has been loaded with authorization checks disabled.");
-        }
+            }
         this.execPermissionsCheckEnabled = conf.getBoolean(AccessControlConstants.EXEC_PERMISSION_CHECKS_KEY,
                 AccessControlConstants.DEFAULT_EXEC_PERMISSION_CHECKS);
         if (env instanceof PhoenixMetaDataControllerEnvironment) {
@@ -138,23 +152,14 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
             throw new IllegalArgumentException(
                     "Not a valid environment, should be loaded by PhoenixMetaDataControllerEnvironment");
         }
-        CompoundConfiguration compoundConf = new CompoundConfiguration();
-        compoundConf.add(env.getConfiguration());
-        ZooKeeperWatcher zk = null;
-        if (env instanceof MasterCoprocessorEnvironment) {
-            // if running on HMaster
-            MasterCoprocessorEnvironment mEnv = (MasterCoprocessorEnvironment) env;
-            zk = mEnv.getMasterServices().getZooKeeper();
-          } else if (env instanceof RegionServerCoprocessorEnvironment) {
-            RegionServerCoprocessorEnvironment rsEnv = (RegionServerCoprocessorEnvironment) env;
-            zk = rsEnv.getRegionServerServices().getZooKeeper();
-          } else if (env instanceof RegionCoprocessorEnvironment) {
-            // if running at region
-            RegionCoprocessorEnvironment regionEnv = (RegionCoprocessorEnvironment) env;
-            compoundConf.addStringMap(regionEnv.getRegion().getTableDesc().getConfiguration());
-            zk = regionEnv.getRegionServerServices().getZooKeeper();
+
+        //2.3+ doesn't need to access ZK object.
+        ZKWatcher zk = null;
+        RegionCoprocessorEnvironment regionEnv = this.env.getRegionCoprocessorEnvironment();
+        if (regionEnv instanceof HasRegionServerServices) {
+            zk = ((HasRegionServerServices) regionEnv).getRegionServerServices().getZooKeeper();
         }
-        accessChecker = new AccessChecker(env.getConfiguration(), zk);
+        accessChecker = CompatPermissionUtil.newAccessChecker(env.getConfiguration(), zk);
         // set the user-provider.
         this.userProvider = UserProvider.instantiate(env.getConfiguration());
         // init superusers and add the server principal (if using security)
@@ -165,7 +170,7 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
     @Override
     public void stop(CoprocessorEnvironment env) throws IOException {
         if(accessChecker.getAuthManager() != null) {
-            TableAuthManager.release(accessChecker.getAuthManager());
+            CompatPermissionUtil.stopAccessChecker(accessChecker);
         }
     }
 
@@ -176,14 +181,13 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
         if (!accessCheckEnabled) { return; }
         
         if (tableType != PTableType.VIEW) {
-            final HTableDescriptor htd = new HTableDescriptor(physicalTableName);
+            TableDescriptorBuilder tableDescBuilder = TableDescriptorBuilder.newBuilder(physicalTableName);
             for (byte[] familyName : familySet) {
-                htd.addFamily(new HColumnDescriptor(familyName));
+                tableDescBuilder.addColumnFamily(ColumnFamilyDescriptorBuilder.newBuilder(familyName).build());
             }
-            for (BaseMasterAndRegionObserver observer : getAccessControllers()) {
-                observer.preCreateTable(
-                    new CompatObserverContext<MasterCoprocessorEnvironment>(getActiveUser()), htd,
-                    null);
+            final TableDescriptor htd = tableDescBuilder.build();
+            for (MasterObserver observer : getAccessControllers()) {
+                observer.preCreateTable(getMasterObsevrverContext(), htd, null);
             }
         }
 
@@ -211,22 +215,22 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
 
                 User user = getActiveUser();
                 List<UserPermission> permissionForUser = getPermissionForUser(
-                        getUserPermissions(index), Bytes.toBytes(user.getShortName()));
+                        getUserPermissions(index), user.getShortName());
                 Set<Action> requireAccess = new HashSet<>();
                 Set<Action> accessExists = new HashSet<>();
                 if (permissionForUser != null) {
                     for (UserPermission userPermission : permissionForUser) {
                         for (Action action : Arrays.asList(requiredActions)) {
-                            if (!userPermission.implies(action)) {
+                            if (!getPermissionFromUP(userPermission).implies(action)) {
                                 requireAccess.add(action);
                             }
                         }
                     }
                     if (!requireAccess.isEmpty()) {
                         for (UserPermission userPermission : permissionForUser) {
-                            accessExists.addAll(Arrays.asList(userPermission.getActions()));
+                            accessExists.addAll(Arrays.asList(
+                                getPermissionFromUP(userPermission).getActions()));
                         }
-
                     }
                 } else {
                     requireAccess.addAll(Arrays.asList(requiredActions));
@@ -302,15 +306,15 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
                             Set<Action> requireAccess = new HashSet<Action>();
                             Set<Action> accessExists = new HashSet<Action>();
                             List<UserPermission> permsToTable = getPermissionForUser(permissionsOnTheTable,
-                                    userPermission.getUser());
+                                    getUserFromUP(userPermission));
                             for (Action action : requiredActionsOnTable) {
                                 boolean haveAccess=false;
-                                if (userPermission.implies(action)) {
+                                if (getPermissionFromUP(userPermission).implies(action)) {
                                     if (permsToTable == null) {
                                         requireAccess.add(action);
                                     } else {
                                         for (UserPermission permToTable : permsToTable) {
-                                            if (permToTable.implies(action)) {
+                                            if (getPermissionFromUP(permToTable).implies(action)) {
                                                 haveAccess=true;
                                             }
                                         }
@@ -323,19 +327,21 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
                             if (permsToTable != null) {
                                 // Append access to already existing access for the user
                                 for (UserPermission permToTable : permsToTable) {
-                                    accessExists.addAll(Arrays.asList(permToTable.getActions()));
+                                    accessExists.addAll(Arrays.asList(
+                                        getPermissionFromUP(permToTable).getActions()));
                                 }
                             }
                             if (!requireAccess.isEmpty()) {
-                                if(AuthUtil.isGroupPrincipal(Bytes.toString(userPermission.getUser()))){
-                                    AUDITLOG.warn("Users of GROUP:" + Bytes.toString(userPermission.getUser())
+                                if(AuthUtil.isGroupPrincipal(getUserFromUP(userPermission))){
+                                    AUDITLOG.warn("Users of GROUP:" + getUserFromUP(userPermission)
                                             + " will not have following access " + requireAccess
                                             + " to the newly created index " + toTable
                                             + ", Automatic grant is not yet allowed on Groups");
                                     continue;
                                 }
-                                handleRequireAccessOnDependentTable(request, Bytes.toString(userPermission.getUser()),
-                                        toTable, toTable.getNameAsString(), requireAccess, accessExists);
+                                handleRequireAccessOnDependentTable(request,
+                                        getUserFromUP(userPermission), toTable,
+                                        toTable.getNameAsString(), requireAccess, accessExists);
                             }
                         }
                     }
@@ -345,13 +351,13 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
         });
     }
 
-    private List<UserPermission> getPermissionForUser(List<UserPermission> perms, byte[] user) {
+    private List<UserPermission> getPermissionForUser(List<UserPermission> perms, String user) {
         if (perms != null) {
             // get list of permissions for the user as multiple implementation of AccessControl coprocessors can give
             // permissions for same users
             List<UserPermission> permissions = new ArrayList<>();
             for (UserPermission p : perms) {
-                if (Bytes.equals(p.getUser(),user)){
+                if (getUserFromUP(p).equals(user)){
                      permissions.add(p);
                 }
             }
@@ -368,17 +374,14 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
             List<PTable> indexes) throws IOException {
         if (!accessCheckEnabled) { return; }
 
-        for (BaseMasterAndRegionObserver observer : getAccessControllers()) {
+        for (MasterObserver observer : getAccessControllers()) {
             if (tableType != PTableType.VIEW) {
-                observer.preDeleteTable(
-                    new CompatObserverContext<MasterCoprocessorEnvironment>(getActiveUser()),
-                    physicalTableName);
+                observer.preDeleteTable(getMasterObsevrverContext(), physicalTableName);
             }
             if (indexes != null) {
                 for (PTable index : indexes) {
-                    observer.preDeleteTable(
-                        new CompatObserverContext<MasterCoprocessorEnvironment>(getActiveUser()),
-                        TableName.valueOf(index.getPhysicalName().getBytes()));
+                    observer.preDeleteTable(getMasterObsevrverContext(),
+                            TableName.valueOf(index.getPhysicalName().getBytes()));
                 }
             }
         }
@@ -396,11 +399,10 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
     public void preAlterTable(ObserverContext<PhoenixMetaDataControllerEnvironment> ctx, String tenantId,
             String tableName, TableName physicalTableName, TableName parentPhysicalTableName, PTableType tableType) throws IOException {
         if (!accessCheckEnabled) { return; }
-        for (BaseMasterAndRegionObserver observer : getAccessControllers()) {
+        for (MasterObserver observer : getAccessControllers()) {
             if (tableType != PTableType.VIEW) {
-                observer.preModifyTable(
-                    new CompatObserverContext<MasterCoprocessorEnvironment>(getActiveUser()),
-                    physicalTableName, new HTableDescriptor(physicalTableName));
+            observer.preModifyTable(getMasterObsevrverContext(), physicalTableName,
+                    TableDescriptorBuilder.newBuilder(physicalTableName).build());
             }
         }
         if (tableType == PTableType.VIEW) {
@@ -416,10 +418,9 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
     public void preGetSchema(ObserverContext<PhoenixMetaDataControllerEnvironment> ctx, String schemaName)
             throws IOException {
         if (!accessCheckEnabled) { return; }
-        for (BaseMasterAndRegionObserver observer : getAccessControllers()) {
-            observer.preListNamespaceDescriptors(
-                new CompatObserverContext<MasterCoprocessorEnvironment>(getActiveUser()),
-                Arrays.asList(NamespaceDescriptor.create(schemaName).build()));
+        for (MasterObserver observer : getAccessControllers()) {
+            observer.preListNamespaceDescriptors(getMasterObsevrverContext(),
+                    Arrays.asList(NamespaceDescriptor.create(schemaName).build()));
         }
     }
 
@@ -427,10 +428,9 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
     public void preCreateSchema(ObserverContext<PhoenixMetaDataControllerEnvironment> ctx, String schemaName)
             throws IOException {
         if (!accessCheckEnabled) { return; }
-        for (BaseMasterAndRegionObserver observer : getAccessControllers()) {
-            observer.preCreateNamespace(
-                new CompatObserverContext<MasterCoprocessorEnvironment>(getActiveUser()),
-                NamespaceDescriptor.create(schemaName).build());
+        for (MasterObserver observer : getAccessControllers()) {
+            observer.preCreateNamespace(getMasterObsevrverContext(),
+                    NamespaceDescriptor.create(schemaName).build());
         }
     }
 
@@ -438,10 +438,8 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
     public void preDropSchema(ObserverContext<PhoenixMetaDataControllerEnvironment> ctx, String schemaName)
             throws IOException {
         if (!accessCheckEnabled) { return; }
-        for (BaseMasterAndRegionObserver observer : getAccessControllers()) {
-            observer.preDeleteNamespace(
-                new CompatObserverContext<MasterCoprocessorEnvironment>(getActiveUser()),
-                schemaName);
+        for (MasterObserver observer : getAccessControllers()) {
+            observer.preDeleteNamespace(getMasterObsevrverContext(), schemaName);
         }
     }
 
@@ -450,10 +448,9 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
             String indexName, TableName physicalTableName, TableName parentPhysicalTableName, PIndexState newState)
             throws IOException {
         if (!accessCheckEnabled) { return; }
-        for (BaseMasterAndRegionObserver observer : getAccessControllers()) {
-            observer.preModifyTable(
-                new CompatObserverContext<MasterCoprocessorEnvironment>(getActiveUser()),
-                physicalTableName, new HTableDescriptor(physicalTableName));
+        for (MasterObserver observer : getAccessControllers()) {
+            observer.preModifyTable(getMasterObsevrverContext(), physicalTableName,
+                    TableDescriptorBuilder.newBuilder(physicalTableName).build());
         }
         // Check for read access in case of rebuild
         if (newState == PIndexState.BUILDING) {
@@ -465,29 +462,28 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
         }
     }
 
-
     /**
-     * Gets all the permissions for a given tableName for all the users
-     * Also, get the permissions at table's namespace level and merge all of them
-     * @throws IOException
-     */
-    private List<UserPermission> getUserPermissions(final TableName tableName) throws IOException {
-
-        return User.runAsLoginUser(new PrivilegedExceptionAction<List<UserPermission>>() {
-                    @Override
+      * Gets all the permissions for a given tableName for all the users
+      * Also, get the permissions at table's namespace level and merge all of them
+      * @throws IOException
+      */
+     private List<UserPermission> getUserPermissions(final TableName tableName) throws IOException {
+         List<UserPermission> userPermissions =
+                 User.runAsLoginUser(new PrivilegedExceptionAction<List<UserPermission>>() {
+            @Override
             public List<UserPermission> run() throws Exception {
                 final List<UserPermission> userPermissions = new ArrayList<UserPermission>();
-                final RpcServer.Call rpcContext = RpcUtil.getRpcContext();
+                final RpcCall rpcContext = RpcUtil.getRpcContext();
                 try (Connection connection = ConnectionFactory.createConnection(env.getConfiguration())) {
                     // Setting RPC context as null so that user can be resetted
                     RpcUtil.setRpcContext(null);
                     // Merge permissions from all accessController coprocessors loaded in memory
-                    for (BaseMasterAndRegionObserver service : getAccessControllers()) {
+                    for (MasterObserver service : getAccessControllers()) {
                         // Use AccessControlClient API's if the accessController is an instance of org.apache.hadoop.hbase.security.access.AccessController
                         if (service.getClass().getName().equals(org.apache.hadoop.hbase.security.access.AccessController.class.getName())) {
                             userPermissions.addAll(AccessControlClient.getUserPermissions(connection, tableName.getNameAsString()));
                             userPermissions.addAll(AccessControlClient.getUserPermissions(
-                                    connection, AuthUtil.toGroupEntry(tableName.getNamespaceAsString())));
+                                     connection, AuthUtil.toGroupEntry(tableName.getNamespaceAsString())));
                         }
                     }
                 } catch (Throwable e) {
@@ -501,45 +497,49 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
                     // Setting RPC context back to original context of the RPC
                     RpcUtil.setRpcContext(rpcContext);
                 }
-                getUserDefinedPermissions(tableName, userPermissions);
-                return userPermissions;
-            }
-        });
-    }
-
-    private void getUserDefinedPermissions(final TableName tableName, final List<UserPermission> userPermissions) throws IOException {
-        User.runAsLoginUser(new PrivilegedExceptionAction<List<UserPermission>>() {
-            @Override
-            public List<UserPermission> run() throws Exception {
-                final RpcServer.Call rpcContext = RpcUtil.getRpcContext();
-                try (Connection connection =
-                        ConnectionFactory.createConnection(env.getConfiguration())) {
-                    // Setting RPC context as null so that user can be resetted
-                    RpcUtil.setRpcContext(null);
-                    for (BaseMasterAndRegionObserver service : getAccessControllers()) {
-                         if (service.getClass().getName().equals(org.apache.hadoop.hbase.security.access.AccessController.class.getName())) {
-                            continue;
-                         } else {
-                             getUserPermsFromUserDefinedAccessController(userPermissions, connection, (AccessControlService.Interface) service);
-                         }
-                    }
-                } catch (Throwable e) {
-                    if (e instanceof Exception) {
-                        throw (Exception) e;
-                    } else if (e instanceof Error) {
-                        throw (Error) e;
-                    }
-                    throw new Exception(e);
-                } finally {
-                    // Setting RPC context back to original context of the RPC
-                    RpcUtil.setRpcContext(rpcContext);
-                }
                 return userPermissions;
             }
+         });
+         getUserDefinedPermissions(tableName, userPermissions);
+         return userPermissions;
+       }
 
+     private void getUserDefinedPermissions(final TableName tableName,
+             final List<UserPermission> userPermissions) throws IOException {
+          User.runAsLoginUser(new PrivilegedExceptionAction<List<UserPermission>>() {
+              @Override
+              public List<UserPermission> run() throws Exception {
+                  final RpcCall rpcContext = RpcUtil.getRpcContext();
+                  try (Connection connection =
+                         ConnectionFactory.createConnection(((CoprocessorEnvironment) env).getConfiguration())) {
+                      // Setting RPC context as null so that user can be resetted
+                      RpcUtil.setRpcContext(null);
+                      for (MasterObserver service : getAccessControllers()) {
+                         if (service.getClass().getName().equals(
+                             org.apache.hadoop.hbase.security.access.AccessController.class
+                                     .getName())) {
+                              continue;
+                           } else {
+                             getUserPermsFromUserDefinedAccessController(userPermissions, connection,
+                                 (AccessControlService.Interface) service);
+                           }
+                      }
+                  } catch (Throwable e) {
+                      if (e instanceof Exception) {
+                          throw (Exception) e;
+                      } else if (e instanceof Error) {
+                          throw (Error) e;
+                      }
+                      throw new Exception(e);
+                  } finally {
+                      // Setting RPC context back to original context of the RPC
+                      RpcUtil.setRpcContext(rpcContext);
+                  }
+                  return userPermissions;
+              }
             private void getUserPermsFromUserDefinedAccessController(final List<UserPermission> userPermissions, Connection connection, AccessControlService.Interface service) {
 
-                ServerRpcController controller = new ServerRpcController();
+                RpcController controller = new ServerRpcController();
 
                 AccessControlProtos.GetUserPermissionsRequest.Builder builderTablePerms = AccessControlProtos.GetUserPermissionsRequest
                         .newBuilder();
@@ -562,17 +562,17 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
             private void callGetUserPermissionsRequest(final List<UserPermission> userPermissions, AccessControlService.Interface service
                     , AccessControlProtos.GetUserPermissionsRequest request, RpcController controller) {
                 service.getUserPermissions(controller, request,
-                        new RpcCallback<AccessControlProtos.GetUserPermissionsResponse>() {
-                            @Override
-                            public void run(AccessControlProtos.GetUserPermissionsResponse message) {
-                                if (message != null) {
-                                    for (AccessControlProtos.UserPermission perm : message
-                                            .getUserPermissionList()) {
-                                        userPermissions.add(ProtobufUtil.toUserPermission(perm));
-                                    }
+                    new RpcCallback<AccessControlProtos.GetUserPermissionsResponse>() {
+                        @Override
+                        public void run(AccessControlProtos.GetUserPermissionsResponse message) {
+                            if (message != null) {
+                                for (AccessControlProtos.UserPermission perm : message
+                                        .getUserPermissionList()) {
+                                    userPermissions.add(AccessControlUtil.toUserPermission(perm));
                                 }
                             }
-                        });
+                        }
+                    });
             }
         });
     }
@@ -588,6 +588,7 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
         User user = getActiveUser();
         AuthResult result = null;
         List<Action> requiredAccess = new ArrayList<Action>();
+
         for (Action permission : permissions) {
              if (hasAccess(getUserPermissions(tableName), tableName, permission, user)) {
                 result = AuthResult.allow(request, "Table permission granted", user, permission, tableName, null, null);
@@ -618,25 +619,23 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
         }
         if (perms != null) {
             if (hbaseAccessControllerEnabled
-                    && accessChecker.getAuthManager().userHasAccess(user, table, action)) {
+                    && authorizeUserTable(accessChecker, user, table, action)) {
                 return true;
             }
-            List<UserPermission> permissionsForUser = getPermissionForUser(perms, user.getShortName().getBytes());
+            List<UserPermission> permissionsForUser =
+                    getPermissionForUser(perms, user.getShortName());
             if (permissionsForUser != null) {
                 for (UserPermission permissionForUser : permissionsForUser) {
-                    if (permissionForUser.implies(action)) { return true; }
+                    if (getPermissionFromUP(permissionForUser).implies(action)) { return true; }
                 }
             }
             String[] groupNames = user.getGroupNames();
             if (groupNames != null) {
               for (String group : groupNames) {
-                List<UserPermission> groupPerms = getPermissionForUser(perms,(AuthUtil.toGroupEntry(group)).getBytes());
-                if (hbaseAccessControllerEnabled && accessChecker.getAuthManager()
-                        .groupHasAccess(group, table, action)) {
-                    return true;
-                }
+                List<UserPermission> groupPerms =
+                        getPermissionForUser(perms, (AuthUtil.toGroupEntry(group)));
                 if (groupPerms != null) for (UserPermission permissionForUser : groupPerms) {
-                    if (permissionForUser.implies(action)) { return true; }
+                    if (getPermissionFromUP(permissionForUser).implies(action)) { return true; }
                 }
               }
             }
@@ -648,20 +647,20 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
     }
 
     private User getActiveUser() throws IOException {
-        User user = RpcServer.getRequestUser();
-        if (user == null) {
+        Optional<User> user = RpcServer.getRequestUser();
+        if (!user.isPresent()) {
             // for non-rpc handling, fallback to system user
-            user = userProvider.getCurrent();
+            return userProvider.getCurrent();
         }
-        return user;
+        return user.get();
     }
 
     private void logResult(AuthResult result) {
         if (AUDITLOG.isTraceEnabled()) {
-            InetAddress remoteAddr = RpcServer.getRemoteAddress();
+            Optional<InetAddress> remoteAddr = RpcServer.getRemoteAddress();
             AUDITLOG.trace("Access " + (result.isAllowed() ? "allowed" : "denied") + " for user "
                     + (result.getUser() != null ? result.getUser().getShortName() : "UNKNOWN") + "; reason: "
-                    + result.getReason() + "; remote address: " + (remoteAddr != null ? remoteAddr : "") + "; request: "
+                    + result.getReason() + "; remote address: " + (remoteAddr.isPresent() ? remoteAddr.get() : "") + "; request: "
                     + result.getRequest() + "; context: " + result.toContextString());
         }
     }
@@ -733,6 +732,14 @@ public class PhoenixAccessController extends BaseMetaDataEndpointObserver {
             }
             return false;
         }
+
+        public static List<String> getSuperUsers() {
+            return superUsers;
+        }
+
+        public static User getSystemUser() {
+            return systemUser;
+        }
     }
     
     public String authString(String user, TableName table, Set<Action> actions) {
