@@ -34,6 +34,7 @@ import java.security.PrivilegedExceptionAction;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Optional;
 import java.util.Set;
 import java.util.concurrent.Callable;
 
@@ -43,30 +44,31 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CoprocessorEnvironment;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
-import org.apache.hadoop.hbase.HColumnDescriptor;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.HRegionInfo;
-import org.apache.hadoop.hbase.HTableDescriptor;
-import org.apache.hadoop.hbase.KeyValue;
+import org.apache.hadoop.hbase.KeepDeletedCells;
 import org.apache.hadoop.hbase.NamespaceDescriptor;
 import org.apache.hadoop.hbase.TableName;
-import org.apache.hadoop.hbase.client.HTable;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
 import org.apache.hadoop.hbase.client.Mutation;
+import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.client.Scan;
+import org.apache.hadoop.hbase.client.Table;
+import org.apache.hadoop.hbase.client.TableDescriptor;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.coprocessor.ObserverContext;
+import org.apache.hadoop.hbase.coprocessor.RegionCoprocessor;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
-import org.apache.hadoop.hbase.filter.FirstKeyOnlyFilter;
+import org.apache.hadoop.hbase.coprocessor.RegionObserver;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 import org.apache.hadoop.hbase.ipc.RpcControllerFactory;
 import org.apache.hadoop.hbase.ipc.controller.InterRegionServerIndexRpcControllerFactory;
 import org.apache.hadoop.hbase.regionserver.InternalScanner;
-import org.apache.hadoop.hbase.regionserver.KeyValueScanner;
 import org.apache.hadoop.hbase.regionserver.Region;
 import org.apache.hadoop.hbase.regionserver.RegionScanner;
-import org.apache.hadoop.hbase.regionserver.ScanInfoUtil;
+import org.apache.hadoop.hbase.regionserver.ScanOptions;
 import org.apache.hadoop.hbase.regionserver.ScanType;
 import org.apache.hadoop.hbase.regionserver.Store;
-import org.apache.hadoop.hbase.regionserver.StoreScanner;
+import org.apache.hadoop.hbase.regionserver.compactions.CompactionLifeCycleTracker;
 import org.apache.hadoop.hbase.regionserver.compactions.CompactionRequest;
 import org.apache.hadoop.hbase.security.User;
 import org.apache.hadoop.hbase.util.Bytes;
@@ -77,7 +79,6 @@ import org.apache.phoenix.exception.SQLExceptionCode;
 import org.apache.phoenix.execute.TupleProjector;
 import org.apache.phoenix.expression.Expression;
 import org.apache.phoenix.expression.ExpressionType;
-import org.apache.phoenix.filter.AllVersionsIndexRebuildFilter;
 import org.apache.phoenix.hbase.index.Indexer;
 import org.apache.phoenix.hbase.index.covered.update.ColumnReference;
 import org.apache.phoenix.hbase.index.exception.IndexWriteException;
@@ -110,7 +111,7 @@ import org.apache.phoenix.schema.types.PLong;
 import org.apache.phoenix.util.EncodedColumnsUtil;
 import org.apache.phoenix.util.EnvironmentEdgeManager;
 import org.apache.phoenix.util.IndexUtil;
-import org.apache.phoenix.util.KeyValueUtil;
+import org.apache.phoenix.util.PhoenixKeyValueUtil;
 import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.PropertiesUtil;
 import org.apache.phoenix.util.QueryUtil;
@@ -122,8 +123,8 @@ import org.apache.phoenix.util.ServerUtil.ConnectionType;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Throwables;
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.base.Throwables;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 /**
  * Region observer that aggregates ungrouped rows(i.e. SQL query with aggregation function and no GROUP BY).
@@ -131,7 +132,7 @@ import com.google.common.collect.Lists;
  *
  * @since 0.1
  */
-public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver {
+public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver implements RegionCoprocessor {
     // TODO: move all constants into a single class
     public static final String UNGROUPED_AGG = "UngroupedAgg";
     public static final String DELETE_AGG = "DeleteAgg";
@@ -174,9 +175,14 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
     private Configuration compactionConfig;
     private Configuration indexWriteConfig;
     private ReadOnlyProps indexWriteProps;
+
+    @Override
+    public Optional<RegionObserver> getRegionObserver() {
+        return Optional.of(this);
+    }
+
     @Override
     public void start(CoprocessorEnvironment e) throws IOException {
-        super.start(e);
         /*
          * We need to create a copy of region's configuration since we don't want any side effect of
          * setting the RpcControllerFactory.
@@ -189,22 +195,23 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
          * priority handlers which could result in a deadlock.
          */
         upsertSelectConfig.setClass(RpcControllerFactory.CUSTOM_CONTROLLER_CONF_KEY,
-            InterRegionServerIndexRpcControllerFactory.class, RpcControllerFactory.class);
+                InterRegionServerIndexRpcControllerFactory.class, RpcControllerFactory.class);
 
         compactionConfig = ServerUtil.getCompactionConfig(e.getConfiguration());
 
         // For retries of index write failures, use the same # of retries as the rebuilder
         indexWriteConfig = PropertiesUtil.cloneConfig(e.getConfiguration());
         indexWriteConfig.setInt(HConstants.HBASE_CLIENT_RETRIES_NUMBER,
-            e.getConfiguration().getInt(QueryServices.INDEX_REBUILD_RPC_RETRIES_COUNTER,
-                QueryServicesOptions.DEFAULT_INDEX_REBUILD_RPC_RETRIES_COUNTER));
+                e.getConfiguration().getInt(QueryServices.INDEX_REBUILD_RPC_RETRIES_COUNTER,
+                        QueryServicesOptions.DEFAULT_INDEX_REBUILD_RPC_RETRIES_COUNTER));
         indexWriteProps = new ReadOnlyProps(indexWriteConfig.iterator());
     }
 
     Configuration getUpsertSelectConfig() {
         return upsertSelectConfig;
     }
-    void incrementScansReferenceCount() throws IOException{
+
+    void incrementScansReferenceCount() throws IOException {
         synchronized (lock) {
             if (isRegionClosingOrSplitting) {
                 throw new IOException("Temporarily unable to write from scan because region is closing or splitting");
@@ -225,6 +232,7 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
             lock.notifyAll();
         }
     }
+
     void commitBatchWithRetries(final Region region, final List<Mutation> localRegionMutations, final long blockingMemstoreSize) throws IOException {
         try {
             commitBatch(region, localRegionMutations, blockingMemstoreSize);
@@ -244,16 +252,18 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
     }
 
     void commitBatch(Region region, List<Mutation> mutations, long blockingMemstoreSize) throws IOException {
-      if (mutations.isEmpty()) {
-          return;
-      }
+        if (mutations.isEmpty()) {
+            return;
+        }
 
        Mutation[] mutationArray = new Mutation[mutations.size()];
       // When memstore size reaches blockingMemstoreSize we are waiting 3 seconds for the
       // flush happen which decrease the memstore size and then writes allowed on the region.
-      for (int i = 0; blockingMemstoreSize > 0 && region.getMemstoreSize() > blockingMemstoreSize && i < 30; i++) {
+      for (int i = 0; blockingMemstoreSize > 0
+              && region.getMemStoreHeapSize() + region.getMemStoreOffHeapSize() > blockingMemstoreSize
+              && i < 30; i++) {
           try {
-              checkForRegionClosing();
+              checkForRegionClosingOrSplitting();
               Thread.sleep(100);
           } catch (InterruptedException e) {
               Thread.currentThread().interrupt();
@@ -262,10 +272,12 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
       }
       // TODO: should we use the one that is all or none?
       LOGGER.debug("Committing batch of " + mutations.size() + " mutations for " + region.getRegionInfo().getTable().getNameAsString());
-      region.batchMutate(mutations.toArray(mutationArray), HConstants.NO_NONCE, HConstants.NO_NONCE);
+      region.batchMutate(mutations.toArray(mutationArray));
     }
 
-    static void setIndexAndTransactionProperties(List<Mutation> mutations, byte[] indexUUID, byte[] indexMaintainersPtr, byte[] txState, byte[] clientVersionBytes, boolean useIndexProto) {
+    static void setIndexAndTransactionProperties(List<Mutation> mutations, byte[] indexUUID,
+                                                 byte[] indexMaintainersPtr, byte[] txState,
+                                                 byte[] clientVersionBytes, boolean useIndexProto) {
         for (Mutation m : mutations) {
            if (indexMaintainersPtr != null) {
                m.setAttribute(useIndexProto ? PhoenixIndexCodec.INDEX_PROTO_MD : PhoenixIndexCodec.INDEX_MD, indexMaintainersPtr);
@@ -282,14 +294,15 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
         }
     }
 
-    private void commitBatchWithHTable(HTable table, List<Mutation> mutations) throws IOException {
-      if (mutations.isEmpty()) {
-          return;
-      }
+    private void commitBatchWithTable(Table table, List<Mutation> mutations) throws IOException {
+        if (mutations.isEmpty()) {
+            return;
+        }
 
         LOGGER.debug("Committing batch of " + mutations.size() + " mutations for " + table);
         try {
-            table.batch(mutations);
+            Object[] results = new Object[mutations.size()];
+            table.batch(mutations, results);
         } catch (InterruptedException e) {
             Thread.currentThread().interrupt();
             throw new RuntimeException(e);
@@ -302,9 +315,9 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
      * a high chance that flush might not proceed and memstore won't be freed up.
      * @throws IOException
      */
-    void checkForRegionClosing() throws IOException {
+    void checkForRegionClosingOrSplitting() throws IOException {
         synchronized (lock) {
-            if(isRegionClosingOrSplitting) {
+            if (isRegionClosingOrSplitting) {
                 lock.notifyAll();
                 throw new IOException("Region is getting closed. Not allowing to write to avoid possible deadlock.");
             }
@@ -316,35 +329,35 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
     }
 
     @Override
-    public RegionScanner preScannerOpen(ObserverContext<RegionCoprocessorEnvironment> e, Scan scan, RegionScanner s)
+    public void preScannerOpen(ObserverContext<RegionCoprocessorEnvironment> e, Scan scan)
             throws IOException {
-        s = super.preScannerOpen(e, scan, s);
+        super.preScannerOpen(e, scan);
         if (ScanUtil.isAnalyzeTable(scan)) {
             // We are setting the start row and stop row such that it covers the entire region. As part
             // of Phonenix-1263 we are storing the guideposts against the physical table rather than
             // individual tenant specific tables.
-            scan.setStartRow(HConstants.EMPTY_START_ROW);
-            scan.setStopRow(HConstants.EMPTY_END_ROW);
+            scan.withStartRow(HConstants.EMPTY_START_ROW);
+            scan.withStopRow(HConstants.EMPTY_END_ROW);
             scan.setFilter(null);
         }
-        return s;
     }
 
     public static class MutationList extends ArrayList<Mutation> {
-        private long byteSize = 0l;
+        private long byteSize = 0L;
+
         public MutationList() {
             super();
         }
-        
-        public MutationList(int size){
+
+        public MutationList(int size) {
             super(size);
         }
-        
+
         @Override
         public boolean add(Mutation e) {
             boolean r = super.add(e);
             if (r) {
-                this.byteSize += KeyValueUtil.calculateMutationDiskSize(e);
+                this.byteSize += PhoenixKeyValueUtil.calculateMutationDiskSize(e);
             }
             return r;
         }
@@ -361,16 +374,16 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
     }
 
     static long getBlockingMemstoreSize(Region region, Configuration conf) {
-       long flushSize = region.getTableDesc().getMemStoreFlushSize();
+        long flushSize = region.getTableDescriptor().getMemStoreFlushSize();
+
+        if (flushSize <= 0) {
+            flushSize = conf.getLong(HConstants.HREGION_MEMSTORE_FLUSH_SIZE,
+                    TableDescriptorBuilder.DEFAULT_MEMSTORE_FLUSH_SIZE);
+        }
+        return flushSize * (conf.getLong(HConstants.HREGION_MEMSTORE_BLOCK_MULTIPLIER,
+                HConstants.DEFAULT_HREGION_MEMSTORE_BLOCK_MULTIPLIER) - 1);
+    }
 
-       if (flushSize <= 0) {
-           flushSize = conf.getLong(HConstants.HREGION_MEMSTORE_FLUSH_SIZE,
-                   HTableDescriptor.DEFAULT_MEMSTORE_FLUSH_SIZE);
-       }
-       return flushSize * (conf.getLong(HConstants.HREGION_MEMSTORE_BLOCK_MULTIPLIER,
-                   HConstants.DEFAULT_HREGION_MEMSTORE_BLOCK_MULTIPLIER)-1);
-   }
-    
     @Override
     protected RegionScanner doPostScannerOpen(final ObserverContext<RegionCoprocessorEnvironment> c, final Scan scan,
                                               final RegionScanner s) throws IOException, SQLException {
@@ -440,15 +453,15 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
                             region, indexMaintainers == null ? null : indexMaintainers.get(0), viewConstants, p, tempPtr, useQualifierAsIndex);
         }
 
-        if (j != null)  {
+        if (j != null) {
             theScanner = new HashJoinRegionScanner(theScanner, scan, p, j, ScanUtil.getTenantId(scan), env, useQualifierAsIndex, useNewValueColumnQualifier);
         }
-        return new UngroupedAggregateRegionScanner(c, theScanner,region, scan, env, this);
+        return new UngroupedAggregateRegionScanner(c, theScanner, region, scan, env, this);
     }
 
-    static void checkForLocalIndexColumnFamilies(Region region,
-            List<IndexMaintainer> indexMaintainers) throws IOException {
-        HTableDescriptor tableDesc = region.getTableDesc();
+    public static void checkForLocalIndexColumnFamilies(Region region,
+                                                        List<IndexMaintainer> indexMaintainers) throws IOException {
+        TableDescriptor tableDesc = region.getTableDescriptor();
         String schemaName =
                 tableDesc.getTableName().getNamespaceAsString()
                         .equals(NamespaceDescriptor.DEFAULT_NAMESPACE_NAME_STR) ? SchemaUtil
@@ -457,43 +470,43 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
         String tableName = SchemaUtil.getTableNameFromFullName(tableDesc.getTableName().getNameAsString());
         for (IndexMaintainer indexMaintainer : indexMaintainers) {
             Set<ColumnReference> coveredColumns = indexMaintainer.getCoveredColumns();
-            if(coveredColumns.isEmpty()) {
+            if (coveredColumns.isEmpty()) {
                 byte[] localIndexCf = indexMaintainer.getEmptyKeyValueFamily().get();
                 // When covered columns empty we store index data in default column family so check for it.
-                if (tableDesc.getFamily(localIndexCf) == null) {
+                if (tableDesc.getColumnFamily(localIndexCf) == null) {
                     ServerUtil.throwIOException("Column Family Not Found",
-                        new ColumnFamilyNotFoundException(schemaName, tableName, Bytes
-                                .toString(localIndexCf)));
+                            new ColumnFamilyNotFoundException(schemaName, tableName, Bytes
+                                    .toString(localIndexCf)));
                 }
             }
             for (ColumnReference reference : coveredColumns) {
                 byte[] cf = IndexUtil.getLocalIndexColumnFamily(reference.getFamily());
-                HColumnDescriptor family = region.getTableDesc().getFamily(cf);
+                ColumnFamilyDescriptor family = region.getTableDescriptor().getColumnFamily(cf);
                 if (family == null) {
                     ServerUtil.throwIOException("Column Family Not Found",
-                        new ColumnFamilyNotFoundException(schemaName, tableName, Bytes.toString(cf)));
+                            new ColumnFamilyNotFoundException(schemaName, tableName, Bytes.toString(cf)));
                 }
             }
         }
     }
 
     void commit(final Region region, List<Mutation> mutations, byte[] indexUUID, final long blockingMemStoreSize,
-            byte[] indexMaintainersPtr, byte[] txState, final HTable targetHTable, boolean useIndexProto,
-                        boolean isPKChanging, byte[] clientVersionBytes)
+                byte[] indexMaintainersPtr, byte[] txState, final Table targetHTable, boolean useIndexProto,
+                boolean isPKChanging, byte[] clientVersionBytes)
             throws IOException {
         final List<Mutation> localRegionMutations = Lists.newArrayList();
         final List<Mutation> remoteRegionMutations = Lists.newArrayList();
         setIndexAndTransactionProperties(mutations, indexUUID, indexMaintainersPtr, txState, clientVersionBytes, useIndexProto);
         separateLocalAndRemoteMutations(targetHTable, region, mutations, localRegionMutations, remoteRegionMutations,
-            isPKChanging);
+                isPKChanging);
         commitBatchWithRetries(region, localRegionMutations, blockingMemStoreSize);
         try {
-            commitBatchWithHTable(targetHTable, remoteRegionMutations);
+            commitBatchWithTable(targetHTable, remoteRegionMutations);
         } catch (IOException e) {
             handleIndexWriteException(remoteRegionMutations, e, new MutateCommand() {
                 @Override
                 public void doMutation() throws IOException {
-                    commitBatchWithHTable(targetHTable, remoteRegionMutations);
+                    commitBatchWithTable(targetHTable, remoteRegionMutations);
                 }
 
                 @Override
@@ -507,7 +520,7 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
     }
 
     private void handleIndexWriteException(final List<Mutation> localRegionMutations, IOException origIOE,
-            MutateCommand mutateCommand) throws IOException {
+                                           MutateCommand mutateCommand) throws IOException {
         long serverTimestamp = ServerUtil.parseTimestampFromRemoteException(origIOE);
         SQLException inferredE = ServerUtil.parseLocalOrRemoteServerException(origIOE);
         if (inferredE != null && inferredE.getErrorCode() == SQLExceptionCode.INDEX_WRITE_FAILURE.getErrorCode()) {
@@ -516,20 +529,20 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
             for (Mutation mutation : localRegionMutations) {
                 if (PhoenixIndexMetaData.isIndexRebuild(mutation.getAttributesMap())) {
                     mutation.setAttribute(BaseScannerRegionObserver.REPLAY_WRITES,
-                        BaseScannerRegionObserver.REPLAY_INDEX_REBUILD_WRITES);
+                            BaseScannerRegionObserver.REPLAY_INDEX_REBUILD_WRITES);
                 } else {
                     mutation.setAttribute(BaseScannerRegionObserver.REPLAY_WRITES,
-                        BaseScannerRegionObserver.REPLAY_ONLY_INDEX_WRITES);
+                            BaseScannerRegionObserver.REPLAY_ONLY_INDEX_WRITES);
                 }
                 // use the server timestamp for index write retrys
-                KeyValueUtil.setTimestamp(mutation, serverTimestamp);
+                PhoenixKeyValueUtil.setTimestamp(mutation, serverTimestamp);
             }
             IndexWriteException iwe = PhoenixIndexFailurePolicy.getIndexWriteException(inferredE);
             try (PhoenixConnection conn =
-                    QueryUtil.getConnectionOnServer(indexWriteConfig)
-                            .unwrap(PhoenixConnection.class)) {
+                         QueryUtil.getConnectionOnServer(indexWriteConfig)
+                                 .unwrap(PhoenixConnection.class)) {
                 PhoenixIndexFailurePolicy.doBatchWithRetries(mutateCommand, iwe, conn,
-                    indexWriteProps);
+                        indexWriteProps);
             } catch (Exception e) {
                 throw new DoNotRetryIOException(e);
             }
@@ -538,16 +551,16 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
         }
     }
 
-    private void separateLocalAndRemoteMutations(HTable targetHTable, Region region, List<Mutation> mutations,
+    private void separateLocalAndRemoteMutations(Table targetHTable, Region region, List<Mutation> mutations,
                                                  List<Mutation> localRegionMutations, List<Mutation> remoteRegionMutations,
-                                                 boolean isPKChanging){
+                                                 boolean isPKChanging) {
         boolean areMutationsInSameTable = areMutationsInSameTable(targetHTable, region);
         //if we're writing to the same table, but the PK can change, that means that some
         //mutations might be in our current region, and others in a different one.
         if (areMutationsInSameTable && isPKChanging) {
-            HRegionInfo regionInfo = region.getRegionInfo();
-            for (Mutation mutation : mutations){
-                if (regionInfo.containsRow(mutation.getRow())){
+            RegionInfo regionInfo = region.getRegionInfo();
+            for (Mutation mutation : mutations) {
+                if (regionInfo.containsRow(mutation.getRow())) {
                     localRegionMutations.add(mutation);
                 } else {
                     remoteRegionMutations.add(mutation);
@@ -560,15 +573,15 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
         }
     }
 
-    private boolean areMutationsInSameTable(HTable targetHTable, Region region) {
-        return (targetHTable == null || Bytes.compareTo(targetHTable.getTableName(),
-                region.getTableDesc().getTableName().getName()) == 0);
+    private boolean areMutationsInSameTable(Table targetHTable, Region region) {
+        return (targetHTable == null || Bytes.compareTo(targetHTable.getName().getName(),
+                region.getTableDescriptor().getTableName().getName()) == 0);
     }
 
     @Override
-    public InternalScanner preCompact(final ObserverContext<RegionCoprocessorEnvironment> c,
-            final Store store, final InternalScanner scanner, final ScanType scanType)
-                    throws IOException {
+    public InternalScanner preCompact(ObserverContext<RegionCoprocessorEnvironment> c, Store store,
+                                      InternalScanner scanner, ScanType scanType, CompactionLifeCycleTracker tracker,
+                                      CompactionRequest request) throws IOException {
         if (scanType.equals(ScanType.COMPACT_DROP_DELETES)) {
             final TableName table = c.getEnvironment().getRegion().getRegionInfo().getTable();
             // Compaction and split upcalls run with the effective user context of the requesting user.
@@ -576,7 +589,8 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
             // the login user. Switch to the login user context to ensure we have the expected
             // security context.
             return User.runAsLoginUser(new PrivilegedExceptionAction<InternalScanner>() {
-                @Override public InternalScanner run() throws Exception {
+                @Override
+                public InternalScanner run() throws Exception {
                     InternalScanner internalScanner = scanner;
                     try {
                         long clientTimeStamp = EnvironmentEdgeManager.currentTimeMillis();
@@ -584,8 +598,8 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
                                 new DelegateRegionCoprocessorEnvironment(c.getEnvironment(),
                                         ConnectionType.COMPACTION_CONNECTION);
                         StatisticsCollector statisticsCollector = StatisticsCollectorFactory.createStatisticsCollector(
-                            compactionConfEnv, table.getNameAsString(), clientTimeStamp,
-                            store.getFamily().getName());
+                                compactionConfEnv, table.getNameAsString(), clientTimeStamp,
+                                store.getColumnFamilyDescriptor().getName());
                         statisticsCollector.init();
                         internalScanner = statisticsCollector.createCompactionScanner(compactionConfEnv, store, internalScanner);
                     } catch (Exception e) {
@@ -617,7 +631,7 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
         if (oldCoproc) {
             return new IndexerRegionScanner(innerScanner, region, scan, env, this);
         } else {
-            if (region.getTableDesc().hasCoprocessor(GlobalIndexChecker.class.getCanonicalName())) {
+            if (region.getTableDescriptor().hasCoprocessor(GlobalIndexChecker.class.getCanonicalName())) {
                 return new IndexRepairRegionScanner(innerScanner, region, scan, env, this);
             } else {
                 return new IndexRebuildRegionScanner(innerScanner, region, scan, env, this);
@@ -627,18 +641,18 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
 
     private RegionScanner rebuildIndices(RegionScanner innerScanner, final Region region, final Scan scan,
                                          final RegionCoprocessorEnvironment env) throws IOException {
-        boolean oldCoproc = region.getTableDesc().hasCoprocessor(Indexer.class.getCanonicalName());
+        boolean oldCoproc = region.getTableDescriptor().hasCoprocessor(Indexer.class.getCanonicalName());
         byte[] valueBytes = scan.getAttribute(BaseScannerRegionObserver.INDEX_REBUILD_VERIFY_TYPE);
         IndexTool.IndexVerifyType verifyType = (valueBytes != null) ?
                 IndexTool.IndexVerifyType.fromValue(valueBytes) : IndexTool.IndexVerifyType.NONE;
-        if (oldCoproc  && verifyType == IndexTool.IndexVerifyType.ONLY) {
+        if (oldCoproc && verifyType == IndexTool.IndexVerifyType.ONLY) {
             return new IndexerRegionScanner(innerScanner, region, scan, env, this);
         }
         RegionScanner scanner;
         if (!scan.isRaw()) {
             Scan rawScan = new Scan(scan);
             rawScan.setRaw(true);
-            rawScan.setMaxVersions();
+            rawScan.readAllVersions();
             rawScan.getFamilyMap().clear();
             adjustScanFilter(rawScan);
             rawScan.setCacheBlocks(false);
@@ -657,9 +671,9 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
         }
         return getRegionScanner(scanner, region, scan, env, oldCoproc);
     }
-    
+
     private RegionScanner collectStats(final RegionScanner innerScanner, StatisticsCollector stats,
-            final Region region, final Scan scan, Configuration config) throws IOException {
+                                       final Region region, final Scan scan, Configuration config) throws IOException {
         StatsCollectionCallable callable =
                 new StatsCollectionCallable(stats, region, innerScanner, config, scan);
         byte[] asyncBytes = scan.getAttribute(BaseScannerRegionObserver.RUN_UPDATE_STATS_ASYNC_ATTRIB);
@@ -670,7 +684,7 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
         long rowCount = 0; // in case of async, we report 0 as number of rows updated
         StatisticsCollectionRunTracker statsRunTracker =
                 StatisticsCollectionRunTracker.getInstance(config);
-        final boolean runUpdateStats = statsRunTracker.addUpdateStatsCommandRegion(region.getRegionInfo(),scan.getFamilyMap().keySet());
+        final boolean runUpdateStats = statsRunTracker.addUpdateStatsCommandRegion(region.getRegionInfo(), scan.getFamilyMap().keySet());
         if (runUpdateStats) {
             if (!async) {
                 rowCount = callable.call();
@@ -683,12 +697,12 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
                     + region.getRegionInfo().getRegionNameAsString());
         }
         byte[] rowCountBytes = PLong.INSTANCE.toBytes(Long.valueOf(rowCount));
-        final KeyValue aggKeyValue =
-                KeyValueUtil.newKeyValue(UNGROUPED_AGG_ROW_KEY, SINGLE_COLUMN_FAMILY,
-                    SINGLE_COLUMN, AGG_TIMESTAMP, rowCountBytes, 0, rowCountBytes.length);
+        final Cell aggKeyValue =
+                PhoenixKeyValueUtil.newKeyValue(UNGROUPED_AGG_ROW_KEY, SINGLE_COLUMN_FAMILY,
+                        SINGLE_COLUMN, AGG_TIMESTAMP, rowCountBytes, 0, rowCountBytes.length);
         RegionScanner scanner = new BaseRegionScanner(innerScanner) {
             @Override
-            public HRegionInfo getRegionInfo() {
+            public RegionInfo getRegionInfo() {
                 return region.getRegionInfo();
             }
 
@@ -735,7 +749,7 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
         private final Scan scan;
 
         StatsCollectionCallable(StatisticsCollector s, Region r, RegionScanner rs,
-                Configuration config, Scan scan) {
+                                Configuration config, Scan scan) {
             this.statsCollector = s;
             this.region = r;
             this.innerScanner = rs;
@@ -765,7 +779,7 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
                     statsCollector.init();
                     synchronized (innerScanner) {
                         do {
-                            List<Cell> results = new ArrayList<Cell>();
+                            List<Cell> results = new ArrayList<>();
                             hasMore = innerScanner.nextRaw(results);
                             statsCollector.collectStatistics(results);
                             rowCount++;
@@ -857,17 +871,11 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
         }
     }
 
-    @Override
-    public void preSplit(ObserverContext<RegionCoprocessorEnvironment> c, byte[] splitRow)
-            throws IOException {
-        waitForScansToFinish(c);
-    }
-
     // Don't allow splitting/closing if operations need read and write to same region are going on in the
     // the coprocessors to avoid dead lock scenario. See PHOENIX-3111.
     private void waitForScansToFinish(ObserverContext<RegionCoprocessorEnvironment> c) throws IOException {
         int maxWaitTime = c.getEnvironment().getConfiguration().getInt(HConstants.HBASE_CLIENT_OPERATION_TIMEOUT,
-            HConstants.DEFAULT_HBASE_CLIENT_OPERATION_TIMEOUT);
+                HConstants.DEFAULT_HBASE_CLIENT_OPERATION_TIMEOUT);
         long start = EnvironmentEdgeManager.currentTimeMillis();
         synchronized (lock) {
             isRegionClosingOrSplitting = true;
@@ -877,10 +885,10 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
                     if (EnvironmentEdgeManager.currentTimeMillis() - start >= maxWaitTime) {
                         isRegionClosingOrSplitting = false; // must reset in case split is not retried
                         throw new IOException(String.format(
-                            "Operations like local index building/delete/upsert select"
-                                    + " might be going on so not allowing to split/close. scansReferenceCount=%s region=%s",
-                            scansReferenceCount,
-                            c.getEnvironment().getRegionInfo().getRegionNameAsString()));
+                                "Operations like local index building/delete/upsert select"
+                                        + " might be going on so not allowing to split/close. scansReferenceCount=%s region=%s",
+                                scansReferenceCount,
+                                c.getEnvironment().getRegionInfo().getRegionNameAsString()));
                     }
                 } catch (InterruptedException e) {
                     Thread.currentThread().interrupt();
@@ -891,7 +899,7 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
 
     @Override
     public void preBulkLoadHFile(ObserverContext<RegionCoprocessorEnvironment> c,
-            List<Pair<byte[], String>> familyPaths) throws IOException {
+                                 List<Pair<byte[], String>> familyPaths) throws IOException {
         // Don't allow bulkload if operations need read and write to same region are going on in the
         // the coprocessors to avoid dead lock scenario. See PHOENIX-3111.
         synchronized (lock) {
@@ -914,9 +922,9 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
     }
 
     @Override
-    public InternalScanner preCompactScannerOpen(final ObserverContext<RegionCoprocessorEnvironment> c,
-            final Store store, final List<? extends KeyValueScanner> scanners, ScanType scanType,
-            long earliestPutTs, final InternalScanner s, final CompactionRequest request) throws IOException {
+    public void preCompactScannerOpen(final ObserverContext<RegionCoprocessorEnvironment> c, final Store store,
+                                      ScanType scanType, ScanOptions options, CompactionLifeCycleTracker tracker,
+                                      final CompactionRequest request) throws IOException {
         // Compaction and split upcalls run with the effective user context of the requesting user.
         // This will lead to failure of cross cluster RPC if the effective user is not
         // the login user. Switch to the login user context to ensure we have the expected
@@ -924,39 +932,24 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
 
         final String fullTableName = c.getEnvironment().getRegion().getRegionInfo().getTable().getNameAsString();
         // since we will make a call to syscat, do nothing if we are compacting syscat itself
-        // also, if max lookback age is already configured, we're already taken care of elsewhere
-        // unless the index stays disabled beyond the max lookback age, in which case you probably
-        // want to rebuild anyway
-        if (request.isMajor() &&
-            !ScanInfoUtil.isMaxLookbackTimeEnabled(compactionConfig) &&
-            !PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME.equals(fullTableName)) {
-            return User.runAsLoginUser(new PrivilegedExceptionAction<InternalScanner>() {
+        if (request.isMajor() && !PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME.equals(fullTableName)) {
+            User.runAsLoginUser(new PrivilegedExceptionAction<Void>() {
                 @Override
-                public InternalScanner run() throws Exception {
+                public Void run() throws Exception {
                     // If the index is disabled, keep the deleted cells so the rebuild doesn't corrupt the index
                     try (PhoenixConnection conn =
-                            QueryUtil.getConnectionOnServer(compactionConfig).unwrap(PhoenixConnection.class)) {
+                                 QueryUtil.getConnectionOnServer(compactionConfig).unwrap(PhoenixConnection.class)) {
                         PTable table = PhoenixRuntime.getTableNoCache(conn, fullTableName);
                         List<PTable> indexes = PTableType.INDEX.equals(table.getType()) ? Lists.newArrayList(table) : table.getIndexes();
                         // FIXME need to handle views and indexes on views as well
                         for (PTable index : indexes) {
                             if (index.getIndexDisableTimestamp() != 0) {
                                 LOGGER.info(
-                                    "Modifying major compaction scanner to retain deleted cells for a table with disabled index: "
-                                            + fullTableName);
-                                Scan scan = new Scan();
-                                scan.setMaxVersions();
-
-                                // close the passed scanner since we are returning a brand-new one
-                                try {
-                                    if (s != null) {
-                                        s.close();
-                                    }
-                                } catch (IOException ignore) {}
-
-                                return new StoreScanner(store, store.getScanInfo(), scan, scanners,
-                                    ScanType.COMPACT_RETAIN_DELETES, store.getSmallestReadPoint(),
-                                    HConstants.OLDEST_TIMESTAMP);
+                                        "Modifying major compaction scanner to retain deleted cells for a table with disabled index: "
+                                                + fullTableName);
+                                options.setKeepDeletedCells(KeepDeletedCells.TRUE);
+                                options.readAllVersions();
+                                options.setTTL(Long.MAX_VALUE);
                             }
                         }
                     } catch (Exception e) {
@@ -965,27 +958,12 @@ public class UngroupedAggregateRegionObserver extends BaseScannerRegionObserver
                             // non-Phoenix HBase tables won't be found, do nothing
                         } else {
                             LOGGER.error("Unable to modify compaction scanner to retain deleted cells for a table with disabled Index; "
-                                    + fullTableName,
-                                    e);
+                                            + fullTableName, e);
                         }
                     }
-                    return s;
+                    return null;
                 }
             });
         }
-        return s;
-    }
-
-     /**
-     * roll back after split failed, will isRegionClosingOrSplitting set false,
-     * and then write region will is available
-     * @param ctx
-     * @throws IOException
-     */
-    @Override
-    public void postRollBackSplit(ObserverContext<RegionCoprocessorEnvironment> ctx) throws IOException {
-        synchronized (lock) {
-            isRegionClosingOrSplitting = false;
-        }
     }
 }
