@@ -45,19 +45,24 @@ import java.util.Arrays;
 import java.util.List;
 import java.util.Set;
 
-import com.google.common.collect.Sets;
-import com.google.common.primitives.Ints;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Sets;
+import org.apache.phoenix.thirdparty.com.google.common.primitives.Ints;
+
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
+import org.apache.hadoop.hbase.CellBuilderFactory;
+import org.apache.hadoop.hbase.CellBuilderType;
 import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
-import org.apache.hadoop.hbase.HRegionInfo;
-import org.apache.hadoop.hbase.KeyValue;
+import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.Connection;
+import org.apache.hadoop.hbase.client.ConnectionFactory;
 import org.apache.hadoop.hbase.client.Delete;
-import org.apache.hadoop.hbase.client.HTable;
 import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.Put;
+import org.apache.hadoop.hbase.client.RegionInfo;
 import org.apache.hadoop.hbase.client.Scan;
+import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.coprocessor.ObserverContext;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
@@ -110,6 +115,7 @@ import org.apache.phoenix.util.EnvironmentEdgeManager;
 import org.apache.phoenix.util.ExpressionUtil;
 import org.apache.phoenix.util.IndexUtil;
 import org.apache.phoenix.util.LogUtil;
+import org.apache.phoenix.util.PhoenixKeyValueUtil;
 import org.apache.phoenix.util.ScanUtil;
 import org.apache.phoenix.util.ServerUtil;
 import org.apache.phoenix.util.StringUtil;
@@ -121,10 +127,10 @@ public class UngroupedAggregateRegionScanner extends BaseRegionScanner {
     private static final Logger LOGGER = LoggerFactory.getLogger(UngroupedAggregateRegionScanner.class);
 
     private long pageSizeMs;
-    private int maxBatchSize = 0;
-    private final Scan scan;
-    private final RegionScanner innerScanner;
-    private final Region region;
+    private  int maxBatchSize = 0;
+    private  Scan scan;
+    private  RegionScanner innerScanner;
+    private  Region region;
     private final UngroupedAggregateRegionObserver ungroupedAggregateRegionObserver;
     private final RegionCoprocessorEnvironment env;
     private final boolean useQualifierAsIndex;
@@ -154,10 +160,11 @@ public class UngroupedAggregateRegionScanner extends BaseRegionScanner {
     private final byte[] clientVersionBytes;
     private final long blockingMemStoreSize;
     private long maxBatchSizeBytes = 0L;
-    private HTable targetHTable = null;
+    private Table targetHTable = null;
     private boolean incrScanRefCount = false;
     private byte[] indexMaintainersPtr;
     private boolean useIndexProto;
+    private Connection targetHConn = null;
 
     public UngroupedAggregateRegionScanner(final ObserverContext<RegionCoprocessorEnvironment> c,
                                            final RegionScanner innerScanner, final Region region, final Scan scan,
@@ -174,7 +181,6 @@ public class UngroupedAggregateRegionScanner extends BaseRegionScanner {
         pageSizeMs = getPageSizeMsForRegionScanner(scan);
         ts = scan.getTimeRange().getMax();
         boolean localIndexScan = ScanUtil.isLocalIndex(scan);
-
         encodingScheme = EncodedColumnsUtil.getQualifierEncodingScheme(scan);
         int offsetToBe = 0;
         if (localIndexScan) {
@@ -224,8 +230,9 @@ public class UngroupedAggregateRegionScanner extends BaseRegionScanner {
         if (upsertSelectTable != null) {
             isUpsert = true;
             projectedTable = deserializeTable(upsertSelectTable);
-            targetHTable = new HTable(ungroupedAggregateRegionObserver.getUpsertSelectConfig(),
-                    projectedTable.getPhysicalName().getBytes());
+            targetHConn = ConnectionFactory.createConnection(ungroupedAggregateRegionObserver.getUpsertSelectConfig());
+            targetHTable = targetHConn.getTable(
+                    TableName.valueOf(projectedTable.getPhysicalName().getBytes()));
             selectExpressions = deserializeExpressions(scan.getAttribute(BaseScannerRegionObserver.UPSERT_SELECT_EXPRS));
             values = new byte[projectedTable.getPKColumns().size()][];
             isPKChanging = ExpressionUtil.isPkPositionChanging(new TableRef(projectedTable), selectExpressions);
@@ -257,7 +264,7 @@ public class UngroupedAggregateRegionScanner extends BaseRegionScanner {
                 || (deleteCQ != null && deleteCF != null) || emptyCF != null || buildLocalIndex) {
             needToWrite = true;
             if((isUpsert && (targetHTable == null ||
-                    !targetHTable.getName().equals(region.getTableDesc().getTableName())))) {
+                    !targetHTable.getName().equals(region.getTableDescriptor().getTableName())))) {
                 needToWrite = false;
             }
             maxBatchSize = conf.getInt(MUTATE_BATCH_SIZE_ATTRIB, QueryServicesOptions.DEFAULT_MUTATE_BATCH_SIZE);
@@ -283,7 +290,7 @@ public class UngroupedAggregateRegionScanner extends BaseRegionScanner {
     }
 
     @Override
-    public HRegionInfo getRegionInfo() {
+    public RegionInfo getRegionInfo() {
         return region.getRegionInfo();
     }
 
@@ -305,6 +312,13 @@ public class UngroupedAggregateRegionScanner extends BaseRegionScanner {
                     LOGGER.error("Closing table: " + targetHTable + " failed: ", e);
                 }
             }
+            if (targetHConn != null) {
+                try {
+                    targetHConn.close();
+                } catch (IOException e) {
+                    LOGGER.error("Closing connection: " + targetHConn + " failed: ", e);
+                }
+            }
         } finally {
             innerScanner.close();
         }
@@ -369,15 +383,31 @@ public class UngroupedAggregateRegionScanner extends BaseRegionScanner {
         byte[] oldRow = Bytes.copy(firstKV.getRowArray(), firstKV.getRowOffset(), firstKV.getRowLength());
         for (Cell cell : results) {
             // Copy existing cell but with new row key
-            Cell newCell = CellUtil.createCell(newRow, CellUtil.cloneFamily(cell), CellUtil.cloneQualifier(cell),
-                    cell.getTimestamp(), cell.getTypeByte(), CellUtil.cloneValue(cell));
-            switch (KeyValue.Type.codeToType(cell.getTypeByte())) {
+            Cell newCell =
+                    CellBuilderFactory.create(CellBuilderType.DEEP_COPY).
+                            setRow(newRow).
+                            setFamily(cell.getFamilyArray(), cell.getFamilyOffset(), cell.getFamilyLength()).
+                            setQualifier(cell.getQualifierArray(),
+                                    cell.getQualifierOffset(), cell.getQualifierLength()).
+                            setTimestamp(cell.getTimestamp()).
+                            setType(cell.getType()).setValue(cell.getValueArray(),
+                            cell.getValueOffset(), cell.getValueLength()).build();
+            switch (cell.getType()) {
                 case Put:
                     // If Put, point delete old Put
                     Delete del = new Delete(oldRow);
-                    del.addDeleteMarker(CellUtil.createCell(CellUtil.cloneRow(cell), CellUtil.cloneFamily(cell),
-                            CellUtil.cloneQualifier(cell), cell.getTimestamp(), KeyValue.Type.Delete.getCode(),
-                            ByteUtil.EMPTY_BYTE_ARRAY));
+                    Cell newDelCell =
+                            CellBuilderFactory.create(CellBuilderType.DEEP_COPY).
+                                    setRow(newRow).
+                                    setFamily(cell.getFamilyArray(), cell.getFamilyOffset(),
+                                            cell.getFamilyLength()).
+                                    setQualifier(cell.getQualifierArray(),
+                                            cell.getQualifierOffset(), cell.getQualifierLength()).
+                                    setTimestamp(cell.getTimestamp()).
+                                    setType(Cell.Type.Delete).
+                                    setValue(ByteUtil.EMPTY_BYTE_ARRAY,
+                                            0, 0).build();
+                    del.add(newDelCell);
                     mutations.add(del);
 
                     Put put = new Put(newRow);
@@ -389,7 +419,7 @@ public class UngroupedAggregateRegionScanner extends BaseRegionScanner {
                 case DeleteFamily:
                 case DeleteFamilyVersion:
                     Delete delete = new Delete(newRow);
-                    delete.addDeleteMarker(newCell);
+                    delete.add(newCell);
                     mutations.add(delete);
                     break;
             }
@@ -444,7 +474,7 @@ public class UngroupedAggregateRegionScanner extends BaseRegionScanner {
             Delete delete = new Delete(results.get(0).getRowArray(),
                     results.get(0).getRowOffset(),
                     results.get(0).getRowLength());
-            delete.deleteColumns(deleteCF,  deleteCQ, ts);
+            delete.addColumns(deleteCF,  deleteCQ, ts);
             // force tephra to ignore this deletes
             delete.setAttribute(PhoenixTransactionContext.TX_ROLLBACK_ATTRIBUTE_KEY, new byte[0]);
             // TODO: We need to set SOURCE_OPERATION_ATTRIB here also. The control will come here if
@@ -489,8 +519,10 @@ public class UngroupedAggregateRegionScanner extends BaseRegionScanner {
                         expression.getMaxLength(), expression.getScale(),
                         column.getMaxLength(), column.getScale())) {
                     throw new DataExceedsCapacityException(
-                            column.getDataType(), column.getMaxLength(),
-                            column.getScale(), column.getName().getString(), ptr);
+                            column.getDataType(),
+                            column.getMaxLength(),
+                            column.getScale(),
+                            column.getName().getString());
                 }
                 column.getDataType().coerceBytes(ptr, null,
                         expression.getDataType(), expression.getMaxLength(),
@@ -552,7 +584,7 @@ public class UngroupedAggregateRegionScanner extends BaseRegionScanner {
             try {
                 synchronized (innerScanner) {
                     do {
-                        ungroupedAggregateRegionObserver.checkForRegionClosing();
+                        ungroupedAggregateRegionObserver.checkForRegionClosingOrSplitting();
                         List<Cell> results = useQualifierAsIndex ? new EncodedColumnQualiferCellsList(minMaxQualifiers.getFirst(), minMaxQualifiers.getSecond(), encodingScheme) : new ArrayList<Cell>();
                         // Results are potentially returned even when the return value of s.next is false
                         // since this is an indication of whether or not there are more values after the
@@ -622,23 +654,23 @@ public class UngroupedAggregateRegionScanner extends BaseRegionScanner {
                 LOGGER.error("Exception in UngroupedAggregateRegionScanner for region "
                         + region.getRegionInfo().getRegionNameAsString(), e);
                 throw e;
+            } finally {
+                region.closeRegionOperation();
             }
-            Cell cell;
+            Cell keyValue;
             if (hasAny) {
                 byte[] value = aggregators.toBytes(rowAggregators);
                 if (pageSizeMs == Long.MAX_VALUE) {
                     // Paging is not set. To be compatible with older clients, do not set the row key
-                    cell = CellUtil.createCell(UNGROUPED_AGG_ROW_KEY, SINGLE_COLUMN_FAMILY, SINGLE_COLUMN,
-                            AGG_TIMESTAMP, KeyValue.Type.Put.getCode(), value);
+                    keyValue = PhoenixKeyValueUtil.newKeyValue(UNGROUPED_AGG_ROW_KEY, SINGLE_COLUMN_FAMILY, SINGLE_COLUMN,
+                            AGG_TIMESTAMP, value, 0, value.length);
                 } else {
-                    cell = CellUtil.createCell(CellUtil.cloneRow(lastCell), SINGLE_COLUMN_FAMILY, SINGLE_COLUMN,
-                            AGG_TIMESTAMP, KeyValue.Type.Put.getCode(), value);
+                    keyValue = PhoenixKeyValueUtil.newKeyValue(CellUtil.cloneRow(lastCell), SINGLE_COLUMN_FAMILY, SINGLE_COLUMN,
+                            AGG_TIMESTAMP, value, 0, value.length);
                 }
-                resultsToReturn.add(cell);
+                resultsToReturn.add(keyValue);
             }
             return hasMore;
-        } finally {
-            region.closeRegionOperation();
         }
     }
 
