@@ -36,7 +36,6 @@ import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellScanner;
 import org.apache.hadoop.hbase.HRegionLocation;
 import org.apache.hadoop.hbase.KeyValue;
-import org.apache.hadoop.hbase.KeyValueUtil;
 import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
@@ -49,6 +48,7 @@ import org.apache.phoenix.cache.IndexMetaDataCache;
 import org.apache.phoenix.compile.ScanRanges;
 import org.apache.phoenix.coprocessor.MetaDataProtocol;
 import org.apache.phoenix.filter.SkipScanFilter;
+import org.apache.phoenix.hbase.index.AbstractValueGetter;
 import org.apache.phoenix.hbase.index.MultiMutation;
 import org.apache.phoenix.hbase.index.ValueGetter;
 import org.apache.phoenix.hbase.index.covered.IndexMetaData;
@@ -68,13 +68,14 @@ import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.schema.types.PVarbinary;
 import org.apache.phoenix.transaction.PhoenixTransactionContext;
 import org.apache.phoenix.transaction.PhoenixTransactionContext.PhoenixVisibilityLevel;
+import org.apache.phoenix.util.PhoenixKeyValueUtil;
 import org.apache.phoenix.util.ScanUtil;
 import org.apache.phoenix.util.SchemaUtil;
 
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
-import com.google.common.collect.Sets;
-import com.google.common.primitives.Longs;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Sets;
+import org.apache.phoenix.thirdparty.com.google.common.primitives.Longs;
 
 
 public class PhoenixTxIndexMutationGenerator {
@@ -378,7 +379,7 @@ public class PhoenixTxIndexMutationGenerator {
     private static class TxTableState implements TableState {
         private final Mutation mutation;
         private final long currentTimestamp;
-        private final List<KeyValue> pendingUpdates;
+        private final List<Cell> pendingUpdates;
         private final Set<ColumnReference> indexedColumns;
         private final Map<ColumnReference, ImmutableBytesWritable> valueMap;
         
@@ -393,7 +394,7 @@ public class PhoenixTxIndexMutationGenerator {
                 CellScanner scanner = mutation.cellScanner();
                 while (scanner.advance()) {
                     Cell cell = scanner.current();
-                    pendingUpdates.add(KeyValueUtil.ensureKeyValue(cell));
+                    pendingUpdates.add(PhoenixKeyValueUtil.maybeCopyCell(cell));
                 }
             } catch (IOException e) {
                 throw new RuntimeException(e); // Impossible
@@ -453,7 +454,7 @@ public class PhoenixTxIndexMutationGenerator {
         }
         
         @Override
-        public Collection<KeyValue> getPendingUpdate() {
+        public Collection<Cell> getPendingUpdate() {
             return pendingUpdates;
         }
 
@@ -462,7 +463,7 @@ public class PhoenixTxIndexMutationGenerator {
                 throws IOException {
             // TODO: creating these objects over and over again is wasteful
             ColumnTracker tracker = new ColumnTracker(indexedColumns);
-            ValueGetter getter = new ValueGetter() {
+            ValueGetter getter = new AbstractValueGetter() {
 
                 @Override
                 public ImmutableBytesWritable getLatestValue(ColumnReference ref, long ts) throws IOException {
