@@ -85,9 +85,9 @@ import org.apache.phoenix.util.SchemaUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.annotations.VisibleForTesting;
-import com.google.common.collect.Lists;
-import com.google.common.collect.Sets;
+import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Sets;
 
 public class SortMergeJoinPlan implements QueryPlan {
     private static final Logger LOGGER = LoggerFactory.getLogger(SortMergeJoinPlan.class);
@@ -248,7 +248,7 @@ public class SortMergeJoinPlan implements QueryPlan {
 
     @Override
     public ParameterMetaData getParameterMetaData() {
-        return PhoenixParameterMetaData.EMPTY_PARAMETER_META_DATA;
+        return context.getBindManager().getParameterMetaData();
     }
 
     @Override
@@ -849,6 +849,7 @@ public class SortMergeJoinPlan implements QueryPlan {
         }
     }
     
+    
     @Override
     public boolean useRoundRobinIterator() {
         return false;
