@@ -37,7 +37,6 @@ import java.util.Set;
 
 import com.google.protobuf.InvalidProtocolBufferException;
 import org.apache.hadoop.hbase.Cell;
-import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
@@ -60,12 +59,12 @@ import org.apache.phoenix.schema.ProjectedColumn;
 import org.apache.phoenix.schema.ValueBitSet;
 import org.apache.phoenix.schema.tuple.BaseTuple;
 import org.apache.phoenix.schema.tuple.Tuple;
-import org.apache.phoenix.util.KeyValueUtil;
 import org.apache.phoenix.util.ByteUtil;
+import org.apache.phoenix.util.PhoenixKeyValueUtil;
 import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.SchemaUtil;
 
-import com.google.common.base.Preconditions;
+import org.apache.phoenix.thirdparty.com.google.common.base.Preconditions;
 
 public class TupleProjector {    
     private static final String SCAN_PROJECTOR = "scanProjector";
@@ -286,7 +285,7 @@ public class TupleProjector {
         long timestamp;
         ImmutableBytesWritable projectedValue = new ImmutableBytesWritable();
         int bitSetLen;
-        KeyValue keyValue;
+        Cell keyValue;
 
         public ProjectedValueTuple(Tuple keyBase, long timestamp, byte[] projectedValue, int valueOffset, int valueLength, int bitSetLen) {
             keyBase.getKey(this.keyPtr);
@@ -337,7 +336,7 @@ public class TupleProjector {
                     DYN_COLS_METADATA_CELL_QUALIFIER, dynColsList);
             ImmutableBytesWritable projectedValueWithDynColsListBytes =
                     new ImmutableBytesWritable(concatBytes);
-            keyValue = KeyValueUtil.newKeyValue(keyPtr.get(), keyPtr.getOffset(),
+            keyValue = PhoenixKeyValueUtil.newKeyValue(keyPtr.get(), keyPtr.getOffset(),
                     keyPtr.getLength(), VALUE_COLUMN_FAMILY, VALUE_COLUMN_QUALIFIER, timestamp,
                     projectedValueWithDynColsListBytes.get(),
                     projectedValueWithDynColsListBytes.getOffset(),
@@ -346,7 +345,7 @@ public class TupleProjector {
         }
 
         @Override
-        public KeyValue getValue(int index) {
+        public Cell getValue(int index) {
             if (index != 0) {
                 throw new IndexOutOfBoundsException(Integer.toString(index));
             }
@@ -354,9 +353,9 @@ public class TupleProjector {
         }
 
         @Override
-        public KeyValue getValue(byte[] family, byte[] qualifier) {
+        public Cell getValue(byte[] family, byte[] qualifier) {
             if (keyValue == null) {
-                keyValue = KeyValueUtil.newKeyValue(keyPtr.get(), keyPtr.getOffset(), keyPtr.getLength(), 
+                keyValue = PhoenixKeyValueUtil.newKeyValue(keyPtr.get(), keyPtr.getOffset(), keyPtr.getLength(), 
                         VALUE_COLUMN_FAMILY, VALUE_COLUMN_QUALIFIER, timestamp, projectedValue.get(), projectedValue.getOffset(), projectedValue.getLength());
             }
             return keyValue;
@@ -393,15 +392,15 @@ public class TupleProjector {
         }
 
         @Override
-        public KeyValue getValue(int index) {
+        public Cell getValue(int index) {
             if (index != 0) { throw new IndexOutOfBoundsException(Integer.toString(index)); }
             return getValue(VALUE_COLUMN_FAMILY, OLD_VALUE_COLUMN_QUALIFIER);
         }
 
         @Override
-        public KeyValue getValue(byte[] family, byte[] qualifier) {
+        public Cell getValue(byte[] family, byte[] qualifier) {
             if (keyValue == null) {
-                keyValue = KeyValueUtil.newKeyValue(keyPtr.get(), keyPtr.getOffset(), keyPtr.getLength(),
+                keyValue = PhoenixKeyValueUtil.newKeyValue(keyPtr.get(), keyPtr.getOffset(), keyPtr.getLength(),
                         VALUE_COLUMN_FAMILY, OLD_VALUE_COLUMN_QUALIFIER, timestamp, projectedValue.get(),
                         projectedValue.getOffset(), projectedValue.getLength());
             }
