@@ -42,9 +42,9 @@ import org.apache.phoenix.util.ByteUtil;
 import org.apache.phoenix.util.ExpressionUtil;
 import org.apache.phoenix.util.StringUtil;
 
-import com.google.common.annotations.VisibleForTesting;
-import com.google.common.collect.Lists;
-import com.google.common.collect.Sets;
+import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Sets;
 
 /*
  * Implementation of a SQL foo IN (a,b,c) expression. Other than the first
@@ -324,11 +324,15 @@ public class InListExpression extends BaseSingleExpression {
         PDataType type = firstChild.getDataType();
         StringBuilder buf = new StringBuilder(firstChild + " IN (");
         for (ImmutableBytesPtr value : values) {
-            ImmutableBytesPtr valueCopy = new ImmutableBytesPtr(value.copyBytes());
-            if (firstChild.getSortOrder() != null) {
-                type.coerceBytes(valueCopy, type, firstChild.getSortOrder(), SortOrder.getDefault());
+            ImmutableBytesWritable currValue = value;
+            if (firstChild.getSortOrder() != null && !firstChild.getSortOrder().equals(SortOrder.getDefault())) {
+                // if we have to invert the bytes create a new ImmutableBytesWritable so that the
+                // original value is not changed
+                currValue = new ImmutableBytesWritable(value);
+                type.coerceBytes(currValue, type, firstChild.getSortOrder(),
+                    SortOrder.getDefault());
             }
-            buf.append(type.toStringLiteral(valueCopy, null));
+            buf.append(type.toStringLiteral(currValue, null));
             buf.append(',');
             if (buf.length() >= maxToStringLen) {
                 buf.append("... ");
