@@ -29,8 +29,8 @@ import java.util.List;
 import java.util.Map;
 
 import org.apache.hadoop.hbase.Cell;
+import org.apache.hadoop.hbase.CellComparatorImpl;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.KeyValue.Type;
 import org.apache.hadoop.hbase.client.Delete;
 import org.apache.hadoop.hbase.client.Get;
@@ -65,7 +65,7 @@ import org.apache.phoenix.schema.tuple.MultiKeyValueTuple;
 import org.apache.phoenix.util.ByteUtil;
 import org.apache.phoenix.util.TrustedByteArrayOutputStream;
 
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 /**
  * Index builder for covered-columns index that ties into phoenix for faster use.
@@ -216,7 +216,7 @@ public class PhoenixIndexBuilder extends NonTxIndexBuilder {
                 // ordered correctly). We only need the list sorted if the expressions are going to be
                 // executed, not when the outer loop is exited. Hence we do it here, at the top of the loop.
                 if (flattenedCells != null) {
-                    Collections.sort(flattenedCells,KeyValue.COMPARATOR);
+                    Collections.sort(flattenedCells,CellComparatorImpl.COMPARATOR);
                 }
                 PRow row = table.newRow(GenericKeyValueBuilder.INSTANCE, ts, ptr, false);
                 int adjust = table.getBucketNum() == null ? 1 : 2;
@@ -267,7 +267,7 @@ public class PhoenixIndexBuilder extends NonTxIndexBuilder {
                     transferAttributes(inc, delete);
                     mutations.add(delete);
                 }
-                delete.addDeleteMarker(cell);
+                delete.add(cell);
             }
         }
         return mutations;
@@ -286,7 +286,7 @@ public class PhoenixIndexBuilder extends NonTxIndexBuilder {
      *       UPSERT VALUES ON DUPLICATE KEY IGNORE followed by UPSERT VALUES ON DUPLICATE KEY UPDATE
      * 2) Short value tracking how many times the next first clause should be executed. This
      *    optimizes the same clause be executed many times by only serializing it once.
-     * 3) Repeating {List<Expression>, PTable} pairs that encapsulate the ON DUPLICATE KEY clause.
+     * 3) Repeating {@code List<Expression>, PTable } pairs that encapsulate the ON DUPLICATE KEY clause.
      * @param table table representing columns being updated
      * @param expressions list of expressions to evaluate for updating columns
      * @return serialized byte array representation of ON DUPLICATE KEY UPDATE info
