@@ -33,12 +33,12 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.HRegionInfo;
-import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.Stoppable;
 import org.apache.hadoop.hbase.client.ConnectionUtils;
-import org.apache.hadoop.hbase.client.HTableInterface;
 import org.apache.hadoop.hbase.client.Mutation;
+import org.apache.hadoop.hbase.client.RegionInfo;
+import org.apache.hadoop.hbase.client.Table;
+import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 import org.apache.hadoop.hbase.security.User;
@@ -72,10 +72,10 @@ import org.apache.phoenix.util.ServerUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Function;
-import com.google.common.collect.Iterables;
-import com.google.common.collect.Lists;
-import com.google.common.collect.Multimap;
+import org.apache.phoenix.thirdparty.com.google.common.base.Function;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Iterables;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Multimap;
 
 /**
  * 
@@ -106,7 +106,7 @@ public class PhoenixIndexFailurePolicy extends DelegateIndexFailurePolicy {
         this.env = env;
         rebuildIndexOnFailure = env.getConfiguration().getBoolean(QueryServices.INDEX_FAILURE_HANDLING_REBUILD_ATTRIB,
                 QueryServicesOptions.DEFAULT_INDEX_FAILURE_HANDLING_REBUILD);
-        HTableDescriptor htd = env.getRegion().getTableDesc();
+        TableDescriptor htd = env.getRegion().getTableDescriptor();
         // If rebuild index is turned off globally, no need to check the table because the background thread
         // won't be running in this case
         if (rebuildIndexOnFailure) {
@@ -229,8 +229,8 @@ public class PhoenixIndexFailurePolicy extends DelegateIndexFailurePolicy {
             timestamp = minTimeStamp;
 
             // If the data table has local index column families then get local indexes to disable.
-            if (ref.getTableName().equals(env.getRegion().getTableDesc().getNameAsString())
-                    && MetaDataUtil.hasLocalIndexColumnFamily(env.getRegion().getTableDesc())) {
+            if (ref.getTableName().equals(env.getRegion().getTableDescriptor().getTableName().getNameAsString())
+                    && MetaDataUtil.hasLocalIndexColumnFamily(env.getRegion().getTableDescriptor())) {
                 for (String tableName : getLocalIndexNames(ref, mutations)) {
                     indexTableNames.put(tableName, minTimeStamp);
                 }
@@ -258,7 +258,7 @@ public class PhoenixIndexFailurePolicy extends DelegateIndexFailurePolicy {
         }
 
         final PIndexState newState = disableIndexOnFailure ? PIndexState.PENDING_DISABLE : PIndexState.PENDING_ACTIVE;
-        final long fTimestamp=timestamp;
+        final long fTimestamp = timestamp;
         // for all the index tables that we've found, try to disable them and if that fails, try to
         return User.runAsLoginUser(new PrivilegedExceptionAction<Long>() {
             @Override
@@ -277,7 +277,7 @@ public class PhoenixIndexFailurePolicy extends DelegateIndexFailurePolicy {
                         minTimeStamp *= -1;
                     }
                     // Disable the index by using the updateIndexState method of MetaDataProtocol end point coprocessor.
-                    try (HTableInterface systemTable = env.getTable(SchemaUtil.getPhysicalTableName(
+                    try (Table systemTable = env.getConnection().getTable(SchemaUtil.getPhysicalTableName(
                             PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME_BYTES, env.getConfiguration()))) {
                         MetaDataMutationResult result = IndexUtil.updateIndexState(indexTableName, minTimeStamp,
                                 systemTable, newState);
@@ -305,7 +305,7 @@ public class PhoenixIndexFailurePolicy extends DelegateIndexFailurePolicy {
                         LOGGER.info("Successfully update INDEX_DISABLE_TIMESTAMP for " +
                                         indexTableName + " due to an exception while" +
                                         " writing updates. indexState=" + newState,
-                            cause);
+                        cause);
                     } catch (Throwable t) {
                         if (t instanceof Exception) {
                             throw (Exception)t;
@@ -343,7 +343,7 @@ public class PhoenixIndexFailurePolicy extends DelegateIndexFailurePolicy {
             }
 
             IndexMaintainer indexMaintainer = localIndex.getIndexMaintainer(dataTable, conn);
-            HRegionInfo regionInfo = this.env.getRegion().getRegionInfo();
+            RegionInfo regionInfo = this.env.getRegion().getRegionInfo();
             int offset =
                     regionInfo.getStartKey().length == 0 ? regionInfo.getEndKey().length
                             : regionInfo.getStartKey().length;
@@ -377,14 +377,11 @@ public class PhoenixIndexFailurePolicy extends DelegateIndexFailurePolicy {
 
     /**
      * Check config for whether to disable index on index write failures
-     * @param htd
-     * @param config
-     * @param connection
-     * @return The table config for {@link PhoenixIndexFailurePolicy.DISABLE_INDEX_ON_WRITE_FAILURE}
-     * @throws SQLException
+     * @param env
+     * @return
      */
     public static boolean getDisableIndexOnFailure(RegionCoprocessorEnvironment env) {
-        HTableDescriptor htd = env.getRegion().getTableDesc();
+        TableDescriptor htd = env.getRegion().getTableDescriptor();
         Configuration config = env.getConfiguration();
         String value = htd.getValue(PhoenixIndexFailurePolicy.DISABLE_INDEX_ON_WRITE_FAILURE);
         boolean disableIndexOnFailure;
@@ -460,7 +457,7 @@ public class PhoenixIndexFailurePolicy extends DelegateIndexFailurePolicy {
      * @param iwe original IndexWriteException
      * @param connection connection to use
      * @param config config used to get retry settings
-     * @throws Exception
+     * @throws IOException
      */
     public static void doBatchWithRetries(MutateCommand mutateCommand,
             IndexWriteException iwe, PhoenixConnection connection, ReadOnlyProps config)
@@ -487,7 +484,7 @@ public class PhoenixIndexFailurePolicy extends DelegateIndexFailurePolicy {
                 // success - change the index state from PENDING_DISABLE back to ACTIVE
                 // If it's not Index Rebuild
                 if (!PhoenixIndexMetaData.isIndexRebuild(
-                    mutateCommand.getMutationList().get(0).getAttributesMap())) {
+                    mutateCommand.getMutationList().get(0).getAttributesMap())){
                     handleIndexWriteSuccessFromClient(iwe, connection);
                 }
                 return;
@@ -596,4 +593,4 @@ public class PhoenixIndexFailurePolicy extends DelegateIndexFailurePolicy {
             }
         }
     }
-}
+}
\ No newline at end of file
