@@ -75,9 +75,9 @@ import org.apache.phoenix.util.IndexUtil;
 import org.apache.phoenix.util.ScanUtil;
 import org.apache.phoenix.util.ServerUtil;
 
-import com.google.common.annotations.VisibleForTesting;
-import com.google.common.collect.Lists;
-import com.google.common.collect.Sets;
+import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Sets;
 
 public class NonAggregateRegionScannerFactory extends RegionScannerFactory {
 
@@ -280,11 +280,11 @@ public class NonAggregateRegionScannerFactory extends RegionScannerFactory {
     try {
       Tuple tuple = iterator.next();
       if (tuple == null && !isLastScan) {
-        List<KeyValue> kvList = new ArrayList<KeyValue>(1);
+        List<Cell> kvList = new ArrayList<Cell>(1);
         KeyValue kv = new KeyValue(QueryConstants.OFFSET_ROW_KEY_BYTES, QueryConstants.OFFSET_FAMILY,
             QueryConstants.OFFSET_COLUMN, PInteger.INSTANCE.toBytes(iterator.getRemainingOffset()));
         kvList.add(kv);
-        Result r = new Result(kvList);
+        Result r = Result.create(kvList);
         firstTuple = new ResultTuple(r);
       } else {
         firstTuple = tuple;
