@@ -41,9 +41,12 @@ import org.apache.hadoop.hbase.regionserver.ScannerContext;
 import org.apache.hadoop.hbase.regionserver.ScannerContextUtil;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.Pair;
+import org.apache.hadoop.io.WritableUtils;
+import org.apache.phoenix.coprocessor.BaseScannerRegionObserver;
 import org.apache.phoenix.coprocessor.generated.DynamicColumnMetaDataProtos;
 import org.apache.phoenix.execute.TupleProjector;
 import org.apache.phoenix.expression.Expression;
+import org.apache.phoenix.expression.ExpressionType;
 import org.apache.phoenix.expression.KeyValueColumnExpression;
 import org.apache.phoenix.hbase.index.covered.update.ColumnReference;
 import org.apache.phoenix.index.IndexMaintainer;
@@ -63,6 +66,8 @@ import org.apache.phoenix.util.IndexUtil;
 import org.apache.phoenix.util.ScanUtil;
 import org.apache.phoenix.util.ServerUtil;
 
+import java.io.ByteArrayInputStream;
+import java.io.DataInputStream;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
@@ -124,6 +129,30 @@ public abstract class RegionScannerFactory {
       private byte[] actualStartKey = getActualStartKey();
       private boolean useNewValueColumnQualifier = EncodedColumnsUtil.useNewValueColumnQualifier(scan);
       final long pageSizeMs = getPageSizeMsForRegionScanner(scan);
+      Expression extraWhere = null;
+      long extraLimit = -1;
+
+      {
+          // for local indexes construct the row filter for uncovered columns if it exists
+          if (ScanUtil.isLocalIndex(scan)) {
+              byte[] expBytes = scan.getAttribute(BaseScannerRegionObserver.LOCAL_INDEX_FILTER);
+              if (expBytes != null) {
+                  try {
+                      ByteArrayInputStream stream = new ByteArrayInputStream(expBytes);
+                      DataInputStream input = new DataInputStream(stream);
+                      extraWhere = ExpressionType.values()[WritableUtils.readVInt(input)].newInstance();
+                      extraWhere.readFields(input);
+                  } catch (IOException io) {
+                      // should not happen since we're reading from a byte[]
+                      throw new RuntimeException(io);
+                  }
+              }
+              byte[] limitBytes = scan.getAttribute(BaseScannerRegionObserver.LOCAL_INDEX_LIMIT);
+              if (limitBytes != null) {
+                  extraLimit = Bytes.toLong(limitBytes);
+              }
+          }
+      }
 
       // Get the actual scan start row of local index. This will be used to compare the row
       // key of the results less than scan start row when there are references.
@@ -183,18 +212,13 @@ public abstract class RegionScannerFactory {
           if (isDummy(result)) {
             return true;
           }
-          Cell arrayElementCell = null;
           if (result.size() == 0) {
             return next;
           }
-          if (arrayFuncRefs != null && arrayFuncRefs.length > 0 && arrayKVRefs.size() > 0) {
-            int arrayElementCellPosition = replaceArrayIndexElement(arrayKVRefs, arrayFuncRefs, result);
-            arrayElementCell = result.get(arrayElementCellPosition);
-          }
           if (ScanUtil.isLocalIndex(scan) && !ScanUtil.isAnalyzeTable(scan)) {
             if(actualStartKey!=null) {
               next = scanTillScanStartRow(s, arrayKVRefs, arrayFuncRefs, result,
-                  null, arrayElementCell);
+                  null);
               if (result.isEmpty() || isDummy(result)) {
                 return next;
               }
@@ -205,6 +229,22 @@ public abstract class RegionScannerFactory {
              */
             IndexUtil.wrapResultUsingOffset(env, result, offset, dataColumns,
                 tupleProjector, dataRegion, indexMaintainer, viewConstants, ptr);
+
+            if (extraWhere != null) {
+                Tuple merged = useQualifierAsListIndex ? new PositionBasedResultTuple(result) :
+                    new ResultTuple(Result.create(result));
+                ImmutableBytesWritable ptr = new ImmutableBytesWritable();
+                extraWhere.evaluate(merged, ptr);
+                if (!Boolean.TRUE.equals(extraWhere.getDataType().toObject(ptr))) {
+                    result.clear();
+                    return next;
+                }
+            }
+          }
+          Cell arrayElementCell = null;
+          if (arrayFuncRefs != null && arrayFuncRefs.length > 0 && arrayKVRefs.size() > 0) {
+            int arrayElementCellPosition = replaceArrayIndexElement(arrayKVRefs, arrayFuncRefs, result);
+            arrayElementCell = result.get(arrayElementCellPosition);
           }
           if (projector != null) {
             Tuple toProject = useQualifierAsListIndex ? new PositionBasedResultTuple(result) :
@@ -222,6 +262,9 @@ public abstract class RegionScannerFactory {
               result.add(arrayElementCell);
             }
           }
+          if (extraLimit >= 0 && --extraLimit == 0) {
+              return false;
+          }
           // There is a scanattribute set to retrieve the specific array element
           return next;
         } catch (Throwable t) {
@@ -300,7 +343,7 @@ public abstract class RegionScannerFactory {
       private boolean scanTillScanStartRow(final RegionScanner s,
           final Set<KeyValueColumnExpression> arrayKVRefs,
           final Expression[] arrayFuncRefs, List<Cell> result,
-          ScannerContext scannerContext, Cell arrayElementCell) throws IOException {
+          ScannerContext scannerContext) throws IOException {
         boolean next = true;
         Cell firstCell = result.get(0);
         long startTime = EnvironmentEdgeManager.currentTimeMillis();
@@ -324,10 +367,6 @@ public abstract class RegionScannerFactory {
           if (isDummy(result)) {
             return true;
           }
-          if (arrayFuncRefs != null && arrayFuncRefs.length > 0 && arrayKVRefs.size() > 0) {
-            int arrayElementCellPosition = replaceArrayIndexElement(arrayKVRefs, arrayFuncRefs, result);
-            arrayElementCell = result.get(arrayElementCellPosition);
-          }
           firstCell = result.get(0);
         }
         return next;
