@@ -61,7 +61,6 @@ import org.apache.hadoop.hbase.mapreduce.MutationSerialization;
 import org.apache.hadoop.hbase.mapreduce.ResultSerialization;
 import org.apache.hadoop.hbase.mapreduce.TableMapReduceUtil;
 import org.apache.hadoop.hbase.regionserver.BloomType;
-import org.apache.hadoop.hbase.regionserver.HStore;
 import org.apache.hadoop.hbase.regionserver.StoreFileWriter;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.io.NullWritable;
@@ -258,8 +257,8 @@ public class MultiHfileOutputFormat extends FileOutputFormat<TableRowkeyPair, Ce
               tempConf.setFloat(HConstants.HFILE_BLOCK_CACHE_SIZE_KEY, 0.0f);
               HFileContextBuilder contextBuilder = new HFileContextBuilder()
                                         .withCompression(compression)
-                                        .withChecksumType(HStore.getChecksumType(conf))
-                                        .withBytesPerCheckSum(HStore.getBytesPerChecksum(conf))
+                                        .withChecksumType(CompatUtil.getChecksumType(conf))
+                                        .withBytesPerCheckSum(CompatUtil.getBytesPerChecksum(conf))
                                         .withBlockSize(blockSize)
                                         .withDataBlockEncoding(encoding);
               CompatUtil.withComparator(contextBuilder, CellComparatorImpl.COMPARATOR);
