@@ -17,18 +17,19 @@
  */
 package org.apache.phoenix.mapreduce.index;
 
-import com.google.common.annotations.VisibleForTesting;
-import org.apache.hadoop.hbase.HColumnDescriptor;
-import org.apache.hadoop.hbase.HTableDescriptor;
+import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
 import org.apache.hadoop.hbase.client.Put;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.Table;
+import org.apache.hadoop.hbase.client.TableDescriptor;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.util.Bytes;
-import org.apache.phoenix.compat.hbase.CompatUtil;
 import org.apache.phoenix.coprocessor.MetaDataProtocol;
 import org.apache.phoenix.hbase.index.table.HTableFactory;
 import org.apache.phoenix.hbase.index.util.ImmutableBytesPtr;
@@ -175,13 +176,14 @@ public class IndexVerificationOutputRepository implements AutoCloseable {
         try (Admin admin = queryServices.getAdmin()) {
             TableName outputTableName = TableName.valueOf(OUTPUT_TABLE_NAME);
             if (!admin.tableExists(outputTableName)) {
-                HTableDescriptor tableDescriptor = new
-                    HTableDescriptor(TableName.valueOf(OUTPUT_TABLE_NAME));
-                HColumnDescriptor columnDescriptor =
-                    new HColumnDescriptor(OUTPUT_TABLE_COLUMN_FAMILY);
-                columnDescriptor.setValue(HColumnDescriptor.TTL,
-                    String.valueOf(MetaDataProtocol.DEFAULT_LOG_TTL));
-                tableDescriptor.addFamily(columnDescriptor);
+                ColumnFamilyDescriptor columnDescriptor =
+                    ColumnFamilyDescriptorBuilder
+                        .newBuilder(OUTPUT_TABLE_COLUMN_FAMILY)
+                        .setTimeToLive(MetaDataProtocol.DEFAULT_LOG_TTL)
+                        .build();
+                TableDescriptor tableDescriptor = TableDescriptorBuilder
+                    .newBuilder(TableName.valueOf(OUTPUT_TABLE_NAME))
+                    .setColumnFamily(columnDescriptor).build();
                 admin.createTable(tableDescriptor);
                 outputTable = admin.getConnection().getTable(outputTableName);
             }
@@ -358,7 +360,7 @@ public class IndexVerificationOutputRepository implements AutoCloseable {
         }
     }
 
-    public class IndexVerificationOutputRowIterator implements Iterator<IndexVerificationOutputRow> {
+    public static class IndexVerificationOutputRowIterator implements Iterator<IndexVerificationOutputRow> {
         Iterator<Result> delegate;
         public IndexVerificationOutputRowIterator(Iterator<Result> delegate){
             this.delegate = delegate;
