@@ -18,16 +18,18 @@
 package org.apache.phoenix.mapreduce.index;
 
 import org.apache.hadoop.hbase.Cell;
-import org.apache.hadoop.hbase.HColumnDescriptor;
-import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
 import org.apache.hadoop.hbase.client.Get;
 import org.apache.hadoop.hbase.client.Put;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.Table;
+import org.apache.hadoop.hbase.client.TableDescriptor;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.regionserver.Region;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.coprocessor.IndexToolVerificationResult;
@@ -158,15 +160,16 @@ public class IndexVerificationResultRepository implements AutoCloseable {
         try (Admin admin = queryServices.getAdmin()) {
             TableName resultTableName = TableName.valueOf(RESULT_TABLE_NAME);
             if (!admin.tableExists(resultTableName)) {
-                HTableDescriptor tableDescriptor =
-                    new HTableDescriptor(TableName.valueOf(RESULT_TABLE_NAME));
-                HColumnDescriptor columnDescriptor =
-                    new HColumnDescriptor(RESULT_TABLE_COLUMN_FAMILY);
-                columnDescriptor.setValue(HColumnDescriptor.TTL,
-                    String.valueOf(MetaDataProtocol.DEFAULT_LOG_TTL));
-                tableDescriptor.addFamily(columnDescriptor);
+                ColumnFamilyDescriptor columnDescriptor =
+                    ColumnFamilyDescriptorBuilder
+                        .newBuilder(RESULT_TABLE_COLUMN_FAMILY)
+                        .setTimeToLive(MetaDataProtocol.DEFAULT_LOG_TTL)
+                        .build();
+                TableDescriptor tableDescriptor =
+                    TableDescriptorBuilder.newBuilder(resultTableName)
+                        .setColumnFamily(columnDescriptor).build();
                 admin.createTable(tableDescriptor);
-                setResultTable(admin.getConnection().getTable(resultTableName));
+                resultTable = admin.getConnection().getTable(resultTableName);
             }
         }
     }
