@@ -17,13 +17,14 @@
  */
 package org.apache.phoenix.mapreduce.util;
 
-import static org.apache.commons.lang.StringUtils.isNotEmpty;
+import static org.apache.commons.lang3.StringUtils.isNotEmpty;
 import static org.apache.phoenix.query.QueryServices.USE_STATS_FOR_PARALLELIZATION;
 import static org.apache.phoenix.query.QueryServicesOptions.DEFAULT_USE_STATS_FOR_PARALLELIZATION;
 
 import java.io.IOException;
 import java.sql.Connection;
 import java.sql.SQLException;
+import java.util.Base64;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
@@ -33,7 +34,7 @@ import org.apache.hadoop.hbase.HBaseConfiguration;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 import org.apache.hadoop.hbase.mapreduce.TableMapReduceUtil;
-import org.apache.hadoop.hbase.util.Base64;
+import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.mapreduce.Job;
 import org.apache.hadoop.mapreduce.lib.db.DBInputFormat.NullDBWritable;
 import org.apache.hadoop.mapreduce.lib.db.DBWritable;
@@ -57,9 +58,9 @@ import org.apache.phoenix.util.QueryUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Joiner;
-import com.google.common.base.Preconditions;
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.base.Joiner;
+import org.apache.phoenix.thirdparty.com.google.common.base.Preconditions;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 /**
  * A utility class to set properties on the {#link Configuration} instance.
@@ -148,6 +149,10 @@ public final class PhoenixConfigurationUtil {
 
     public static final String DISABLED_INDEXES = "phoenix.mr.index.disabledIndexes";
 
+    public static final String VERIFY_INDEX = "phoenix.mr.index.verifyIndex";
+
+    public static final String ONLY_VERIFY_INDEX = "phoenix.mr.index.onlyVerifyIndex";
+
     public static final String INDEX_VERIFY_TYPE = "phoenix.mr.index.IndexVerifyType";
 
     public static final String DISABLE_LOGGING_TYPE = "phoenix.mr.index" +
@@ -438,7 +443,8 @@ public final class PhoenixConfigurationUtil {
         
     }
 
-    public static void setUpsertStatement(final Configuration configuration, String upsertStmt) throws SQLException {
+    public static void setUpsertStatement(final Configuration configuration, String upsertStmt)
+            throws SQLException {
         Preconditions.checkNotNull(configuration);
         Preconditions.checkNotNull(upsertStmt);
         configuration.set(UPSERT_STATEMENT, upsertStmt);
@@ -637,14 +643,14 @@ public final class PhoenixConfigurationUtil {
 
     public static byte[] getIndexMaintainers(final Configuration configuration){
         Preconditions.checkNotNull(configuration);
-        return Base64.decode(configuration.get(INDEX_MAINTAINERS));
+        return Base64.getDecoder().decode(configuration.get(INDEX_MAINTAINERS));
     }
     
     public static void setIndexMaintainers(final Configuration configuration,
             final ImmutableBytesWritable indexMetaDataPtr) {
         Preconditions.checkNotNull(configuration);
         Preconditions.checkNotNull(indexMetaDataPtr);
-        configuration.set(INDEX_MAINTAINERS, Base64.encodeBytes(indexMetaDataPtr.get()));
+        configuration.set(INDEX_MAINTAINERS,Bytes.toString(Base64.getEncoder().encode(indexMetaDataPtr.get())));
     }
     
     public static void setDisableIndexes(Configuration configuration, String indexName) {
@@ -653,6 +659,16 @@ public final class PhoenixConfigurationUtil {
         configuration.set(DISABLED_INDEXES, indexName);
     }
 
+    public static void setVerifyIndex(Configuration configuration, boolean verify) {
+        Preconditions.checkNotNull(configuration);
+        configuration.setBoolean(VERIFY_INDEX, verify);
+    }
+
+    public static void setOnlyVerifyIndex(Configuration configuration, boolean verify) {
+        Preconditions.checkNotNull(configuration);
+        configuration.setBoolean(ONLY_VERIFY_INDEX, verify);
+    }
+
     public static void setIndexVerifyType(Configuration configuration, IndexTool.IndexVerifyType verifyType) {
         Preconditions.checkNotNull(configuration);
         configuration.set(INDEX_VERIFY_TYPE, verifyType.getValue());
@@ -802,6 +818,16 @@ public final class PhoenixConfigurationUtil {
         return configuration.get(DISABLED_INDEXES);
     }
 
+    public static boolean getVerifyIndex(Configuration configuration) {
+        Preconditions.checkNotNull(configuration);
+        return configuration.getBoolean(VERIFY_INDEX, false);
+    }
+
+    public static boolean getOnlyVerifyIndex(Configuration configuration) {
+        Preconditions.checkNotNull(configuration);
+        return configuration.getBoolean(ONLY_VERIFY_INDEX, false);
+    }
+
     public static IndexTool.IndexVerifyType getIndexVerifyType(Configuration configuration) {
         Preconditions.checkNotNull(configuration);
         String value = configuration.get(INDEX_VERIFY_TYPE, IndexTool.IndexVerifyType.NONE.getValue());
@@ -872,7 +898,7 @@ public final class PhoenixConfigurationUtil {
     public static boolean isMRSnapshotManagedExternally(final Configuration configuration) {
         Preconditions.checkNotNull(configuration);
         boolean isSnapshotRestoreManagedExternally =
-            configuration.getBoolean(MAPREDUCE_EXTERNAL_SNAPSHOT_RESTORE, DEFAULT_MAPREDUCE_EXTERNAL_SNAPSHOT_RESTORE);
+                configuration.getBoolean(MAPREDUCE_EXTERNAL_SNAPSHOT_RESTORE, DEFAULT_MAPREDUCE_EXTERNAL_SNAPSHOT_RESTORE);
         return isSnapshotRestoreManagedExternally;
     }
 
