@@ -33,14 +33,14 @@ import java.util.concurrent.ExecutionException;
 
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.HRegionInfo;
 import org.apache.hadoop.hbase.HRegionLocation;
 import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.TableName;
-import org.apache.hadoop.hbase.client.HBaseAdmin;
-import org.apache.hadoop.hbase.client.HTableInterface;
+import org.apache.hadoop.hbase.client.Admin;
 import org.apache.hadoop.hbase.client.Mutation;
+import org.apache.hadoop.hbase.client.RegionInfo;
+import org.apache.hadoop.hbase.client.RegionInfoBuilder;
 import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 import org.apache.hadoop.hbase.security.User;
@@ -97,8 +97,8 @@ import org.apache.phoenix.util.ReadOnlyProps;
 import org.apache.phoenix.util.SchemaUtil;
 import org.apache.phoenix.util.SequenceUtil;
 
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 
 /**
  *
@@ -208,7 +208,7 @@ public class ConnectionlessQueryServicesImpl extends DelegateQueryServices imple
     }
 
     @Override
-    public HTableInterface getTable(byte[] tableName) throws SQLException {
+    public Table getTable(byte[] tableName) throws SQLException {
         throw new UnsupportedOperationException();
     }
 
@@ -223,9 +223,11 @@ public class ConnectionlessQueryServicesImpl extends DelegateQueryServices imple
         if (regions != null) {
             return regions;
         }
-        return Collections.singletonList(new HRegionLocation(
-            new HRegionInfo(TableName.valueOf(tableName), HConstants.EMPTY_START_ROW, HConstants.EMPTY_END_ROW),
-            SERVER_NAME, -1));
+        RegionInfo hri =
+                RegionInfoBuilder.newBuilder(TableName.valueOf(tableName))
+                        .setStartKey(HConstants.EMPTY_START_ROW)
+                        .setStartKey(HConstants.EMPTY_END_ROW).build();
+        return Collections.singletonList(new HRegionLocation(hri, SERVER_NAME, -1));
     }
 
     @Override
@@ -286,14 +288,14 @@ public class ConnectionlessQueryServicesImpl extends DelegateQueryServices imple
         byte[] startKey = HConstants.EMPTY_START_ROW;
         List<HRegionLocation> regions = Lists.newArrayListWithExpectedSize(splits.length);
         for (byte[] split : splits) {
-            regions.add(new HRegionLocation(
-                    new HRegionInfo(TableName.valueOf(physicalName), startKey, split),
-                    SERVER_NAME, -1));
+            regions.add(new HRegionLocation(RegionInfoBuilder
+                    .newBuilder(TableName.valueOf(physicalName)).setStartKey(startKey)
+                    .setEndKey(split).build(), SERVER_NAME, -1));
             startKey = split;
         }
-        regions.add(new HRegionLocation(
-                new HRegionInfo(TableName.valueOf(physicalName), startKey, HConstants.EMPTY_END_ROW),
-                SERVER_NAME, -1));
+        regions.add(new HRegionLocation(RegionInfoBuilder
+                .newBuilder(TableName.valueOf(physicalName)).setStartKey(startKey)
+                .setEndKey(HConstants.EMPTY_END_ROW).build(), SERVER_NAME, -1));
         return regions;
     }
     
@@ -453,7 +455,7 @@ public class ConnectionlessQueryServicesImpl extends DelegateQueryServices imple
     }
 
     @Override
-    public HBaseAdmin getAdmin() throws SQLException {
+    public Admin getAdmin() throws SQLException {
         throw new UnsupportedOperationException();
     }
 
@@ -493,7 +495,7 @@ public class ConnectionlessQueryServicesImpl extends DelegateQueryServices imple
     }
 
     @Override
-    public void clearTableRegionCache(byte[] tableName) throws SQLException {
+    public void clearTableRegionCache(TableName tableName) throws SQLException {
     }
 
     @Override
@@ -692,16 +694,16 @@ public class ConnectionlessQueryServicesImpl extends DelegateQueryServices imple
     public HRegionLocation getTableRegionLocation(byte[] tableName, byte[] row) throws SQLException {
        List<HRegionLocation> regions = tableSplits.get(Bytes.toString(tableName));
        if (regions != null) {
-               for(HRegionLocation region: regions) {
-                       if (Bytes.compareTo(region.getRegionInfo().getStartKey(), row) <= 0
-                                       && Bytes.compareTo(region.getRegionInfo().getEndKey(), row) > 0) {
-                           return region;
-                       }
-               }
+            for (HRegionLocation region : regions) {
+                if (Bytes.compareTo(region.getRegion().getStartKey(), row) <= 0
+                        && Bytes.compareTo(region.getRegion().getEndKey(), row) > 0) {
+                    return region;
+                }
+            }
        }
-       return new HRegionLocation(
-                       new HRegionInfo(TableName.valueOf(tableName), HConstants.EMPTY_START_ROW, HConstants.EMPTY_END_ROW),
-                       SERVER_NAME, -1);
+        return new HRegionLocation(RegionInfoBuilder.newBuilder(TableName.valueOf(tableName))
+                .setStartKey(HConstants.EMPTY_START_ROW).setEndKey(HConstants.EMPTY_END_ROW)
+                .build(), SERVER_NAME, -1);
     }
 
     @Override
@@ -737,8 +739,8 @@ public class ConnectionlessQueryServicesImpl extends DelegateQueryServices imple
      * Manually adds {@link GuidePostsInfo} for a table to the client-side cache. Not a
      * {@link ConnectionQueryServices} method. Exposed for testing purposes.
      *
-     * @param tableName Table name
-     * @param stats Stats instance
+     * @param key
+     * @param info
      */
     public void addTableStats(GuidePostsKey key, GuidePostsInfo info) {
         this.guidePostsCache.put(Objects.requireNonNull(key), info);
