@@ -71,7 +71,7 @@ public interface QueryServices extends SQLCloseable {
     /**
 	 * max size to spool the the result into
 	 * ${java.io.tmpdir}/ResultSpoolerXXX.bin if
-	 * {@link QueryServices#SPOOL_THRESHOLD_BYTES_ATTRIB } is reached.
+	 * QueryServices#SPOOL_THRESHOLD_BYTES_ATTRIB is reached.
 	 * <p>
 	 * default is unlimited(-1)
 	 * <p>
@@ -309,9 +309,11 @@ public interface QueryServices extends SQLCloseable {
     public static final String WILDCARD_QUERY_DYNAMIC_COLS_ATTRIB =
             "phoenix.query.wildcard.dynamicColumns";
     public static final String LOG_LEVEL = "phoenix.log.level";
+    public static final String AUDIT_LOG_LEVEL = "phoenix.audit.log.level";
     public static final String LOG_BUFFER_SIZE = "phoenix.log.buffer.size";
     public static final String LOG_BUFFER_WAIT_STRATEGY = "phoenix.log.wait.strategy";
     public static final String LOG_SAMPLE_RATE = "phoenix.log.sample.rate";
+    public static final String LOG_HANDLER_COUNT = "phoenix.log.handler.count";
 
 	public static final String SYSTEM_CATALOG_SPLITTABLE = "phoenix.system.catalog.splittable";
 
@@ -337,6 +339,7 @@ public interface QueryServices extends SQLCloseable {
     // The time limit on the amount of work to be done in one RPC call
     public static final String PHOENIX_SERVER_PAGE_SIZE_MS = "phoenix.server.page.size.ms";
 
+
     // Before 4.15 when we created a view we included the parent table column metadata in the view
     // metadata. After PHOENIX-3534 we allow SYSTEM.CATALOG to split and no longer store the parent
     // table column metadata along with the child view metadata. When we resolve a child view, we
