@@ -65,7 +65,7 @@ import java.util.Map.Entry;
 
 import javax.annotation.Nonnull;
 
-import com.google.common.annotations.VisibleForTesting;
+import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.client.Delete;
@@ -112,15 +112,15 @@ import org.apache.phoenix.util.SchemaUtil;
 import org.apache.phoenix.util.SizedUtil;
 import org.apache.phoenix.util.TrustedByteArrayOutputStream;
 
-import com.google.common.base.Objects;
-import com.google.common.base.Preconditions;
-import com.google.common.collect.ArrayListMultimap;
-import com.google.common.collect.ImmutableList;
-import com.google.common.collect.ImmutableMap;
-import com.google.common.collect.ImmutableSortedMap;
-import com.google.common.collect.ListMultimap;
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.base.Objects;
+import org.apache.phoenix.thirdparty.com.google.common.base.Preconditions;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ArrayListMultimap;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableList;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableMap;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableSortedMap;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ListMultimap;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 
 
 /**
@@ -807,8 +807,8 @@ public class PTableImpl implements PTable {
     @VisibleForTesting
     PTableImpl() {
         this(new PTableImpl.Builder()
-                .setIndexes(Collections.<PTable>emptyList())
-                .setPhysicalNames(Collections.<PName>emptyList())
+                .setIndexes(Collections.emptyList())
+                .setPhysicalNames(Collections.emptyList())
                 .setRowKeySchema(RowKeySchema.EMPTY_SCHEMA));
     }
 
@@ -924,7 +924,7 @@ public class PTableImpl implements PTable {
                 .setEncodedCQCounter(table.getEncodedCQCounter())
                 .setUseStatsForParallelization(table.useStatsForParallelization())
                 .setExcludedColumns(table.getExcludedColumns() == null ?
-                        ImmutableList.<PColumn>of() : ImmutableList.copyOf(table.getExcludedColumns()))
+                        ImmutableList.of() : ImmutableList.copyOf(table.getExcludedColumns()))
                 .setTenantId(table.getTenantId())
                 .setSchemaName(table.getSchemaName())
                 .setTableName(table.getTableName())
@@ -933,11 +933,11 @@ public class PTableImpl implements PTable {
                 .setRowKeyOrderOptimizable(table.rowKeyOrderOptimizable())
                 .setBucketNum(table.getBucketNum())
                 .setIndexes(table.getIndexes() == null ?
-                        Collections.<PTable>emptyList() : table.getIndexes())
+                        Collections.emptyList() : table.getIndexes())
                 .setParentSchemaName(table.getParentSchemaName())
                 .setParentTableName(table.getParentTableName())
                 .setPhysicalNames(table.getPhysicalNames() == null ?
-                        ImmutableList.<PName>of() : ImmutableList.copyOf(table.getPhysicalNames()))
+                        ImmutableList.of() : ImmutableList.copyOf(table.getPhysicalNames()))
                 .setViewModifiedUseStatsForParallelization(table
                         .hasViewModifiedUseStatsForParallelization())
                 .setViewModifiedUpdateCacheFrequency(table.hasViewModifiedUpdateCacheFrequency())
@@ -1391,7 +1391,7 @@ public class PTableImpl implements PTable {
                 String fam = Bytes.toString(family);
                 if (column.isDynamic()) {
                     if (!this.colFamToDynamicColumnsMapping.containsKey(fam)) {
-                        this.colFamToDynamicColumnsMapping.put(fam, new ArrayList<PColumn>());
+                        this.colFamToDynamicColumnsMapping.put(fam, new ArrayList<>());
                     }
                     this.colFamToDynamicColumnsMapping.get(fam).add(column);
                 }
@@ -1432,7 +1432,6 @@ public class PTableImpl implements PTable {
             setValues.setAttribute(DYNAMIC_COLUMN_METADATA_STORED_FOR_MUTATION, TRUE_BYTES);
         }
 
-        @SuppressWarnings("deprecation")
         @Override
         public void delete() {
             newMutations();
@@ -1444,13 +1443,12 @@ public class PTableImpl implements PTable {
                     delete.addFamily(colFamily.getName().getBytes(), ts);
                 }
             }
-
             deleteRow = delete;
-
             if (isWALDisabled()) {
                 deleteRow.setDurability(Durability.SKIP_WAL);
             }
         }
+        
     }
 
     @Override
@@ -1825,7 +1823,7 @@ public class PTableImpl implements PTable {
                     .setUseStatsForParallelization(useStatsForParallelization)
                     .setPhoenixTTL(phoenixTTL)
                     .setPhoenixTTLHighWaterMark(phoenixTTLHighWaterMark)
-                    .setExcludedColumns(ImmutableList.<PColumn>of())
+                    .setExcludedColumns(ImmutableList.of())
                     .setTenantId(tenantId)
                     .setSchemaName(schemaName)
                     .setTableName(tableName)
@@ -1833,11 +1831,11 @@ public class PTableImpl implements PTable {
                     .setDefaultFamilyName(defaultFamilyName)
                     .setRowKeyOrderOptimizable(rowKeyOrderOptimizable)
                     .setBucketNum((bucketNum == NO_SALTING) ? null : bucketNum)
-                    .setIndexes(indexes == null ? Collections.<PTable>emptyList() : indexes)
+                    .setIndexes(indexes == null ? Collections.emptyList() : indexes)
                     .setParentSchemaName(parentSchemaName)
                     .setParentTableName(parentTableName)
                     .setPhysicalNames(physicalNames == null ?
-                            ImmutableList.<PName>of() : ImmutableList.copyOf(physicalNames))
+                            ImmutableList.of() : ImmutableList.copyOf(physicalNames))
                     .setColumns(columns)
                     .setViewModifiedUpdateCacheFrequency(viewModifiedUpdateCacheFrequency)
                     .setViewModifiedUseStatsForParallelization(viewModifiedUseStatsForParallelization)
