@@ -27,10 +27,9 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
 
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.client.Delete;
-import org.apache.hadoop.hbase.client.HTableInterface;
-import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.Table;
+import org.apache.hadoop.hbase.client.Delete;
+import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.Pair;
@@ -61,7 +60,8 @@ import org.apache.tephra.visibility.VisibilityFence;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+
 
 public class TephraTransactionContext implements PhoenixTransactionContext {
     private static final Logger LOGGER = LoggerFactory.getLogger(TephraTransactionContext.class);
@@ -482,13 +482,14 @@ public class TephraTransactionContext implements PhoenixTransactionContext {
                             deletes.iterator());
                     for (PTable index : indexes) {
                         byte[] physicalName = index.getPhysicalName().getBytes();
-                        try (HTableInterface hindex = connection.getQueryServices().getTable(physicalName)) {
+                        try (Table hindex = connection.getQueryServices().getTable(physicalName)) {
                             List<Mutation> indexDeletes = Lists.newArrayListWithExpectedSize(deletes.size());
                             for (Pair<Mutation, byte[]> mutationPair : indexUpdates) {
                                 if (Bytes.equals(mutationPair.getSecond(), physicalName)) {
                                     indexDeletes.add(mutationPair.getFirst());
                                 }
-                                hindex.batch(indexDeletes);
+                                Object[] results = new Object[indexDeletes.size()];
+                                hindex.batch(indexDeletes, results);
                             }
                         } catch (InterruptedException e) {
                             Thread.currentThread().interrupt();
