@@ -25,30 +25,31 @@ import java.io.IOException;
 import java.sql.SQLException;
 import java.util.*;
 
-import com.google.common.annotations.VisibleForTesting;
+import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellUtil;
-import org.apache.hadoop.hbase.HColumnDescriptor;
+import org.apache.hadoop.hbase.ExtendedCell;
+import org.apache.hadoop.hbase.ExtendedCellBuilder;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.HRegionLocation;
-import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.ServerName;
-import org.apache.hadoop.hbase.Tag;
+import org.apache.hadoop.hbase.TagUtil;
+import org.apache.hadoop.hbase.client.ClusterConnection;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
+import org.apache.hadoop.hbase.client.ConnectionFactory;
 import org.apache.hadoop.hbase.client.Delete;
-import org.apache.hadoop.hbase.client.HConnection;
-import org.apache.hadoop.hbase.client.HConnectionManager;
 import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.Put;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.Scan;
+import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
-import org.apache.hadoop.hbase.protobuf.ProtobufUtil;
-import org.apache.hadoop.hbase.protobuf.RequestConverter;
-import org.apache.hadoop.hbase.protobuf.generated.AdminProtos.AdminService;
-import org.apache.hadoop.hbase.protobuf.generated.AdminProtos.GetRegionInfoRequest;
+import org.apache.hadoop.hbase.ipc.HBaseRpcController;
+import org.apache.hadoop.hbase.shaded.protobuf.generated.AdminProtos.AdminService;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.ipc.RemoteException;
 import org.apache.phoenix.coprocessor.MetaDataEndpointImpl;
@@ -75,11 +76,9 @@ import org.apache.phoenix.schema.types.PUnsignedTinyint;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.collect.ImmutableList;
-import com.google.common.collect.Iterables;
-import com.google.common.collect.Lists;
-import com.google.protobuf.ServiceException;
-
+import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableList;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Iterables;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 public class MetaDataUtil {
     private static final Logger LOGGER = LoggerFactory.getLogger(MetaDataUtil.class);
@@ -103,9 +102,9 @@ public class MetaDataUtil {
 
     // See PHOENIX-3955
     public static final List<String> SYNCED_DATA_TABLE_AND_INDEX_COL_FAM_PROPERTIES = ImmutableList.of(
-            HColumnDescriptor.TTL,
-            HColumnDescriptor.KEEP_DELETED_CELLS,
-            HColumnDescriptor.REPLICATION_SCOPE);
+            ColumnFamilyDescriptorBuilder.TTL,
+            ColumnFamilyDescriptorBuilder.KEEP_DELETED_CELLS,
+            ColumnFamilyDescriptorBuilder.REPLICATION_SCOPE);
 
     public static Put getLastDDLTimestampUpdate(byte[] tableHeaderRowKey,
                                                      long clientTimestamp,
@@ -126,7 +125,7 @@ public class MetaDataUtil {
      * @return True if a table or view, false otherwise (such as for an index, system table, or
      * subquery)
      */
-    public static boolean isTableTypeDirectlyQueried(PTableType tableType) {
+    public static boolean isTableDirectlyQueried(PTableType tableType) {
         return tableType.equals(PTableType.TABLE) || tableType.equals(PTableType.VIEW);
     }
 
@@ -232,8 +231,8 @@ public class MetaDataUtil {
      * Encode HBase and Phoenix version along with some server-side config information such as whether WAL codec is
      * installed (necessary for non transactional, mutable secondar indexing), and whether systemNamespace mapping is enabled.
      * 
-     * @param env
-     *            RegionCoprocessorEnvironment to access HBase version and Configuration.
+     * @param hbaseVersionStr
+     * @param config
      * @return long value sent back during initialization of a cluster connection.
      */
     public static long encodeVersion(String hbaseVersionStr, Configuration config) {
@@ -301,7 +300,7 @@ public class MetaDataUtil {
                     Cell replacementCell = new KeyValue(cell.getRowArray(), cell.getRowOffset(), cell.getRowLength(),
                         cell.getFamilyArray(), cell.getFamilyOffset(), cell.getFamilyLength(), cell.getQualifierArray(),
                         cell.getQualifierOffset(), cell.getQualifierLength(), cell.getTimestamp(),
-                        KeyValue.Type.codeToType(cell.getTypeByte()), newValue, 0, newValue.length);
+                        KeyValue.Type.codeToType(cell.getType().getCode()), newValue, 0, newValue.length);
                     newCells.add(replacementCell);
                 } else {
                     newCells.add(cell);
@@ -319,11 +318,12 @@ public class MetaDataUtil {
      * @param somePut Put operation
      * @param family column family of the cells
      * @param qualifier column qualifier of the cells
+     * @param cellBuilder ExtendedCellBuilder object
      * @param valueArray byte array of values or null
      * @param tagArray byte array of tags to add to the cells
      */
     public static void conditionallyAddTagsToPutCells(Put somePut, byte[] family, byte[] qualifier,
-            byte[] valueArray, byte[] tagArray) {
+            ExtendedCellBuilder cellBuilder, byte[] valueArray, byte[] tagArray) {
         NavigableMap<byte[], List<Cell>> familyCellMap = somePut.getFamilyCellMap();
         List<Cell> cells = familyCellMap.get(family);
         List<Cell> newCells = Lists.newArrayList();
@@ -332,18 +332,20 @@ public class MetaDataUtil {
                 if (Bytes.compareTo(cell.getQualifierArray(), cell.getQualifierOffset(),
                         cell.getQualifierLength(), qualifier, 0, qualifier.length) == 0 &&
                         (valueArray == null || !CellUtil.matchingValue(cell, valueArray))) {
-                    final byte[] combinedTags =
-                            ByteUtil.concat(CellUtil.getTagArray(cell), tagArray);
-                    Cell newCell = CellUtil.createCell(
-                            CellUtil.cloneRow(cell),
-                            CellUtil.cloneFamily(cell),
-                            CellUtil.cloneQualifier(cell),
-                            cell.getTimestamp(),
-                            KeyValue.Type.codeToType(cell.getTypeByte()),
-                            CellUtil.cloneValue(cell),
-                            combinedTags);
+                    ExtendedCell extendedCell = cellBuilder
+                            .setRow(cell.getRowArray(), cell.getRowOffset(), cell.getRowLength())
+                            .setFamily(cell.getFamilyArray(), cell.getFamilyOffset(),
+                                    cell.getFamilyLength())
+                            .setQualifier(cell.getQualifierArray(), cell.getQualifierOffset(),
+                                    cell.getQualifierLength())
+                            .setValue(cell.getValueArray(), cell.getValueOffset(),
+                                    cell.getValueLength())
+                            .setTimestamp(cell.getTimestamp())
+                            .setType(cell.getType())
+                            .setTags(TagUtil.concatTags(tagArray, cell))
+                            .build();
                     // Replace existing cell with a cell that has the custom tags list
-                    newCells.add(newCell);
+                    newCells.add(extendedCell);
                 } else {
                     // Add cell as is
                     newCells.add(cell);
@@ -468,7 +470,7 @@ public class MetaDataUtil {
         List<Cell> kvs = headerRow.getFamilyCellMap().get(PhoenixDatabaseMetaData.TABLE_FAMILY_BYTES);
         if (kvs != null) {
             for (Cell cell : kvs) {
-                KeyValue kv = org.apache.hadoop.hbase.KeyValueUtil.ensureKeyValue(cell);
+                KeyValue kv = PhoenixKeyValueUtil.maybeCopyCell(cell);
                 if (builder.compareQualifier(kv, key, 0, key.length) ==0) {
                     builder.getValueAsPtr(kv, ptr);
                     return true;
@@ -734,7 +736,7 @@ public class MetaDataUtil {
             throws SQLException {
         byte[] physicalIndexName = MetaDataUtil.getViewIndexPhysicalName(physicalTableName);
         try {
-            HTableDescriptor desc = connection.getQueryServices().getTableDescriptor(physicalIndexName);
+            TableDescriptor desc = connection.getQueryServices().getTableDescriptor(physicalIndexName);
             return desc != null && Boolean.TRUE.equals(PBoolean.INSTANCE.toObject(desc.getValue(IS_VIEW_INDEX_TABLE_PROP_BYTES)));
         } catch (TableNotFoundException e) {
             return false;
@@ -747,7 +749,7 @@ public class MetaDataUtil {
 
     public static boolean hasLocalIndexTable(PhoenixConnection connection, byte[] physicalTableName) throws SQLException {
         try {
-            HTableDescriptor desc = connection.getQueryServices().getTableDescriptor(physicalTableName);
+            TableDescriptor desc = connection.getQueryServices().getTableDescriptor(physicalTableName);
             if(desc == null ) return false;
             return hasLocalIndexColumnFamily(desc);
         } catch (TableNotFoundException e) {
@@ -755,8 +757,8 @@ public class MetaDataUtil {
         }
     }
 
-    public static boolean hasLocalIndexColumnFamily(HTableDescriptor desc) {
-        for (HColumnDescriptor cf : desc.getColumnFamilies()) {
+    public static boolean hasLocalIndexColumnFamily(TableDescriptor desc) {
+        for (ColumnFamilyDescriptor cf : desc.getColumnFamilies()) {
             if (cf.getNameAsString().startsWith(QueryConstants.LOCAL_INDEX_COLUMN_FAMILY_PREFIX)) {
                 return true;
             }
@@ -764,9 +766,9 @@ public class MetaDataUtil {
         return false;
     }
 
-    public static List<byte[]> getNonLocalIndexColumnFamilies(HTableDescriptor desc) {
+    public static List<byte[]> getNonLocalIndexColumnFamilies(TableDescriptor desc) {
     	List<byte[]> families = new ArrayList<byte[]>(desc.getColumnFamilies().length);
-        for (HColumnDescriptor cf : desc.getColumnFamilies()) {
+        for (ColumnFamilyDescriptor cf : desc.getColumnFamilies()) {
             if (!cf.getNameAsString().startsWith(QueryConstants.LOCAL_INDEX_COLUMN_FAMILY_PREFIX)) {
             	families.add(cf.getName());
             }
@@ -775,10 +777,10 @@ public class MetaDataUtil {
     }
 
     public static List<byte[]> getLocalIndexColumnFamilies(PhoenixConnection conn, byte[] physicalTableName) throws SQLException {
-        HTableDescriptor desc = conn.getQueryServices().getTableDescriptor(physicalTableName);
+        TableDescriptor desc = conn.getQueryServices().getTableDescriptor(physicalTableName);
         if(desc == null ) return Collections.emptyList();
         List<byte[]> families = new ArrayList<byte[]>(desc.getColumnFamilies().length / 2);
-        for (HColumnDescriptor cf : desc.getColumnFamilies()) {
+        for (ColumnFamilyDescriptor cf : desc.getColumnFamilies()) {
             if (cf.getNameAsString().startsWith(QueryConstants.LOCAL_INDEX_COLUMN_FAMILY_PREFIX)) {
                 families.add(cf.getName());
             }
@@ -799,14 +801,13 @@ public class MetaDataUtil {
     
     /**
      * This function checks if all regions of a table is online
+     * @param conf
      * @param table
      * @return true when all regions of a table are online
-     * @throws IOException
-     * @throws
      */
     public static boolean tableRegionsOnline(Configuration conf, PTable table) {
-        try (HConnection hcon =
-               HConnectionManager.getConnection(conf)) {
+        try (ClusterConnection hcon =
+                (ClusterConnection) ConnectionFactory.createConnection(conf)) {
             List<HRegionLocation> locations = hcon.locateRegions(
               org.apache.hadoop.hbase.TableName.valueOf(table.getPhysicalName().getBytes()));
 
@@ -816,16 +817,11 @@ public class MetaDataUtil {
                     if (sn == null) continue;
 
                     AdminService.BlockingInterface admin = hcon.getAdmin(sn);
-                    GetRegionInfoRequest request = RequestConverter.buildGetRegionInfoRequest(
-                        loc.getRegionInfo().getRegionName());
-
-                    admin.getRegionInfo(null, request);
-                } catch (ServiceException e) {
-                    IOException ie = ProtobufUtil.getRemoteException(e);
-                    LOGGER.debug("Region " + loc.getRegionInfo().getEncodedName() + " isn't online due to:" + ie);
-                    return false;
+                    HBaseRpcController controller = hcon.getRpcControllerFactory().newController();
+                    org.apache.hadoop.hbase.shaded.protobuf.ProtobufUtil.getRegionInfo(controller,
+                        admin, loc.getRegion().getRegionName());
                 } catch (RemoteException e) {
-                    LOGGER.debug("Cannot get region " + loc.getRegionInfo().getEncodedName() + " info due to error:" + e);
+                    LOGGER.debug("Cannot get region " + loc.getRegion().getEncodedName() + " info due to error:" + e);
                     return false;
                 }
             }
@@ -840,7 +836,7 @@ public class MetaDataUtil {
         return SYNCED_DATA_TABLE_AND_INDEX_COL_FAM_PROPERTIES.contains(colFamProp);
     }
 
-    public static Map<String, Object> getSyncedProps(HColumnDescriptor defaultCFDesc) {
+    public static Map<String, Object> getSyncedProps(ColumnFamilyDescriptor defaultCFDesc) {
         Map<String, Object> syncedProps = new HashMap<>();
         if (defaultCFDesc != null) {
             for (String propToKeepInSync: SYNCED_DATA_TABLE_AND_INDEX_COL_FAM_PROPERTIES) {
@@ -922,7 +918,7 @@ public class MetaDataUtil {
     }
 
     public static boolean isHColumnProperty(String propName) {
-        return HColumnDescriptor.getDefaultValues().containsKey(propName);
+        return ColumnFamilyDescriptorBuilder.getDefaultValues().containsKey(propName);
     }
 
     public static boolean isHTableProperty(String propName) {
@@ -955,7 +951,7 @@ public class MetaDataUtil {
 		Iterator<Mutation> iter = metadataMutations.iterator();
 		while (iter.hasNext()) {
 			Mutation m = iter.next();
-			for (KeyValue kv : m.getFamilyMap().get(PhoenixDatabaseMetaData.TABLE_FAMILY_BYTES)) {
+			for (Cell kv : m.getFamilyCellMap().get(PhoenixDatabaseMetaData.TABLE_FAMILY_BYTES)) {
 				// remove mutations of link type LinkType.CHILD_TABLE
 				if ((Bytes.compareTo(kv.getQualifierArray(), kv.getQualifierOffset(), kv.getQualifierLength(),
 						PhoenixDatabaseMetaData.LINK_TYPE_BYTES, 0,
