@@ -25,39 +25,32 @@ import static org.apache.phoenix.hbase.index.write.IndexWriterUtils.INDEX_WRITER
 import java.io.IOException;
 import java.sql.SQLException;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.ExecutorService;
+import java.util.function.Function;
 import java.util.concurrent.Future;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
 import org.apache.hadoop.conf.Configuration;
-import org.apache.hadoop.hbase.CoprocessorEnvironment;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.NotServingRegionException;
 import org.apache.hadoop.hbase.TableName;
-import org.apache.hadoop.hbase.client.ClusterConnection;
-import org.apache.hadoop.hbase.client.CoprocessorHConnection;
-import org.apache.hadoop.hbase.client.HTableInterface;
-import org.apache.hadoop.hbase.client.HTablePool;
+import org.apache.hadoop.hbase.client.Connection;
 import org.apache.hadoop.hbase.client.RetriesExhaustedWithDetailsException;
 import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.coprocessor.RegionCoprocessorEnvironment;
 import org.apache.hadoop.hbase.ipc.RpcControllerFactory;
 import org.apache.hadoop.hbase.ipc.controller.InterRegionServerIndexRpcControllerFactory;
-import org.apache.hadoop.hbase.regionserver.HRegionServer;
 import org.apache.hadoop.hbase.regionserver.Region;
-import org.apache.hadoop.hbase.regionserver.RegionServerServices;
+import org.apache.hadoop.hbase.regionserver.Region.RowLock;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.coprocessor.HashJoinCacheNotFoundException;
 import org.apache.phoenix.exception.PhoenixIOException;
 import org.apache.phoenix.exception.SQLExceptionCode;
 import org.apache.phoenix.exception.SQLExceptionInfo;
-import org.apache.phoenix.hbase.index.table.CoprocessorHTableFactory;
-import org.apache.phoenix.hbase.index.table.HTableFactory;
-import org.apache.phoenix.hbase.index.util.ImmutableBytesPtr;
 import org.apache.phoenix.hbase.index.util.IndexManagementUtil;
 import org.apache.phoenix.hbase.index.util.VersionUtil;
 import org.apache.phoenix.hbase.index.write.IndexWriterUtils;
@@ -67,10 +60,9 @@ import org.apache.phoenix.schema.StaleRegionBoundaryCacheException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-@SuppressWarnings("deprecation")
 public class ServerUtil {
-    private static final Logger LOGGER = LoggerFactory.getLogger(ServerUtil.class);
     private static final int COPROCESSOR_SCAN_WORKS = VersionUtil.encodeVersion("0.98.6");
+    private static final Logger LOGGER = LoggerFactory.getLogger(ServerUtil.class);
     
     private static final String FORMAT = "ERROR %d (%s): %s";
     private static final Pattern PATTERN = Pattern.compile("ERROR (\\d+) \\((\\w+)\\): (.*)");
@@ -202,14 +194,13 @@ public class ServerUtil {
      * This code works around HBASE-11837 which causes HTableInterfaces retrieved from
      * RegionCoprocessorEnvironment to not read local data.
      */
-    private static HTableInterface getTableFromSingletonPool(RegionCoprocessorEnvironment env, byte[] tableName) throws IOException {
+    private static Table getTableFromSingletonPool(RegionCoprocessorEnvironment env, TableName tableName) throws IOException {
         // It's ok to not ever do a pool.close() as we're storing a single
         // table only. The HTablePool holds no other resources that this table
         // which will be closed itself when it's no longer needed.
-        @SuppressWarnings("resource")
-        HTablePool pool = new HTablePool(env.getConfiguration(),1);
+        Connection conn = ConnectionFactory.getConnection(ConnectionType.DEFAULT_SERVER_CONNECTION, env);
         try {
-            return pool.getTable(tableName);
+            return conn.getTable(tableName);
         } catch (RuntimeException t) {
             // handle cases that an IOE is wrapped inside a RuntimeException like HTableInterface#createHTableInterface
             if(t.getCause() instanceof IOException) {
@@ -225,12 +216,12 @@ public class ServerUtil {
         if (coprocessorScanWorks(env)) {
             return writerTable;
         }
-        return getTableFromSingletonPool(env, writerTable.getName().getName());
+        return getTableFromSingletonPool(env, writerTable.getName());
     }
     
-    public static HTableInterface getHTableForCoprocessorScan (RegionCoprocessorEnvironment env, byte[] tableName) throws IOException {
+    public static Table getHTableForCoprocessorScan (RegionCoprocessorEnvironment env, TableName tableName) throws IOException {
         if (coprocessorScanWorks(env)) {
-            return env.getTable(TableName.valueOf(tableName));
+            return env.getConnection().getTable(tableName);
         }
         return getTableFromSingletonPool(env, tableName);
     }
@@ -281,54 +272,24 @@ public class ServerUtil {
                     endKey) < 0));
     }
 
-    public static HTableFactory getDelegateHTableFactory(CoprocessorEnvironment env, ConnectionType connectionType) {
-        if (env instanceof RegionCoprocessorEnvironment) {
-            RegionCoprocessorEnvironment e = (RegionCoprocessorEnvironment) env;
-            RegionServerServices services = e.getRegionServerServices();
-            if (services instanceof HRegionServer) {
-                return new CoprocessorHConnectionTableFactory(env.getConfiguration(), (HRegionServer) services, connectionType);
-            }
+    public static RowLock acquireLock(Region region, byte[] key, List<RowLock> locks)
+            throws IOException {
+        RowLock rowLock = region.getRowLock(key, false);
+        if (rowLock == null) {
+            throw new IOException("Failed to acquire lock on " + Bytes.toStringBinary(key));
         }
-        return new CoprocessorHTableFactory(env);
+        if (locks != null) {
+            locks.add(rowLock);
+        }
+        return rowLock;
     }
 
-    /**
-     * {@code HTableFactory} that creates HTables by using a {@link CoprocessorHConnection} This
-     * factory was added as a workaround to the bug reported in
-     * https://issues.apache.org/jira/browse/HBASE-18359
-     */
-    public static class CoprocessorHConnectionTableFactory implements HTableFactory {
-        private final Configuration conf;
-        private final HRegionServer server;
-        private final ConnectionType connectionType;
-
-        CoprocessorHConnectionTableFactory(Configuration conf, HRegionServer server, ConnectionType connectionType) {
-            this.conf = conf;
-            this.server = server;
-            this.connectionType = connectionType;
-        }
-
-        private ClusterConnection getConnection() throws IOException {
-            return ConnectionFactory.getConnection(connectionType, conf, server);
-        }
-
-        @Override
-        public HTableInterface getTable(ImmutableBytesPtr tablename) throws IOException {
-            return getConnection().getTable(tablename.copyBytesIfNecessary());
-        }
-
-        @Override
-        public void shutdown() {
-      // close the connections when region server is going down
-      if (this.server.isStopping() || this.server.isStopped() || this.server.isAborted()) {
-        ConnectionFactory.shutdown();
-      }
-        }
-
-        @Override
-        public HTableInterface getTable(ImmutableBytesPtr tablename, ExecutorService pool)
-                throws IOException {
-            return getConnection().getTable(tablename.copyBytesIfNecessary(), pool);
+    public static void releaseRowLocks(List<RowLock> rowLocks) {
+        if (rowLocks != null) {
+            for (RowLock rowLock : rowLocks) {
+                rowLock.release();
+            }
+            rowLocks.clear();
         }
     }
 
@@ -342,35 +303,20 @@ public class ServerUtil {
 
     public static class ConnectionFactory {
         
-        private static Map<ConnectionType, ClusterConnection> connections =
-                new ConcurrentHashMap<ConnectionType, ClusterConnection>();
+        private static Map<ConnectionType, Connection> connections =
+                new ConcurrentHashMap<ConnectionType, Connection>();
 
-        public static void shutdown() {
-            synchronized (CoprocessorHConnectionTableFactory.class) {
-                for (ClusterConnection connection : connections.values()) {
+        public static Connection getConnection(final ConnectionType connectionType, final RegionCoprocessorEnvironment env) {
+            return connections.computeIfAbsent(connectionType, new Function<ConnectionType, Connection>() {
+                @Override
+                    public Connection apply(ConnectionType t) {
                     try {
-                        connection.close();
+                        return env.createConnection(getTypeSpecificConfiguration(connectionType, env.getConfiguration()));
                     } catch (IOException e) {
-                        LOGGER.warn("Unable to close coprocessor connection", e);
+                       throw new RuntimeException(e);
                     }
                 }
-                connections.clear();
-            }
-        }
-            
-        
-        public static ClusterConnection getConnection(final ConnectionType connectionType, final Configuration conf, final HRegionServer server) throws IOException {
-            ClusterConnection connection = null;
-            if((connection = connections.get(connectionType)) == null) {
-                synchronized (CoprocessorHConnectionTableFactory.class) {
-                    if((connection = connections.get(connectionType)) == null) {
-                        connection = new CoprocessorHConnection(getTypeSpecificConfiguration(connectionType, conf), server);
-                        connections.put(connectionType, connection);
-                        return connection;
-                    }
-                }
-            }
-            return connection;
+            });
         }
 
         public static Configuration getTypeSpecificConfiguration(ConnectionType connectionType, Configuration conf) {
@@ -388,15 +334,26 @@ public class ServerUtil {
             default:
                 return conf;
             }
+         }
+        
+        public static void shutdown() {
+            synchronized (ConnectionFactory.class) {
+                for (Connection connection : connections.values()) {
+                    try {
+                        connection.close();
+                    } catch (IOException e) {
+                        LOGGER.warn("Unable to close coprocessor connection", e);
+                    }
+                }
+                connections.clear();
+            }
         }
 
-    /**
-     * Added for testing
-     */
-    public static int getConnectionsCount() {
-      return connections.size();
-    }
-    }
+        public static int getConnectionsCount() {
+            return connections.size();
+        }
+
+     }
 
     public static Configuration getCompactionConfig(Configuration conf) {
         Configuration compactionConfig = PropertiesUtil.cloneConfig(conf);
@@ -460,5 +417,4 @@ public class ServerUtil {
         }
         return t;
     }
-
 }
