@@ -15,30 +15,12 @@
  */
 package org.apache.phoenix.util;
 
-import static org.apache.phoenix.coprocessor.MetaDataProtocol.MIN_SPLITTABLE_SYSTEM_CATALOG;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.LINK_TYPE_BYTES;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.PARENT_TENANT_ID_BYTES;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME_BYTES;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.SYSTEM_CHILD_LINK_NAME;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.SYSTEM_CHILD_LINK_NAME_BYTES;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.TABLE_FAMILY_BYTES;
-import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.TABLE_TYPE_BYTES;
-import static org.apache.phoenix.schema.PTableImpl.getColumnsToClone;
-import static org.apache.phoenix.util.PhoenixRuntime.CURRENT_SCN_ATTRIB;
-import static org.apache.phoenix.util.PhoenixRuntime.TENANT_ID_ATTRIB;
-import static org.apache.phoenix.util.SchemaUtil.getVarChars;
-
-import java.io.IOException;
-import java.sql.SQLException;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collections;
-import java.util.List;
-import java.util.Map;
-import java.util.Properties;
-import java.util.Set;
-
+import org.apache.phoenix.thirdparty.com.google.common.base.Objects;
+import org.apache.phoenix.thirdparty.com.google.common.collect.ImmutableList;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.hadoop.conf.Configuration;
+import org.apache.hadoop.hbase.ExtendedCellBuilder;
 import org.apache.hadoop.hbase.HConstants;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Mutation;
@@ -81,10 +63,29 @@ import org.apache.phoenix.schema.types.PLong;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Objects;
-import com.google.common.collect.ImmutableList;
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
+import java.io.IOException;
+import java.nio.charset.StandardCharsets;
+import java.sql.SQLException;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Collections;
+import java.util.List;
+import java.util.Map;
+import java.util.Properties;
+import java.util.Set;
+
+import static org.apache.phoenix.coprocessor.MetaDataProtocol.MIN_SPLITTABLE_SYSTEM_CATALOG;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.LINK_TYPE_BYTES;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.PARENT_TENANT_ID_BYTES;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME_BYTES;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.SYSTEM_CHILD_LINK_NAME;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.SYSTEM_CHILD_LINK_NAME_BYTES;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.TABLE_FAMILY_BYTES;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.TABLE_TYPE_BYTES;
+import static org.apache.phoenix.schema.PTableImpl.getColumnsToClone;
+import static org.apache.phoenix.util.PhoenixRuntime.CURRENT_SCN_ATTRIB;
+import static org.apache.phoenix.util.PhoenixRuntime.TENANT_ID_ATTRIB;
+import static org.apache.phoenix.util.SchemaUtil.getVarChars;
 
 public class ViewUtil {
 
@@ -92,7 +93,7 @@ public class ViewUtil {
 
     /**
      * Find all the descendant views of a given table or view in a depth-first fashion.
-     * Note that apart from scanning the parent->child links, we also validate each view
+     * Note that apart from scanning the {@code parent->child } links, we also validate each view
      * by trying to resolve it.
      * Use {@link ViewUtil#findAllRelatives(Table, byte[], byte[], byte[], LinkType,
      * TableViewFinderResult)} if you want to find other links and don't care about orphan results.
@@ -284,9 +285,11 @@ public class ViewUtil {
                     continue;
                 }
                 byte[] viewSchemaName = SchemaUtil.getSchemaNameFromFullName(
-                        rowKeyMetaData[PhoenixDatabaseMetaData.FAMILY_NAME_INDEX]).getBytes();
+                        rowKeyMetaData[PhoenixDatabaseMetaData.FAMILY_NAME_INDEX])
+                        .getBytes(StandardCharsets.UTF_8);
                 byte[] viewName = SchemaUtil.getTableNameFromFullName(
-                        rowKeyMetaData[PhoenixDatabaseMetaData.FAMILY_NAME_INDEX]).getBytes();
+                        rowKeyMetaData[PhoenixDatabaseMetaData.FAMILY_NAME_INDEX])
+                        .getBytes(StandardCharsets.UTF_8);
                 tableInfoList.add(new TableInfo(viewTenantId, viewSchemaName, viewName));
             }
             return new TableViewFinderResult(tableInfoList);
@@ -295,7 +298,7 @@ public class ViewUtil {
     
     /**
      * Check metadata to find if a given table/view has any immediate child views. Note that this
-     * is not resilient to orphan parent->child links.
+     * is not resilient to orphan {@code parent->child } links.
      * @param sysCatOrsysChildLink For older (pre-4.15.0) clients, we look for child links inside
      *                             SYSTEM.CATALOG, otherwise we look for them inside
      *                             SYSTEM.CHILD_LINK
@@ -332,14 +335,15 @@ public class ViewUtil {
     }
 
     /**
-     * Attempt to drop an orphan child view i.e. a child view for which we see a parent->child entry
+     * Attempt to drop an orphan child view i.e. a child view for which we see a
+     * {@code parent->child } entry
      * in SYSTEM.CHILD_LINK/SYSTEM.CATALOG (as a child) but for whom the parent no longer exists.
      * @param env Region Coprocessor environment
      * @param tenantIdBytes tenantId of the parent
      * @param schemaName schema of the parent
      * @param tableOrViewName parent table/view name
      * @param sysCatOrSysChildLink SYSTEM.CATALOG or SYSTEM.CHILD_LINK which is used to find the
-     *                             parent->child linking rows
+     *                             {@code parent->child } linking rows
      * @throws IOException thrown if there is an error scanning SYSTEM.CHILD_LINK or SYSTEM.CATALOG
      * @throws SQLException thrown if there is an error getting a connection to the server or
      * an error retrieving the PTable for a child view
@@ -349,8 +353,9 @@ public class ViewUtil {
             throws IOException, SQLException {
         Table hTable = null;
         try {
-            hTable = ServerUtil.getHTableForCoprocessorScan(env, sysCatOrSysChildLink);
-        } catch (Exception e) {
+            hTable = ServerUtil.getHTableForCoprocessorScan(env, SchemaUtil.getPhysicalTableName(
+                            sysCatOrSysChildLink, env.getConfiguration()));
+        } catch (Exception e){
             logger.error("ServerUtil.getHTableForCoprocessorScan error!", e);
         }
         // if the SYSTEM.CATALOG or SYSTEM.CHILD_LINK doesn't exist just return
@@ -368,7 +373,7 @@ public class ViewUtil {
                     LinkType.CHILD_TABLE,
                     HConstants.LATEST_TIMESTAMP);
         } finally {
-           hTable.close();
+            hTable.close();
         }
 
         for (TableInfo viewInfo : childViewsResult.getLinks()) {
@@ -431,8 +436,8 @@ public class ViewUtil {
 
 
     /**
-     * Determines whether we should use SYSTEM.CATALOG or SYSTEM.CHILD_LINK to find parent->child
-     * links i.e. {@link LinkType#CHILD_TABLE}.
+     * Determines whether we should use SYSTEM.CATALOG or SYSTEM.CHILD_LINK to find
+     * {@code parent->child } links i.e. {@link LinkType#CHILD_TABLE}.
      * If the client is older than 4.15.0 and the SYSTEM.CHILD_LINK table does not exist, we use
      * the SYSTEM.CATALOG table. In all other cases, we use the SYSTEM.CHILD_LINK table.
      * This is required for backwards compatibility.
@@ -442,7 +447,7 @@ public class ViewUtil {
      * @throws SQLException thrown if there is an error connecting to the server
      */
     public static TableName getSystemTableForChildLinks(int clientVersion,
-            Configuration conf) throws SQLException, IOException {
+                                                        Configuration conf) throws SQLException, IOException {
         byte[] fullTableName = SYSTEM_CHILD_LINK_NAME_BYTES;
         if (clientVersion < MIN_SPLITTABLE_SYSTEM_CATALOG) {
 
@@ -460,7 +465,6 @@ public class ViewUtil {
         }
         return SchemaUtil.getPhysicalTableName(fullTableName, conf);
     }
-
     public static boolean isDivergedView(PTable view) {
         return view.getBaseColumnCount() == QueryConstants.DIVERGED_VIEW_BASE_COLUMN_COUNT;
     }
@@ -563,40 +567,6 @@ public class ViewUtil {
             }
         }
     }
-    
-    /**
-     * Inherit all indexes and columns from the parent 
-     * @return table with inherited columns and indexes
-     */
-    public static PTable addDerivedColumnsAndIndexesFromParent(PhoenixConnection connection,
-            PTable table, PTable parentTable) throws SQLException {
-        PTable pTable = addDerivedColumnsFromParent(table, parentTable);
-        boolean hasIndexId = table.getViewIndexId() != null;
-        // For views :
-        if (!hasIndexId) {
-            // 1. need to resolve the views's own indexes so that any columns added by ancestors
-            // are included
-            List<PTable> allIndexes = Lists.newArrayList();
-            if (pTable !=null && pTable.getIndexes() !=null && !pTable.getIndexes().isEmpty()) {
-                for (PTable viewIndex : pTable.getIndexes()) {
-                    PTable resolvedViewIndex = ViewUtil.addDerivedColumnsAndIndexesFromParent(
-                            connection, viewIndex, pTable);
-                    if (resolvedViewIndex!=null)
-                        allIndexes.add(resolvedViewIndex);
-                }
-            }
-            
-            // 2. include any indexes from ancestors that can be used by this view
-            List<PTable> inheritedIndexes = Lists.newArrayList();
-            addIndexesFromParent(connection, pTable, parentTable, inheritedIndexes);
-            allIndexes.addAll(inheritedIndexes);
-            if (!allIndexes.isEmpty()) {
-                pTable = PTableImpl.builderWithColumns(pTable, getColumnsToClone(pTable))
-                        .setIndexes(allIndexes).build();
-            }
-        }
-        return pTable;
-    }
 
     /**
      * Inherit all columns from the parent unless it's an excluded column.
@@ -604,8 +574,8 @@ public class ViewUtil {
      * PHOENIX-3534) we choose the child column over the parent column
      * @return table with inherited columns
      */
-    public static PTable addDerivedColumnsFromParent(PTable view, PTable parentTable)
-            throws SQLException {
+    public static PTable addDerivedColumnsAndIndexesFromParent(PhoenixConnection connection,
+            PTable view, PTable parentTable) throws SQLException {
         // combine columns for view and view indexes
         boolean hasIndexId = view.getViewIndexId() != null;
         boolean isSalted = view.getBucketNum() != null;
@@ -657,9 +627,10 @@ public class ViewUtil {
         // set the final table timestamp and DDL timestamp as the respective max timestamps of the
         // view/view index or its ancestors
         maxTableTimestamp = Math.max(maxTableTimestamp, parentTable.getTimeStamp());
-
+        //Diverged views no longer inherit ddl timestamps from their ancestors because they don't
+        // inherit column changes
         maxDDLTimestamp = Math.max(maxDDLTimestamp,
-                parentTable.getLastDDLTimestamp() != null ? parentTable.getLastDDLTimestamp() : 0L);
+            parentTable.getLastDDLTimestamp() != null ? parentTable.getLastDDLTimestamp() : 0L);
 
         if (hasIndexId) {
             // add all pk columns of parent tables to indexes
@@ -762,7 +733,28 @@ public class ViewUtil {
                 .setLastDDLTimestamp(maxDDLTimestamp)
                 .build();
         pTable = WhereConstantParser.addViewInfoToPColumnsIfNeeded(pTable);
-        
+
+        // For views :
+        if (!hasIndexId) {
+            // 1. need to resolve the views's own indexes so that any columns added by ancestors are included
+            List<PTable> allIndexes = Lists.newArrayList();
+            if (pTable !=null && pTable.getIndexes() !=null && !pTable.getIndexes().isEmpty()) {
+                for (PTable viewIndex : pTable.getIndexes()) {
+                    PTable resolvedViewIndex =
+                            ViewUtil.addDerivedColumnsAndIndexesFromParent(connection, viewIndex, pTable);
+                    if (resolvedViewIndex!=null)
+                        allIndexes.add(resolvedViewIndex);
+                }
+            }
+            // 2. include any indexes from ancestors that can be used by this view
+            List<PTable> inheritedIndexes = Lists.newArrayList();
+            addIndexesFromParent(connection, pTable, parentTable, inheritedIndexes);
+            allIndexes.addAll(inheritedIndexes);
+            if (!allIndexes.isEmpty()) {
+                pTable = PTableImpl.builderWithColumns(pTable, getColumnsToClone(pTable))
+                        .setIndexes(allIndexes).build();
+            }
+        }
         return pTable;
     }
 
@@ -829,8 +821,8 @@ public class ViewUtil {
                                 existingColumn.getTimestamp()) {
                             allColumns.remove(existingColumnIndex);
                             // Remove the existing column and add the ancestor
-                            // column at the end and make sure to mark it
-                            // as derived
+                            // column at the end and make sure to mark it as
+                            // derived
                             allColumns.add(new PColumnImpl(ancestorColumn, true,
                                     ancestorColumn.getPosition()));
                         } else {
@@ -869,7 +861,7 @@ public class ViewUtil {
      * @param parent PTable of the parent or null
      */
     public static void addTagsToPutsForViewAlteredProperties(List<Mutation> tableMetaData,
-            PTable parent) {
+            PTable parent, ExtendedCellBuilder extendedCellBuilder) {
         byte[] parentUpdateCacheFreqBytes = null;
         byte[] parentUseStatsForParallelizationBytes = null;
         byte[] parentPhoenixTTLBytes = null;
@@ -890,16 +882,19 @@ public class ViewUtil {
                 MetaDataUtil.conditionallyAddTagsToPutCells((Put)m,
                         PhoenixDatabaseMetaData.TABLE_FAMILY_BYTES,
                         PhoenixDatabaseMetaData.UPDATE_CACHE_FREQUENCY_BYTES,
+                        extendedCellBuilder,
                         parentUpdateCacheFreqBytes,
                         MetaDataEndpointImpl.VIEW_MODIFIED_PROPERTY_BYTES);
                 MetaDataUtil.conditionallyAddTagsToPutCells((Put)m,
                         PhoenixDatabaseMetaData.TABLE_FAMILY_BYTES,
                         PhoenixDatabaseMetaData.USE_STATS_FOR_PARALLELIZATION_BYTES,
+                        extendedCellBuilder,
                         parentUseStatsForParallelizationBytes,
                         MetaDataEndpointImpl.VIEW_MODIFIED_PROPERTY_BYTES);
                 MetaDataUtil.conditionallyAddTagsToPutCells((Put)m,
                         PhoenixDatabaseMetaData.TABLE_FAMILY_BYTES,
                         PhoenixDatabaseMetaData.PHOENIX_TTL_BYTES,
+                        extendedCellBuilder,
                         parentPhoenixTTLBytes,
                         MetaDataEndpointImpl.VIEW_MODIFIED_PROPERTY_BYTES);
             }
