@@ -17,19 +17,21 @@
  */
 package org.apache.phoenix.index;
 
-import com.google.common.collect.Lists;
-import com.google.common.collect.Maps;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.hadoop.hbase.Cell;
+import org.apache.hadoop.hbase.CellBuilderFactory;
+import org.apache.hadoop.hbase.CellBuilderType;
 import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.DoNotRetryIOException;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.KeyValue;
 import org.apache.hadoop.hbase.client.Delete;
 import org.apache.hadoop.hbase.client.Mutation;
 import org.apache.hadoop.hbase.client.Put;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.Pair;
+import org.apache.phoenix.compat.hbase.HbaseCompatCapabilities;
 import org.apache.phoenix.coprocessor.GlobalIndexRegionScanner;
 import org.apache.phoenix.coprocessor.IndexRebuildRegionScanner;
 import org.apache.phoenix.coprocessor.IndexToolVerificationResult;
@@ -41,6 +43,7 @@ import org.apache.phoenix.query.QueryConstants;
 import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.schema.PTableKey;
 import org.apache.phoenix.util.*;
+import org.junit.Assume;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
@@ -237,17 +240,21 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
     }
 
     private void convertUpsertToMutations(Connection conn) throws SQLException, IOException {
-        Iterator<Pair<byte[],List<KeyValue>>>
+        Iterator<Pair<byte[],List<Cell>>>
                 dataTableNameAndMutationKeyValuesIter = PhoenixRuntime.getUncommittedDataIterator(conn);
-        Pair<byte[], List<KeyValue>> elem = dataTableNameAndMutationKeyValuesIter.next();
-        byte[] key = elem.getSecond().get(0).getRow();
+        Pair<byte[], List<Cell>> elem = dataTableNameAndMutationKeyValuesIter.next();
+        byte[] key = CellUtil.cloneRow(elem.getSecond().get(0));
         long mutationTS = EnvironmentEdgeManager.currentTimeMillis();
 
-        for (KeyValue kv : elem.getSecond()) {
+        for (Cell kv : elem.getSecond()) {
             Cell cell =
-                    CellUtil.createCell(kv.getRow(), kv.getFamily(), kv.getQualifier(),
-                            mutationTS, kv.getType(), kv.getValue());
-            if (KeyValue.Type.codeToType(cell.getTypeByte()) == KeyValue.Type.Put) {
+                CellBuilderFactory.create(CellBuilderType.DEEP_COPY).setRow(CellUtil.cloneRow(kv)).
+                    setFamily(CellUtil.cloneFamily(kv)).
+                    setQualifier(CellUtil.cloneQualifier(kv)).
+                    setTimestamp(mutationTS).
+                    setType(kv.getType()).
+                    setValue(CellUtil.cloneValue(kv)).build();
+            if (cell.getType().equals(Cell.Type.Put)) {
                 if (put == null ) {
                     put = new Put(key);
                 }
@@ -256,7 +263,7 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
                 if (delete == null) {
                     delete = new Delete(key);
                 }
-                delete.addDeleteMarker(cell);
+                delete.add(cell);
             }
         }
     }
@@ -308,7 +315,7 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
             rebuildScanner.verifySingleIndexRow(indexRow.getRow(), actualMutationList,
                     indexKeyToMutationMap.get(indexRow.getRow()), mostRecentIndexRowKeys, Collections.EMPTY_LIST, actualPR, true);
 
-            assertTrue(actualPR.equals(expectedPR));
+            assertEquals(actualPR, expectedPR);
         }
     }
 
@@ -319,10 +326,11 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
                 entry : indexKeyToMutationMap.entrySet()) {
             initializeLocalMockitoSetup(entry, TestType.VALID_MORE_MUTATIONS);
             //test code
+
             rebuildScanner.verifySingleIndexRow(indexRow.getRow(), actualMutationList,
                     indexKeyToMutationMap.get(indexRow.getRow()), mostRecentIndexRowKeys, Collections.EMPTY_LIST, actualPR, true);
 
-            assertTrue(actualPR.equals(expectedPR));
+            assertEquals(actualPR, expectedPR);
         }
     }
 
@@ -333,10 +341,11 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
                 entry : indexKeyToMutationMap.entrySet()) {
             initializeLocalMockitoSetup(entry, TestType.VALID_MIX_MUTATIONS);
             //test code
+
             rebuildScanner.verifySingleIndexRow(indexRow.getRow(), actualMutationList,
                     indexKeyToMutationMap.get(indexRow.getRow()), mostRecentIndexRowKeys, Collections.EMPTY_LIST, actualPR, true);
 
-            assertTrue(actualPR.equals(expectedPR));
+            assertEquals(actualPR, expectedPR);
         }
     }
 
@@ -347,10 +356,11 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
                 entry : indexKeyToMutationMap.entrySet()) {
             initializeLocalMockitoSetup(entry, TestType.VALID_NEW_UNVERIFIED_MUTATIONS);
             //test code
+
             rebuildScanner.verifySingleIndexRow(indexRow.getRow(), actualMutationList,
                     indexKeyToMutationMap.get(indexRow.getRow()), mostRecentIndexRowKeys, Collections.EMPTY_LIST, actualPR, true);
 
-            assertTrue(actualPR.equals(expectedPR));
+            assertEquals(actualPR, expectedPR);
         }
     }
 
@@ -367,7 +377,7 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
                 rebuildScanner.verifySingleIndexRow(indexRow.getRow(), actualMutationList,
                         indexKeyToMutationMap.get(indexRow.getRow()), mostRecentIndexRowKeys, Collections.EMPTY_LIST, actualPR, true);
 
-                assertTrue(actualPR.equals(expectedPR));
+                assertEquals(actualPR, expectedPR);
             }
         } finally {
             EnvironmentEdgeManager.reset();
@@ -382,10 +392,11 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
                 entry : indexKeyToMutationMap.entrySet()) {
             initializeLocalMockitoSetup(entry, TestType.INVALID_CELL_VALUE);
             //test code
+
             rebuildScanner.verifySingleIndexRow(indexRow.getRow(), actualMutationList,
                     indexKeyToMutationMap.get(indexRow.getRow()), mostRecentIndexRowKeys, Collections.EMPTY_LIST, actualPR, true);
 
-            assertTrue(actualPR.equals(expectedPR));
+            assertEquals(actualPR, expectedPR);
         }
     }
 
@@ -399,7 +410,7 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
             rebuildScanner.verifySingleIndexRow(indexRow.getRow(), actualMutationList,
                     indexKeyToMutationMap.get(indexRow.getRow()), mostRecentIndexRowKeys, Collections.EMPTY_LIST, actualPR, true);
 
-            assertTrue(actualPR.equals(expectedPR));
+            assertEquals(actualPR, expectedPR);
         }
     }
 
@@ -414,7 +425,7 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
             rebuildScanner.verifySingleIndexRow(indexRow.getRow(), actualMutationList,
                     indexKeyToMutationMap.get(indexRow.getRow()), mostRecentIndexRowKeys, Collections.EMPTY_LIST, actualPR, true);
 
-            assertTrue(actualPR.equals(expectedPR));
+            assertEquals(actualPR, expectedPR);
         }
     }
 
@@ -428,7 +439,7 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
             rebuildScanner.verifySingleIndexRow(indexRow.getRow(), actualMutationList,
                     indexKeyToMutationMap.get(indexRow.getRow()), mostRecentIndexRowKeys, Collections.EMPTY_LIST, actualPR, true);
 
-            assertTrue(actualPR.equals(expectedPR));
+            assertEquals(actualPR, expectedPR);
         }
     }
 
@@ -460,6 +471,7 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
     // We will report such row as a valid row.
     @Test
     public void testVerifySingleIndexRow_compactionOnIndexTable_atLeastOneExpectedMutationWithinMaxLookBack() throws Exception {
+        Assume.assumeTrue(HbaseCompatCapabilities.isMaxLookbackTimeSupported());
         String dataRowKey = "k1";
         byte[] indexRowKey1Bytes = generateIndexRowKey(dataRowKey, "val1");
         ManualEnvironmentEdge injectEdge = new ManualEnvironmentEdge();
@@ -473,11 +485,11 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
         rebuildScanner.setMaxLookBackInMills(maxLookbackInMills);
 
         Put put = new Put(indexRowKey1Bytes);
-        Cell cell = CellUtil.createCell(indexRowKey1Bytes,
+        Cell cell = getNewCell(indexRowKey1Bytes,
                 QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES,
                 QueryConstants.EMPTY_COLUMN_BYTES,
                 EnvironmentEdgeManager.currentTimeMillis(),
-                KeyValue.Type.Put.getCode(),
+                Cell.Type.Put,
                 IndexRegionObserver.VERIFIED_BYTES);
         put.add(cell);
         // This mutation is beyond maxLookBack, so add it to expectedMutations only.
@@ -487,11 +499,11 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
         // next mutation will be within maxLookBack
         injectEdge.incrementValue(maxLookbackInMills);
         put =  new Put(indexRowKey1Bytes);
-        cell = CellUtil.createCell(indexRowKey1Bytes,
+        cell = getNewCell(indexRowKey1Bytes,
                 QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES,
                 QueryConstants.EMPTY_COLUMN_BYTES,
                 EnvironmentEdgeManager.currentTimeMillis(),
-                KeyValue.Type.Put.getCode(),
+                Cell.Type.Put,
                 IndexRegionObserver.VERIFIED_BYTES);
         put.add(cell);
         // This mutation is in both expectedMutations and actualMutations, as it is within the maxLookBack, so it will not get chance to be compacted away
@@ -519,6 +531,7 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
     // We will report such row as an invalid beyond maxLookBack row.
     @Test
     public void testVerifySingleIndexRow_compactionOnIndexTable_noExpectedMutationWithinMaxLookBack() throws Exception {
+        Assume.assumeTrue(HbaseCompatCapabilities.isMaxLookbackTimeSupported());
         String dataRowKey = "k1";
         byte[] indexRowKey1Bytes = generateIndexRowKey(dataRowKey, "val1");
         List<Mutation> expectedMutations = new ArrayList<>();
@@ -532,11 +545,11 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
         EnvironmentEdgeManager.injectEdge(injectEdge);
 
         Put put = new Put(indexRowKey1Bytes);
-        Cell cell = CellUtil.createCell(indexRowKey1Bytes,
+        Cell cell = getNewCell(indexRowKey1Bytes,
                 QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES,
                 QueryConstants.EMPTY_COLUMN_BYTES,
                 EnvironmentEdgeManager.currentTimeMillis(),
-                KeyValue.Type.Put.getCode(),
+                Cell.Type.Put,
                 VERIFIED_BYTES);
         put.add(cell);
         // This mutation is beyond maxLookBack, so add it to expectedMutations only.
@@ -544,11 +557,11 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
 
         injectEdge.incrementValue(maxLookbackInMills);
         put =  new Put(indexRowKey1Bytes);
-        cell = CellUtil.createCell(indexRowKey1Bytes,
+        cell = getNewCell(indexRowKey1Bytes,
                 QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES,
                 QueryConstants.EMPTY_COLUMN_BYTES,
                 EnvironmentEdgeManager.currentTimeMillis(),
-                KeyValue.Type.Put.getCode(),
+                Cell.Type.Put,
                 UNVERIFIED_BYTES);
         put.add(cell);
         // This mutation is actualMutations only, as it is an unverified put
@@ -573,10 +586,10 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
     private static byte[] generateIndexRowKey(String dataRowKey, String dataVal){
         List<Byte> idxKey = new ArrayList<>();
         if (dataVal != null && !dataVal.isEmpty())
-            idxKey.addAll(com.google.common.primitives.Bytes.asList(Bytes.toBytes(dataVal)));
+            idxKey.addAll(org.apache.phoenix.thirdparty.com.google.common.primitives.Bytes.asList(Bytes.toBytes(dataVal)));
         idxKey.add(QueryConstants.SEPARATOR_BYTE);
-        idxKey.addAll(com.google.common.primitives.Bytes.asList(Bytes.toBytes(dataRowKey)));
-        return com.google.common.primitives.Bytes.toArray(idxKey);
+        idxKey.addAll(org.apache.phoenix.thirdparty.com.google.common.primitives.Bytes.asList(Bytes.toBytes(dataRowKey)));
+        return org.apache.phoenix.thirdparty.com.google.common.primitives.Bytes.toArray(idxKey);
     }
 
     private IndexToolVerificationResult.PhaseResult getValidPhaseResult() {
@@ -640,9 +653,8 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
             for (Mutation m : newActualMutations) {
                 if (m instanceof Put) {
                     List<Cell> origList = m.getFamilyCellMap().firstEntry().getValue();
-                    Cell newCell =
-                            CellUtil.createCell(m.getRow(), CellUtil.cloneFamily(origList.get(0)),
-                                    Bytes.toBytes("EXTRACOL"), m.getTimeStamp(), KeyValue.Type.Put.getCode(),
+                    Cell newCell = getNewCell(m.getRow(), CellUtil.cloneFamily(origList.get(0)),
+                                    Bytes.toBytes("EXTRACOL"), m.getTimestamp(), Cell.Type.Put,
                                     Bytes.toBytes("asdfg"));
                     byte[] fam = CellUtil.cloneFamily(origList.get(0));
                     m.getFamilyCellMap().get(fam).add(newCell);
@@ -667,8 +679,13 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
                 infiltrateCell(c, newCellList, testType);
             }
             familyCellMap.put(fam, newCellList);
-            m.setFamilyCellMap(familyCellMap);
-            newActualMutations.add(m);
+            Mutation newM;
+            if (m instanceof Put) {
+                newM = new Put(m.getRow(), m.getTimestamp(), familyCellMap);
+            } else {
+                newM = new Delete(m.getRow(), m.getTimestamp(), familyCellMap);
+            }
+            newActualMutations.add(newM);
         }
         return newActualMutations;
     }
@@ -678,11 +695,10 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
         Cell emptyCell;
         switch(e) {
         case INVALID_COLUMN:
-            newCell =
-                    CellUtil.createCell(CellUtil.cloneRow(c), CellUtil.cloneFamily(c),
+            newCell = getNewCell(CellUtil.cloneRow(c), CellUtil.cloneFamily(c),
                             Bytes.toBytes(UNEXPECTED_COLUMN),
                             c.getTimestamp(),
-                            KeyValue.Type.Put.getCode(), Bytes.toBytes("zxcv"));
+                            Cell.Type.Put, Bytes.toBytes("zxcv"));
             newCellList.add(newCell);
             newCellList.add(c);
             break;
@@ -699,9 +715,9 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
         case INVALID_EMPTY_CELL:
             if (CellUtil.matchingQualifier(c, EMPTY_COLUMN_BYTES)) {
                 newCell =
-                        CellUtil.createCell(CellUtil.cloneRow(c), CellUtil.cloneFamily(c),
+                        getNewCell(CellUtil.cloneRow(c), CellUtil.cloneFamily(c),
                                 CellUtil.cloneQualifier(c), c.getTimestamp(),
-                                KeyValue.Type.Delete.getCode(), VERIFIED_BYTES);
+                                Cell.Type.Delete, VERIFIED_BYTES);
                 newCellList.add(newCell);
             } else {
                 newCellList.add(c);
@@ -717,16 +733,16 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
     }
 
     private Cell getVerifiedEmptyCell(Cell c) {
-        return CellUtil.createCell(CellUtil.cloneRow(c), CellUtil.cloneFamily(c),
+        return getNewCell(CellUtil.cloneRow(c), CellUtil.cloneFamily(c),
                 indexMaintainer.getEmptyKeyValueQualifier(),
                 c.getTimestamp(),
-                KeyValue.Type.Put.getCode(), VERIFIED_BYTES);
+                Cell.Type.Put, VERIFIED_BYTES);
     }
 
     private Cell getCellWithPut(Cell c) {
-        return CellUtil.createCell(CellUtil.cloneRow(c),
+        return getNewCell(CellUtil.cloneRow(c),
                 CellUtil.cloneFamily(c), Bytes.toBytes(INCLUDED_COLUMN),
-                c.getTimestamp(), KeyValue.Type.Put.getCode(),
+                c.getTimestamp(), Cell.Type.Put,
                 Bytes.toBytes("zxcv"));
     }
 
@@ -740,8 +756,8 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
         Mutation m = new Delete(orig.getRow());
         List<Cell> origList = orig.getFamilyCellMap().firstEntry().getValue();
         ts = ts == null ? EnvironmentEdgeManager.currentTimeMillis() : ts;
-        Cell c = getNewPutCell(orig, origList, ts, KeyValue.Type.DeleteFamilyVersion);
-        Cell empty = getEmptyCell(orig, origList, ts, KeyValue.Type.Put, true);
+        Cell c = getNewPutCell(orig, origList, ts, Cell.Type.DeleteFamilyVersion);
+        Cell empty = getEmptyCell(orig, origList, ts, Cell.Type.Put, true);
         byte[] fam = CellUtil.cloneFamily(origList.get(0));
         List<Cell> famCells = Lists.newArrayList();
         m.getFamilyCellMap().put(fam, famCells);
@@ -759,8 +775,8 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
         }
         List<Cell> origList = orig.getFamilyCellMap().firstEntry().getValue();
         ts = ts == null ? EnvironmentEdgeManager.currentTimeMillis() : ts;
-        Cell c = getNewPutCell(orig, origList, ts, KeyValue.Type.Put);
-        Cell empty = getEmptyCell(orig, origList, ts, KeyValue.Type.Put, false);
+        Cell c = getNewPutCell(orig, origList, ts, Cell.Type.Put);
+        Cell empty = getEmptyCell(orig, origList, ts, Cell.Type.Put, false);
         byte[] fam = CellUtil.cloneFamily(origList.get(0));
         List<Cell> famCells = Lists.newArrayList();
         m.getFamilyCellMap().put(fam, famCells);
@@ -769,16 +785,24 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
         return m;
     }
 
-    private Cell getEmptyCell(Mutation orig, List<Cell> origList, Long ts, KeyValue.Type type,
+    private Cell getEmptyCell(Mutation orig, List<Cell> origList, Long ts, Cell.Type type,
             boolean verified) {
-        return CellUtil.createCell(orig.getRow(), CellUtil.cloneFamily(origList.get(0)),
+        return getNewCell(orig.getRow(), CellUtil.cloneFamily(origList.get(0)),
                 indexMaintainer.getEmptyKeyValueQualifier(),
-                ts, type.getCode(), verified ? VERIFIED_BYTES : UNVERIFIED_BYTES);
+                ts, type, verified ? VERIFIED_BYTES : UNVERIFIED_BYTES);
     }
 
-    private Cell getNewPutCell(Mutation orig, List<Cell> origList, Long ts, KeyValue.Type type) {
-        return CellUtil.createCell(orig.getRow(),
+    private Cell getNewPutCell(Mutation orig, List<Cell> origList, Long ts, Cell.Type type) {
+        return getNewCell(orig.getRow(),
                 CellUtil.cloneFamily(origList.get(0)), Bytes.toBytes(INCLUDED_COLUMN),
-                ts, type.getCode(), Bytes.toBytes("asdfg"));
+                ts, type, Bytes.toBytes("asdfg"));
+    }
+
+    private Cell getNewCell(byte[] row, byte[] family, byte[] qualifier,
+                            long timestamp, Cell.Type type, byte[] value) {
+      return CellBuilderFactory.create(CellBuilderType.DEEP_COPY).setRow(row).
+          setFamily(family).setQualifier(qualifier).
+          setTimestamp(timestamp).setType(type).
+          setValue(value).build();
     }
 }
