@@ -30,8 +30,13 @@ import static org.junit.Assert.assertTrue;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellUtil;
+import org.apache.hadoop.hbase.ExtendedCell;
+import org.apache.hadoop.hbase.ExtendedCellBuilder;
 import org.apache.hadoop.hbase.KeyValue;
+import org.apache.hadoop.hbase.PrivateCellUtil;
+import org.apache.hadoop.hbase.RawCellBuilderFactory;
 import org.apache.hadoop.hbase.Tag;
+import org.apache.hadoop.hbase.TagUtil;
 import org.apache.hadoop.hbase.client.Put;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.VersionInfo;
@@ -47,12 +52,16 @@ import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.schema.SortOrder;
 import org.apache.phoenix.schema.types.PInteger;
 import org.apache.phoenix.schema.types.PLong;
+import org.junit.Before;
 import org.junit.Test;
+import org.mockito.Mockito;
 
-import java.util.Arrays;
 import java.util.Iterator;
 import java.util.List;
 
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
 import static org.apache.hadoop.hbase.HConstants.EMPTY_BYTE_ARRAY;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.TABLE_FAMILY_BYTES;
 
@@ -62,6 +71,26 @@ public class MetaDataUtilTest {
     private static final byte[] QUALIFIER = Bytes.toBytes("qual");
     private static final byte[] ORIGINAL_VALUE = Bytes.toBytes("generic-value");
     private static final byte[] DUMMY_TAGS = Bytes.toBytes("tags");
+    private final ExtendedCellBuilder mockBuilder = Mockito.mock(ExtendedCellBuilder.class);
+    private final ExtendedCell mockCellWithTags = Mockito.mock(ExtendedCell.class);
+
+    @Before
+    public void setupMockCellBuilder() {
+        Mockito.when(mockBuilder.setRow(Mockito.any(byte[].class), Mockito.anyInt(),
+                Mockito.anyInt())).thenReturn(mockBuilder);
+        Mockito.when(mockBuilder.setFamily(Mockito.any(byte[].class), Mockito.anyInt(),
+                Mockito.anyInt())).thenReturn(mockBuilder);
+        Mockito.when(mockBuilder.setQualifier(Mockito.any(byte[].class), Mockito.anyInt(),
+                Mockito.anyInt())).thenReturn(mockBuilder);
+        Mockito.when(mockBuilder.setValue(Mockito.any(byte[].class), Mockito.anyInt(),
+                Mockito.anyInt())).thenReturn(mockBuilder);
+        Mockito.when(mockBuilder.setTimestamp(Mockito.anyLong())).thenReturn(mockBuilder);
+        Mockito.when(mockBuilder.setType(Mockito.any(Cell.Type.class)))
+                .thenReturn(mockBuilder);
+        Mockito.when(mockBuilder.setTags(Mockito.any(byte[].class)))
+                .thenReturn(mockBuilder);
+        Mockito.when(mockBuilder.build()).thenReturn(mockCellWithTags);
+    }
 
     @Test
     public void testEncode() {
@@ -131,10 +160,11 @@ public class MetaDataUtilTest {
 
         // Different qualifier, so no tags should be set
         MetaDataUtil.conditionallyAddTagsToPutCells(put, TABLE_FAMILY_BYTES, EMPTY_BYTE_ARRAY,
-                EMPTY_BYTE_ARRAY, DUMMY_TAGS);
+                mockBuilder, EMPTY_BYTE_ARRAY, DUMMY_TAGS);
+        verify(mockBuilder, never()).setTags(Mockito.any(byte[].class));
         Cell newCell = put.getFamilyCellMap().get(TABLE_FAMILY_BYTES).get(0);
         assertEquals(initialCell, newCell);
-        assertNull(Tag.carryForwardTags(newCell));
+        assertNull(TagUtil.carryForwardTags(newCell));
     }
 
     @Test
@@ -143,9 +173,10 @@ public class MetaDataUtilTest {
 
         // valueArray is null so we always set tags
         MetaDataUtil.conditionallyAddTagsToPutCells(put, TABLE_FAMILY_BYTES, QUALIFIER,
-                null, DUMMY_TAGS);
+                mockBuilder, null, DUMMY_TAGS);
+        verify(mockBuilder, times(1)).setTags(Mockito.any(byte[].class));
         Cell newCell = put.getFamilyCellMap().get(TABLE_FAMILY_BYTES).get(0);
-        assertTrue(Arrays.equals(DUMMY_TAGS, CellUtil.getTagArray(newCell)));
+        assertEquals(mockCellWithTags, newCell);
     }
 
     @Test
@@ -155,10 +186,11 @@ public class MetaDataUtilTest {
 
         // valueArray is set as the value stored in the cell, so we skip tagging the cell
         MetaDataUtil.conditionallyAddTagsToPutCells(put, TABLE_FAMILY_BYTES, QUALIFIER,
-                ORIGINAL_VALUE, DUMMY_TAGS);
+                mockBuilder, ORIGINAL_VALUE, DUMMY_TAGS);
+        verify(mockBuilder, never()).setTags(Mockito.any(byte[].class));
         Cell newCell = put.getFamilyCellMap().get(TABLE_FAMILY_BYTES).get(0);
         assertEquals(initialCell, newCell);
-        assertNull(Tag.carryForwardTags(newCell));
+        assertNull(TagUtil.carryForwardTags(newCell));
     }
 
     @Test
@@ -167,9 +199,10 @@ public class MetaDataUtilTest {
 
         // valueArray is set to a value different than the one in the cell, so we tag the cell
         MetaDataUtil.conditionallyAddTagsToPutCells(put, TABLE_FAMILY_BYTES, QUALIFIER,
-                EMPTY_BYTE_ARRAY, DUMMY_TAGS);
+                mockBuilder, EMPTY_BYTE_ARRAY, DUMMY_TAGS);
+        verify(mockBuilder, times(1)).setTags(Mockito.any(byte[].class));
         Cell newCell = put.getFamilyCellMap().get(TABLE_FAMILY_BYTES).get(0);
-        assertTrue(Arrays.equals(DUMMY_TAGS, CellUtil.getTagArray(newCell)));
+        assertEquals(mockCellWithTags, newCell);
     }
 
     /**
@@ -259,7 +292,7 @@ public class MetaDataUtilTest {
 
     @Test
     public void testConditionallyAddTagsToPutCells( ) {
-        List<Tag> tags = Tag.asList(VIEW_MODIFIED_PROPERTY_BYTES, 0, VIEW_MODIFIED_PROPERTY_BYTES.length);
+        List<Tag> tags = TagUtil.asList(VIEW_MODIFIED_PROPERTY_BYTES, 0, VIEW_MODIFIED_PROPERTY_BYTES.length);
         assertEquals(tags.size(), 1);
         Tag expectedTag = tags.get(0);
 
@@ -270,21 +303,22 @@ public class MetaDataUtilTest {
         Put put = new Put(ROW);
         KeyValueBuilder.addQuietly(put, kv);
 
-        MetaDataUtil.conditionallyAddTagsToPutCells(put, TABLE_FAMILY_BYTES, UPDATE_CACHE_FREQUENCY_BYTES, PInteger.INSTANCE.toBytes(1), VIEW_MODIFIED_PROPERTY_BYTES);
+        ExtendedCellBuilder cellBuilder = (ExtendedCellBuilder) RawCellBuilderFactory.create();
+        MetaDataUtil.conditionallyAddTagsToPutCells(put, TABLE_FAMILY_BYTES, UPDATE_CACHE_FREQUENCY_BYTES, cellBuilder,
+                PInteger.INSTANCE.toBytes(1), VIEW_MODIFIED_PROPERTY_BYTES);
 
         Cell cell = put.getFamilyCellMap().get(TABLE_FAMILY_BYTES).get(0);
 
         // To check the cell tag whether view has modified this property
-        assertTrue(Bytes.compareTo(expectedTag.getBuffer(), concatTags(EMPTY_BYTE_ARRAY, cell)) == 0);
-        assertTrue(Bytes.contains(concatTags(EMPTY_BYTE_ARRAY, cell), expectedTag.getBuffer()));
+        assertTrue(Bytes.compareTo(expectedTag.getValueArray(), TagUtil.concatTags(EMPTY_BYTE_ARRAY, cell)) == 0);
+        assertTrue(Bytes.contains(TagUtil.concatTags(EMPTY_BYTE_ARRAY, cell), expectedTag.getValueArray()));
 
         // To check tag data can be correctly deserialized
-        byte[] tagsBytes = CellUtil.getTagArray(cell);
-        Iterator<Tag> tagIterator = CellUtil.tagsIterator(tagsBytes, 0, tagsBytes.length);
+        Iterator<Tag> tagIterator = PrivateCellUtil.tagsIterator(cell);
         assertTrue(tagIterator.hasNext());
         Tag actualTag = tagIterator.next();
-        assertTrue(Bytes.compareTo(actualTag.getBuffer(), actualTag.getTagOffset(), actualTag.getTagLength(),
-                expectedTag.getBuffer(), expectedTag.getTagOffset(), expectedTag.getTagLength()) == 0);
+        assertTrue(Bytes.compareTo(actualTag.getValueArray(), actualTag.getValueOffset(), actualTag.getValueLength(),
+                expectedTag.getValueArray(), expectedTag.getValueOffset(), expectedTag.getValueLength()) == 0);
         assertFalse(tagIterator.hasNext());
     }
 
