@@ -59,27 +59,27 @@ import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellScanner;
 import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.HBaseTestingUtility;
-import org.apache.hadoop.hbase.HColumnDescriptor;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
+import org.apache.hadoop.hbase.client.CompactionState;
 import org.apache.hadoop.hbase.client.Delete;
+
 import org.apache.hadoop.hbase.client.Get;
-import org.apache.hadoop.hbase.client.HBaseAdmin;
-import org.apache.hadoop.hbase.client.HTableInterface;
 import org.apache.hadoop.hbase.client.Put;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.client.ResultScanner;
 import org.apache.hadoop.hbase.client.Scan;
 import org.apache.hadoop.hbase.client.Table;
+import org.apache.hadoop.hbase.client.TableDescriptor;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.client.coprocessor.Batch;
 import org.apache.hadoop.hbase.filter.CompareFilter.CompareOp;
 import org.apache.hadoop.hbase.filter.Filter;
 import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
-import org.apache.hadoop.hbase.ipc.BlockingRpcCallback;
+import org.apache.hadoop.hbase.ipc.CoprocessorRpcUtils.BlockingRpcCallback;
 import org.apache.hadoop.hbase.ipc.ServerRpcController;
-import org.apache.hadoop.hbase.protobuf.generated.AdminProtos;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.compile.AggregationManager;
 import org.apache.phoenix.compile.ColumnResolver;
@@ -150,8 +150,8 @@ import org.junit.Assert;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.base.Objects;
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.base.Objects;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 
 
@@ -214,7 +214,7 @@ public class TestUtil {
     public final static String ROW7 = "00B723122312312";
     public final static String ROW8 = "00B823122312312";
     public final static String ROW9 = "00C923122312312";
-
+    
     public final static String PARENTID1 = "0500x0000000001";
     public final static String PARENTID2 = "0500x0000000002";
     public final static String PARENTID3 = "0500x0000000003";
@@ -224,9 +224,9 @@ public class TestUtil {
     public final static String PARENTID7 = "0500x0000000007";
     public final static String PARENTID8 = "0500x0000000008";
     public final static String PARENTID9 = "0500x0000000009";
-
+    
     public final static List<String> PARENTIDS = Lists.newArrayList(PARENTID1, PARENTID2, PARENTID3, PARENTID4, PARENTID5, PARENTID6, PARENTID7, PARENTID8, PARENTID9);
-
+    
     public final static String ENTITYHISTID1 = "017x00000000001";
     public final static String ENTITYHISTID2 = "017x00000000002";
     public final static String ENTITYHISTID3 = "017x00000000003";
@@ -238,7 +238,7 @@ public class TestUtil {
     public final static String ENTITYHISTID9 = "017x00000000009";
 
     public final static List<String> ENTITYHISTIDS = Lists.newArrayList(ENTITYHISTID1, ENTITYHISTID2, ENTITYHISTID3, ENTITYHISTID4, ENTITYHISTID5, ENTITYHISTID6, ENTITYHISTID7, ENTITYHISTID8, ENTITYHISTID9);
-
+    
     public static final String LOCALHOST = "localhost";
     public static final String PHOENIX_JDBC_URL = JDBC_PROTOCOL + JDBC_PROTOCOL_SEPARATOR + LOCALHOST + JDBC_PROTOCOL_TERMINATOR + PHOENIX_TEST_DRIVER_URL_PARAM;
     public static final String PHOENIX_CONNECTIONLESS_JDBC_URL = JDBC_PROTOCOL + JDBC_PROTOCOL_SEPARATOR + CONNECTIONLESS + JDBC_PROTOCOL_TERMINATOR + PHOENIX_TEST_DRIVER_URL_PARAM;
@@ -486,7 +486,7 @@ public class TestUtil {
 
     public static void clearMetaDataCache(Connection conn) throws Throwable {
         PhoenixConnection pconn = conn.unwrap(PhoenixConnection.class);
-        HTableInterface htable = pconn.getQueryServices().getTable(PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME_BYTES);
+        Table htable = pconn.getQueryServices().getTable(PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME_BYTES);
         htable.coprocessorService(MetaDataService.class, HConstants.EMPTY_START_ROW,
             HConstants.EMPTY_END_ROW, new Batch.Call<MetaDataService, ClearCacheResponse>() {
                 @Override
@@ -811,11 +811,11 @@ public class TestUtil {
         Admin admin = utility.getHBaseAdmin();
         admin.majorCompact(table);
         long lastCompactionTimestamp;
-        AdminProtos.GetRegionInfoResponse.CompactionState state = null;
+        CompactionState state = null;
         while ((lastCompactionTimestamp = admin.getLastMajorCompactionTimestamp(table))
             < compactionRequestedSCN
-            || (state = admin.getCompactionState(table)).
-            equals(AdminProtos.GetRegionInfoResponse.CompactionState.MAJOR)) {
+            || (state = admin.getCompactionState(table)).equals(CompactionState.MAJOR)
+            || admin.getCompactionState(table).equals(CompactionState.MAJOR_AND_MINOR)){
             Thread.sleep(100);
         }
     }
@@ -857,10 +857,10 @@ public class TestUtil {
             if (table.isTransactional()) {
                 mutationState.commit();
             }
-
-            HBaseAdmin hbaseAdmin = services.getAdmin();
-            hbaseAdmin.flush(tableName);
-            hbaseAdmin.majorCompact(tableName);
+        
+            Admin hbaseAdmin = services.getAdmin();
+            hbaseAdmin.flush(TableName.valueOf(tableName));
+            hbaseAdmin.majorCompact(TableName.valueOf(tableName));
             hbaseAdmin.close();
 
             boolean compactionDone = false;
@@ -870,8 +870,8 @@ public class TestUtil {
                 scan.setStartRow(markerRowKey);
                 scan.setStopRow(Bytes.add(markerRowKey, new byte[]{0}));
                 scan.setRaw(true);
-
-                try (HTableInterface htableForRawScan = services.getTable(Bytes.toBytes(tableName))) {
+        
+                try (Table htableForRawScan = services.getTable(Bytes.toBytes(tableName))) {
                     ResultScanner scanner = htableForRawScan.getScanner(scan);
                     List<Result> results = Lists.newArrayList(scanner);
                     LOGGER.info("Results: " + results);
@@ -883,8 +883,8 @@ public class TestUtil {
                 // need to run compaction after the next txn snapshot has been written so that compaction can remove deleted rows
                 if (!compactionDone && table.isTransactional()) {
                     hbaseAdmin = services.getAdmin();
-                    hbaseAdmin.flush(tableName);
-                    hbaseAdmin.majorCompact(tableName);
+                    hbaseAdmin.flush(TableName.valueOf(tableName));
+                    hbaseAdmin.majorCompact(TableName.valueOf(tableName));
                     hbaseAdmin.close();
                 }
             }
@@ -902,16 +902,15 @@ public class TestUtil {
     public static void dumpTable(Connection conn, TableName tableName)
         throws SQLException, IOException {
         ConnectionQueryServices cqs = conn.unwrap(PhoenixConnection.class).getQueryServices();
-        HTableInterface table = cqs.getTable(tableName.getName());
+        Table table = cqs.getTable(tableName.getName());
         dumpTable(table);
     }
 
-    public static void dumpTable(HTableInterface table) throws IOException {
+    public static void dumpTable(Table table) throws IOException {
         System.out.println("************ dumping " + table + " **************");
         Scan s = new Scan();
-        s.setRaw(true);
-        ;
-        s.setMaxVersions();
+        s.setRaw(true);;
+        s.readAllVersions();
         try (ResultScanner scanner = table.getScanner(s)) {
             Result result = null;
             while ((result = scanner.next()) != null) {
@@ -919,7 +918,7 @@ public class TestUtil {
                 Cell current = null;
                 while (cellScanner.advance()) {
                     current = cellScanner.current();
-                    System.out.println(current + "column= " +
+                    System.out.println(current + " column= " +
                         Bytes.toString(CellUtil.cloneQualifier(current)) +
                         " val=" + Bytes.toStringBinary(CellUtil.cloneValue(current)));
                 }
@@ -993,8 +992,9 @@ public class TestUtil {
         }
     }
 
+
     public static void dumpIndexStatus(Connection conn, String indexName) throws IOException, SQLException {
-        try (HTableInterface table = conn.unwrap(PhoenixConnection.class).getQueryServices().getTable(PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME_BYTES)) {
+        try (Table table = conn.unwrap(PhoenixConnection.class).getQueryServices().getTable(PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME_BYTES)) {
             System.out.println("************ dumping index status for " + indexName + " **************");
             Scan s = new Scan();
             s.setRaw(true);
@@ -1038,8 +1038,8 @@ public class TestUtil {
                     builder.append("\n");
                 }
             }
+            System.out.println(builder.toString());
         }
-        System.out.println(builder.toString());
     }
 
     public static void waitForIndexRebuild(Connection conn, String fullIndexName, PIndexState indexState) throws InterruptedException, SQLException {
@@ -1172,18 +1172,21 @@ public class TestUtil {
     public static void addCoprocessor(Connection conn, String tableName, Class coprocessorClass) throws Exception {
         int priority = QueryServicesOptions.DEFAULT_COPROCESSOR_PRIORITY + 100;
         ConnectionQueryServices services = conn.unwrap(PhoenixConnection.class).getQueryServices();
-        HTableDescriptor descriptor = services.getTableDescriptor(Bytes.toBytes(tableName));
-        if (!descriptor.getCoprocessors().contains(coprocessorClass.getName())) {
-            descriptor.addCoprocessor(coprocessorClass.getName(), null, priority, null);
-        } else {
-            return;
-        }
+        TableDescriptor descriptor = services.getTableDescriptor(Bytes.toBytes(tableName));
+        TableDescriptorBuilder descriptorBuilder = null;
+		if (!descriptor.getCoprocessors().contains(coprocessorClass.getName())) {
+		    descriptorBuilder=TableDescriptorBuilder.newBuilder(descriptor);
+		    descriptorBuilder.addCoprocessor(coprocessorClass.getName(), null, priority, null);
+		}else{
+			return;
+		}
         final int retries = 10;
         int numTries = 10;
-        try (HBaseAdmin admin = services.getAdmin()) {
-            admin.modifyTable(Bytes.toBytes(tableName), descriptor);
-            while (!admin.getTableDescriptor(Bytes.toBytes(tableName)).equals(descriptor)
-                && numTries > 0) {
+        descriptor = descriptorBuilder.build();
+        try (Admin admin = services.getAdmin()) {
+            admin.modifyTable(descriptor);
+            while (!admin.getDescriptor(TableName.valueOf(tableName)).equals(descriptor)
+                    && numTries > 0) {
                 numTries--;
                 if (numTries == 0) {
                     throw new Exception(
@@ -1197,18 +1200,21 @@ public class TestUtil {
 
     public static void removeCoprocessor(Connection conn, String tableName, Class coprocessorClass) throws Exception {
         ConnectionQueryServices services = conn.unwrap(PhoenixConnection.class).getQueryServices();
-        HTableDescriptor descriptor = services.getTableDescriptor(Bytes.toBytes(tableName));
+        TableDescriptor descriptor = services.getTableDescriptor(Bytes.toBytes(tableName));
+        TableDescriptorBuilder descriptorBuilder = null;
         if (descriptor.getCoprocessors().contains(coprocessorClass.getName())) {
-            descriptor.removeCoprocessor(coprocessorClass.getName());
-        } else {
+            descriptorBuilder=TableDescriptorBuilder.newBuilder(descriptor);
+            descriptorBuilder.removeCoprocessor(coprocessorClass.getName());
+        }else{
             return;
         }
         final int retries = 10;
         int numTries = retries;
-        try (HBaseAdmin admin = services.getAdmin()) {
-            admin.modifyTable(Bytes.toBytes(tableName), descriptor);
-            while (!admin.getTableDescriptor(Bytes.toBytes(tableName)).equals(descriptor)
-                && numTries > 0) {
+        descriptor = descriptorBuilder.build();
+        try (Admin admin = services.getAdmin()) {
+            admin.modifyTable(descriptor);
+            while (!admin.getDescriptor(TableName.valueOf(tableName)).equals(descriptor)
+                    && numTries > 0) {
                 numTries--;
                 if (numTries == 0) {
                     throw new Exception(
@@ -1333,21 +1339,21 @@ public class TestUtil {
 
     public static void assertTableHasTtl(Connection conn, TableName tableName, int ttl)
         throws SQLException, IOException {
-        HColumnDescriptor cd = getColumnDescriptor(conn, tableName);
+        ColumnFamilyDescriptor cd = getColumnDescriptor(conn, tableName);
         Assert.assertEquals(ttl, cd.getTimeToLive());
     }
 
     public static void assertTableHasVersions(Connection conn, TableName tableName, int versions)
         throws SQLException, IOException {
-        HColumnDescriptor cd = getColumnDescriptor(conn, tableName);
+        ColumnFamilyDescriptor cd = getColumnDescriptor(conn, tableName);
         Assert.assertEquals(versions, cd.getMaxVersions());
     }
 
-    public static HColumnDescriptor getColumnDescriptor(Connection conn, TableName tableName)
+    public static ColumnFamilyDescriptor getColumnDescriptor(Connection conn, TableName tableName)
         throws SQLException, IOException {
         Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin();
-        HTableDescriptor td = admin.getTableDescriptor(tableName);
-        return td.getFamily(QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES);
+        TableDescriptor td = admin.getDescriptor(tableName);
+        return td.getColumnFamily(QueryConstants.DEFAULT_COLUMN_FAMILY_BYTES);
     }
 
     public static void assertRawRowCount(Connection conn, TableName table, int expectedRowCount)
