@@ -19,6 +19,7 @@ package org.apache.phoenix.compat.hbase;
 
 import java.io.IOException;
 
+import org.apache.hadoop.hbase.client.RegionLocator;
 import org.apache.hadoop.hbase.client.RowMutations;
 import org.apache.hadoop.hbase.client.Table;
 
@@ -30,6 +31,11 @@ public abstract class CompatDelegateHTable implements Table {
         this.delegate = delegate;
     }
 
+    @Override
+    public RegionLocator getRegionLocator() throws IOException {
+        return delegate.getRegionLocator();
+    }
+
     @Override
     public void mutateRow(RowMutations rm) throws IOException {
         delegate.mutateRow(rm);
