@@ -17,21 +17,19 @@
  */
 package org.apache.phoenix.schema;
 
-import com.google.common.base.Strings;
-import com.google.common.collect.Sets;
-import org.apache.commons.lang.StringUtils;
-import org.apache.commons.lang.math.NumberUtils;
+import org.apache.commons.lang3.math.NumberUtils;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.HColumnDescriptor;
 import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
-import org.apache.hadoop.hbase.io.ImmutableBytesWritable;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.util.StringUtils;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.mapreduce.util.ConnectionUtil;
 import org.apache.phoenix.query.ConnectionQueryServices;
 import org.apache.phoenix.query.QueryConstants;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Sets;
 import org.apache.phoenix.util.MetaDataUtil;
 import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.SchemaUtil;
@@ -255,10 +253,10 @@ public class SchemaExtractionProcessor {
     }
 
     private void setHTableProperties(HTableDescriptor htd) {
-        Map<ImmutableBytesWritable, ImmutableBytesWritable> propsMap = htd.getValues();
-        for (Map.Entry<ImmutableBytesWritable, ImmutableBytesWritable> entry : propsMap.entrySet()) {
-            ImmutableBytesWritable key = entry.getKey();
-            ImmutableBytesWritable value = entry.getValue();
+        Map<Bytes, Bytes> propsMap = htd.getValues();
+        for (Map.Entry<Bytes, Bytes> entry : propsMap.entrySet()) {
+            Bytes key = entry.getKey();
+            Bytes value = entry.getValue();
             if(Bytes.toString(key.get()).contains("coprocessor") || Bytes.toString(key.get()).contains(
                     HTableDescriptor.IS_META)) {
                 continue;
@@ -269,15 +267,15 @@ public class SchemaExtractionProcessor {
     }
 
     private void setHColumnFamilyProperties(HColumnDescriptor[] columnDescriptors) {
-        Map<ImmutableBytesWritable, ImmutableBytesWritable> propsMap = columnDescriptors[0].getValues();
-        for(Map.Entry<ImmutableBytesWritable, ImmutableBytesWritable> entry : propsMap.entrySet()) {
-            ImmutableBytesWritable key = entry.getKey();
-            ImmutableBytesWritable globalValue = entry.getValue();
+        Map<Bytes, Bytes> propsMap = columnDescriptors[0].getValues();
+        for(Map.Entry<Bytes, Bytes> entry : propsMap.entrySet()) {
+            Bytes key = entry.getKey();
+            Bytes globalValue = entry.getValue();
             Map<String, String> cfToPropertyValueMap = new HashMap<String, String>();
-            Set<ImmutableBytesWritable> cfPropertyValueSet = new HashSet<ImmutableBytesWritable>();
+            Set<Bytes> cfPropertyValueSet = new HashSet<>();
             for(HColumnDescriptor columnDescriptor: columnDescriptors) {
                 String columnFamilyName = Bytes.toString(columnDescriptor.getName());
-                ImmutableBytesWritable value = columnDescriptor.getValues().get(key);
+                Bytes value = columnDescriptor.getValues().get(key);
                 // check if it is universal properties
                 if (SYNCED_DATA_TABLE_AND_INDEX_COL_FAM_PROPERTIES.contains(Bytes.toString(key.get()))) {
                     definedProps.put(Bytes.toString(key.get()), Bytes.toString(value.get()));
@@ -336,7 +334,7 @@ public class SchemaExtractionProcessor {
                         key : String.format("\"%s\".%s", columnFamilyName, key);
                 // properties value that corresponds to a number will not need single quotes around it
                 // properties value that corresponds to a boolean value will not need single quotes around it
-                if(!(StringUtils.isNumeric(value)) &&
+                if(!(NumberUtils.isNumber(value)) &&
                         !(value.equalsIgnoreCase(Boolean.TRUE.toString()) ||value.equalsIgnoreCase(Boolean.FALSE.toString()))) {
                     value= "'" + value + "'";
                 }
@@ -384,7 +382,7 @@ public class SchemaExtractionProcessor {
         }
         if (colDefs.size() > 0) {
             colInfo.append('(');
-            colInfo.append(StringUtils.join(colDefs, ", "));
+            colInfo.append(StringUtils.join( ", " ,colDefs));
         }
         if (pkColumns.size() > 1) {
             // multi column primary key
@@ -497,7 +495,7 @@ public class SchemaExtractionProcessor {
         for (PColumn pkCol : pkColumns) {
             colDefs.add(pkCol.getName().getString() + extractPKColumnAttributes(pkCol));
         }
-        return StringUtils.join(colDefs, ", ");
+        return StringUtils.join(", ", colDefs);
     }
 
 }
